@@ -5,16 +5,10 @@
 ;; Last: Sun Jun 15 03:50:21 CEST 2003
 ;; changed slightly 14-Jun-06 Bill to match bess.scm, fix pitch problem in make-oscil.
 ;;   then again 18-Dec-09 to use s7 rather than Guile
+;; changed float-vector-map! to use a loop instead (Bill 4-July-12)
 
 (if (not (provided? 'snd-motif)) (error "bess1.scm needs motif"))
 
-(if (not (provided? 'xm))
-    (let ((hxm (dlopen "xm.so")))
-      (if (string? hxm)
-	  (error "bess1.scm needs the xm module (either 'make xm' or build Snd with --with-static-xm): ~A" hxm)
-	  (dlinit hxm "Init_libxm"))))
-
-
 ;;; Commentary:
 
 ;; This file provides simple mono real time output to DAC.  Tempo,
@@ -27,12 +21,15 @@
 ;;
 ;; (rt-motif :srate       *clm-srate*        ;; 22050
 ;;           :bufsize     *clm-rt-bufsize*   ;; 128
-;;           :data-format *clm-data-format*) ;; mus-lshort
+;;           :sample-type *clm-sample-type*) ;; mus-lshort
 
 ;;; Code:
 
-(define *clm-srate* 22050)
-(define *clm-data-format* mus-lfloat)
+(with-let *motif*
+
+(set! *clm-srate* 22050)
+
+(define *clm-sample-type* mus-lfloat)
 (define *clm-rt-bufsize* 1024)
 (define *output* #f)			;holds fd from (mus-audio-open-output)
 
@@ -45,53 +42,54 @@
 (define sliderback "lightsteelblue")
 (define background "lightsteelblue1")
 
-;(define (seconds->samples secs) (round (* secs (mus-srate))))
+;(define (seconds->samples secs) (round (* secs *clm-srate*)))
 
 ;; called by XtAppAddWorkProc
 (define (rt-send->dac func)
   (if cplay
-      (begin
-	(mus-audio-write *output* (vct->sound-data (vct-map! (make-vct *clm-rt-bufsize*) (func))
-						   (make-sound-data 1 *clm-rt-bufsize*) 0)
-			 *clm-rt-bufsize*)
+      (let ((data (make-float-vector *clm-rt-bufsize*)))
+	(do ((i 0 (+ i 1)))
+	    ((= i *clm-rt-bufsize*))
+	  (set! (data i) (func)))
+	(mus-audio-write *output* (copy data (make-float-vector (list 1 *clm-rt-bufsize*) 0.0)) *clm-rt-bufsize*)
 	#f)
       (begin
 	(mus-audio-close *output*)
 	#t)))
 
-(define* (make-rt-violin dur freq amp :key
-			       (fm-index 1.0)
-			       (amp-env '(0 0 25 1 75 1 100 0)))
-  "(make-rt-violin dur freq amp (fm-index 1.0) (amp-env '(0 0 25 1 75 1
-100 0))) real time simple violin (see snd-11/fm.html)"
-  (let* ((frq-scl (hz->radians freq))
-         (maxdev (* frq-scl fm-index))
-         (index1 (* maxdev (/ 5.0 (log freq))))
-         (index2 (* maxdev 3.0 (/ (- 8.5 (log freq)) (+ 3.0 (/ freq 1000)))))
-         (index3 (* maxdev (/ 4.0 (sqrt freq))))
-         (carrier (make-oscil :frequency freq))
-         (fmosc1 (make-oscil :frequency freq))
-         (fmosc2 (make-oscil :frequency (* 3 freq)))
-         (fmosc3 (make-oscil :frequency (* 4 freq)))
-         (ampf  (make-env :envelope amp-env :scaler amp :duration dur))
-         (indf1 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index1 :duration dur))
-         (indf2 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index2 :duration dur))
-         (indf3 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index3 :duration dur))
-         (pervib (make-triangle-wave :frequency 5 :amplitude (* 0.0025 frq-scl)))
-         (ranvib (make-rand-interp :frequency 16 :amplitude (* 0.005 frq-scl))))
-    (lambda ()
-      (let ((vib (+ (triangle-wave pervib) (rand-interp ranvib))))
-	(* (env ampf)
-	   (oscil carrier
-		  (+ vib 
-		     (* (env indf1) (oscil fmosc1 vib))
-		     (* (env indf2) (oscil fmosc2 (* 3.0 vib)))
-		     (* (env indf3) (oscil fmosc3 (* 4.0 vib))))))))))
+(define make-rt-violin 
+  (let ((documentation "(make-rt-violin dur freq amp (fm-index 1.0) (amp-env '(0 0 25 1 75 1 100 0))) real time simple violin (see fm.html)"))
+    (lambda* (dur freq amp (fm-index 1.0) (amp-env '(0 0 25 1 75 1 100 0)))
+      (let* ((frq-scl (hz->radians freq))
+	     (maxdev (* frq-scl fm-index))
+	     (index1 (* maxdev (/ 5.0 (log freq))))
+	     (index2 (* maxdev 3.0 (/ (- 8.5 (log freq)) (+ 3.0 (/ freq 1000)))))
+	     (index3 (* maxdev (/ 4.0 (sqrt freq))))
+	     (carrier (make-oscil :frequency freq))
+	     (fmosc1 (make-oscil :frequency freq))
+	     (fmosc2 (make-oscil :frequency (* 3 freq)))
+	     (fmosc3 (make-oscil :frequency (* 4 freq)))
+	     (ampf  (make-env :envelope amp-env :scaler amp :duration dur))
+	     (indf1 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index1 :duration dur))
+	     (indf2 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index2 :duration dur))
+	     (indf3 (make-env :envelope '(0 1 25 0.4 75 0.6 100 0) :scaler index3 :duration dur))
+	     (pervib (make-triangle-wave :frequency 5 :amplitude (* 0.0025 frq-scl)))
+	     (ranvib (make-rand-interp :frequency 16 :amplitude (* 0.005 frq-scl))))
+	(lambda ()
+	  (let ((vib (+ (triangle-wave pervib) (rand-interp ranvib))))
+	    (* (env ampf)
+	       (oscil carrier
+		      (+ vib 
+			 (* (env indf1) (oscil fmosc1 vib))
+			 (* (env indf2) (oscil fmosc2 (* 3.0 vib)))
+			 (* (env indf3) (oscil fmosc3 (* 4.0 vib))))))))))))
+
+(define lim 256)
 
 ;; from clm-2/rt.lisp
-(define* (make-vct-test (srate *clm-srate*)
+(define* (make-float-vector-test (srate *clm-srate*)
 			(bufsize *clm-rt-bufsize*)
-			(data-format *clm-data-format*))
+			(sample-type *clm-sample-type*))
   (let ((vmode (vector 0 12 2 4 14 4 5 5 0 7 7 11 11))
 	(vpits (make-vector (+ 1 lim) 0))
 	(vbegs (make-vector (+ 1 lim) 0))
@@ -107,14 +105,13 @@
       (set! (vbegs i) (+ 1 (floor (random 3.0)))))
     (set! *clm-srate* srate)
     (set! *clm-rt-bufsize* bufsize)
-    (set! (mus-srate) srate)
-    (set! *output* (mus-audio-open-output mus-audio-default srate 1 data-format (* bufsize 2)))
+    (set! *output* (mus-audio-open-output mus-audio-default srate 1 sample-type (* bufsize 2)))
     (lambda ()
       (if (> len 1)
 	  (set! len (- len 1))
 	  (begin
-	    (set! dur (* ctempo (vbegs (+ 1 cellctr))))
-	    (set! cellctr (+ 1 cellctr))
+	    (set! dur (* ctempo (vbegs (+ cellctr 1))))
+	    (set! cellctr (+ cellctr 1))
 	    (if (> cellctr (+ cellsiz cellbeg))
 		(begin
 		  (if (> (random 1.0) 0.5) (set! cellbeg (+ 1 cellbeg)))
@@ -143,7 +140,6 @@
       func)))
 
 ;; from clm-2/bess5.cl and clm-2/clm-example.lisp
-(define lim 256)
 (define time 60)
 (define mode (vector 0 0 2 4 11 11 5 6 7 9 2 0 0))
 (define rats (vector 1.0 256/243 9/8 32/27 81/64 4/3 1024/729 3/2 128/81 27/16 16/9 243/128 2.0))
@@ -167,7 +163,7 @@
 
 (define* (make-agn (srate *clm-srate*)
 		   (bufsize *clm-rt-bufsize*)
-		   (data-format *clm-data-format*))
+		   (sample-type *clm-sample-type*))
   (let ((wins (vector '(0 0 40 0.1 60 0.2 75 0.4 82 1 90 1 100 0)
 		      '(0 0 60 0.1 80 0.2 90 0.4 95 1 100 0)
 		      '(0 0 10 1 16 0 32 0.1 50 1 56 0 60 0 90 0.3 100 0)
@@ -190,7 +186,7 @@
 	(whichway 1)
 	(func #f)
 	(len 0))
-    (do ((i 0 (+ 1 i)))
+    (do ((i 0 (+ i 1)))
 	((= i lim))
       (set! (octs i) (floor (+ 4 (* 2 (rbell (random 1.0))))))
       (set! (pits i) (mode (floor (random 12.0))))
@@ -198,11 +194,10 @@
       (set! (begs i) (if (< (random 1.0) 0.9) 
 		      (floor (+ 4 (random 2.0)))
 		      (floor (random 24.0))))
-      (set! (amps i) (floor (+ 1 (* 8 (rbell (random 1.0)))))) i)
+      (set! (amps i) (floor (+ 1 (* 8 (rbell (random 1.0)))))))
     (set! *clm-srate* srate)
     (set! *clm-rt-bufsize* bufsize)
-    (set! (mus-srate) srate)
-    (set! *output* (mus-audio-open-output mus-audio-default srate 1 data-format (* bufsize 2)))
+    (set! *output* (mus-audio-open-output mus-audio-default srate 1 sample-type (* bufsize 2)))
     (lambda ()
       (if (> len 1)
 	  (set! len (- len 1))
@@ -213,7 +208,7 @@
 	    (set! freq (* cfreq 16.351 (tune (pits cellctr)) (expt 2 (octs cellctr))))
 	    (set! ampl (* camp 10 (max 0.003 (* (amps cellctr) 0.01))))
 	    (set! ind (* cindex (random 3.0)))
-	    (set! cellctr (+ 1 cellctr))
+	    (set! cellctr (+ cellctr 1))
 	    (if (> cellctr (+ cellsiz cellbeg))
 		(begin
 		  (set! cellbeg (+ 1 cellbeg))
@@ -232,6 +227,7 @@
 	    (set! len (ceiling (/ (seconds->samples dur) bufsize)))))
       func)))
 
+#|
 ;; from env.scm
 (define* (envelope-interp :rest args)
   (let ((x (car args))
@@ -257,18 +253,18 @@
 					  (- (caddr env) (car env))))
 			    1.0))))))
 	  (else (envelope-interp x (cddr env))))))
+|#
 
 (define* (rt-motif :rest args)
   (let* ((shell-app (XtVaOpenApplication 
-		     "FM" 0 '() applicationShellWidgetClass
+		     "FM" 0 () applicationShellWidgetClass
 		     (list XmNallowShellResize #t)))
 	 (app (cadr shell-app))
 	 (shell (car shell-app))
 	 (dpy (XtDisplay shell))
 	 (screen (DefaultScreenOfDisplay dpy))
 	 (cmap (DefaultColormap dpy (DefaultScreen dpy)))
-	 (black (BlackPixelOfScreen screen))
-	 (white (WhitePixelOfScreen screen)))
+	 (black (BlackPixelOfScreen screen)))
 
     (define (get-color color)
       (let ((col (XColor)))
@@ -528,8 +524,8 @@
 			   (begin
 			     (set-defaults)
 			     (if (= which-play 0)
-				 (set! func (apply make-agn (or args '())))
-				 (set! func (apply make-vct-test (or args '()))))
+				 (set! func (apply make-agn (or args ())))
+				 (set! func (apply make-float-vector-test (or args ()))))
 			     (set! proc (XtAppAddWorkProc app (lambda (c) (rt-send->dac func)))))
 			   (if proc (XtRemoveWorkProc proc)))))
       (XmToggleButtonSetState play-button cplay #f)
@@ -538,5 +534,5 @@
     (XtAppMainLoop app)))
 
 (rt-motif)
-
+)
 ;; bess1.scm ends here
