@@ -9,15 +9,15 @@
 
 ;;; -------- strings (0-terminated)
 
-(define (read-string)
-  (let ((chars '()))
+(define (io-read-string)
+  (let ((chars ()))
     (do ((c (read-byte) (read-byte)))
-	((or (= c 0)
-	     (eof-object? c))
+	((or (eof-object? c)
+	     (= c 0))
 	 (apply string (reverse chars)))
       (set! chars (cons (integer->char c) chars)))))
 
-(define (write-string str)
+(define (io-write-string str)
   (for-each write-char str) ; or maybe (lambda (c) (write-byte (char->integer c)))
   (write-byte 0))
 
@@ -28,7 +28,7 @@
   (let ((str (make-string len)))
     (do ((i 0 (+ i 1)))
 	((= i len) str)
-      (string-set! str i (read-char)))))
+      (set! (str i) (read-char)))))
 	 
 (define (write-chars str)
   (for-each write-char str))
@@ -37,7 +37,7 @@
 ;;; -------- 16-bit ints
 
 (define (read-bint16)
-  (let ((int (+ (ash (read-byte) 8) (read-byte))))
+  (let ((int (+ (ash (read-byte) 8) (read-byte)))) ; this depends on arg evaluation left->right
     (if (> int 32767)
 	(- int 65536)
 	int)))
@@ -130,8 +130,7 @@
 	 (signif (car data))
 	 (expon (cadr data))
 	 (sign (caddr data)))
-    (if (and (= expon 0)
-	     (= signif 0))
+    (if (= expon signif 0)
 	0
 	;; we're assuming floats are (64-bit) doubles in s7, so this is coercing to a 32-bit float in a sense
 	;;   this causes some round-off error
@@ -168,8 +167,7 @@
 	 (signif (car data))
 	 (expon (cadr data))
 	 (sign (caddr data)))
-    (if (and (= expon 0)
-	     (= signif 0))
+    (if (= expon signif 0)
 	0
 	(logior (if (negative? sign) #x8000000000000000 0)
 		(ash (+ expon 52 1023) 52)
@@ -186,11 +184,11 @@
 ;;; -------- 80-bit floats (IEEE 754, sign + 63(+1) bits significand + 15 bits exponent, needed for aifc headers)
 
 (define (read-bfloat80->int)
-  (let* ((exp 0)
-	 (mant1 0)
-	 (mant0 0)
-	 (sign 0)
-	 (buf (make-vector 10)))
+  (let ((exp 0)
+	(mant1 0)
+	(mant0 0)
+	(sign 0)
+	(buf (make-vector 10)))
     (do ((i 0 (+ i 1)))
 	((= i 10))
       (set! (buf i) (read-byte)))
@@ -214,7 +212,7 @@
     (if (negative? val) 
 	(begin
 	  (set! sign 1) 
-	  (set! val (abs val))))
+	  (set! val (- val))))
     (if (not (zero? val))
 	(begin
 	  (set! exp (round (+ (log val 2.0) 16383.0)))
@@ -243,16 +241,16 @@
       (let ((magic (read-chars 4)))
 	(if (not (string=? magic ".snd"))
 	    (error 'bad-header "~A is not an au file: ~A" file)
-	    (let* ((data-location (read-bint32))
-		   (data-size (read-bint32))
-		   (data-format (read-bint32))
-		   (srate (read-bint32))
-		   (chans (read-bint32))
-		   (comment (read-string)))
-	      (list magic data-location data-size data-format srate chans comment)))))))
+	    (let ((data-location (read-bint32))
+		  (data-size (read-bint32))
+		  (sample-type (read-bint32))
+		  (srate (read-bint32))
+		  (chns (read-bint32))
+		  (comment (io-read-string)))
+	      (list magic data-location data-size sample-type srate chns comment)))))))
 
-(define (write-au-header file chans srate data-size data-format comment) ; data-size in bytes
-  ;; common data-formats: 1 mulaw, 2 linear_8, 3 linear_16, 4 linear_24, 5 linear_32, 6 float, 5 double, 27 alaw
+(define (write-au-header file chns srate data-size sample-type comment) ; data-size in bytes
+  ;; common sample-types: 1 mulaw, 2 linear_8, 3 linear_16, 4 linear_24, 5 linear_32, 6 float, 5 double, 27 alaw
   (with-output-to-file file
     (lambda ()
       (let* ((comlen (length comment))
@@ -261,34 +259,32 @@
 	(write-chars ".snd")
 	(write-bint32 data-location)
 	(write-bint32 data-size)
-	(write-bint32 data-format)
+	(write-bint32 sample-type)
 	(write-bint32 srate)
-	(write-bint32 chans)
+	(write-bint32 chns)
 	(if (> comlen 0)
 	    (begin
-	      (write-string comment)
-	      (set! curloc (+ curloc comlen 1)))) ; write-string adds a trailing 0
+	      (io-write-string comment)
+	      (set! curloc (+ curloc comlen 1)))) ; io-write-string adds a trailing 0
 	(do ((i curloc (+ i 1)))
 	    ((>= i data-location))
 	  (write-byte 0))))))
 
 
-;;; TODO: read/write wav, write aifc
-
 (define (read-aif-header file)
   (let ((data-location 0)
 	(data-size 0)
-	(data-format 0)
+	(sample-type 0)
 	(srate 0)
-	(chans 0)
+	(chns 0)
 	(current-location 0))
     (with-input-from-file file
       (lambda ()
 	(let ((magic (read-chars 4)))
 	  (if (not (string=? magic "FORM"))
 	      (error 'bad-header "~A is not an aif file: ~A" file magic)
-	      (let* ((size (read-bint32))
-		     (magic (read-chars 4)))
+	      (let (;(size (read-bint32))
+		    (magic (read-chars 4)))
 		(set! current-location 12)
 		(if (and (not (string=? magic "AIFF"))
 			 (not (string=? magic "AIFC")))
@@ -297,23 +293,23 @@
 		    (call-with-exit
 		     (lambda (return)
 		       (let loop ()
-			 (let* ((chunk (read-chars 4))
-				(chunk-size (read-bint32)))
+			 (let ((chunk (read-chars 4))
+			       (chunk-size (read-bint32)))
 			   (if (odd? chunk-size) (set! chunk-size (+ chunk-size 1)))
 			   (if (string=? chunk "SSND")
 			       (begin
 				 (set! data-location (+ 16 current-location (read-bint32)))
 				 (if (> srate 0)
-				     (return (list magic data-location data-size data-format srate chans))))
+				     (return (list magic data-location data-size sample-type srate chns))))
 			       (if (string=? chunk "COMM")
-				   (let ((frames 0))
-				     (set! chans (read-bint16))
-				     (set! frames (read-bint32))
-				     (set! data-format (read-bint16))
+				   (let ((len 0))
+				     (set! chns (read-bint16))
+				     (set! len (read-bint32))
+				     (set! sample-type (read-bint16))
 				     (set! srate (read-bfloat80->int))
-				     (set! data-size (* frames chans data-format 1/8))
+				     (set! data-size (* len chns sample-type 1/8))
 				     (if (> data-location 0)
-					 (return (list magic data-location data-size data-format srate chans))))
+					 (return (list magic data-location data-size sample-type srate chns))))
 				   (do ((i 0 (+ i 1))) ; here we really need built-in file IO stuff!
 				       ((= i chunk-size))
 				     (if (eof-object? (read-byte))
