@@ -1,21 +1,29 @@
-(if (provided? 'xm)
-    (if (not (provided? 'snd-effects-utils.scm))
-	(load "effects-utils.scm"))) ; make-effect-dialog
+(when (and (provided? 'xm)
+	   (not (provided? 'snd-effects-utils.scm)))
+  (load "effects-utils.scm"))
 
-(if (provided? 'xg)
-    (if (not (provided? 'snd-gtk-effects-utils.scm))
-	(load "gtk-effects-utils.scm")))
+(if (and (provided? 'xg)
+	 (not (provided? 'snd-gtk-effects-utils.scm)))
+    (load "gtk-effects-utils.scm"))
 
-(if (not (provided? 'snd-examp.scm)) (load "examp.scm")) ; squelch-vowels
+(define *e* (if (provided? 'snd-motif) *motif* *gtk*))
+(define update-label (*e* 'update-label))
+(define change-label (*e* 'change-label))
+(define make-effect-dialog (*e* 'make-effect-dialog))
+(define add-sliders (*e* 'add-sliders))
+(define activate-dialog (*e* 'activate-dialog))
+(define select-file (*e* 'select-file))
+
+(require snd-examp.scm)
 
 (provide 'snd-fft-menu.scm)
 
 
-(define fft-list '()) ; menu labels are updated to show current default settings
+(define fft-list ()) ; menu labels are updated to show current default settings
 
 (define fft-menu (add-to-main-menu "FFT Edits" (lambda ()
 						 (define (update-label fft)
-						   (if (not (null? fft))
+						   (if (pair? fft)
 						       (begin
 							 ((car fft))
 							 (update-label (cdr fft)))))
@@ -42,7 +50,7 @@
             ;; if fft-edit-dialog doesn't exist, create it
             (let ((initial-fft-edit-low-frequency 100)
                   (initial-fft-edit-high-frequency 1000)
-                  (sliders '()))
+                  (sliders ()))
 
               (set! fft-edit-dialog
                     (make-effect-dialog 
@@ -66,16 +74,14 @@ removes all energy below the low frequency and above the high frequency, then co
 			 (lambda (w data)
 			   (set! fft-edit-low-frequency initial-fft-edit-low-frequency)
 			   (set! fft-edit-high-frequency initial-fft-edit-high-frequency)
-			   (gtk_adjustment_set_value (GTK_ADJUSTMENT (car sliders))  (floor fft-edit-low-frequency))
-			   ;;; (gtk_adjustment_value_changed (GTK_ADJUSTMENT (car sliders)))
-			   (gtk_adjustment_set_value (GTK_ADJUSTMENT (cadr sliders))  (floor fft-edit-high-frequency))
-			   ;;; (gtk_adjustment_value_changed (GTK_ADJUSTMENT (cadr sliders)))
+			   ((*gtk* 'gtk_adjustment_set_value) ((*gtk* 'GTK_ADJUSTMENT) (car sliders))  (floor fft-edit-low-frequency))
+			   ((*gtk* 'gtk_adjustment_set_value) ((*gtk* 'GTK_ADJUSTMENT) (cadr sliders))  (floor fft-edit-high-frequency))
 			   )
 			 (lambda (w c i)
 			   (set! fft-edit-low-frequency initial-fft-edit-low-frequency)
 			   (set! fft-edit-high-frequency initial-fft-edit-high-frequency)
-			   (XtSetValues (car sliders) (list XmNvalue (floor fft-edit-low-frequency)))
-			   (XtSetValues (cadr sliders) (list XmNvalue (floor fft-edit-high-frequency)))))))
+			   ((*motif* 'XtSetValues) (car sliders) (list (*motif* 'XmNvalue) (floor fft-edit-low-frequency)))
+			   ((*motif* 'XtSetValues) (cadr sliders) (list (*motif* 'XmNvalue) (floor fft-edit-high-frequency)))))))
 	      
               (set! sliders
 		    (add-sliders 
@@ -83,18 +89,18 @@ removes all energy below the low frequency and above the high frequency, then co
 		     
 		     (list (list "low frequency" 20 initial-fft-edit-low-frequency 22050
 				 (if (provided? 'snd-gtk)
-				     (lambda (w data) (set! fft-edit-low-frequency (gtk_adjustment_get_value (GTK_ADJUSTMENT w))))
-				     (lambda (w context info) (set! fft-edit-low-frequency (.value info))))
+				     (lambda (w data) (set! fft-edit-low-frequency ((*gtk* 'gtk_adjustment_get_value) ((*gtk* 'GTK_ADJUSTMENT) w))))
+				     (lambda (w context info) (set! fft-edit-low-frequency ((*motif* '.value) info))))
 				 1)
 			   
 			   (list "high frequency" 20 initial-fft-edit-high-frequency 22050
 				 (if (provided? 'snd-gtk) 
-				     (lambda (w data) (set! fft-edit-high-frequency (gtk_adjustment_get_value (GTK_ADJUSTMENT w))))
-				     (lambda (w context info) (set! fft-edit-high-frequency (.value info))))
+				     (lambda (w data) (set! fft-edit-high-frequency ((*gtk* 'gtk_adjustment_get_value) ((*gtk* 'GTK_ADJUSTMENT) w))))
+				     (lambda (w context info) (set! fft-edit-high-frequency ((*motif* '.value) info))))
 				 1))))))
         (activate-dialog fft-edit-dialog))
       
-      (set! fft-edit-menu-label (add-to-menu fft-menu "FFT notch filter" (lambda () (post-fft-edit-dialog)))))
+      (set! fft-edit-menu-label (add-to-menu fft-menu "FFT notch filter" post-fft-edit-dialog)))
     
     (set! fft-edit-menu-label (add-to-menu fft-menu fft-edit-label cp-fft-edit)))
 
@@ -126,7 +132,7 @@ removes all energy below the low frequency and above the high frequency, then co
         (if (not fft-squelch-dialog)
             ;; if fft-squelch-dialog doesn't exist, create it
             (let ((initial-fft-squelch-amount 0.0)
-                  (sliders '()))
+                  (sliders ()))
 	      
               (set! fft-squelch-dialog
                     (make-effect-dialog 
@@ -147,12 +153,11 @@ removes all energy below the low frequency and above the high frequency, then co
 		     (if (provided? 'snd-gtk)
 			 (lambda (w data)
 			   (set! fft-squelch-amount initial-fft-squelch-amount)
-			   (gtk_adjustment_set_value (GTK_ADJUSTMENT (car sliders)) (round (* fft-squelch-amount 100)))
-			   ;;; (gtk_adjustment_value_changed (GTK_ADJUSTMENT (car sliders)))
+			   ((*gtk* 'gtk_adjustment_set_value) ((*gtk* 'GTK_ADJUSTMENT) (car sliders)) (round (* fft-squelch-amount 100)))
 			   )
 			 (lambda (w c i)
 			   (set! fft-squelch-amount initial-fft-squelch-amount)
-			   (XtSetValues (list-ref sliders 0) (list XmNvalue (round (* fft-squelch-amount 100))))))))
+			   ((*motif* 'XtSetValues) (list-ref sliders 0) (list (*motif* 'XmNvalue) (round (* fft-squelch-amount 100))))))))
 	      
               (set! sliders
                     (add-sliders 
@@ -160,14 +165,14 @@ removes all energy below the low frequency and above the high frequency, then co
 		     (list (list "squelch amount" 0.0 initial-fft-squelch-amount 1.0
 				 (if (provided? 'snd-gtk)
 				     (lambda (w data)
-				       (set! fft-squelch-amount (/ (gtk_adjustment_get_value (GTK_ADJUSTMENT w)) 100)))
+				       (set! fft-squelch-amount (/ ((*gtk* 'gtk_adjustment_get_value) ((*gtk* 'GTK_ADJUSTMENT) w)) 100)))
 				     (lambda (w context info)
-				       (set! fft-squelch-amount (/ (.value info) 100))))
+				       (set! fft-squelch-amount (/ ((*motif* '.value) info) 100))))
 				 100))))))
 	
         (activate-dialog fft-squelch-dialog))
       
-      (set! fft-squelch-menu-label (add-to-menu fft-menu "FFT squelch" (lambda () (post-fft-squelch-dialog)))))
+      (set! fft-squelch-menu-label (add-to-menu fft-menu "FFT squelch" post-fft-squelch-dialog)))
     
     (set! fft-squelch-menu-label (add-to-menu fft-menu fft-squelch-label cp-fft-squelch)))
 
@@ -179,4 +184,4 @@ removes all energy below the low frequency and above the high frequency, then co
 
 (add-to-menu fft-menu #f #f)
 
-(add-to-menu fft-menu "Squelch vowels" (lambda () (squelch-vowels)))
+(add-to-menu fft-menu "Squelch vowels" squelch-vowels)
