@@ -1,7 +1,7 @@
 ;;; from VOIDAT.SAI[220,JDC] and GLSVOI.SAI[220,JDC], then (30 years later) jcvoi.ins
 
 (provide 'snd-jcvoi.scm)
-(if (not (provided? 'snd-env.scm)) (load "env.scm"))
+(require snd-env.scm)
 
 (define fnc #f)  ;; fnc[sex,vowel,formant number,formant freq,amp or fm index]
 (define vibfreqfun #f)
@@ -9,15 +9,14 @@
 (define i3fun2 #f)
 
 (define (flipxy data)			; SEG functions expected data in (y x) pairs.
-  (let ((unseg '())
+  (let ((unseg ())
 	(len (length data)))
     (do ((i 0 (+ i 2)))
-	((>= i len))
-      (let ((x (list-ref data (+ 1 i)))
-	    (y (list-ref data i)))
-	(set! unseg (cons x unseg))
-	(set! unseg (cons y unseg))))
-    (reverse unseg)))
+	((>= i len)
+	 (reverse unseg))
+      (let ((x (data (+ 1 i)))
+	    (y (data i)))
+	(set! unseg (cons y (cons x unseg)))))))
 
 (define (addenv env1 sc1 off1 env2 sc2 off2)
   (add-envelopes (scale-envelope env1 sc1 off1)
@@ -40,10 +39,10 @@
 (define (fillfnc)
   (if (not fnc)
       (begin
-	(set! fnc (make-vector (* 3 6 4 4) '()))
-	(set! vibfreqfun (make-vector 3 '()))
-	(set! i3fun1 (make-vector 3 '()))
-	(set! i3fun2 (make-vector 3 '()))
+	(set! fnc (make-vector (* 3 6 4 4) ()))
+	(set! vibfreqfun (make-vector 3 ()))
+	(set! i3fun1 (make-vector 3 ()))
+	(set! i3fun2 (make-vector 3 ()))
 
 	(setf-aref fnc 1 1 1 1 (flipxy '(350  130.8 524  261.6 392  392 523 523.2 784 784 1046 1064 1568 1568)))
 	(setf-aref fnc 1 1 1 2 (flipxy '(.3   130.8   .8 261.6   .9 392  .9 523.2  .7 784   .86 1064 .86  1568)))
@@ -157,122 +156,122 @@
   (envelope-interp pitch ptr))
 
 (definstrument (fm-voice beg dur pitch amp vowel-1 sex-1 ampfun1 ampfun2 ampfun3 indxfun skewfun vibfun ranfun
-			 dis pcrev deg vibscl pcran skewscl ranpower glissfun glissamt)
+			 dis pcrev deg vibscl pcran skewscl glissfun glissamt)
   (fillfnc)
-  (let* ((c 261.62)
-	 (vowel (floor vowel-1))
-	 (sex (floor sex-1))
-	 (ampref (expt amp .8))
-	 (deg (- deg 45))
-	 (vibfreq (fncval (vibfreqfun sex) pitch))
-	 (vibpc (* .01 (/ (log pitch) (log 2)) (+ .15 (sqrt amp)) vibscl))
-	 (ranfreq 20)
-	 (ranpc (* .002 (/ (log pitch) (log 2)) (- 2 (expt amp .25)) pcran))
-	 (skewpc (if (= sex 1)
-		     (* (sqrt (+ .1 (* .05 ampref (- 1568 130.8)))) skewscl)
-		     (* (sqrt (+ .1 (* .05 ampref (- 130.8 16.5)))) skewscl)))
-	 (form1 (/ (fncval (aref fnc sex vowel 1 1) pitch) pitch))
-	 (form2 (/ (fncval (aref fnc sex vowel 2 1) pitch) pitch))
-	 (form3 (/ (fncval (aref fnc sex vowel 3 1) pitch) pitch))
-	 (fmntfreq1 (round form1))
-	 (fmntfreq2 (round form2))
-	 (fmntfreq3 (round form3))
-	 (fm2 3)
-	 (mscale 1)
-	 (mconst 0)
-	 (mfq (+ (* pitch mscale) mconst))
-	 (freqratios1 fm2)
-	 (freqratios2 mscale)
-	 (freqratios3 mscale)
-	 (freqratios4 mscale)
-	 (freqratios5 fmntfreq1)
-	 (freqratios6 fmntfreq2)
-	 (freqratios7 fmntfreq3)
-	 (amp1 (sqrt amp))
-	 (amp2 (expt amp 1.5))
-	 (amp3 (* amp amp))
-	 (formscl1 (abs (- form1 fmntfreq1)))
-	 (formscl2 (abs (- form2 fmntfreq2)))
-	 (formscl3 (abs (- form3 fmntfreq3)))
-	 (caramp1sc (* (fncval (aref fnc sex vowel 1 2) pitch) (- 1 formscl1) amp1))
-	 (caramp2sc (* (fncval (aref fnc sex vowel 2 2) pitch) (- 1 formscl2) amp2))
-	 (caramp3sc (* (fncval (aref fnc sex vowel 3 2) pitch) (- 1 formscl3) amp3))
-	 (scdev1 (fncval (aref fnc sex vowel 1 3) pitch))
-	 (scdev2 (fncval (aref fnc sex vowel 2 3) pitch))
-	 (scdev3 (fncval (aref fnc sex vowel 3 3) pitch))
-	 (indx0 (if (or (= vowel 3) (= vowel 4)) 0 1.5))
-	 (indx1 1)
-	 (i3 (if (< pitch (/ c 2)) 
-		 (fncval (i3fun1 sex) pitch) 
-		 (fncval (i3fun2 sex) pitch)))
-	 (dev (hz->radians (* i3 mfq)))
-	 (dev0 (hz->radians (* indx0 mfq)))
-	 (dev1 (hz->radians (* (- indx1 indx0) mfq))))
-    (let* ((gens1 (make-oscil 0))
-	   (gens2 (make-oscil 0 (/ pi 2.0)))
-	   (gens2ampenv (make-env indxfun  :duration dur
-				  :scaler (* scdev1 dev1)
-				  :offset (* scdev1 dev0)))
-	   (gens3 (make-oscil 0 (/ pi 2.0)))
-	   (gens3ampenv (make-env indxfun  :duration dur
-				  :scaler (* scdev2 dev1)
-				  :offset (* scdev2 dev0)))
-	   (gens4 (make-oscil 0 (/ pi 2.0)))
-	   (gens4ampenv (make-env indxfun  :duration dur
-				  :scaler (* scdev3 dev1)
-				  :offset (* scdev3 dev0)))
-	   (gens5 (make-oscil 0))
-	   (gens5ampenv (make-env ampfun1 :duration dur
-				  :scaler (* amp caramp1sc .75)))
-	   (gens6 (make-oscil 0))
-	   (gens6ampenv (make-env ampfun2 :duration dur
-				  :scaler (* amp caramp2sc .75)))
-	   (gens7 (make-oscil 0))
-	   (gens7ampenv (make-env ampfun3 :duration dur
-				  :scaler (* amp caramp3sc .75)))
-	   (freqenv (make-env (addenv glissfun (* glissamt pitch) 0 skewfun (* skewpc pitch) pitch) :duration dur
-			      :scaler (hz->radians 1.0)))
-	   (pervenv (make-env vibfun :duration dur
-			      :scaler vibpc))
-	   (ranvenv (make-env :envelope ranfun :duration dur
-			      :scaler ranpc))
-	   (per-vib (make-triangle-wave :frequency vibfreq
-					:amplitude (hz->radians pitch)))
-	   (ran-vib (make-rand-interp :frequency ranfreq
-				:amplitude (hz->radians pitch)))
-	   (loc (make-locsig :degree deg :distance dis :reverb pcrev))
-	   (vib 0.0)
-	   (cascadeout 0.0)
-	   (start (floor (* (mus-srate) beg)))
-	   (end (+ start (floor (* (mus-srate) dur)))))
-      (run
-       (do ((i start (+ i 1)))
-	   ((> i end))
-	 (set! vib (+ (env freqenv) 
-		      (* (env pervenv) 
-			 (triangle-wave per-vib)) 
-		      (* (env ranvenv) 
-			 (rand-interp ran-vib))))
-	 (set! cascadeout (* dev (oscil gens1 (* vib freqratios1))))
-	 (locsig loc i (+ (* (env gens5ampenv) 
-			     (oscil gens5 (+ (* vib freqratios5) 
-					     (* (env gens2ampenv) 
-						(oscil gens2 (+ cascadeout (* vib freqratios2)))))))
-			  (* (env gens6ampenv) 
-			     (oscil gens6 (+ (* vib freqratios6)
-					     (* (env gens3ampenv) 
-						(oscil gens3 (+ cascadeout (* vib freqratios3)))))))
-			  (* (env gens7ampenv) 
-			     (oscil gens7 (+ (* vib freqratios7)
-					     (* (env gens4ampenv) 
-						(oscil gens4 (+ cascadeout (* vib freqratios4))))))))))))))
-
+  (let ((c 261.62)
+	(vowel (floor vowel-1))
+	(sex (floor sex-1))
+	(ampref (expt amp .8))
+	(deg (- deg 45))
+	(ranfreq 20)
+	(fm2 3)
+	(mscale 1)
+	(mconst 0)
+	(indx1 1))
+    (let ((vibfreq (fncval (vibfreqfun sex) pitch))
+	  (vibpc (* .01 (log pitch 2) (+ .15 (sqrt amp)) vibscl))
+	  (ranpc (* .002 (log pitch 2) (- 2 (expt amp .25)) pcran))
+	  (skewpc (if (= sex 1)
+		      (* (sqrt (+ .1 (* .05 ampref (- 1568 130.8)))) skewscl)
+		      (* (sqrt (+ .1 (* .05 ampref (- 130.8 16.5)))) skewscl)))
+	  (form1 (/ (fncval (aref fnc sex vowel 1 1) pitch) pitch))
+	  (form2 (/ (fncval (aref fnc sex vowel 2 1) pitch) pitch))
+	  (form3 (/ (fncval (aref fnc sex vowel 3 1) pitch) pitch)))
+      (let ((fmntfreq1 (round form1))
+	    (fmntfreq2 (round form2))
+	    (fmntfreq3 (round form3))
+	    (mfq (+ (* pitch mscale) mconst))
+	    (freqratios1 fm2)
+	    (freqratios2 mscale)
+	    (freqratios3 mscale)
+	    (freqratios4 mscale))
+	(let ((freqratios5 fmntfreq1)
+	      (freqratios6 fmntfreq2)
+	      (freqratios7 fmntfreq3)
+	      (amp1 (sqrt amp))
+	      (amp2 (expt amp 1.5))
+	      (amp3 (* amp amp))
+	      (formscl1 (abs (- form1 fmntfreq1)))
+	      (formscl2 (abs (- form2 fmntfreq2)))
+	      (formscl3 (abs (- form3 fmntfreq3)))
+	      (i3 (if (< pitch (/ c 2)) 
+		      (fncval (i3fun1 sex) pitch) 
+		      (fncval (i3fun2 sex) pitch)))
+	      (indx0 (if (or (= vowel 3) (= vowel 4)) 0 1.5)))
+	  (let ((caramp1sc (* (fncval (aref fnc sex vowel 1 2) pitch) (- 1 formscl1) amp1))
+		(caramp2sc (* (fncval (aref fnc sex vowel 2 2) pitch) (- 1 formscl2) amp2))
+		(caramp3sc (* (fncval (aref fnc sex vowel 3 2) pitch) (- 1 formscl3) amp3))
+		(scdev1 (fncval (aref fnc sex vowel 1 3) pitch))
+		(scdev2 (fncval (aref fnc sex vowel 2 3) pitch))
+		(scdev3 (fncval (aref fnc sex vowel 3 3) pitch))
+		(dev (hz->radians (* i3 mfq)))
+		(dev0 (hz->radians (* indx0 mfq)))
+		(dev1 (hz->radians (* (- indx1 indx0) mfq))))
+	    (let ((gens1 (make-oscil 0))
+		  (gens2 (make-oscil 0 (/ pi 2.0)))
+		  (gens2ampenv (make-env indxfun  :duration dur
+					 :scaler (* scdev1 dev1)
+					 :offset (* scdev1 dev0)))
+		  (gens3 (make-oscil 0 (/ pi 2.0)))
+		  (gens3ampenv (make-env indxfun  :duration dur
+					 :scaler (* scdev2 dev1)
+					 :offset (* scdev2 dev0)))
+		  (gens4 (make-oscil 0 (/ pi 2.0)))
+		  (gens4ampenv (make-env indxfun  :duration dur
+					 :scaler (* scdev3 dev1)
+					 :offset (* scdev3 dev0)))
+		  (gens5 (make-oscil 0))
+		  (gens5ampenv (make-env ampfun1 :duration dur
+					 :scaler (* amp caramp1sc .75)))
+		  (gens6 (make-oscil 0))
+		  (gens6ampenv (make-env ampfun2 :duration dur
+					 :scaler (* amp caramp2sc .75)))
+		  (gens7 (make-oscil 0))
+		  (gens7ampenv (make-env ampfun3 :duration dur
+					 :scaler (* amp caramp3sc .75)))
+		  (freqenv (make-env (addenv glissfun (* glissamt pitch) 0 skewfun (* skewpc pitch) pitch) :duration dur
+				     :scaler (hz->radians 1.0)))
+		  (pervenv (make-env vibfun :duration dur
+				     :scaler vibpc))
+		  (ranvenv (make-env :envelope ranfun :duration dur
+				     :scaler ranpc))
+		  (per-vib (make-triangle-wave :frequency vibfreq
+					       :amplitude (hz->radians pitch)))
+		  (ran-vib (make-rand-interp :frequency ranfreq
+					     :amplitude (hz->radians pitch)))
+		  (loc (make-locsig :degree deg :distance dis :reverb pcrev))
+		  (start (floor (* *clm-srate* beg)))
+		  (end (floor (* *clm-srate* (+ beg dur)))))
+	      (do ((i start (+ i 1)))
+		  ((= i end))
+		(let* ((vib (+ (env freqenv) 
+			       (* (env pervenv) 
+				  (triangle-wave per-vib)) 
+			       (* (env ranvenv) 
+				  (rand-interp ran-vib))))
+		       (cascadeout (* dev (oscil gens1 (* vib freqratios1)))))
+		  (locsig loc i (+ (* (env gens5ampenv) 
+				      (oscil gens5 (+ (* vib freqratios5) 
+						      (* (env gens2ampenv) 
+							 (oscil gens2 (+ cascadeout (* vib freqratios2)))))))
+				   (* (env gens6ampenv) 
+				      (oscil gens6 (+ (* vib freqratios6)
+						      (* (env gens3ampenv) 
+							 (oscil gens3 (+ cascadeout (* vib freqratios3)))))))
+				   (* (env gens7ampenv) 
+				      (oscil gens7 (+ (* vib freqratios7)
+						      (* (env gens4ampenv) 
+							 (oscil gens4 (+ cascadeout (* vib freqratios4))))))))))))))
+	))))
 #|
 (let ((ampf '(0 0 1 1 2 1 3 0))) 
-  (with-sound (:play #t) (fm-voice 0 1 300 .8 3 1 ampf ampf ampf ampf ampf ampf ampf 1 0 0 .25 1 .01 0 ampf .01)))
+  (with-sound (:play #t) (fm-voice 0 1 300 .8 3 1 ampf ampf ampf ampf ampf ampf ampf 1 0 0 .25 .01 0 ampf .01)))
 
-(defmacro voi (beg dur pitch amp vowel-1 sex-1 ampfun1 ampfun2 ampfun3 indxfun skewfun vibfun ranfun
-		   dis pcrev deg vibscl skewscl ranpower)
+(definstrument (fm-voice beg dur pitch amp vowel-1 sex-1 ampfun1 ampfun2 ampfun3 indxfun skewfun vibfun ranfun
+			 dis pcrev deg vibscl pcran skewscl glissfun glissamt)
+
+(define-macro (voi beg dur pitch amp vowel-1 sex-1 ampfun1 ampfun2 ampfun3 indxfun skewfun vibfun ranfun
+		   dis pcrev deg vibscl skewscl)
   `(fm-voice ,beg ,dur ,pitch ,amp ,vowel-1 ,sex-1 ,ampfun1 ,ampfun2 ,ampfun3 ,indxfun ,skewfun ,vibfun ,ranfun
-	     ,dis ,pcrev ,deg ,vibscl 0 ,skewscl ,ranpower '(0 0 100 0)))
+	     ,dis ,pcrev ,deg ,vibscl 0 ,skewscl '(0 0 100 0)))
 |#
