@@ -1,40 +1,19 @@
 (provide 'snd-misc.scm)
 
-(if (not (provided? 'snd-snd-motif.scm)) (load "snd-motif.scm"))
-(if (not (provided? 'snd-examp.scm)) (load "examp.scm"))
-(if (not (provided? 'snd-extensions.scm)) (load "extensions.scm"))
-(if (not (provided? 'snd-dsp.scm)) (load "dsp.scm"))
-(if (not (provided? 'snd-draw.scm)) (load "draw.scm"))
-(if (not (provided? 'snd-env.scm)) (load "env.scm"))
-(if (not (provided? 'snd-enved.scm)) (load "enved.scm"))
-(if (not (provided? 'snd-hooks.scm)) (load "hooks.scm"))
-(if (not (provided? 'snd-marks.scm)) (load "marks.scm"))
-(if (not (provided? 'snd-mix.scm)) (load "mix.scm"))
-(if (not (provided? 'snd-moog.scm)) (load "moog.scm"))
-(if (not (provided? 'snd-play.scm)) (load "play.scm"))
-(if (not (provided? 'snd-popup.scm)) (load "popup.scm"))
-(if (not (provided? 'snd-rubber.scm)) (load "rubber.scm"))
-(if (not (provided? 'snd-zip.scm)) (load "zip.scm"))
-(if (not (provided? 'snd-new-effects.scm)) (load "new-effects.scm"))
-(if (not (provided? 'snd-snd7.scm)) (load "snd7.scm"))
-(if (not (provided? 'snd-special-menu.scm)) (load "special-menu.scm"))
-(if (not (provided? 'snd-new-backgrounds.scm)) (load "new-backgrounds.scm"))
-(if (not (provided? 'snd-marks-menu.scm)) (load "marks-menu.scm"))
-(if (not (provided? 'snd-toolbar.scm)) (load "toolbar.scm"))
-(if (not (provided? 'snd-panic.scm)) (load "panic.scm"))
-(if (and (provided? 'snd-gtk) (not (provided? 'snd-ladspa.scm))) (load "ladspa.scm"))
-(if (and (provided? 'snd-gtk) (not (provided? 'snd-ladspa-help.scm))) (load "ladspa-help.scm"))
-(if (not (provided? 'snd-fft-menu.scm)) (load "fft-menu.scm"))
-(if (not (provided? 'snd-edit123.scm)) (load "edit123.scm"))
-(if (not (provided? 'snd-effects-utils.scm)) (load "effects-utils.scm"))
+(if (not (provided? 'snd-motif)) (snd-error "misc.scm only works in the Motif version of Snd."))
+
+(require snd-snd-motif.scm snd-examp.scm snd-extensions.scm snd-dsp.scm snd-draw.scm snd-env.scm snd-enved.scm)
+(require snd-hooks.scm snd-marks.scm snd-mix.scm snd-moog.scm snd-play.scm snd-rubber.scm snd-zip.scm snd-edit123.scm)
+(require snd-new-effects.scm snd-special-menu.scm snd-new-backgrounds.scm snd-marks-menu.scm snd-fft-menu.scm snd-effects-utils.scm)
+
+(with-let *motif*
 
 (keep-file-dialog-open-upon-ok)
-(make-hidden-controls-dialog)
-(check-for-unsaved-edits #t)
+(set! *ask-about-unsaved-edits* #t)
 (if (not (hook-member show-disk-space after-open-hook))
-    (add-hook! after-open-hook show-disk-space))
+    (hook-push after-open-hook show-disk-space))
 
-;(define wd (make-pixmap (cadr (main-widgets)) rough))
+;(define wd (make-pixmap (cadr (main-widgets)) rough)) ; this comes from new-backgrounds.scm
 ;(for-each-child (cadr (main-widgets)) (lambda (w) (XtSetValues w (list XmNbackgroundPixmap wd))))
 
 (define wd (make-pixmap (cadr (main-widgets)) rough))
@@ -67,10 +46,13 @@
        (paint-all w)))
  (dialog-widgets))
 
-(if (not (hook-member paint-all new-widget-hook))
-    (add-hook! new-widget-hook paint-all))
+(define (hook-paint-all hook) 
+  (paint-all (hook 'widget)))
 
-(set! (mix-waveform-height) 32)
+(if (not (hook-member hook-paint-all new-widget-hook))
+    (hook-push new-widget-hook hook-paint-all))
+
+(set! *mix-waveform-height* 32)
 
 ;;; (with-level-meters 2)
 
@@ -108,9 +90,9 @@
 ;;; disable original Play radio button
 ;;;
 
-;(add-hook! after-open-hook
-;           (lambda (snd)
-;             (XtUnmanageChild (find-child (list-ref (sound-widgets snd) 2) "play"))))
+;(hook-push after-open-hook
+;           (lambda (hook)
+;             (XtUnmanageChild (find-child (list-ref (sound-widgets (hook 'snd)) 2) "play"))))
 
 
 ;;;
@@ -150,16 +132,16 @@
 				       XmNdialogTitle         titlestr
 				       XmNresizePolicy        XmRESIZE_GROW
 				       XmNnoResize            #f
-				       XmNbackground          (basic-color)
+				       XmNbackground          *basic-color*
 				       XmNtransient           #f))))
 	      (for-each
 	       (lambda (button color)
 		 (XtVaSetValues
 		   (XmMessageBoxGetChild new-dialog button)
-		   (list XmNarmColor   (pushed-button-color)
+		   (list XmNarmColor   *selection-color*
 			 XmNbackground color)))
 	       (list XmDIALOG_HELP_BUTTON XmDIALOG_CANCEL_BUTTON XmDIALOG_OK_BUTTON)
-	       (list (help-button-color) (quit-button-color) (doit-button-color)))
+	       (list *highlight-color* *highlight-color* *highlight-color*))
     
 	      (XtAddCallback new-dialog XmNcancelCallback 
 			      (lambda (w c i) (XtUnmanageChild w)))
@@ -172,12 +154,13 @@
 			      (lambda (w c i)
 				(let ((new-name (XmTextFieldGetString rename-text)))
 				  (if (and (string? new-name)
-					   (> (string-length new-name) 0)
+					   (> (length new-name) 0)
 					   (>= (selected-sound) 0))
-				      (let ((current-name (file-name)))
+				      (let ();(current-name (file-name)))
 					(save-sound-as new-name)
 					(close-sound)
-					(rename-file current-name new-name)
+					;(rename-file current-name new-name)
+					;; (delete-file current-name) perhaps?
 					(open-sound new-name)
 					(XtUnmanageChild w))))))
 	      (XmStringFree xhelp)
@@ -192,13 +175,13 @@
 					   XmNbottomAttachment    XmATTACH_WIDGET
 					   XmNbottomWidget        (XmMessageBoxGetChild rename-dialog XmDIALOG_SEPARATOR)
 					   XmNorientation         XmVERTICAL
-					   XmNbackground          (basic-color))))
+					   XmNbackground          *basic-color*)))
 		     (label (XtCreateManagedWidget "new name:" xmLabelWidgetClass mainform
 				     (list XmNleftAttachment      XmATTACH_FORM
 					   XmNrightAttachment     XmATTACH_NONE
 					   XmNtopAttachment       XmATTACH_FORM
 					   XmNbottomAttachment    XmATTACH_FORM
-					   XmNbackground          (basic-color)))))
+					   XmNbackground          *basic-color*))))
 		(set! rename-text 
 		      (XtCreateManagedWidget "newname" xmTextFieldWidgetClass mainform
 				     (list XmNleftAttachment      XmATTACH_WIDGET
@@ -206,14 +189,14 @@
 					   XmNrightAttachment     XmATTACH_FORM
 					   XmNtopAttachment       XmATTACH_FORM
 					   XmNbottomAttachment    XmATTACH_FORM
-					   XmNbackground          (basic-color))))
+					   XmNbackground          *basic-color*)))
 		(XtAddEventHandler rename-text EnterWindowMask #f
 				    (lambda (w context ev flag)
 				      (XmProcessTraversal w XmTRAVERSE_CURRENT)
 				      (XtSetValues w (list XmNbackground (white-pixel)))))
 		(XtAddEventHandler rename-text LeaveWindowMask #f
 				    (lambda (w context ev flag)
-				      (XtSetValues w (list XmNbackground (basic-color))))))))
+				      (XtSetValues w (list XmNbackground *basic-color*)))))))
 	(if (not (XtIsManaged rename-dialog))
 	    (XtManageChild rename-dialog)
 	    (raise-dialog rename-dialog)))
@@ -223,59 +206,7 @@
 (add-delete-option)
 (add-rename-option)
 
-;;;
-;;; poup menu stuff
-;;;
 
-(change-graph-popup-color "pink")
-
-;;;(add-selection-popup)
-
-
-(define (change-selection-popup-color new-color)
-  ;; new-color can be the color name, an xm Pixel, a snd color, or a list of rgb values (as in Snd's make-color)
-  (let ((color-pixel
-         (if (string? new-color) ; assuming X11 color names here
-             (let* ((shell (cadr (main-widgets)))
-                    (dpy (XtDisplay shell))
-                    (scr (DefaultScreen dpy))
-                    (cmap (DefaultColormap dpy scr))
-                    (col (XColor)))
-               (if (= (XAllocNamedColor dpy cmap new-color col col) 0)
-                   (snd-error (format #f "can't allocate ~S" new-color))
-                   (.pixel col)))
-             (if (color? new-color)
-                     new-color
-                     ;; assume a list of rgb vals?
-                     (apply make-color new-color)))))
-    (for-each-child
-     selection-popup-menu
-     (lambda (n)
-       (XmChangeColor n color-pixel)))))
-(change-selection-popup-color "coral")
-
-(define (change-fft-popup-color new-color)
-  (let ((color-pixel
-         (if (string? new-color) ; assuming X11 color names here
-             (let* ((shell (cadr (main-widgets)))
-                    (dpy (XtDisplay shell))
-                    (scr (DefaultScreen dpy))
-                    (cmap (DefaultColormap dpy scr))
-                    (col (XColor)))
-               (if (= (XAllocNamedColor dpy cmap new-color col col) 0)
-                   (snd-error (format #f "can't allocate ~S" new-color))
-                   (.pixel col)))
-             (if (color? new-color)
-                     new-color
-                     ;; assume a list of rgb vals?
-                     (apply make-color new-color)))))
-    (for-each-child
-     fft-popup-menu
-     (lambda (n)
-       (XmChangeColor n color-pixel)))))
-(change-fft-popup-color "orange")
-
-;(change-listener-popup-color "red")
 
 (add-to-menu 1 #f #f) ; separator
 
@@ -301,7 +232,7 @@
 
 (define (append-selection)
   (if (selection?)
-      (insert-selection (frames))))
+      (insert-selection (framples))))
 
 (add-to-menu 1 "Append Selection" append-selection)
 
@@ -310,7 +241,7 @@
 
 (define (replace-with-selection)
   (let ((beg (cursor))
-        (len (selection-frames)))
+        (len (selection-framples)))
     (delete-samples beg len)
     (insert-selection beg)))
 
@@ -324,17 +255,17 @@
 ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(add-hook! open-raw-sound-hook
-           (lambda (file choices)
-             (list 2 44100 (if (little-endian?) mus-lshort mus-bshort))))
+(hook-push open-raw-sound-hook
+           (lambda (hook)
+             (set! (hook 'result) (list 2 44100 (if (little-endian?) mus-lshort mus-bshort)))))
 
-(add-hook! open-hook
-           (lambda (filename)
-             (if (= (mus-sound-header-type filename) mus-raw)
-                 (let ((rawfile (string-append filename ".raw")))
-                   (system (format #f "mpg123 -s ~A > ~A" filename rawfile))
-                   rawfile)
-                 #f)))
+(hook-push open-hook
+           (lambda (hook)
+	     (let ((filename (hook 'name)))
+	       (if (= (mus-sound-header-type filename) mus-raw)
+		   (let ((rawfile (string-append filename ".raw")))
+		     (system (format #f "mpg123 -s ~A > ~A" filename rawfile))
+		     (set! (hook 'result) rawfile))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -342,17 +273,17 @@
 ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(add-hook! open-raw-sound-hook
-           (lambda (file choices)
-             (list 2 44100 (if (little-endian?) mus-lshort mus-bshort))))
+(hook-push open-raw-sound-hook
+           (lambda (hook)
+             (set! (hook 'result) (list 2 44100 (if (little-endian?) mus-lshort mus-bshort)))))
 
-(add-hook! open-hook
-           (lambda (filename)
-             (if (= (mus-sound-header-type filename) mus-raw)
-                 (let ((rawfile (string-append filename ".raw")))
-                   (system (format #f "ogg123 -d raw -f ~A ~A" rawfile filename))
-                   rawfile)
-                 #f)))
+(hook-push open-hook
+           (lambda (hook)
+	     (let ((filename (hook 'name)))
+	       (if (= (mus-sound-header-type filename) mus-raw)
+		   (let ((rawfile (string-append filename ".raw")))
+		     (system (format #f "ogg123 -d raw -f ~A ~A" rawfile filename))
+		     (set! (hook 'result) rawfile))))))
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -376,7 +307,6 @@
 ;;; Deselect function
 ;;;
 
-(define (deselect-all)
-  (if (selection?)
-      (set! (selection-member? #t) #f)))
+(define deselect-all unselect-all)
 
+)
