@@ -1,5 +1,11 @@
 (provide 'snd-numerics.scm)
 
+(when (provided? 'pure-s7)
+  (define (make-polar mag ang)
+    (if (and (real? mag) (real? ang))
+	(complex (* mag (cos ang)) (* mag (sin ang)))
+	(error 'wrong-type-arg "make-polar args should be real"))))
+
 ;;; random stuff I needed at one time or another while goofing around...
 ;;;   there are a lot more in snd-test.scm
 
@@ -15,32 +21,56 @@
 		(old-facts factorials))
 	    (set! num-factorials n)
 	    (set! factorials (make-vector num-factorials 0))
-	    (do ((i 0 (+ 1 i)))
+	    (do ((i 0 (+ i 1)))
 		((= i old-num))
 	      (set! (factorials i) (old-facts i)))))
       (if (zero? (factorials n))
 	  (set! (factorials n) (* n (factorial (- n 1)))))
       (factorials n))))
 
-(define (binomial-direct n m) ; "n-choose-m" might be a better name (there are much better ways to compute this -- see below)
+#|
+;;; maxima uses this:
+
+;; From Richard Fateman's paper, "Comments on Factorial Programs",
+;; http://www.cs.berkeley.edu/~fateman/papers/factorial.pdf
+;;
+;; k(n,m) = n*(n-m)*(n-2*m)*...
+;;
+;; (k n 1) is n!
+;;
+;; This is much faster (3-4 times) than the original factorial
+;; function.
+
+(define (factorial n)
+  (define (k n m)
+    (if (<= n m)
+	n
+	(* (k n (* 2 m))
+	   (k (- n m) (* 2 m)))))
+  (if (zero? n)
+      1
+      (k n 1)))
+|#
+
+(define (binomial-direct n m) 
   (/ (factorial n)
      (* (factorial m) (factorial (- n m)))))
 
-(define (n-choose-k n k)
-  "(n-choose-k n k) computes the binomial coefficient C(N,K)"
-  (let ((mn (min k (- n k))))
-    (if (< mn 0)
-	0
-	(if (= mn 0)
-	    1
-	    (let* ((mx (max k (- n k)))
-		   (cnk (+ 1 mx)))
-	      (do ((i 2 (+ 1 i)))
-		  ((> i mn) cnk)
-		(set! cnk (/ (* cnk (+ mx i)) i))))))))
-
-(define binomial n-choose-k)
-
+(define n-choose-k 
+  (let ((documentation "(n-choose-k n k) computes the binomial coefficient C(N,K)"))
+    (lambda (n k)
+      (let ((mn (min k (- n k))))
+	(if (< mn 0)
+	    0
+	    (if (= mn 0)
+		1
+		(let* ((mx (max k (- n k)))
+		       (cnk (+ 1 mx)))
+		  (do ((i 2 (+ i 1)))
+		      ((> i mn) cnk)
+		    (set! cnk (/ (* cnk (+ mx i)) i))))))))))
+    
+    
 
 ;;; --------------------------------------------------------------------------------
 ;;; from Numerical Recipes
@@ -57,7 +87,7 @@
 	    (begin
 	      (set! somx2 (sqrt (* (- 1.0 x) (+ 1.0 x))))
 	      (set! fact 1.0)
-	      (do ((i 1 (+ 1 i)))
+	      (do ((i 1 (+ i 1)))
 		  ((> i m))
 		(set! pmm (* (- pmm) fact somx2))
 		(set! fact (+ fact 2.0)))))
@@ -67,7 +97,7 @@
 	      (if (= l (+ m 1)) 
 		  pmmp1
 		  (let ((pk 0.0)) ; NR used "ll" which is unreadable
-		    (do ((k (+ m 2) (+ 1 k)))
+		    (do ((k (+ m 2) (+ k 1)))
 			((> k l))
 		      (set! pk (/ (- (* x (- (* 2 k) 1) pmmp1) 
 				      (* (+ k m -1) pmm)) 
@@ -82,11 +112,11 @@
   (let ((n (- (length a) 1)))
     (if (= n 0) 
 	(a 0)
-	(let* ((r x)
-	       (s 1.0)
-	       (h 0.0)
-	       (sum (a 0)))
-	  (do ((k 1 (+ 1 k)))
+	(let ((r x)
+	      (s 1.0)
+	      (h 0.0)
+	      (sum (a 0)))
+	  (do ((k 1 (+ k 1)))
 	      ((= k n))
 	    (set! h r)
 	    (set! sum (+ sum (* r (a k))))
@@ -100,12 +130,12 @@
 			 v)
 		       x))
 
-;;; (with-sound (:scaled-to 0.5) (do ((i 0 (+ 1 i)) (x 0.0 (+ x .1))) ((= i 10000)) (outa i (legendre 20 (cos x)))))
+;;; (with-sound (:scaled-to 0.5) (do ((i 0 (+ i 1)) (x 0.0 (+ x .1))) ((= i 10000)) (outa i (legendre 20 (cos x)))))
 
 #|
 ;; if l odd, there seems to be sign confusion:
 (with-sound (:channels 2 :scaled-to 1.0)
-  (do ((i 0 (+ 1 i))
+  (do ((i 0 (+ i 1))
        (theta 0.0 (+ theta 0.01)))
       ((= i 10000))
     (outa i (plgndr 1 1 (cos theta)))
@@ -114,7 +144,7 @@
 
 ;; this works:
 (with-sound (:channels 2 :scaled-to 1.0)
-  (do ((i 0 (+ 1 i))
+  (do ((i 0 (+ i 1))
        (theta 0.0 (+ theta 0.01)))
       ((= i 10000))
     (let ((x (cos theta)))
@@ -139,7 +169,7 @@
 			(fn2 1.0))
 		    (if (= n 1)
 			fn1
-			(do ((k 2 (+ 1 k))
+			(do ((k 2 (+ k 1))
 			     (k0 2.0 (+ k0 1.0)))
 			    ((> k n) fn)
 			  (set! fn (/ (- (* 2 x fn1 (+ k alpha -1.0))
@@ -149,11 +179,11 @@
 			  (set! fn1 fn)))))))))
 
 
-;;; (with-sound (:scaled-to 0.5) (do ((i 0 (+ 1 i)) (x 0.0 (+ x .1))) ((= i 10000)) (outa i (gegenbauer 15 (cos x) 1.0))))
+;;; (with-sound (:scaled-to 0.5) (do ((i 0 (+ i 1)) (x 0.0 (+ x .1))) ((= i 10000)) (outa i (gegenbauer 15 (cos x) 1.0))))
 
 #|
 (with-sound (:scaled-to 0.5)
-  (do ((i 0 (+ 1 i))
+  (do ((i 0 (+ i 1))
        (theta 0.0 (+ theta 0.05)))
       ((= i 10000))
     (let ((x (cos theta)))
@@ -165,11 +195,11 @@
   (let ((n (- (length a) 1)))
     (if (= n 0) 
 	(a 0)
-	(let* ((r (* kind x))
-	       (s 1.0)
-	       (h 0.0)
-	       (sum (a 0)))
-	  (do ((k 1 (+ 1 k)))
+	(let ((r (* kind x))
+	      (s 1.0)
+	      (h 0.0)
+	      (sum (a 0)))
+	  (do ((k 1 (+ k 1)))
 	      ((= k n))
 	    (set! h r)
 	    (set! sum (+ sum (* r (a k))))
@@ -187,11 +217,11 @@
   (let ((n (- (length a) 1)))
     (if (= n 0) 
 	(a 0)
-	(let* ((r (* 2 x))
-	       (s 1.0)
-	       (h 0.0)
-	       (sum (a 0)))
-	  (do ((k 1 (+ 1 k))
+	(let ((r (* 2 x))
+	      (s 1.0)
+	      (h 0.0)
+	      (sum (a 0)))
+	  (do ((k 1 (+ k 1))
 	       (k2 2 (+ k2 2)))
 	      ((= k n))
 	    (set! h r)
@@ -210,11 +240,11 @@
   (let ((n (- (length a) 1)))
     (if (= n 0) 
 	(a 0)
-	(let* ((r (- (+ alpha 1.0) x))
-	       (s 1.0)
-	       (h 0.0)
-	       (sum (a 0)))
-	  (do ((k 1 (+ 1 k)))
+	(let ((r (- (+ alpha 1.0) x))
+	      (s 1.0)
+	      (h 0.0)
+	      (sum (a 0)))
+	  (do ((k 1 (+ k 1)))
 	      ((= k n))
 	    (set! h r)
 	    (set! sum (+ sum (* r (a k))))
@@ -241,17 +271,18 @@
 ;;; most cases won't work right because we're assuming real output and so on
 
 (define* (automorph a b c d snd chn)
-  (let* ((len (frames snd chn))
-	 (pow2 (ceiling (/ (log len) (log 2))))
+  (let* ((len (framples snd chn))
+	 (pow2 (ceiling (log len 2)))
 	 (fftlen (floor (expt 2 pow2)))
+	 (fftlen2 (/ fftlen 2))
 	 (fftscale (/ 1.0 fftlen))
-	 (rl (channel->vct 0 fftlen snd chn))
-	 (im (make-vct fftlen)))
+	 (rl (channel->float-vector 0 fftlen snd chn))
+	 (im (make-float-vector fftlen)))
     (fft rl im 1)
-    (vct-scale! rl fftscale)
-    (vct-scale! im fftscale)
+    (float-vector-scale! rl fftscale)
+    (float-vector-scale! im fftscale)
     ;; handle 0 case by itself
-    (let* ((c1 (make-rectangular (rl 0) (im 0)))
+    (let* ((c1 (complex (rl 0) (im 0)))
 	   (val (/ (+ (* a c1) b)
 		   (+ (* c c1) d)))
 	   (rval (real-part val))
@@ -260,8 +291,8 @@
       (set! (im 0) ival))
     (do ((i 1 (+ i 1))
 	 (k (- fftlen 1) (- k 1)))
-	((= i (/ fftlen 2)))
-      (let* ((c1 (make-rectangular (rl i) (im i)))
+	((= i fftlen2))
+      (let* ((c1 (complex (rl i) (im i)))
 	     (val (/ (+ (* a c1) b)      ; (az + b) / (cz + d)
 		     (+ (* c c1) d)))
 	     (rval (real-part val))
@@ -271,15 +302,17 @@
 	(set! (rl k) rval)
 	(set! (im k) (- ival))))
     (fft rl im -1)
-    (vct->channel rl 0 len snd chn #f (format #f "automorph ~A ~A ~A ~A" a b c d))))
+    (float-vector->channel rl 0 len snd chn #f (format #f "automorph ~A ~A ~A ~A" a b c d))))
 |#
 
 
+#|
 ;;; --------------------------------------------------------------------------------
+;;; these are in snd-xen.c??
 
 (define (bes-i1 x)				;I1(x)
   (if (< (abs x) 3.75)
-      (let* ((y (expt (/ x 3.75) 2)))
+      (let ((y (expt (/ x 3.75) 2)))
 	(* x (+ 0.5
 		(* y (+ 0.87890594
 			(* y (+ 0.51498869
@@ -330,6 +363,7 @@
 		  (if (= j n) (set! ans bip)))
 		(if (and (< x 0.0) (odd? n)) (set! ans (- ans)))
 		(* ans (/ (bes-i0 x) bi)))))))
+|#
 
 
 ;;; --------------------------------------------------------------------------------
@@ -347,13 +381,13 @@
 (define (Si x) 
   (if (>= x 1.0)
       (- (/ pi 2) (* (cos x) (aux-f x)) (* (sin x) (aux-g x)))
-    (let* ((sum x)
-	   (fact 2.0)
-	   (one -1.0)
-	   (xs x)
-	   (x2 (* x x))
-	   (err .000001)
-	   (unhappy #t))
+    (let ((sum x)
+	  (fact 2.0)
+	  (one -1.0)
+	  (xs x)
+	  (x2 (* x x))
+	  (err .000001)
+	  (unhappy #t))
       (do ((i 3.0 (+ i 2.0)))
 	  ((not unhappy))
 	(set! xs (/ (* one x2 xs) (* i fact)))
@@ -367,14 +401,14 @@
 (define (Ci x) 
   (if (>= x 1.0)
       (- (* (sin x) (aux-f x)) (* (cos x) (aux-g x)))
-    (let* ((g .5772156649)
-	   (sum 0.0)
-	   (fact 1.0)
-	   (one -1.0)
-	   (xs 1.0)
-	   (x2 (* x x))
-	   (err .000001)
-	   (unhappy #t))
+    (let ((g .5772156649)
+	  (sum 0.0)
+	  (fact 1.0)
+	  (one -1.0)
+	  (xs 1.0)
+	  (x2 (* x x))
+	  (err .000001)
+	  (unhappy #t))
       (do ((i 2.0 (+ i 2.0)))
 	  ((not unhappy))
 	(set! xs (/ (* one x2 xs) (* i fact)))
@@ -417,8 +451,7 @@
 			     (/ (* 2.0 sum2 (factorial n)
 				   (if (= (modulo n 4) 0) -1 1))
 				(expt (* 2.0 pi) n))))))
-	    (set! (saved-values n) value)
-	    value)))))
+	    (set! (saved-values n) value))))))
 
 (define (bernoulli-poly n x)
   (let ((fact 1.0)
@@ -675,7 +708,7 @@
       (do ((i 0 (+ i 1)))
 	  ((= i nhx))
 	(set! y (* 16.0 (- y (floor y))))
-	(string-set! chx i (string-ref hx (floor y))))
+	(set! (chx i) (hx (floor y))))
       chx))
   
   (define expm
@@ -790,7 +823,7 @@
 
 ;;; --------------------------------------------------------------------------------
 
-(define* (sin-nx-peak n (error 1e-12))
+(define* (sin-nx-peak n (err 1e-12))
   ;; return the min peak amp and its location for sin(x)+sin(nx+a)
   (let* ((size (* n 100))
 	 (incr (/ (* 2 pi) size))
@@ -806,10 +839,9 @@
 	      (set! peak val)
 	      (set! location x)))))
     ;; now narrow it by zigzagging around the peak
-    (let ((zig-size (* incr 2))
-	  (x location))
+    (let ((x location))
       (do ((zig-size (* incr 2) (/ zig-size 2)))
-	  ((< zig-size error))
+	  ((< zig-size err))
 	(let ((cur (abs (+ (sin x) (sin (+ offset (* n x))))))
 	      (left (abs (+ (sin (- x zig-size)) (sin (+ (* n (- x zig-size)) offset))))))
 	  (if (< left cur)
@@ -818,3 +850,10 @@
 		    (set! x (+ x zig-size))))
 	      (set! x (- x zig-size)))))
       (list (abs (+ (sin x) (sin (+ (* n x) offset)))) x))))
+
+;;; --------------------------------------------------------------------------------
+
+(define (exptmod a b n) ; from the net somewhere: (modulo (expt a b) n)
+  (cond ((zero? b) 1)
+        ((even? b) (exptmod (modulo (* a a) n) (quotient b 2) n))
+        (else (modulo (* a (exptmod (modulo (* a a) n) (quotient b 2) n)) n))))
