@@ -90,7 +90,7 @@
 	   (else
 	    (slib:warn "require.scm" 'unknown 'software-type (software-type))
 	    "/"))))
-    (lambda (chr) (and (memv chr suffi) #t))))
+    (lambda (chr) (memv chr suffi))))
 ;@
 (define (pathname->vicinity pathname)
   (let loop ((i (- (string-length pathname) 1)))
@@ -158,7 +158,6 @@
     macro				;R5RS high level macros
 
 ;;;	delay				;has DELAY and FORCE
-;;; "delay" is named "make-promise" in s7
 
     multiarg-apply		     ;APPLY can take more than 2 args.
     char-ready?
@@ -286,7 +285,7 @@
 		`(set! *defmacros* (cons (cons ',name (lambda ,parms ,@body))
 					 *defmacros*))))))
 ;@
-(define (defmacro? m) (and (assq m *defmacros*) #t))
+(define (defmacro? m) (assq m *defmacros*))
 ;@
 (define (macroexpand-1 e)
   (if (pair? e)
@@ -317,7 +316,7 @@
 (define (defmacro:eval x) (base:eval (defmacro:expand* x)))
 
 (define (defmacro:expand* x)
-  (slib:require 'defmacroexpand) (apply defmacro:expand* x '()))
+  (slib:require 'defmacroexpand) (apply defmacro:expand* x ()))
 ;@
 (define (defmacro:load <pathname>)
   (slib:eval-load <pathname> defmacro:eval))
@@ -331,11 +330,8 @@
       (newline cep))))
 
 ;;@ define an error procedure for the library
-(define slib:error
-  (let ((error error))
-    (lambda args
-      (if (provided? 'trace) (print-call-stack (current-error-port)))
-      (apply error args))))
+(define slib:error error)
+
 ;@
 (define (make-exchanger obj)
   (lambda (rep) (let ((old obj)) (set! obj rep) old)))
@@ -385,7 +381,7 @@
 
 ;;@ Define SLIB:EXIT to be the implementation procedure to exit or
 ;;; return if exiting not supported.
-(define slib:exit quit)
+(define slib:exit exit) 
 
 ;;@ Here for backward compatability
 (define scheme-file-suffix
@@ -415,3 +411,20 @@
 ;;(define syncase:load slib:load-source)
 
 (slib:load (in-vicinity (library-vicinity) "require"))
+
+
+;;; --------------------------------------------------------------------------------
+;;; for wttree.scm
+
+(set! *#readers* 
+	  (cons (cons #\F (lambda (str)
+			    (not (string=? str ""))))
+		*#readers*))
+
+;;; for r4syn.scm
+
+(set! *#readers* 
+	  (cons (cons #\T (lambda (str)
+			    (string=? str "")))
+		*#readers*))
+
