@@ -19,6 +19,7 @@ typedef struct {
 static bool compare_names(const char *symbol_name, void *data)
 {
   match_info *m = (match_info *)data;
+
   if (strncmp(m->text, symbol_name, m->len) == 0)
     {
       m->matches++;
@@ -44,6 +45,7 @@ static int completions(const char *text)
 {
   match_info *m;
   int matches;
+
   m = (match_info *)calloc(1, sizeof(match_info));
   m->text = text;
   m->len = strlen(text);
@@ -58,11 +60,11 @@ static int completions(const char *text)
 
 
 #if HAVE_RUBY
-static XEN snd_rb_methods(void)
+static Xen snd_rb_methods(void)
 {
   /* returns all the functions we defined */
-  XEN argv[1];
-  argv[0] = XEN_TRUE;
+  Xen argv[1];
+  argv[0] = Xen_true;
   return(rb_class_private_instance_methods(1, argv, rb_mKernel));
   /* rb_ary_new here -- should we free? */
 }
@@ -70,17 +72,21 @@ static XEN snd_rb_methods(void)
 
 static int completions(const char *text)
 {
-  XEN tab;
+  Xen tab;
   int i, n, len, matches = 0;
+
   tab = snd_rb_methods();
-  n = XEN_VECTOR_LENGTH(tab);
+  n = Xen_vector_length(tab);
   len = strlen(text);
+
   for (i = 0; i < n; ++i)
     {
       char *sym;
-      XEN handle;
-      handle = XEN_VECTOR_REF(tab, i);
-      sym = XEN_AS_STRING(handle);
+      Xen handle;
+
+      handle = Xen_vector_ref(tab, i);
+      sym = Xen_object_to_C_string(handle);
+
       if (strncmp(text, sym, len) == 0)
 	{
 	  matches++;
@@ -99,9 +105,6 @@ static int completions(const char *text)
 		  }
 	    }
 	}
-#if HAVE_SCHEME
-      if (sym) free(sym);
-#endif
     }
   return(matches);
 }
@@ -111,11 +114,12 @@ static int completions(const char *text)
 #if HAVE_FORTH
 static int completions(const char *text)
 {
-  XEN tab = fth_find_in_wordlist(text);
-  int i, matches = XEN_VECTOR_LENGTH(tab);
+  Xen tab = fth_find_in_wordlist(text);
+  int i, matches = Xen_vector_length(tab);
+
   for (i = 0; i < matches; i++)
     {
-      char *sym = XEN_TO_C_STRING(XEN_VECTOR_REF(tab, i));
+      char *sym = Xen_string_to_C_string(Xen_vector_ref(tab, i));
       add_possible_completion(sym);
       if (current_match == NULL)
 	current_match = mus_strdup(sym);
@@ -142,13 +146,13 @@ static int completions(const char *text) {return(0);}
 
 
 #if HAVE_FORTH
-bool separator_char_p(char c)
+static bool is_separator(char c)
 {
   /* only space is separator */
   return(!(isgraph((int)c)));
 }
 #else
-bool separator_char_p(char c)
+static bool is_separator(char c)
 {
   return((!(isalpha((int)c))) &&
 	 (!(isdigit((int)c))) &&
@@ -176,21 +180,39 @@ bool separator_char_p(char c)
 #endif
 
 
+char *direct_completions(const char *str)
+{
+  int matches = 0;
+  current_match = NULL;
+  clear_possible_completions();
+  set_completion_matches(0);
+  set_save_completions(true);
+  matches = completions(str);
+  set_completion_matches(matches);
+  set_save_completions(false);
+  return(current_match);
+}
+
+
 char *expression_completer(widget_t w, const char *original_text, void *data)
 {
-  int i, len, beg, matches = 0;
+  int len, beg, matches = 0;
   /* first back up to some delimiter to get the current expression */
 
   current_match = NULL;
   set_completion_matches(0);
+
   if ((original_text) && (*original_text))
     {
       const char *text;
+      int i;
+
       len = strlen(original_text);
       for (i = len - 1; i >= 0; i--)
-	if (separator_char_p(original_text[i]))
+	if (is_separator(original_text[i]))
 	  break;
       beg = i + 1;
+
       if (beg == len) 
 	{
 	  /* returning original = no-op response to <tab> which seems useless;
@@ -201,6 +223,7 @@ char *expression_completer(widget_t w, const char *original_text, void *data)
 	   */
 	  return(mus_strdup(original_text));
 	}
+
       if (beg > 0) 
 	text = (const char *)(original_text + beg);
       else text = original_text;
@@ -240,16 +263,14 @@ void preload_best_completions(void)
   /* set up the array with some reasonable first choices */
   int n = 0;
   best_completions[n++] = mus_strdup(S_open_sound);
-  best_completions[n++] = mus_strdup(S_auto_resize);
   best_completions[n++] = mus_strdup(S_channels);
   best_completions[n++] = mus_strdup(S_close_sound);
   best_completions[n++] = mus_strdup(S_cursor);
   best_completions[n++] = mus_strdup(S_env_channel);
   best_completions[n++] = mus_strdup(S_file_name);
-  best_completions[n++] = mus_strdup(S_frames);
+  best_completions[n++] = mus_strdup(S_framples);
   best_completions[n++] = mus_strdup(S_map_channel);
   best_completions[n++] = mus_strdup(S_maxamp);
-  best_completions[n++] = mus_strdup(S_optimization);
   best_completions[n++] = mus_strdup(S_play);
   best_completions[n++] = mus_strdup(S_save_sound);
   best_completions[n++] = mus_strdup(S_scale_channel);
@@ -259,7 +280,6 @@ void preload_best_completions(void)
   best_completions[n++] = mus_strdup("*output*");
   best_completions[n++] = mus_strdup("lambda");
   best_completions[n++] = mus_strdup("define");
-  best_completions[n++] = mus_strdup(S_vct_length);
 }
 
 
@@ -267,6 +287,7 @@ void save_completion_choice(const char *selection)
 {
   int i;
   char *cur = NULL, *old = NULL;
+
   cur = mus_strdup(selection);
   for (i = 0; i < BEST_COMPLETIONS; i++)
     {
@@ -332,6 +353,7 @@ int add_completer_func(char *(*func)(widget_t w, const char *text, void *context
   return(completer_funcs_end - 1);
 }
 
+
 int add_completer_func_with_multicompleter(char *(*func)(widget_t w, const char *text, void *context), void *data, void (*multi_func)(widget_t w, void *data))
 {
   int row;
@@ -443,41 +465,29 @@ static void init_srate_list(void)
 }
 
 
-char *srate_list_to_string(int row)
-{
-  if ((srate_info) &&
-      (srate_info->num_values > row))
-    return(srate_info->values[row]);
-  return(NULL);
-}
-
-
-list_completer_info *srate_list(void)
-{
-  init_srate_list();
-  return(srate_info);
-}
-
-
 void add_srate_to_completion_list(int srate)
 {
   char *str;
   int i;
+
   init_srate_list();
-  str = (char *)calloc(16, sizeof(char));
-  mus_snprintf(str, 16, "%d", srate);
+  str = (char *)malloc(16 * sizeof(char));
+  snprintf(str, 16, "%d", srate);
+
   for (i = 0; i < srate_info->num_values; i++)
     if (mus_strcmp(srate_info->values[i], str))
       {
 	free(str);
 	return;
       }
+
   if (srate_info->num_values >= srate_info->values_size)
     {
       srate_info->values_size += 16;
       srate_info->values = (char **)realloc(srate_info->values, srate_info->values_size * sizeof(char *));
       for (i = srate_info->num_values; i < srate_info->values_size; i++) srate_info->values[i] = NULL;
     }
+
   srate_info->values[srate_info->num_values++] = str;
 }
 
@@ -489,7 +499,7 @@ char *srate_completer(widget_t w, const char *text, void * data)
 }
 
 
-#if HAVE_DIRENT_H
+#ifndef _MSC_VER
   #include <dirent.h>
 #endif
 
@@ -498,41 +508,45 @@ enum {ANY_FILE_TYPE, SOUND_FILE_TYPE};
 
 static char *filename_completer_1(widget_t w, const char *text, int file_type)
 {
-#if HAVE_OPENDIR
   /* assume text is a partial filename */
   /* get directory name, opendir, read files checking for match */
   /* return name of same form as original (i.e. don't change user's directory indication) */
-  /* if directory, add "/" -- directory_p(name) static in snd-xfile.c */
+  /* if directory, add "/" -- is_directory(name) static in snd-xfile.c */
 
   char *full_name = NULL, *dir_name = NULL, *file_name = NULL, *current_match = NULL;
   int i, j, k, len, curlen, matches = 0;
-  struct dirent *dirp;
   DIR *dpos;
+
   if (mus_strlen(text) == 0) return(NULL);
   full_name = mus_expand_filename(text);
   len = mus_strlen(full_name);
   for (i = len - 1; i > 0; i--)
     if (full_name[i] == '/')
       break;
+
   dir_name = (char *)calloc(i + 1, sizeof(char));
   strncpy(dir_name, full_name, i);
+
   file_name = (char *)calloc(len - i + 2, sizeof(char));
   for (j = 0, k = i + 1; k < len; j++, k++) 
     file_name[j] = full_name[k];
+
   if (full_name) 
     {
       free(full_name); 
       full_name = NULL;
     }
+
   len = mus_strlen(file_name);
   if ((dpos = opendir(dir_name)) != NULL)
     {
+      struct dirent *dirp;
       while ((dirp = readdir(dpos)) != NULL)
 	if ((dirp->d_name[0] != '.') && 
 	    (strncmp(dirp->d_name, file_name, len) == 0)) /* match dirp->d_name against rest of text */
 	  {
 	    if ((file_type == ANY_FILE_TYPE) ||
-		(sound_file_p(dirp->d_name)))
+		(is_sound_file(dirp->d_name)))
 	      {
 		matches++;
 		add_possible_completion(dirp->d_name);
@@ -554,9 +568,12 @@ static char *filename_completer_1(widget_t w, const char *text, int file_type)
       if (closedir(dpos) != 0) 
 	snd_error("closedir %s failed (%s)!", dir_name, snd_io_strerror());
     }
+
   if (dir_name) free(dir_name);
   if (file_name) free(file_name);
+
   set_completion_matches(matches);
+
   if ((current_match) && 
       (*current_match))
     {
@@ -570,12 +587,11 @@ static char *filename_completer_1(widget_t w, const char *text, int file_type)
       file_name = (char *)calloc(curlen, sizeof(char));
       strncpy(file_name, text, i + 1);
       strcat(file_name, current_match);
-      if (directory_p(file_name)) 
+      if (is_directory(file_name)) 
 	strcat(file_name, "/");
       free(current_match);
       return(file_name);
     }
-#endif
   return(mus_strdup(text));
 }
 
@@ -592,59 +608,6 @@ char *sound_filename_completer(widget_t w, const char *text, void *data)
 }
 
 
-static bool use_sound_filename_completer(sp_filing_t filing)
-{
-  return((filing == INPUT_FILING) ||  /* C-x C-f */
-	 (filing == CHANGE_FILING) || /* C-x C-q */
-	 (filing == INSERT_FILING));   /* C-x C-i */
-}
-
-
-char *info_completer(widget_t w, const char *text, void *data)
-{
-  snd_info *sp = (snd_info *)data;
-  if (sp)
-    {
-      char *new_text = NULL;
-      if (sp->search_count != 0) return(mus_strdup(text));      /* C-s or C-r so as above */
-      if ((sp->marking) || (sp->finding_mark)) return(mus_strdup(text)); /* C-x C-m etc */
-      if (sp->printing) return(mus_strdup(text));               /* C-x C-d so anything is possible */
-      if (sp->amp_count != 0) return(env_name_completer(w, text, NULL));
-      if (use_sound_filename_completer(sp->filing)) return(sound_filename_completer(w, text, NULL));
-      if (sp->loading) return(filename_completer(w, text, NULL));   /* C-x C-l */
-
-      new_text = expression_completer(w, text, NULL);
-      if (get_completion_matches() == 0)
-	{
-	  int i, beg, parens, len;
-	  beg = 0;
-	  parens = 0;  	                                 /* filename would have to be a string in this context */
-	  len = mus_strlen(text);
-	  for (i = 0; i < len; i++)
-	    if (text[i] == '\"')
-	      {
-		beg = i + 1;
-		parens++;
-		break;
-	      }
-	  if ((beg > 0) && (parens & 1))                 /* i.e. there is a string and we're in it */
-	    {
-	      char *new_file;
-	      if (new_text) free(new_text);
-	      new_file = filename_completer(w, (char *)(text + beg), NULL);
-	      len = beg + 2 + mus_strlen(new_file);
-	      new_text = (char *)calloc(len, sizeof(char));
-	      strncpy(new_text, text, beg);
-	      strcat(new_text, new_file);
-	      if (new_file) free(new_file);
-	    }
-	}
-      return(new_text);
-    }
-  return(expression_completer(w, text, NULL));
-}
-
-
 static int find_indentation(char *str, int loc)
 {
   int line_beg = 0, open_paren = -1, parens, i;
@@ -676,6 +639,7 @@ char *complete_listener_text(char *old_text, int end, bool *try_completion, char
 {
   int len, i, k, spaces, text_pos = 0, cr_pos = 0;
   char *new_text = NULL, *file_text = NULL, *new_file = NULL;
+
   len = strlen(old_text);
   for (i = len - 1; i > 0; i--)
     {
@@ -697,6 +661,7 @@ char *complete_listener_text(char *old_text, int end, bool *try_completion, char
 	  (*try_completion) = false;
 	  return(NULL);
 	}
+
       if (old_text[i] == ';')
 	{
 	  /* this isn't quite right, but how much effort should we put in it? */
@@ -728,6 +693,7 @@ char *complete_listener_text(char *old_text, int end, bool *try_completion, char
 	  (*try_completion) = false;
 	  return(NULL);
 	}
+
       if (old_text[i] == '\"')
 	{
 	  file_text = mus_strdup((char *)(old_text + i + 1));
@@ -739,12 +705,13 @@ char *complete_listener_text(char *old_text, int end, bool *try_completion, char
 	      new_text = (char *)calloc(len, sizeof(char));
 	      strncpy(new_text, old_text, i + 1);
 	      strcat(new_text, new_file);
-	      if (new_file) free(new_file);
+	      free(new_file);
 	    }
 	  break;
 	}
       if (isspace((int)(old_text[i]))) break;
     }
+
   if (new_text == NULL) new_text = expression_completer(NULL_WIDGET, old_text, NULL);
   (*try_completion) = true;
   (*to_file_text) = file_text;
@@ -757,20 +724,24 @@ char *list_completer(widget_t w, const char *text, void *data)
   list_completer_info *info = (list_completer_info *)data;
   int i, j = 0, len, matches = 0, current_match = -1;
   char *trimmed_text;
+
   set_completion_matches(0);
   /* check for null text */
   len = mus_strlen(text);
   if (len == 0) return(mus_strdup(text));
+
   /* strip away leading and trailing white space */
   trimmed_text = (char *)calloc(len + 1, sizeof(char));
   for (i = 0; i < len; i++)
-    if (!(isspace(text[i])))
+    if (!(isspace((int)text[i])))
       trimmed_text[j++] = text[i];
+
   if (j == 0)
     {
       free(trimmed_text);
       return(mus_strdup(text));
     }
+
   /* check for match(es) against values */
   if (info->exact_match)
     {
@@ -796,5 +767,6 @@ char *list_completer(widget_t w, const char *text, void *data)
   if (matches != 1)
     return(mus_strdup(text));
   set_completion_matches(1);
+
   return(mus_strdup(info->values[current_match]));
 }
