@@ -7,10 +7,17 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
   if (!cip)
     {
       cp = (chan_info *)calloc(1, sizeof(chan_info)); 
-      cp->cgx = (chan_context *)calloc(1, sizeof(chan_context));
-      cp->cgx->ax = (axis_context *)calloc(1, sizeof(axis_context));
-#if USE_GTK && USE_CAIRO
-      cp->cgx->progress_pct = -1.0;
+      cp->ax = (graphics_context *)calloc(1, sizeof(graphics_context));
+
+      switch (chan % 4)
+	{
+	case 0: cp->combined_data_color = ss->black;      break;
+	case 1: cp->combined_data_color = ss->red;        break;
+	case 2: cp->combined_data_color = ss->green;      break;
+	case 3: cp->combined_data_color = ss->blue;       break;
+	}
+#if USE_GTK
+      cp->progress_pct = -1.0;
 #endif
       cp->last_sonogram = NULL;
       cp->last_wavogram = NULL;
@@ -20,28 +27,23 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
       cp->gl_fft_list = NO_LIST;
       cp->gl_wavo_list = NO_LIST;
 #endif
-      cp->edit_hook = XEN_FALSE;
+      cp->edit_hook = Xen_false;
       cp->edit_hook_loc = NOT_A_GC_LOC;
-      cp->after_edit_hook = XEN_FALSE;
+      cp->after_edit_hook = Xen_false;
       cp->after_edit_hook_loc = NOT_A_GC_LOC;
-      cp->undo_hook = XEN_FALSE;
+      cp->undo_hook = Xen_false;
       cp->undo_hook_loc = NOT_A_GC_LOC;
-      cp->properties = XEN_FALSE; /* will be a vector of 1 element if it's ever used */
+      cp->properties = Xen_false; /* will be a vector of 1 element if it's ever used */
       cp->properties_loc = NOT_A_GC_LOC;
       cp->active = CHANNEL_INACTIVE;
     }
   else cp = cip;
-  cp->tcgx = NULL;
   cp->chan = chan;
   cp->sound = sound;
   cp->sound_ctr = NOT_A_SOUND;
   cp->edit_ctr = -1;
   cp->sound_size = 0;
-  cp->ptrees = NULL;
-  cp->ptree_size = 0;
-  cp->ptree_ctr = -1;
   cp->edit_size = 0;
-  cp->tracking = false;
   cp->cursor_on = false;
   cp->cursor_visible = false;
   cp->fft_cursor_visible = false;
@@ -51,7 +53,7 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
   cp->cursor_style = cursor_style(ss);
   cp->tracking_cursor_style = tracking_cursor_style(ss);
   cp->cursor_size = cursor_size(ss);
-  cp->cursor_proc = XEN_UNDEFINED;
+  cp->cursor_proc = Xen_undefined;
   cp->cursor_proc_loc = NOT_A_GC_LOC;
   cp->squelch_update = false;
   cp->show_y_zero = show_y_zero(ss);
@@ -63,7 +65,7 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
   cp->max_transform_peaks = max_transform_peaks(ss);
   cp->show_transform_peaks = show_transform_peaks(ss);
   cp->zero_pad = zero_pad(ss);
-  cp->verbose_cursor = verbose_cursor(ss);
+  cp->with_verbose_cursor = with_verbose_cursor(ss);
   cp->fft_log_frequency = fft_log_frequency(ss);
   cp->fft_log_magnitude = fft_log_magnitude(ss);
   cp->fft_with_phases = fft_with_phases(ss);
@@ -98,8 +100,8 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
   cp->beats_per_minute = beats_per_minute(ss);
   cp->beats_per_measure = beats_per_measure(ss);
   cp->show_axes = show_axes(ss);
-  cp->graph_time_p = true; /* the default state (button is set when we start) */
-  cp->graph_transform_p = false;
+  cp->graph_time_on = true; /* the default state (button is set when we start) */
+  cp->graph_transform_on = false;
   cp->printing = NOT_PRINTING;
   cp->waiting_to_make_graph = false;
   cp->new_peaks = false;
@@ -111,7 +113,6 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
   cp->cy = 0;
   cp->fft_cx = 0;
   cp->selection_transform_size = 0;
-  cp->last_search_result = SEARCH_OK;
   if (cp->last_sonogram) 
     {
       free(cp->last_sonogram); 
@@ -136,23 +137,21 @@ static chan_info *free_chan_info(chan_info *cp)
   cp->active = CHANNEL_INACTIVE;
   /* need an indication right away that this channel is being deleted -- during free_snd_info (close-sound),
    *   an error may occur (an edit list temp file might have vanished for example), and normally Snd
-   *   attempts to post an error message in the sound's minibuffer.  To force this out, we have to
+   *   attempts to post an error message in the sound's status area.  To force this out, we have to
    *   call XmUpdate or equivalent, which can cause all the sound's channels to attempt to redisplay;
    *   since the one causing the error is half-deallocated, trouble can ensue.  So both the channel
    *   and the sound have "active" flags that are true only when everything is ship-shape.
    */
   chan_info_cleanup(cp);
   cp->squelch_update = true;
-  cp->tcgx = NULL;
   cp->axis = free_axis_info(cp->axis);
   if (cp->fft) cp->fft = free_fft_info(cp->fft);
   cp_free_fft_state(cp);
-  cp->graph_transform_p = false;
+  cp->graph_transform_on = false;
   cp->printing = NOT_PRINTING;
-  cp->graph_time_p = true;
+  cp->graph_time_on = true;
   if (cp->edits) free_edit_list(cp);
   if (cp->sounds) free_sound_list(cp);
-  if (cp->ptrees) free_ptree_list(cp);
   free_channel_mixes(cp);
   cp->sound = NULL;  /* a backpointer */
   cp->cursor_on = false;
@@ -166,14 +165,14 @@ static chan_info *free_chan_info(chan_info *cp)
       free(cp->amp_control);
       cp->amp_control = NULL;
     }
-  if (XEN_PROCEDURE_P(cp->cursor_proc))
+  if (Xen_is_procedure(cp->cursor_proc))
     {
       snd_unprotect_at(cp->cursor_proc_loc);
-      cp->cursor_proc = XEN_UNDEFINED;
+      cp->cursor_proc = Xen_undefined;
       cp->cursor_proc_loc = NOT_A_GC_LOC;
     }
-  if (XEN_VECTOR_P(cp->properties)) /* using vector as node for GC */
-    XEN_VECTOR_SET(cp->properties, 0, XEN_EMPTY_LIST);
+  if (Xen_is_vector(cp->properties)) /* using vector as node for GC */
+    Xen_vector_set(cp->properties, 0, Xen_empty_list);
   cp->waiting_to_make_graph = false;
   if (cp->sonogram_data) free_sono_info(cp);
   if (cp->temp_sonogram) 
@@ -200,7 +199,7 @@ static chan_info *free_chan_info(chan_info *cp)
       free_lisp_info(cp);
       cp->lisp_info = NULL;
     }
-  cp->graph_lisp_p = false;
+  cp->graph_lisp_on = false;
   cp->selection_transform_size = 0;
 
   if (cp->as_one_edit_positions)
@@ -210,25 +209,25 @@ static chan_info *free_chan_info(chan_info *cp)
       cp->as_one_edit_positions_size = 0;
     }
 
-  if (XEN_HOOK_P(cp->edit_hook))
+  if (Xen_is_hook(cp->edit_hook))
     {
-      XEN_CLEAR_HOOK(cp->edit_hook);
+      Xen_clear_hook_list(cp->edit_hook);
       snd_unprotect_at(cp->edit_hook_loc);
-      cp->edit_hook = XEN_FALSE;
+      cp->edit_hook = Xen_false;
       cp->edit_hook_loc = NOT_A_GC_LOC;
     }
-  if (XEN_HOOK_P(cp->after_edit_hook))
+  if (Xen_is_hook(cp->after_edit_hook))
     {
-      XEN_CLEAR_HOOK(cp->after_edit_hook);
+      Xen_clear_hook_list(cp->after_edit_hook);
       snd_unprotect_at(cp->after_edit_hook_loc);
-      cp->after_edit_hook = XEN_FALSE;
+      cp->after_edit_hook = Xen_false;
       cp->after_edit_hook_loc = NOT_A_GC_LOC;
     }
-  if (XEN_HOOK_P(cp->undo_hook))
+  if (Xen_is_hook(cp->undo_hook))
     {
-      XEN_CLEAR_HOOK(cp->undo_hook);
+      Xen_clear_hook_list(cp->undo_hook);
       snd_unprotect_at(cp->undo_hook_loc);
-      cp->undo_hook = XEN_FALSE;
+      cp->undo_hook = Xen_false;
       cp->undo_hook_loc = NOT_A_GC_LOC;
     }
   if (cp->inset_graph)
@@ -244,18 +243,10 @@ snd_info *make_basic_snd_info(int chans)
   sp = (snd_info *)calloc(1, sizeof(snd_info));
   sp->chans = (chan_info **)calloc(chans, sizeof(chan_info *));
   sp->allocated_chans = chans;
-  sp->properties = XEN_FALSE; /* will be a vector of 1 element if it's ever used */
+  sp->properties = Xen_false; /* will be a vector of 1 element if it's ever used */
   sp->properties_loc = NOT_A_GC_LOC;
-#if HAVE_PTHREADS
-  /* multichannel cases can all try to change the "*" in the file name */
-  sp->starred_name_lock = (mus_lock_t *)malloc(sizeof(mus_lock_t));
-  MUS_LOCK_INIT(sp->starred_name_lock);
-  /* similarly the stop and bomb icons */
-  sp->stop_sign_lock = (mus_lock_t *)malloc(sizeof(mus_lock_t));
-  MUS_LOCK_INIT(sp->stop_sign_lock);
-  /* edit history list of multichannel file (after explicit open) */
-  sp->edit_history_lock = (mus_lock_t *)malloc(sizeof(mus_lock_t));
-  MUS_LOCK_INIT(sp->edit_history_lock);
+#if USE_NO_GUI
+  sp->snd_widgets = false; /* it's a bool if no gui */
 #endif
   return(sp);
 }
@@ -268,7 +259,7 @@ void initialize_control_panel(snd_info *sp)
   sp->expand_control_max = expand_control_max(ss);
   sp->last_expand_control = 0.0;
   sp->saved_expand_control = 0.0;
-  sp->expand_control_p = DEFAULT_EXPAND_CONTROL_P;
+  sp->expand_control_on = DEFAULT_EXPAND_CONTROL_ON;
   sp->amp_control = DEFAULT_AMP_CONTROL;
   sp->amp_control_min = amp_control_min(ss);
   sp->amp_control_max = amp_control_max(ss);
@@ -280,15 +271,15 @@ void initialize_control_panel(snd_info *sp)
   sp->last_speed_control = 1.0;
   sp->saved_speed_control = 1.0;
   if (DEFAULT_SPEED_CONTROL > 0.0) sp->speed_control_direction = 1; else sp->speed_control_direction = -1;
-  sp->contrast_control_p = DEFAULT_CONTRAST_CONTROL_P;
+  sp->contrast_control_on = DEFAULT_CONTRAST_CONTROL_ON;
   sp->contrast_control = DEFAULT_CONTRAST_CONTROL;
   sp->contrast_control_min = contrast_control_min(ss);
   sp->contrast_control_max = contrast_control_max(ss);
   sp->contrast_control_amp = contrast_control_amp(ss);
   sp->last_contrast_control = contrast_control_min(ss);
   sp->saved_contrast_control = contrast_control_min(ss);
-  sp->reverb_control_p = DEFAULT_REVERB_CONTROL_P;
-  sp->filter_control_p = DEFAULT_FILTER_CONTROL_P;
+  sp->reverb_control_on = DEFAULT_REVERB_CONTROL_ON;
+  sp->filter_control_on = DEFAULT_FILTER_CONTROL_ON;
   sp->expand_control_length = expand_control_length(ss);
   sp->expand_control_ramp = expand_control_ramp(ss);
   sp->expand_control_hop = expand_control_hop(ss);
@@ -314,7 +305,7 @@ void initialize_control_panel(snd_info *sp)
   sp->filter_control_in_dB = filter_control_in_dB(ss);
   sp->filter_control_in_hz = filter_control_in_hz(ss);
   if (sp->filter_control_in_hz)
-    sp->filter_control_xmax = (mus_float_t)(SND_SRATE(sp) / 2);
+    sp->filter_control_xmax = (mus_float_t)(snd_srate(sp) / 2);
   else sp->filter_control_xmax = 1.0;
   sp->filter_control_changed = false;
   sp->saved_controls = NULL;
@@ -331,7 +322,6 @@ snd_info *make_snd_info(snd_info *sip, const char *filename, file_info *hdr, int
   if (!sip)
     {
       sp = make_basic_snd_info(chans);
-      sp->sgx = (snd_context *)calloc(1, sizeof(snd_context));
     }
   else 
     {
@@ -345,8 +335,6 @@ snd_info *make_snd_info(snd_info *sip, const char *filename, file_info *hdr, int
     }
   sp->user_read_only = read_only;  /* need to be sure this is set before any hooks run */
   sp->bomb_in_progress = false;
-  sp->watchers = NULL;
-  sp->watchers_size = 0;
   sp->index = snd_slot;
   sp->nchans = chans;
   sp->hdr = hdr;
@@ -356,7 +344,6 @@ snd_info *make_snd_info(snd_info *sip, const char *filename, file_info *hdr, int
   sp->sync = DEFAULT_SYNC;
   sp->previous_sync = sp->sync;
   initialize_control_panel(sp);
-  sp->search_count = 0;
   sp->selectpos = -1;
 
   if (chans > 1)
@@ -370,24 +357,13 @@ snd_info *make_snd_info(snd_info *sip, const char *filename, file_info *hdr, int
     }
   else sp->channel_style = CHANNELS_SEPARATE;
 
-  sp->loading = false;
-  sp->marking = 0;
-  sp->filing = NOT_FILING;
-  sp->minibuffer_on = MINI_OFF;
   sp->selected_channel = NO_SELECTION;
   sp->playing = 0;
   sp->applying = false;
-  sp->search_expr = NULL;
   sp->lacp = NULL;
-  sp->search_tree = NULL;
-  sp->search_proc = XEN_UNDEFINED;
-  sp->search_proc_loc = NOT_A_GC_LOC;
-  sp->prompt_callback = XEN_UNDEFINED;
-  sp->prompt_callback_loc = NOT_A_GC_LOC;
   sp->delete_me = NULL;
   sp->name_string = NULL;
   sp->active = true;
-  sp->with_tracking_cursor = with_tracking_cursor(ss);
   return(sp);
 }
 
@@ -395,43 +371,32 @@ snd_info *make_snd_info(snd_info *sip, const char *filename, file_info *hdr, int
 void free_snd_info(snd_info *sp)
 {
   int i;
-  if (sp->watchers)
+
+#if (!USE_NO_GUI)
+  env_editor *edp;
+
+  /* make sure trough colors are ok upon reuse */
+  if (sp->reverb_control_on != DEFAULT_REVERB_CONTROL_ON)
+    toggle_reverb_button(sp, DEFAULT_REVERB_CONTROL_ON);
+  if (sp->expand_control_on != DEFAULT_EXPAND_CONTROL_ON)
+    toggle_expand_button(sp, DEFAULT_EXPAND_CONTROL_ON);
+  if (sp->contrast_control_on != DEFAULT_CONTRAST_CONTROL_ON)
+    toggle_contrast_button(sp, DEFAULT_CONTRAST_CONTROL_ON);
+
+  edp = sp->flt;
+  if (edp)
     {
-      int i;
-      call_sp_watchers(sp, SP_ANY_WATCHER, SP_IS_CLOSING);
-      for (i = 0; i < sp->watchers_size; i++)
-	if (sp->watchers[i])
-	  free(sp->watchers[i]); /* normally watcher will do this, I assume */
-      free(sp->watchers);
-      sp->watchers = NULL;
-      sp->watchers_size = 0;
-    }
-  if (sp->sgx)
-    {
-      /* make sure trough colors are ok upon reuse */
-      if (sp->reverb_control_p != DEFAULT_REVERB_CONTROL_P)
-	toggle_reverb_button(sp, DEFAULT_REVERB_CONTROL_P);
-      if (sp->expand_control_p != DEFAULT_EXPAND_CONTROL_P)
-	toggle_expand_button(sp, DEFAULT_EXPAND_CONTROL_P);
-      if (sp->contrast_control_p != DEFAULT_CONTRAST_CONTROL_P)
-	toggle_contrast_button(sp, DEFAULT_CONTRAST_CONTROL_P);
+      edp->edited = false;
+      edp->env_dragged = false;
+      edp->env_pos = 0;
+      edp->click_to_delete = false;
     }
+  set_filter_text(sp, "");
+#endif
+
   /* leave most for reuse as in free_chan_info */
   sp->active = false;
   sp->selectpos = -1;
-  if (sp->sgx)
-    {
-      env_editor *edp;
-      edp = sp->sgx->flt;
-      if (edp)
-	{
-	  edp->edited = false;
-	  edp->env_dragged = false;
-	  edp->env_pos = 0;
-	  edp->click_to_delete = false;
-	}
-      set_filter_text(sp, "");
-    }
   sp->sync = 0;
   snd_info_cleanup(sp);
   sp->previous_sync = sp->sync;
@@ -439,29 +404,16 @@ void free_snd_info(snd_info *sp)
     if (sp->chans[i]) 
       sp->chans[i] = free_chan_info(sp->chans[i]);
   sp->inuse = SOUND_IDLE;
-  sp->playing_mark = NULL;
   sp->playing = 0;
-  sp->search_count = 0;
-  sp->loading = false;
   sp->bomb_in_progress = false;
-  sp->marking = 0;
-  sp->filing = NOT_FILING;
   sp->applying = false;
   sp->channel_style = CHANNELS_SEPARATE;
   sp->user_read_only = FILE_READ_WRITE;
   sp->file_read_only = FILE_READ_WRITE;
   sp->need_update = false;
   sp->file_unreadable = false;
-  sp->minibuffer_on = MINI_OFF;
-  clear_sound_search_procedure(sp, true);
-  if (XEN_PROCEDURE_P(sp->prompt_callback))
-    {
-      snd_unprotect_at(sp->prompt_callback_loc);
-      sp->prompt_callback_loc = NOT_A_GC_LOC;
-    }
-  sp->prompt_callback = XEN_UNDEFINED;
-  if (XEN_VECTOR_P(sp->properties)) /* using vector as node for GC */
-    XEN_VECTOR_SET(sp->properties, 0, XEN_EMPTY_LIST);
+  if (Xen_is_vector(sp->properties)) /* using vector as node for GC */
+    Xen_vector_set(sp->properties, 0, Xen_empty_list);
   sp->selected_channel = NO_SELECTION;
   sp->short_filename = NULL;                      /* was a pointer into filename */
   if (sp->filename) free(sp->filename);
@@ -474,31 +426,26 @@ void free_snd_info(snd_info *sp)
   sp->lacp = NULL;
   sp->hdr = free_file_info(sp->hdr);
   if (sp->edited_region) clear_region_backpointer(sp);
-  clear_mini_strings(sp);
-  clear_filter_strings(sp);
   clear_players();
   reflect_mix_change(ANY_MIX_ID);
+
+  if (Xen_hook_has_list(ss->effects_hook))
+    run_hook(ss->effects_hook, Xen_empty_list, S_effects_hook);
 }
 
 
 snd_info *completely_free_snd_info(snd_info *sp)
 {
   int i;
-  chan_info *cp;
+
   free_snd_info(sp);
-  if (sp->sgx) free(sp->sgx);
   for (i = 0; i < sp->allocated_chans; i++) 
     {
+      chan_info *cp;
       cp = sp->chans[i];
       if (cp)
 	{
-	  if (cp->cgx) 
-	    {
-	      if (cp->cgx->ax) 
-		free(cp->cgx->ax);
-	      free(cp->cgx);
-	    }
-	  if (XEN_VECTOR_P(cp->properties))
+	  if (Xen_is_vector(cp->properties))
 	    {
 	      snd_unprotect_at(cp->properties_loc);
 	      cp->properties_loc = NOT_A_GC_LOC;
@@ -512,7 +459,7 @@ snd_info *completely_free_snd_info(snd_info *sp)
 	}
     }
   free(sp->chans);
-  if (XEN_VECTOR_P(sp->properties))
+  if (Xen_is_vector(sp->properties))
     {
       snd_unprotect_at(sp->properties_loc);
       sp->properties_loc = NOT_A_GC_LOC;
@@ -524,9 +471,10 @@ snd_info *completely_free_snd_info(snd_info *sp)
 
 void for_each_chan_with_int(void (*func)(chan_info *ncp, int val), int value)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -540,9 +488,10 @@ void for_each_chan_with_int(void (*func)(chan_info *ncp, int val), int value)
 
 void for_each_chan_with_mus_long_t(void (*func)(chan_info *ncp, mus_long_t val), mus_long_t value)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -556,9 +505,10 @@ void for_each_chan_with_mus_long_t(void (*func)(chan_info *ncp, mus_long_t val),
 
 void for_each_chan_with_bool(void (*func)(chan_info *ncp, bool val), bool value)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -572,9 +522,10 @@ void for_each_chan_with_bool(void (*func)(chan_info *ncp, bool val), bool value)
 
 void for_each_chan_with_float(void (*func)(chan_info *ncp, mus_float_t val), mus_float_t value)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -588,9 +539,10 @@ void for_each_chan_with_float(void (*func)(chan_info *ncp, mus_float_t val), mus
 
 void for_each_chan(void (*func)(chan_info *ncp))
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -604,9 +556,10 @@ void for_each_chan(void (*func)(chan_info *ncp))
 
 void for_each_normal_chan_with_void(void (*func)(chan_info *ncp, void *ptr), void *userptr)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -620,9 +573,10 @@ void for_each_normal_chan_with_void(void (*func)(chan_info *ncp, void *ptr), voi
 
 void for_each_normal_chan_with_int(void (*func)(chan_info *ncp, int val), int value)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -636,9 +590,10 @@ void for_each_normal_chan_with_int(void (*func)(chan_info *ncp, int val), int va
 
 void for_each_normal_chan_with_refint(void (*func)(chan_info *ncp, int *val), int *value)
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -652,9 +607,10 @@ void for_each_normal_chan_with_refint(void (*func)(chan_info *ncp, int *val), in
 
 void for_each_normal_chan(void (*func)(chan_info *ncp))
 {
-  int i, j;
+  int i;
   for (i = 0; i < ss->max_sounds; i++)
     {
+      int j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -883,17 +839,17 @@ chan_info *selected_channel(void)
 }
 
 
-static XEN select_sound_hook;
-static XEN select_channel_hook;
+static Xen select_sound_hook;
+static Xen select_channel_hook;
 static int current_selectpos = 0;
 
 static void select_sound(snd_info *sp)
 {
   if ((sp == NULL) || (sp->inuse != SOUND_NORMAL)) return;
 
-  if (XEN_HOOKED(select_sound_hook))
+  if (Xen_hook_has_list(select_sound_hook))
     run_hook(select_sound_hook,
-	     XEN_LIST_1(C_INT_TO_XEN_SOUND(sp->index)),
+	     Xen_list_1(C_int_to_Xen_sound(sp->index)),
 	     S_select_sound_hook);
 
   if (ss->selected_sound != sp->index)
@@ -901,9 +857,12 @@ static void select_sound(snd_info *sp)
       reflect_sound_selection(sp);
       ss->selected_sound = sp->index;
       new_active_channel_alert();
+      reflect_save_as_sound_selection(sp->short_filename);
     }
   sp->selectpos = current_selectpos++;
-  run_watchers();
+
+  if (Xen_hook_has_list(ss->effects_hook))
+    run_hook(ss->effects_hook, Xen_empty_list, S_effects_hook);
 }
 
 
@@ -912,7 +871,7 @@ chan_info *color_selected_channel(snd_info *sp)
   chan_info *ncp;
   ncp = sp->chans[sp->selected_channel];
   recolor_graph(ncp, true);
-  (ncp->cgx)->selected = true;
+  ncp->selected = true;
   update_graph(ncp); /* update any indication of change in selected channel (channel id for example) */
   return(ncp);
 }
@@ -920,25 +879,26 @@ chan_info *color_selected_channel(snd_info *sp)
 
 void select_channel(snd_info *sp, int chan)
 {
-  chan_info *cp, *ncp;
+  chan_info *cp;
 
   if ((sp == NULL) || (sp->inuse != SOUND_NORMAL)) return;
   cp = selected_channel();
   if (cp != sp->chans[chan])
     {
+      chan_info *ncp;
       sp->selected_channel = chan;
       select_sound(sp);
       if (cp) 
 	{
 	  recolor_graph(cp, false);
-	  cp->cgx->selected = false;
+	  cp->selected = false;
 	  if (sp != cp->sound) cp->sound->selected_channel = NO_SELECTION;
 	  update_graph(cp);
 	}
-      if (XEN_HOOKED(select_channel_hook))
+      if (Xen_hook_has_list(select_channel_hook))
 	run_hook(select_channel_hook,
-		 XEN_LIST_2(C_INT_TO_XEN_SOUND(sp->index),
-			    C_TO_XEN_INT(chan)),
+		 Xen_list_2(C_int_to_Xen_sound(sp->index),
+			    C_int_to_Xen_integer(chan)),
 		 S_select_channel_hook);
       ncp = color_selected_channel(sp);
       goto_graph(ncp);
@@ -971,7 +931,7 @@ sync_info *free_sync_info(sync_info *si)
 }
 
 
-static int syncd_channels(int sync)
+int syncd_channels(int sync)
 {
   if (sync != 0)
     {
@@ -993,19 +953,20 @@ static int syncd_channels(int sync)
 
 sync_info *snd_sync(int sync)
 {
-  int i, j, k, chans;
+  int chans;
   snd_info *sp;
   chans = syncd_channels(sync);
   if (chans > 0)
     {
+      int i, j;
       sync_info *si;
       si = (sync_info *)calloc(1, sizeof(sync_info));
       si->begs = (mus_long_t *)calloc(chans, sizeof(mus_long_t));
       si->cps = (chan_info **)calloc(chans, sizeof(chan_info *));
       si->chans = chans;
-      j = 0;
-      for (i = 0; i < ss->max_sounds; i++)
+      for (i = 0, j = 0; i < ss->max_sounds; i++)
 	{
+	  int k;
 	  sp = ss->sounds[i];
 	  if ((sp) && 
 	      (sp->inuse == SOUND_NORMAL) && 
@@ -1065,74 +1026,6 @@ snd_info *find_sound(const char *name, int nth)
 }
 
 
-static char *display_maxamps(const char *filename, int chans)
-{
-  char *ampstr;
-  int i, len;
-  mus_sample_t *vals;
-  mus_long_t *times;
-  len = chans * 32;
-  ampstr = (char *)calloc(len, sizeof(char));
-  vals = (mus_sample_t *)calloc(chans, sizeof(mus_sample_t));
-  times = (mus_long_t *)calloc(chans, sizeof(mus_long_t));
-  mus_snprintf(ampstr, len, "%s", _("\nmax amp: "));
-  mus_sound_maxamps(filename, chans, vals, times);
-  for (i = 0; i < chans; i++)
-    {
-      ampstr = mus_strcat(ampstr, prettyf(MUS_SAMPLE_TO_DOUBLE(vals[i]), 3), &len);
-      ampstr = mus_strcat(ampstr, " ", &len);
-    }
-  free(vals);
-  free(times);
-  return(ampstr);
-}
-
-
-void display_info(snd_info *sp)
-{
-  #define INFO_BUFFER_SIZE 1024
-  if (sp)
-    {
-      file_info *hdr;
-      hdr = sp->hdr;
-      if (hdr)
-	{
-	  char *comment = NULL, *ampstr = NULL, *quoted_comment = NULL;
-	  char *buffer = NULL;
-	  comment = hdr->comment;
-	  while ((comment) && (*comment) && 
-		 (((*comment) == '\n') || 
-		  ((*comment) == '\t') || 
-		  ((*comment) == ' ') || 
-		  ((*comment) == '\xd')))
-	    comment++;
-	  if ((comment) && (*comment))
-	    quoted_comment = mus_format("\"%s\"", comment);
-	  if (mus_sound_maxamp_exists(sp->filename))
-	    ampstr = display_maxamps(sp->filename, sp->nchans);
-	  buffer = (char *)calloc(INFO_BUFFER_SIZE, sizeof(char));
-	  mus_snprintf(buffer, INFO_BUFFER_SIZE, 
-		       _("srate: %d\nchans: %d\nlength: %.3f (" MUS_LD " %s)\ntype: %s\nformat: %s\nwritten: %s%s%s%s\n"),
-		       hdr->srate,
-		       hdr->chans,
-		       (mus_float_t)((double)(hdr->samples) / (mus_float_t)(hdr->chans * hdr->srate)),
-		       (mus_long_t)((hdr->samples) / (hdr->chans)),
-		       (hdr->chans == 1) ? _("samples") : _("frames"),
-		       mus_header_type_name(hdr->type),
-		       mus_data_format_name(hdr->format),
-		       snd_strftime(STRFTIME_FORMAT, sp->write_date),
-		       (ampstr) ? ampstr : "",
-		       (quoted_comment) ? _("\ncomment: ") : "",
-		       (quoted_comment) ? quoted_comment : "");
-	  post_it(sp->short_filename, buffer);
-	  if (ampstr) free(ampstr);
-	  if (quoted_comment) free(quoted_comment);
-	  free(buffer);
-	}
-    }
-}
-
-
 void g_init_data(void)
 {
   #define H_select_sound_hook S_select_sound_hook " (snd): called whenever a sound is selected."
@@ -1140,7 +1033,7 @@ void g_init_data(void)
   #define H_select_channel_hook S_select_channel_hook " (snd chn): called whenever a channel is selected. \
 Its arguments are the sound index and the channel number."
 
-  select_sound_hook = XEN_DEFINE_HOOK(S_select_sound_hook, 1, H_select_sound_hook);       /* arg = sound index */
-  select_channel_hook = XEN_DEFINE_HOOK(S_select_channel_hook, 2, H_select_channel_hook); /* args = sound index, channel */
+  select_sound_hook =   Xen_define_hook(S_select_sound_hook,   "(make-hook 'snd)",      1, H_select_sound_hook);
+  select_channel_hook = Xen_define_hook(S_select_channel_hook, "(make-hook 'snd 'chn)", 2, H_select_channel_hook);
 }
 
