@@ -7,14 +7,15 @@
  */
 
 
-slist *transform_list = NULL, *size_list = NULL, *window_list = NULL, *wavelet_list = NULL;
+static slist *transform_list = NULL, *size_list = NULL, *window_list = NULL, *wavelet_list = NULL;
 static GtkWidget *transform_dialog = NULL; /* main dialog shell */
 static GtkWidget *outer_table, *db_button, *peaks_button, *logfreq_button, *sono_button, *spectro_button, *normal_fft_button, *phases_button;
-static GtkWidget *normalize_button, *selection_button, *window_beta_scale, *window_alpha_scale, *graph_drawer = NULL, *graph_frame = NULL;
-static GtkObject *beta_adj, *alpha_adj, *spectrum_start_adj, *spectrum_end_adj;
+static GtkWidget *normalize_button, *selection_button;
+static GtkWidget *alpha_label = NULL, *beta_label = NULL, *graph_drawer = NULL, *fft_window_label = NULL;
+static GtkAdjustment *beta_adj, *alpha_adj, *spectrum_start_adj, *spectrum_end_adj;
 static GtkWidget *spectrum_start_scale, *spectrum_end_scale;
 static GtkWidget *db_txt, *peaks_txt, *lf_txt;
-static gc_t *gc = NULL, *fgc = NULL;
+static gc_t *fft_gc = NULL, *fgc = NULL;
 static bool ignore_callbacks;
 
 #define NUM_TRANSFORM_SIZES 15
@@ -42,10 +43,10 @@ static axis_info *axis_ap = NULL;
 
 static void graph_redisplay(void)
 {
-  GdkDrawable *wn;
+  Drawable *wn;
   int ix0, iy0, ix1, iy1, i;
   mus_float_t xincr, x;
-  axis_context *ax;
+  graphics_context *ax;
 
   if (!(transform_dialog_is_active())) return;
   if (graph_drawer == NULL) return;
@@ -56,23 +57,28 @@ static void graph_redisplay(void)
   if (!axis_ap)
     {
       axis_ap = (axis_info *)calloc(1, sizeof(axis_info));
-      ax = (axis_context *)calloc(1, sizeof(axis_context));
+      ax = (graphics_context *)calloc(1, sizeof(graphics_context));
       axis_ap->ax = ax;
     }
   else ax = axis_ap->ax;
   ax->wn = WIDGET_TO_WINDOW(graph_drawer);
   ax->w = graph_drawer;
-  ax->gc = gc;
-  ax->current_font = AXIS_NUMBERS_FONT(ss);
-#if USE_CAIRO
-  ax->cr = gdk_cairo_create(ax->wn);
-#endif
+  ax->gc = fft_gc;
+  ax->current_font = TINY_FONT(ss);  /* we're right on the edge; this changes if user makes dialog bigger */
   axis_ap->xmin = 0.0;
   axis_ap->xmax = 1.0;
   axis_ap->x_ambit = 1.0;
   axis_ap->x0 = 0.0;
   axis_ap->x1 = 1.0;
 
+  ss->cr = make_cairo(ax->wn);
+  cairo_push_group(ss->cr);
+
+  /* erase previous */
+  cairo_set_source_rgba(ss->cr, ax->gc->bg_color->red, ax->gc->bg_color->green, ax->gc->bg_color->blue, ax->gc->bg_color->alpha);
+  cairo_rectangle(ss->cr, 0, 0, widget_width(graph_drawer), widget_height(graph_drawer));
+  cairo_fill(ss->cr);
+
   if (axis_ap->xlabel) free(axis_ap->xlabel);
   if (fft_beta_max(fft_window(ss)) != 1.0)
     axis_ap->xlabel = mus_format("(%d, beta: %.2f)", GRAPH_SIZE, fft_beta_max(fft_window(ss)) * fft_window_beta(ss));
@@ -100,10 +106,9 @@ static void graph_redisplay(void)
   axis_ap->height = widget_height(graph_drawer);
   axis_ap->graph_x0 = 0;
 
-  gdk_window_clear(ax->wn);
   make_axes_1(axis_ap, X_AXIS_IN_SECONDS, 1 /* "srate" */, SHOW_ALL_AXES, NOT_PRINTING, WITH_X_AXIS, NO_GRID, WITH_LINEAR_AXES, grid_density(ss));
 
-  ax->gc = gc;
+  ax->gc = fft_gc;
   ix1 = grf_x(0.0, axis_ap);
   iy1 = grf_y(graph_data[0], axis_ap);
   xincr = 1.0 / (mus_float_t)GRAPH_SIZE;
@@ -131,10 +136,11 @@ static void graph_redisplay(void)
       else iy1 = grf_y(graph_fftr[i], axis_ap);
       draw_line(ax, ix0, iy0, ix1, iy1);
     }
-#if USE_CAIRO
-  cairo_destroy(ax->cr);
-  ax->cr = NULL;
-#endif
+
+  cairo_pop_group_to_source(ss->cr);
+  cairo_paint(ss->cr);
+  free_cairo(ss->cr);
+  ss->cr = NULL;
 }
 
 
@@ -162,23 +168,14 @@ static void chans_transform_size(chan_info *cp, mus_long_t size)
 }
 
 
-/* gtk_frame_set_label actually creates a new label widget! */
-
-static void sg_frame_set_label(GtkFrame *frame, const char *text)
-{
-  gtk_button_set_label(GTK_BUTTON(gtk_frame_get_label_widget(frame)), text);
-}
-
-
 static void size_browse_callback(const char *name, int row, void *data)
 {
   for_each_chan(force_fft_clear);
   in_set_transform_size(transform_sizes[row]);
   for_each_chan_with_mus_long_t(chans_transform_size, transform_size(ss));
   for_each_chan(calculate_fft);
-  if (graph_frame) 
-    sg_frame_set_label(GTK_FRAME(graph_frame), 
-		       mus_fft_window_name(fft_window(ss)));
+  if (fft_window_label) 
+    gtk_label_set_text(GTK_LABEL(fft_window_label), mus_fft_window_name(fft_window(ss)));
 }
 
 
@@ -240,15 +237,36 @@ void set_wavelet_type(int val)
 
 /* ---------------- window choice ---------------- */
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+/* this won't work in gtk2 because it requires the alpha field (GdkRGBA not defined) */
+static color_t not_so_black;
+
+static void alpha_beta_alpha(mus_fft_window_t val)
+{
+#if (!GTK_CHECK_VERSION(3, 16, 0))
+  if (fft_window_beta_in_use(val))
+    gtk_widget_override_color(beta_label, GTK_STATE_FLAG_ACTIVE, (GdkRGBA *)(ss->black));
+  else gtk_widget_override_color(beta_label, GTK_STATE_FLAG_ACTIVE, (GdkRGBA *)not_so_black);
+ 
+  if (fft_window_alpha_in_use(val))
+    gtk_widget_override_color(alpha_label, GTK_STATE_FLAG_ACTIVE, (GdkRGBA *)(ss->black));
+  else gtk_widget_override_color(alpha_label, GTK_STATE_FLAG_ACTIVE, (GdkRGBA *)not_so_black);
+#endif
+}
+#endif
+
+
 static void window_browse_callback(const char *name, int row, void *data)
 {
   in_set_fft_window((mus_fft_window_t)row);
   for_each_chan(calculate_fft);
-  if (graph_frame) 
-    sg_frame_set_label(GTK_FRAME(graph_frame), 
-		       mus_fft_window_name(fft_window(ss)));
+  if (fft_window_label) 
+    gtk_label_set_text(GTK_LABEL(fft_window_label), mus_fft_window_name(fft_window(ss)));
   get_fft_window_data();
   graph_redisplay();
+#if GTK_CHECK_VERSION(3, 0, 0)
+  alpha_beta_alpha(fft_window(ss));
+#endif
 }
 
 
@@ -260,11 +278,13 @@ void set_fft_window(mus_fft_window_t val)
     {
       slist_select(window_list, (int)val);
       slist_moveto(window_list, (int)val);
-      if (graph_frame) 
-	sg_frame_set_label(GTK_FRAME(graph_frame),
-			   mus_fft_window_name(val));
+      if (fft_window_label) 
+	gtk_label_set_text(GTK_LABEL(fft_window_label), mus_fft_window_name(val));
       get_fft_window_data();
       graph_redisplay();
+#if GTK_CHECK_VERSION(3, 0, 0)
+      alpha_beta_alpha(val);
+#endif
     }
 }
   
@@ -298,14 +318,14 @@ void make_transform_type_list(void)
       num = max_transform_type();
       transform_names = (const char **)calloc(num, sizeof(char *));
       for (i = 0, j = 0; i < num; i++) 
-	if (transform_p(i))
+	if (is_transform(i))
 	  {
 	    set_transform_position(i, j);
 	    transform_names[j++] = transform_name(i);
 	  }
       if (!transform_list)
 	{
-	  transform_list = slist_new_with_title_and_table_data(_("type"), outer_table, transform_names, j, TABLE_ATTACH, 0, 3, 0, 3);
+	  transform_list = slist_new_with_title_and_table_data("type", outer_table, transform_names, j, TABLE_ATTACH, 0, 3, 0, 4);
 	  transform_list->select_callback = transform_browse_callback;
 	}
       else
@@ -322,7 +342,7 @@ void make_transform_type_list(void)
 
 void set_transform_type(int val)
 {
-  if (transform_p(val))
+  if (is_transform(val))
     {
       if (!(ss->graph_hook_active)) for_each_chan(force_fft_clear);
       in_set_transform_type(val);
@@ -403,7 +423,7 @@ static void map_show_transform_peaks(chan_info *cp, bool value)
 
 static void peaks_callback(GtkWidget *w, gpointer context)
 {
-  bool val = false;
+  bool val;
   val = (bool)(TOGGLE_BUTTON_ACTIVE(w));
   in_set_show_transform_peaks(val);
   for_each_chan_with_bool(map_show_transform_peaks, val);
@@ -784,7 +804,6 @@ static void spectrum_end_callback(GtkAdjustment *adj, gpointer context)
 
 
 
-
 /* ---------------- dialog buttons ---------------- */
 
 static gboolean graph_configure_callback(GtkWidget *w, GdkEventConfigure *ev, gpointer data)
@@ -809,7 +828,7 @@ static void dismiss_transform_callback(GtkWidget *w, gpointer context)
 
 static void color_orientation_transform_callback(GtkWidget *w, gpointer context)
 {
-  start_color_orientation_dialog(true);
+  make_color_orientation_dialog(true);
 }
 
 
@@ -828,53 +847,62 @@ static void help_transform_callback(GtkWidget *w, gpointer context)
 
 gboolean spin_button_focus_callback(GtkWidget *w, GdkEventCrossing *ev, gpointer unknown)
 {
-  widget_modify_base(w, GTK_STATE_NORMAL, ss->sgx->white);
+  widget_modify_base(w, GTK_STATE_NORMAL, ss->white);
   return(false);
 }
 
 
 gboolean spin_button_unfocus_callback(GtkWidget *w, GdkEventCrossing *ev, gpointer unknown)
 {
-  widget_modify_base(w, GTK_STATE_NORMAL, ss->sgx->basic_color);
+  widget_modify_base(w, GTK_STATE_NORMAL, ss->basic_color);
   return(false);
 }
 
+
 #define RIGHT_SEP_SIZE 10
 
 
-GtkWidget *fire_up_transform_dialog(bool managed)
+GtkWidget *make_transform_dialog(bool managed)
 {
   bool need_callback = false, need_moveto = true;
   if (!transform_dialog)
     {
       GtkWidget *buttons;
       GtkWidget *display_frame, *help_button, *dismiss_button;
-      GtkWidget *ab_box, *ab_frame, *ab_label, *color_button;
+      GtkWidget *color_button;
       GtkWidget *se_box, *se_frame, *se_label;
-      GtkWidget *alpha_box, *alpha_label, *beta_box, *beta_label;
       GtkWidget *end_box, *end_label, *start_box, *start_label;
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+      not_so_black = rgb_to_color(0.0, 0.0, 0.0);
+      not_so_black->alpha = 0.5;
+#endif
+
       transform_dialog = snd_gtk_dialog_new();
+#if GTK_CHECK_VERSION(3, 14, 0)
+      gtk_window_set_transient_for(GTK_WINDOW(transform_dialog), GTK_WINDOW(MAIN_SHELL(ss)));
+#endif
+      gtk_widget_set_name(transform_dialog, "fft_dialog");
       SG_SIGNAL_CONNECT(transform_dialog, "delete_event", delete_transform_dialog, NULL);
-      gtk_window_set_title(GTK_WINDOW(transform_dialog), _("Transform Options"));
+      gtk_window_set_title(GTK_WINDOW(transform_dialog), "Transform Options");
       sg_make_resizable(transform_dialog);
-      gtk_container_set_border_width(GTK_CONTAINER(transform_dialog), 4);
+      gtk_container_set_border_width(GTK_CONTAINER(transform_dialog), 6);
       gtk_widget_realize(transform_dialog);
       /* gtk_window_resize(GTK_WINDOW(transform_dialog), 400, 500); */
 
-      help_button = gtk_button_new_from_stock(GTK_STOCK_HELP);
-      gtk_widget_set_name(help_button, "help_button");
+      help_button = gtk_dialog_add_button(GTK_DIALOG(transform_dialog), "Help", GTK_RESPONSE_NONE);
+      dismiss_button = gtk_dialog_add_button(GTK_DIALOG(transform_dialog), "Go away", GTK_RESPONSE_NONE);
+      color_button = gtk_dialog_add_button(GTK_DIALOG(transform_dialog), "Color/Orientation", GTK_RESPONSE_NONE);
 
-      dismiss_button = gtk_button_new_from_stock(GTK_STOCK_QUIT);
-      gtk_widget_set_name(dismiss_button, "quit_button");
-      set_stock_button_label(dismiss_button, _("Go Away"));
+      gtk_widget_set_name(help_button, "dialog_button");
+      gtk_widget_set_name(dismiss_button, "dialog_button");
+      gtk_widget_set_name(color_button, "dialog_button");
 
-      color_button = sg_button_new_from_stock_with_label(_("Color/Orientation"), GTK_STOCK_SELECT_COLOR);
-      gtk_widget_set_name(color_button, "doit_button");
-
-      gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(transform_dialog)), color_button, false, true, 10);
-      gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(transform_dialog)), dismiss_button, false, true, 10);
-      gtk_box_pack_end(GTK_BOX(DIALOG_ACTION_AREA(transform_dialog)), help_button, false, true, 10);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(dismiss_button);
+      add_highlight_button_style(color_button);
+      add_highlight_button_style(help_button);
+#endif
 
       SG_SIGNAL_CONNECT(dismiss_button, "clicked", dismiss_transform_callback, NULL);
       SG_SIGNAL_CONNECT(color_button, "clicked", color_orientation_transform_callback, NULL);
@@ -884,10 +912,10 @@ GtkWidget *fire_up_transform_dialog(bool managed)
       gtk_widget_show(color_button);
       gtk_widget_show(help_button);
 
-      outer_table = gtk_table_new(8, 11, false); /* rows cols */
+      outer_table = gtk_table_new(16, 11, false); /* rows cols */
       gtk_container_add(GTK_CONTAINER(DIALOG_CONTENT_AREA(transform_dialog)), outer_table);
-      gtk_table_set_row_spacings(GTK_TABLE(outer_table), 8);
-      gtk_table_set_col_spacings(GTK_TABLE(outer_table), 12);
+      gtk_table_set_row_spacings(GTK_TABLE(outer_table), 16);
+      gtk_table_set_col_spacings(GTK_TABLE(outer_table), 16);
       gtk_table_set_homogeneous(GTK_TABLE(outer_table), true);
 
       /* now 8 boxes within the main box:
@@ -901,20 +929,23 @@ GtkWidget *fire_up_transform_dialog(bool managed)
       make_transform_type_list();
 
       /* SIZE */
-      size_list = slist_new_with_title_and_table_data(_("size"), outer_table, transform_size_names, NUM_TRANSFORM_SIZES, TABLE_ATTACH, 3, 6, 0, 3);
+      size_list = slist_new_with_title_and_table_data("size", outer_table, transform_size_names, NUM_TRANSFORM_SIZES, TABLE_ATTACH, 3, 6, 0, 6);
       size_list->select_callback = size_browse_callback;
 
       /* DISPLAY */
       display_frame = gtk_frame_new(NULL);
-      gtk_table_attach_defaults(GTK_TABLE(outer_table), display_frame, 6, 11, 0, 4);
-      gtk_frame_set_shadow_type(GTK_FRAME(display_frame), GTK_SHADOW_ETCHED_IN);
+      gtk_table_attach_defaults(GTK_TABLE(outer_table), display_frame, 6, 11, 0, 7);
+      gtk_frame_set_shadow_type(GTK_FRAME(display_frame), GTK_SHADOW_IN);
 
       {
 	GtkWidget *label, *vbb, *hb;
 	GtkWidget *pk_lab, *db_lab, *lf_lab;
-	GtkObject *pk_vals, *db_vals, *lf_vals;
+	GtkAdjustment *pk_vals, *db_vals, *lf_vals;
 	GtkWidget *vb, *sep1, *sep2;
 
+	#define DISPLAY_MARGIN 2
+	#define LEFT_MARGIN 8
+
 	vbb = gtk_vbox_new(false, 6);
 	gtk_container_add(GTK_CONTAINER(display_frame), vbb);
 	gtk_widget_show(vbb);
@@ -930,60 +961,78 @@ GtkWidget *fire_up_transform_dialog(bool managed)
 	buttons = gtk_vbox_new(false, 0);
 	gtk_container_add(GTK_CONTAINER(hb), buttons);
 	
-	normal_fft_button = gtk_radio_button_new_with_label(NULL, _("single transform"));
-	gtk_box_pack_start(GTK_BOX(buttons), normal_fft_button, false, false, 2);
+	normal_fft_button = gtk_radio_button_new_with_label(NULL, "single transform");
+	widget_set_margin_left(normal_fft_button, LEFT_MARGIN);
+	add_check_button_style(normal_fft_button);
+	gtk_box_pack_start(GTK_BOX(buttons), normal_fft_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(normal_fft_button);
 	SG_SIGNAL_CONNECT(normal_fft_button, "clicked", normal_fft_callback, NULL);
 	
-	sono_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(normal_fft_button)), _("sonogram"));
-	gtk_box_pack_start(GTK_BOX(buttons), sono_button, false, false, 2);
+	sono_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(normal_fft_button)), "sonogram");
+	widget_set_margin_left(sono_button, LEFT_MARGIN);
+	add_check_button_style(sono_button);
+	gtk_box_pack_start(GTK_BOX(buttons), sono_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(sono_button);
 	SG_SIGNAL_CONNECT(sono_button, "clicked", sonogram_callback, NULL);
 	
-	spectro_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(normal_fft_button)), _("spectrogram"));
-	gtk_box_pack_start(GTK_BOX(buttons), spectro_button, false, false, 2);
+	spectro_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(normal_fft_button)), "spectrogram");
+	widget_set_margin_left(spectro_button, LEFT_MARGIN);
+	add_check_button_style(spectro_button);
+	gtk_box_pack_start(GTK_BOX(buttons), spectro_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(spectro_button);
 	SG_SIGNAL_CONNECT(spectro_button, "clicked", spectrogram_callback, NULL);
 	
-	peaks_button = gtk_check_button_new_with_label(_("peaks"));
-	gtk_box_pack_start(GTK_BOX(buttons), peaks_button, false, false, 2);
+	peaks_button = gtk_check_button_new_with_label("peaks");
+	widget_set_margin_left(peaks_button, LEFT_MARGIN);
+	add_check_button_style(peaks_button);
+	gtk_box_pack_start(GTK_BOX(buttons), peaks_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(peaks_button);
 	SG_SIGNAL_CONNECT(peaks_button, "toggled", peaks_callback, NULL);
 	
-	db_button = gtk_check_button_new_with_label(_("dB"));
-	gtk_box_pack_start(GTK_BOX(buttons), db_button, false, false, 2);
+	db_button = gtk_check_button_new_with_label("dB");
+	widget_set_margin_left(db_button, LEFT_MARGIN);
+	add_check_button_style(db_button);
+	gtk_box_pack_start(GTK_BOX(buttons), db_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(db_button);
 	SG_SIGNAL_CONNECT(db_button, "toggled", db_callback, NULL);
 	
-	logfreq_button = gtk_check_button_new_with_label(_("log freq"));
-	gtk_box_pack_start(GTK_BOX(buttons), logfreq_button, false, false, 2);
+	logfreq_button = gtk_check_button_new_with_label("log freq");
+	widget_set_margin_left(logfreq_button, LEFT_MARGIN);
+	add_check_button_style(logfreq_button);
+	gtk_box_pack_start(GTK_BOX(buttons), logfreq_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(logfreq_button);
 	SG_SIGNAL_CONNECT(logfreq_button, "toggled", logfreq_callback, NULL);
 	
-	normalize_button = gtk_check_button_new_with_label(_("normalize"));
-	gtk_box_pack_start(GTK_BOX(buttons), normalize_button, false, false, 2);
+	normalize_button = gtk_check_button_new_with_label("normalize");
+	widget_set_margin_left(normalize_button, LEFT_MARGIN);
+	add_check_button_style(normalize_button);
+	gtk_box_pack_start(GTK_BOX(buttons), normalize_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(normalize_button);
 	SG_SIGNAL_CONNECT(normalize_button, "toggled", normalize_callback, NULL);
 	
-	selection_button = gtk_check_button_new_with_label(_("selection"));
-	gtk_box_pack_start(GTK_BOX(buttons), selection_button, false, false, 2);
+	selection_button = gtk_check_button_new_with_label("selection");
+	widget_set_margin_left(selection_button, LEFT_MARGIN);
+	add_check_button_style(selection_button);
+	gtk_box_pack_start(GTK_BOX(buttons), selection_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(selection_button);
 	SG_SIGNAL_CONNECT(selection_button, "toggled", selection_callback, NULL);
 
-	phases_button = gtk_check_button_new_with_label(_("with phases"));
-	gtk_box_pack_end(GTK_BOX(buttons), phases_button, false, false, 2);
+	phases_button = gtk_check_button_new_with_label("with phases");
+	widget_set_margin_left(phases_button, LEFT_MARGIN);
+	add_check_button_style(phases_button);
+	gtk_box_pack_end(GTK_BOX(buttons), phases_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(phases_button);
 	SG_SIGNAL_CONNECT(phases_button, "toggled", phases_callback, NULL);
 	
 	
 	vb = gtk_vbox_new(false, 0);
-	gtk_container_add(GTK_CONTAINER(hb), vb);	
+	gtk_container_add(GTK_CONTAINER(hb), vb);
 	
-	pk_lab = snd_gtk_highlight_label_new(_("max peaks:"));
+	pk_lab = snd_gtk_highlight_label_new("max peaks");
 	gtk_box_pack_start(GTK_BOX(vb), pk_lab, false, false, 0);
 	gtk_widget_show(pk_lab);
 	
-	pk_vals = gtk_adjustment_new(max_transform_peaks(ss), 2, 1000, 2, 10, 0);
+	pk_vals = (GtkAdjustment *)gtk_adjustment_new(max_transform_peaks(ss), 2, 1000, 2, 10, 0);
 	peaks_txt = gtk_spin_button_new(GTK_ADJUSTMENT(pk_vals), 0.0, 0);
 	gtk_box_pack_start(GTK_BOX(vb), peaks_txt, false, false, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(peaks_txt), true);
@@ -996,11 +1045,11 @@ GtkWidget *fire_up_transform_dialog(bool managed)
 	gtk_box_pack_start(GTK_BOX(vb), sep1, false, false, RIGHT_SEP_SIZE);
 	gtk_widget_show(sep1);
 
-	db_lab = snd_gtk_highlight_label_new(_("min dB:"));
+	db_lab = snd_gtk_highlight_label_new("min dB");
 	gtk_box_pack_start(GTK_BOX(vb), db_lab, false, false, 0);
 	gtk_widget_show(db_lab);
       
-	db_vals = gtk_adjustment_new((int)(-(min_dB(ss))), 2, 1000, 2, 10, 0); /* can't be negative!! */
+	db_vals = (GtkAdjustment *)gtk_adjustment_new((int)(-(min_dB(ss))), 2, 1000, 2, 10, 0); /* can't be negative!! */
 	db_txt = gtk_spin_button_new(GTK_ADJUSTMENT(db_vals), 0.0, 0);
 	gtk_box_pack_start(GTK_BOX(vb), db_txt, false, false, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(db_txt), true);
@@ -1013,11 +1062,11 @@ GtkWidget *fire_up_transform_dialog(bool managed)
 	gtk_box_pack_start(GTK_BOX(vb), sep2, false, false, RIGHT_SEP_SIZE);
 	gtk_widget_show(sep2);
 
-	lf_lab = snd_gtk_highlight_label_new(_("log freq start:"));
+	lf_lab = snd_gtk_highlight_label_new("log freq start");
 	gtk_box_pack_start(GTK_BOX(vb), lf_lab, false, false, 0);
 	gtk_widget_show(lf_lab);
       
-	lf_vals = gtk_adjustment_new((int)(log_freq_start(ss)), 1, 1000, 1, 10, 0);
+	lf_vals = (GtkAdjustment *)gtk_adjustment_new((int)(log_freq_start(ss)), 1, 1000, 1, 10, 0);
 	lf_txt = gtk_spin_button_new(GTK_ADJUSTMENT(lf_vals), 0.0, 0);
 	gtk_box_pack_start(GTK_BOX(vb), lf_txt, false, false, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(lf_txt), true);
@@ -1034,98 +1083,103 @@ GtkWidget *fire_up_transform_dialog(bool managed)
 
 
       /* WINDOWS */
-      window_list = slist_new_with_title_and_table_data(_("window"), outer_table, (const char **)mus_fft_window_names(), MUS_NUM_FFT_WINDOWS, TABLE_ATTACH, 0, 3, 3, 6);
+      window_list = slist_new_with_title_and_table_data("window", outer_table, (const char **)mus_fft_window_names(), MUS_NUM_FFT_WINDOWS, TABLE_ATTACH, 0, 3, 6, 12);
       window_list->select_callback = window_browse_callback;
 
       
       /* WAVELETS */
-      wavelet_list = slist_new_with_title_and_table_data(_("wavelet"), outer_table, (const char **)wavelet_names(), NUM_WAVELETS, TABLE_ATTACH, 3, 6, 3, 6);
+      wavelet_list = slist_new_with_title_and_table_data("wavelet", outer_table, (const char **)wavelet_names(), NUM_WAVELETS, TABLE_ATTACH, 3, 6, 6, 12);
       wavelet_list->select_callback = wavelet_browse_callback;
 
       
       /* ALPHA/BETA */
 
-      ab_frame = gtk_frame_new(NULL);
-      gtk_table_attach_defaults(GTK_TABLE(outer_table), ab_frame, 0, 6, 6, 7);
-      gtk_frame_set_shadow_type(GTK_FRAME(ab_frame), GTK_SHADOW_ETCHED_IN);
-
-      ab_box = gtk_vbox_new(false, 0);
-      gtk_container_add(GTK_CONTAINER(ab_frame), ab_box);	
-
-      ab_label = snd_gtk_highlight_label_new("window parameter");
-      gtk_box_pack_start(GTK_BOX(ab_box), ab_label, false, false, 0);
-      gtk_widget_show(ab_label);
-
-      
-      alpha_box = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(ab_box), alpha_box, false, false, 0);      
-      gtk_widget_show(alpha_box);
-
-      alpha_label = gtk_label_new("alpha: ");
-      gtk_box_pack_start(GTK_BOX(alpha_box), alpha_label, false, false, 0);
-      gtk_widget_show(alpha_label);      
-
-      alpha_adj = gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
-      window_alpha_scale = gtk_hscale_new(GTK_ADJUSTMENT(alpha_adj));
-      UNSET_CAN_FOCUS(window_alpha_scale);
-      gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(window_alpha_scale)), GTK_UPDATE_CONTINUOUS);
-      gtk_scale_set_digits(GTK_SCALE(window_alpha_scale), 2);
-      gtk_scale_set_value_pos(GTK_SCALE(window_alpha_scale), GTK_POS_LEFT);
-      gtk_scale_set_draw_value(GTK_SCALE(window_alpha_scale), true);
-      SG_SIGNAL_CONNECT(alpha_adj, "value_changed", alpha_callback, NULL);
-
-      gtk_box_pack_start(GTK_BOX(alpha_box), window_alpha_scale, true, true, 0);      
-
-
-      beta_box = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(ab_box), beta_box, false, false, 0);      
-      gtk_widget_show(beta_box);
-
-      beta_label = gtk_label_new("beta:  ");
-      gtk_box_pack_start(GTK_BOX(beta_box), beta_label, false, false, 0);
-      gtk_widget_show(beta_label);      
-
-      beta_adj = gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
-      window_beta_scale = gtk_hscale_new(GTK_ADJUSTMENT(beta_adj));
-      UNSET_CAN_FOCUS(window_beta_scale);
-      gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(window_beta_scale)), GTK_UPDATE_CONTINUOUS);
-      gtk_scale_set_digits(GTK_SCALE(window_beta_scale), 2);
-      gtk_scale_set_value_pos(GTK_SCALE(window_beta_scale), GTK_POS_LEFT);
-      gtk_scale_set_draw_value(GTK_SCALE(window_beta_scale), true);
-      SG_SIGNAL_CONNECT(beta_adj, "value_changed", beta_callback, NULL);
-
-      gtk_box_pack_start(GTK_BOX(beta_box), window_beta_scale, true, true, 0);      
-
-
-      gtk_widget_show(window_alpha_scale);
-      gtk_widget_show(window_beta_scale);
-      gtk_widget_show(ab_box);
-      gtk_widget_show(ab_frame);
+      {
+	GtkWidget *alpha_box, *beta_box;
+	GtkWidget *alpha_scale, *beta_scale, *ab_box, *ab_frame, *ab_label;
+	ab_frame = gtk_frame_new(NULL);
+	gtk_table_attach_defaults(GTK_TABLE(outer_table), ab_frame, 0, 6, 12, 14);
+	gtk_frame_set_shadow_type(GTK_FRAME(ab_frame), GTK_SHADOW_IN);
+	
+	ab_box = gtk_vbox_new(false, 2);
+	gtk_container_add(GTK_CONTAINER(ab_frame), ab_box);	
+	
+	ab_label = snd_gtk_highlight_label_new("window parameter");
+	gtk_box_pack_start(GTK_BOX(ab_box), ab_label, false, false, 1);
+	gtk_widget_show(ab_label);
+	
+	
+	alpha_box = gtk_hbox_new(false, 0);
+	gtk_box_pack_start(GTK_BOX(ab_box), alpha_box, false, false, 1);      
+	gtk_widget_show(alpha_box);
+	
+	alpha_label = gtk_label_new("alpha: ");
+	gtk_box_pack_start(GTK_BOX(alpha_box), alpha_label, false, false, 8);
+	gtk_widget_show(alpha_label);      
+	
+	alpha_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
+	alpha_scale = gtk_hscale_new(GTK_ADJUSTMENT(alpha_adj));
+	UNSET_CAN_FOCUS(alpha_scale);
+	gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(alpha_scale)), GTK_UPDATE_CONTINUOUS);
+	gtk_scale_set_digits(GTK_SCALE(alpha_scale), 2);
+	gtk_scale_set_value_pos(GTK_SCALE(alpha_scale), GTK_POS_LEFT);
+	gtk_scale_set_draw_value(GTK_SCALE(alpha_scale), true);
+	SG_SIGNAL_CONNECT(alpha_adj, "value_changed", alpha_callback, NULL);
+	SG_SIGNAL_CONNECT(alpha_scale, "format-value", scale_double_format_callback, NULL);
+	
+	gtk_box_pack_start(GTK_BOX(alpha_box), alpha_scale, true, true, 1);      
+	
+	
+	beta_box = gtk_hbox_new(false, 0);
+	gtk_box_pack_start(GTK_BOX(ab_box), beta_box, false, false, 1);      
+	gtk_widget_show(beta_box);
+	
 
+	beta_label = gtk_label_new("beta:  ");
+	gtk_box_pack_start(GTK_BOX(beta_box), beta_label, false, false, 8);
+	gtk_widget_show(beta_label);      
+	
+	beta_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
+	beta_scale = gtk_hscale_new(GTK_ADJUSTMENT(beta_adj));
+	UNSET_CAN_FOCUS(beta_scale);
+	gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(beta_scale)), GTK_UPDATE_CONTINUOUS);
+	gtk_scale_set_digits(GTK_SCALE(beta_scale), 2);
+	gtk_scale_set_value_pos(GTK_SCALE(beta_scale), GTK_POS_LEFT);
+	gtk_scale_set_draw_value(GTK_SCALE(beta_scale), true);
+	SG_SIGNAL_CONNECT(beta_adj, "value_changed", beta_callback, NULL);
+	SG_SIGNAL_CONNECT(beta_scale, "format-value", scale_double_format_callback, NULL);
+	
+	gtk_box_pack_start(GTK_BOX(beta_box), beta_scale, true, true, 1);      
+	
+	gtk_widget_show(alpha_scale);
+	gtk_widget_show(beta_scale);
+	gtk_widget_show(ab_box);
+	gtk_widget_show(ab_frame);
+      }
 
 
       /* SPECTRUM_START/END */
 
       se_frame = gtk_frame_new(NULL);
-      gtk_table_attach_defaults(GTK_TABLE(outer_table), se_frame, 0, 6, 7, 8);
-      gtk_frame_set_shadow_type(GTK_FRAME(se_frame), GTK_SHADOW_ETCHED_IN);
+      gtk_table_attach_defaults(GTK_TABLE(outer_table), se_frame, 0, 6, 14, 16);
+      gtk_frame_set_shadow_type(GTK_FRAME(se_frame), GTK_SHADOW_IN);
 
-      se_box = gtk_vbox_new(false, 0);
+      se_box = gtk_vbox_new(false, 2);
       gtk_container_add(GTK_CONTAINER(se_frame), se_box);	
 
       se_label = snd_gtk_highlight_label_new("spectrum start/end");
-      gtk_box_pack_start(GTK_BOX(se_box), se_label, false, false, 0);
+      gtk_box_pack_start(GTK_BOX(se_box), se_label, false, false, 1);
       gtk_widget_show(se_label);
 
       start_box = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(se_box), start_box, false, false, 0);      
+      gtk_box_pack_start(GTK_BOX(se_box), start_box, false, false, 1);      
       gtk_widget_show(start_box);
 
       start_label = gtk_label_new("start: ");
-      gtk_box_pack_start(GTK_BOX(start_box), start_label, false, false, 0);
+      gtk_box_pack_start(GTK_BOX(start_box), start_label, false, false, 8);
       gtk_widget_show(start_label);      
 
-      spectrum_start_adj = gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
+      spectrum_start_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
       spectrum_start_scale = gtk_hscale_new(GTK_ADJUSTMENT(spectrum_start_adj));
       UNSET_CAN_FOCUS(spectrum_start_scale);
       gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(spectrum_start_scale)), GTK_UPDATE_CONTINUOUS);
@@ -1133,19 +1187,20 @@ GtkWidget *fire_up_transform_dialog(bool managed)
       gtk_scale_set_value_pos(GTK_SCALE(spectrum_start_scale), GTK_POS_LEFT);
       gtk_scale_set_draw_value(GTK_SCALE(spectrum_start_scale), true);
       SG_SIGNAL_CONNECT(spectrum_start_adj, "value_changed", spectrum_start_callback, NULL);
+      SG_SIGNAL_CONNECT(spectrum_start_scale, "format-value", scale_double_format_callback, NULL);
 
-      gtk_box_pack_start(GTK_BOX(start_box), spectrum_start_scale, true, true, 0);      
+      gtk_box_pack_start(GTK_BOX(start_box), spectrum_start_scale, true, true, 1);      
 
 
       end_box = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(se_box), end_box, false, false, 0);      
+      gtk_box_pack_start(GTK_BOX(se_box), end_box, false, false, 1);      
       gtk_widget_show(end_box);
 
       end_label = gtk_label_new("end:  ");
-      gtk_box_pack_start(GTK_BOX(end_box), end_label, false, false, 0);
+      gtk_box_pack_start(GTK_BOX(end_box), end_label, false, false, 8);
       gtk_widget_show(end_label);      
 
-      spectrum_end_adj = gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
+      spectrum_end_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
       spectrum_end_scale = gtk_hscale_new(GTK_ADJUSTMENT(spectrum_end_adj));
       UNSET_CAN_FOCUS(spectrum_end_scale);
       gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(spectrum_end_scale)), GTK_UPDATE_CONTINUOUS);
@@ -1153,8 +1208,9 @@ GtkWidget *fire_up_transform_dialog(bool managed)
       gtk_scale_set_value_pos(GTK_SCALE(spectrum_end_scale), GTK_POS_LEFT);
       gtk_scale_set_draw_value(GTK_SCALE(spectrum_end_scale), true);
       SG_SIGNAL_CONNECT(spectrum_end_adj, "value_changed", spectrum_end_callback, NULL);
+      SG_SIGNAL_CONNECT(spectrum_end_scale, "format-value", scale_double_format_callback, NULL);
 
-      gtk_box_pack_start(GTK_BOX(end_box), spectrum_end_scale, true, true, 0);      
+      gtk_box_pack_start(GTK_BOX(end_box), spectrum_end_scale, true, true, 1);      
 
       gtk_widget_show(spectrum_start_scale);
       gtk_widget_show(spectrum_end_scale);
@@ -1165,32 +1221,37 @@ GtkWidget *fire_up_transform_dialog(bool managed)
 
       /* GRAPH */
       {
-	GtkWidget *label;
-	label = snd_gtk_highlight_label_new(mus_fft_window_name(fft_window(ss)));
+	GtkWidget *graph_frame, *g_vbox;
 
 	graph_frame = gtk_frame_new(NULL);
-	gtk_table_attach_defaults(GTK_TABLE(outer_table), graph_frame, 6, 11, 4, 8);
+	gtk_table_attach_defaults(GTK_TABLE(outer_table), graph_frame, 6, 11, 7, 16);
 	gtk_frame_set_label_align(GTK_FRAME(graph_frame), 0.5, 0.0);
-	gtk_frame_set_shadow_type(GTK_FRAME(graph_frame), GTK_SHADOW_ETCHED_IN);
-	gtk_frame_set_label_widget(GTK_FRAME(graph_frame), label);
-	gtk_widget_show(label);
+	gtk_frame_set_shadow_type(GTK_FRAME(graph_frame), GTK_SHADOW_IN);
+
+	g_vbox = gtk_vbox_new(false, 2);
+	gtk_container_add(GTK_CONTAINER(graph_frame), g_vbox);	
+
+	fft_window_label = snd_gtk_highlight_label_new(mus_fft_window_name(fft_window(ss)));
+	gtk_box_pack_start(GTK_BOX(g_vbox), fft_window_label, false, false, 1);
+	gtk_widget_show(fft_window_label);
+
+	graph_drawer = gtk_drawing_area_new();
+	gtk_box_pack_end(GTK_BOX(g_vbox), graph_drawer, true, true, 0);
+	widget_modify_bg(graph_drawer, GTK_STATE_NORMAL, ss->white);
+	gtk_widget_show(g_vbox);
+
+	fgc = gc_new();
+	gc_set_background(fgc, ss->white);
+	gc_set_foreground(fgc, ss->enved_waveform_color);
+
+	fft_gc = gc_new();
+	gc_set_background(fft_gc, ss->white);
+	gc_set_foreground(fft_gc, ss->black);
+
+	gtk_widget_show(graph_drawer);
+	gtk_widget_show(graph_frame);
       }
 
-      graph_drawer = gtk_drawing_area_new();
-      gtk_container_add(GTK_CONTAINER(graph_frame), graph_drawer);
-      widget_modify_bg(graph_drawer, GTK_STATE_NORMAL, ss->sgx->white);
-
-      fgc = gc_new(MAIN_WINDOW(ss));
-      gc_set_background(fgc, ss->sgx->white);
-      gc_set_foreground(fgc, ss->sgx->enved_waveform_color);
-
-      gc = gc_new(MAIN_WINDOW(ss));
-      gc_set_background(gc, ss->sgx->white);
-      gc_set_foreground(gc, ss->sgx->black);
-
-      gtk_widget_show(graph_drawer);
-      gtk_widget_show(graph_frame);
-
       ignore_callbacks = true;
       if (transform_graph_type(ss) == GRAPH_ONCE) set_toggle_button(normal_fft_button, true, false, NULL);
       if (transform_graph_type(ss) == GRAPH_AS_SONOGRAM) set_toggle_button(sono_button, true, false, NULL);
@@ -1209,7 +1270,9 @@ GtkWidget *fire_up_transform_dialog(bool managed)
       if (fft_window_alpha(ss) != 0.0) ADJUSTMENT_SET_VALUE(alpha_adj, fft_window_alpha(ss));
       if (fft_window_beta(ss) != 0.0) ADJUSTMENT_SET_VALUE(beta_adj, fft_window_beta(ss));
 
-      /* highlight_alpha_beta_scales(fft_window(ss)); */
+#if GTK_CHECK_VERSION(3, 0, 0)
+      alpha_beta_alpha(fft_window(ss));
+#endif
       need_callback = true;
       gtk_widget_show(outer_table);
       set_dialog_widget(TRANSFORM_DIALOG, transform_dialog);
@@ -1245,9 +1308,8 @@ GtkWidget *fire_up_transform_dialog(bool managed)
   if (need_callback)
     {
       get_fft_window_data();
-      SG_SIGNAL_CONNECT(graph_drawer, "expose_event", graph_expose_callback, NULL);
+      SG_SIGNAL_CONNECT(graph_drawer, DRAW_SIGNAL, graph_expose_callback, NULL);
       SG_SIGNAL_CONNECT(graph_drawer, "configure_event", graph_configure_callback, NULL);
-      need_callback = false;
     }
 
   return(transform_dialog);
