@@ -2,11 +2,6 @@
 
 /* ---------------- HELP MONOLOG ---------------- */
 
-/* I tried gtkhtml (and XmHTML in 1999), and in both cases decided not to use them.  Both work fine,
- *   but is it that much of a difference to have an html widget in a dialog as opposed to mozilla
- *   running remotely?  And it would require fixing up all the help texts.  
- */
-
 static GtkWidget *help_dialog = NULL;
 
 static void dismiss_help_dialog(GtkWidget *w, gpointer context) 
@@ -31,8 +26,6 @@ slist *related_items = NULL;
 static char *original_help_text = NULL;
 static const char **help_urls = NULL;
 
-/* gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "some text in red", -1, "red_foreground", NULL); */
-
 static void add_help_text(GtkWidget *text, const char *message)
 {
   sg_text_insert(text, (char *)message);
@@ -90,14 +83,14 @@ static bool new_help(const char *pattern, bool complain)
   if (url)
     {
       /* given name, find doc string, if any */
-      XEN xstr;
-      xstr = g_snd_help(C_TO_XEN_STRING(pattern), 0);
-      if (XEN_STRING_P(xstr))
+      Xen xstr;
+      xstr = g_snd_help(C_string_to_Xen_string(pattern), 0);
+      if (Xen_is_string(xstr))
 	{
 	  int gc_loc;
 	  gc_loc = snd_protect(xstr);
 	  xrefs = help_name_to_xrefs(pattern);
-	  snd_help_with_xrefs(pattern, XEN_TO_C_STRING(xstr), WITH_WORD_WRAP, xrefs, NULL);
+	  snd_help_with_xrefs(pattern, Xen_string_to_C_string(xstr), WITH_WORD_WRAP, xrefs, NULL);
 	  snd_unprotect_at(gc_loc);
 	  if (xrefs) free(xrefs);
 	  return(true);
@@ -120,64 +113,6 @@ static bool new_help(const char *pattern, bool complain)
 }
 
 
-static char **help_history = NULL;
-static int help_history_size = 0;
-static int help_history_pos = 0;
-static bool help_needed = true;
-
-static void add_pattern_to_help_history(const char *pattern)
-{
-  if (!help_needed) return;
-  if (help_history_size == 0)
-    {
-      help_history_size = 16; /* not 8! -- need room for cycle below */
-      help_history = (char **)calloc(help_history_size, sizeof(char *));
-    }
-  else
-    {
-      if (help_history_pos >= help_history_size)
-	{
-	  int i;
-	  for (i = 0; i < 8; i++) 
-	    {
-	      if (help_history[i]) free(help_history[i]);
-	      help_history[i] = help_history[i + 8];
-	      help_history[i + 8] = NULL;
-	    }
-	  help_history_pos = 8;
-	}
-    }
-  if (help_history[help_history_pos]) free(help_history[help_history_pos]);
-  help_history[help_history_pos++] = mus_strdup(pattern);
-}
-
-
-static void help_next_callback(GtkWidget *w, gpointer context)
-{
-  if ((help_history_pos < help_history_size) && 
-      (help_history[help_history_pos]))
-    {
-      help_needed = false;
-      help_history_pos++;
-      new_help(help_history[help_history_pos - 1], true);
-      help_needed = true;
-    }
-}
-
-
-static void help_previous_callback(GtkWidget *w, gpointer context)
-{
-  if ((help_history_pos > 1) &&
-      (help_history[help_history_pos - 2]))
-    {
-      help_needed = false;
-      help_history_pos--;
-      new_help(help_history[help_history_pos - 1], true);
-      help_needed = true;
-    }
-}
-
-
 static char *find_highlighted_text(const char *value)
 {
   int i, len, start = -1;
@@ -208,11 +143,11 @@ static char *find_highlighted_text(const char *value)
 
 static void help_browse_callback(const char *name, int row, void *data)
 {
-  char *topic = NULL;
   if ((help_urls) && (help_urls[row]))
     url_to_html_viewer(help_urls[row]);
   else
     {
+      char *topic = NULL;
       topic = find_highlighted_text(name);
       if (topic)
 	{
@@ -245,7 +180,7 @@ static gboolean text_release_callback(GtkTreeSelection *selection, gpointer *gp)
 	  bool one_word = true;
 	  len = mus_strlen(txt);
 	  for (i = 0; i < len; i++)
-	    if (isspace(txt[i]))
+	    if (isspace((int)txt[i]))
 	      {
 		one_word = false;
 		break;
@@ -268,64 +203,76 @@ static void search_activated(GtkWidget *w, gpointer context)
 }
 
 
-static GtkWidget *help_next_button = NULL, *help_previous_button = NULL;
-
 static void create_help_monolog(void)
 {
   /* create scrollable but not editable text window */
-  GtkWidget *ok_button, *search, *frame, *label, *hbox;
+  GtkWidget *ok_button, *search, *frame;
   help_dialog = snd_gtk_dialog_new();
+#if GTK_CHECK_VERSION(3, 14, 0)
+  gtk_window_set_transient_for(GTK_WINDOW(help_dialog), GTK_WINDOW(MAIN_SHELL(ss)));
+#endif
   SG_SIGNAL_CONNECT(help_dialog, "delete_event", delete_help_dialog, NULL);
 
-  gtk_window_set_title(GTK_WINDOW(help_dialog), _("Help"));
+  gtk_window_set_title(GTK_WINDOW(help_dialog), I_HELP);
   sg_make_resizable(help_dialog);
   gtk_container_set_border_width (GTK_CONTAINER(help_dialog), 10);
   gtk_window_resize(GTK_WINDOW(help_dialog), HELP_COLUMNS * 9, HELP_ROWS * 40);
   gtk_widget_realize(help_dialog);
 
-  ok_button = gtk_button_new_from_stock(GTK_STOCK_QUIT);
-  gtk_widget_set_name(ok_button, "quit_button");
-  gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(help_dialog)), ok_button, false, true, 20);
+  ok_button = gtk_dialog_add_button(GTK_DIALOG(help_dialog), "Go Away", GTK_RESPONSE_NONE);
+  gtk_widget_set_name(ok_button, "dialog_button");
   SG_SIGNAL_CONNECT(ok_button, "clicked", dismiss_help_dialog, NULL);
+#if GTK_CHECK_VERSION(3, 0, 0)
+  add_highlight_button_style(ok_button);
+#endif
   gtk_widget_show(ok_button);
-  set_stock_button_label(ok_button, _("Go Away"));
-
-  help_previous_button = gtk_button_new_from_stock(GTK_STOCK_GO_BACK);
-  gtk_widget_set_name(help_previous_button, "reset_button");
-  gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(help_dialog)), help_previous_button, true, true, 10);
-  SG_SIGNAL_CONNECT(help_previous_button, "clicked", help_previous_callback, NULL);
-  gtk_widget_show(help_previous_button);
-
-  help_next_button = gtk_button_new_from_stock(GTK_STOCK_GO_FORWARD);
-  gtk_widget_set_name(help_next_button, "doit_button");
-  gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(help_dialog)), help_next_button, true, true, 10);
-  SG_SIGNAL_CONNECT(help_next_button, "clicked", help_next_callback, NULL);
-  gtk_widget_show(help_next_button);
 
   frame = gtk_frame_new(NULL);
   gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(help_dialog)), frame, true, true, 10); 
   gtk_widget_show(frame);
 
-  help_text = make_scrolled_text(frame, false, 0, false); /* last arg ignored */
+  help_text = make_scrolled_text(frame, false, CONTAINER_ADD, false); /* last arg ignored */
   gtk_widget_add_events(help_text, GDK_BUTTON_RELEASE);
   gtk_text_view_set_left_margin(GTK_TEXT_VIEW(help_text), 10);
   SG_SIGNAL_CONNECT(help_text, "button_release_event", text_release_callback, NULL);
 
-  related_items = slist_new_with_title(_("related topics"), DIALOG_CONTENT_AREA(help_dialog), NULL, 0, BOX_PACK);
+  related_items = slist_new_with_title("related topics", DIALOG_CONTENT_AREA(help_dialog), NULL, 0, BOX_PACK);
   related_items->select_callback = help_browse_callback;
 
-  hbox = gtk_hbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(help_dialog)), hbox, false, false, 10); 
-  gtk_widget_show(hbox);
+  {
+    GtkWidget *label, *hbox;
+#if (!HAVE_GTK_GRID_NEW)
+    hbox = gtk_hbox_new(false, 0);
+    gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(help_dialog)), hbox, false, false, 10); 
+    gtk_widget_show(hbox);
 
-  label = gtk_label_new(_("help topic:"));
-  gtk_box_pack_start(GTK_BOX(hbox), label, false, false, 0); 
-  gtk_widget_show(label);
+    label = gtk_label_new("help topic:");
+    gtk_box_pack_start(GTK_BOX(hbox), label, false, false, 0); 
+    gtk_widget_show(label);
+    
+    search = snd_entry_new(hbox, NULL, WITH_WHITE_BACKGROUND);
+#else
+    GtkWidget *content_area;
+    content_area = gtk_dialog_get_content_area(GTK_DIALOG(help_dialog));
+
+    hbox = gtk_grid_new();
+    gtk_container_add(GTK_CONTAINER(content_area), hbox);
+    gtk_widget_show(hbox);
+
+    label = gtk_label_new("help topic:");
+    gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+    gtk_widget_set_hexpand(label, false);
+    g_object_set(label, "margin", 10, NULL);
+    gtk_grid_attach(GTK_GRID(hbox), label, 0, 0, 1, 1);
+    gtk_widget_show(label);
+
+    search = snd_entry_new(hbox, label, WITH_WHITE_BACKGROUND);
+#endif
+  }
 
-  search = snd_entry_new(hbox, WITH_WHITE_BACKGROUND);
   SG_SIGNAL_CONNECT(search, "activate", search_activated, NULL);
   gtk_widget_show(help_dialog);
-  SG_SIGNAL_CONNECT(GTK_OBJECT(help_dialog), "expose_event", help_expose_callback, NULL);
+  SG_SIGNAL_CONNECT((gpointer)help_dialog, DRAW_SIGNAL, help_expose_callback, NULL);
   set_dialog_widget(HELP_DIALOG, help_dialog);
 }
 
@@ -353,10 +300,7 @@ GtkWidget *snd_help(const char *subject, const char *helpstr, with_word_wrap_t w
     }
   else add_help_text(help_text, helpstr);
 
-  if (help_needed) add_pattern_to_help_history(subject);
   slist_clear(related_items); /* this can clobber "subject"! */
-  gtk_widget_set_sensitive(help_next_button, (help_history_pos < help_history_size) && (help_history[help_history_pos]));
-  gtk_widget_set_sensitive(help_previous_button, (help_history_pos > 1));
   return(help_dialog);
 }
 
@@ -378,7 +322,8 @@ GtkWidget *snd_help_with_xrefs(const char *subject, const char *helpstr, with_wo
 
 void snd_help_append(const char *text)
 {
-  if (help_text) sg_text_insert(help_text, text);
+  if (help_text) 
+    sg_text_insert(help_text, text);
 }
 
 
@@ -393,10 +338,3 @@ void snd_help_back_to_top(void)
       gtk_text_view_scroll_to_iter(GTK_TEXT_VIEW(help_text), &pos, 0.0, true, 0.0, 0.0);
     }
 }
-
-
-bool help_dialog_is_active(void)
-{
-  return((help_dialog) &&
-	 (widget_is_active(help_dialog)));
-}
