@@ -49,12 +49,14 @@ static void stop_dragging(int mix_id)
 /* -------- speed -------- */
 
 static GtkWidget *w_speed, *w_speed_label, *w_speed_number, *w_speed_form, *w_speed_event, *w_speed_label_event;
-static GtkObject *w_speed_adj;
+static GtkAdjustment *w_speed_adj;
 static bool speed_pressed = false, speed_dragged = false;
 /* can't use value_changed on adjustment and motion event happens even when the mouse merely moves across the slider without dragging */
 
 static speed_style_t gmix_speed_control_style = SPEED_CONTROL_AS_FLOAT;
-static axis_context *mix_play_ax = NULL;
+#if WITH_AUDIO
+  static graphics_context *mix_play_ax = NULL;
+#endif
 
 static mus_float_t speed_to_scrollbar(mus_float_t minval, mus_float_t val, mus_float_t maxval)
 {
@@ -91,7 +93,7 @@ static void reflect_mix_speed(mus_float_t speed)
 }
 
 
-static gboolean speed_click_callback(GtkWidget *w, GdkEventButton *ev, gpointer data)
+static gboolean mix_speed_click_callback(GtkWidget *w, GdkEventButton *ev, gpointer data)
 {
   /* label click -- not part of slider stuff */
   speed_pressed = false;
@@ -151,7 +153,7 @@ static gboolean speed_motion_callback(GtkWidget *w, GdkEventMotion *ev, gpointer
 }
 
 
-static gboolean speed_release_callback(GtkWidget *w, GdkEventButton *ev, gpointer data) 
+static gboolean mix_speed_release_callback(GtkWidget *w, GdkEventButton *ev, gpointer data) 
 {
   mus_float_t speed;
 
@@ -182,7 +184,7 @@ static gboolean speed_press_callback(GtkWidget *w, GdkEventButton *ev, gpointer
 /* -------- amp -------- */
 
 static GtkWidget *w_amp, *w_amp_label, *w_amp_number, *w_amp_event, *w_amp_form;
-static GtkObject *w_amp_adj;
+static GtkAdjustment *w_amp_adj;
 
 static mus_float_t scrollbar_to_amp(mus_float_t val)
 {
@@ -203,12 +205,12 @@ static void reflect_mix_amp(mus_float_t val)
   char sfs[6];
   ADJUSTMENT_SET_VALUE(w_amp_adj, amp_to_scroll(amp_control_min(ss), val, amp_control_max(ss)));
   /* gtk_adjustment_value_changed(GTK_ADJUSTMENT(w_amp_adj)); */
-  mus_snprintf(sfs, 6, "%.2f", val);
+  snprintf(sfs, 6, "%.2f", val);
   gtk_label_set_text(GTK_LABEL(w_amp_number), sfs);
 }
 
 
-static gboolean amp_click_callback(GtkWidget *w, GdkEventButton *ev, gpointer data)
+static gboolean mix_amp_click_callback(GtkWidget *w, GdkEventButton *ev, gpointer data)
 {
   amp_dragged = false;
   amp_pressed = false;
@@ -242,7 +244,7 @@ static gboolean amp_motion_callback(GtkWidget *w, GdkEventMotion *ev, gpointer d
 }
 
 
-static gboolean amp_release_callback(GtkWidget *w, GdkEventButton *ev, gpointer data)
+static gboolean mix_amp_release_callback(GtkWidget *w, GdkEventButton *ev, gpointer data)
 {
   mus_float_t amp;
   dragging = false;
@@ -273,7 +275,7 @@ static gboolean amp_press_callback(GtkWidget *w, GdkEventButton *ev, gpointer da
 /* -------- amp-env -------- */
 
 static GtkWidget *w_env_frame, *w_env;
-static axis_context *ax = NULL;
+static graphics_context *ax = NULL;
 static gc_t *cur_gc;
 static env_editor *spf = NULL;
 static bool with_mix_background_wave = false;
@@ -288,11 +290,11 @@ static void show_mix_background_wave(int mix_id)
   pts = prepare_mix_dialog_waveform(mix_id, e->axis, &two_sided);
   if (pts > 0)
     {
-      gc_set_foreground(ax->gc, ss->sgx->enved_waveform_color);
+      gc_set_foreground(ax->gc, ss->enved_waveform_color);
       if (two_sided)
 	draw_both_grf_points(1, ax, pts, GRAPH_LINES);
       else draw_grf_points(1, ax, pts, e->axis, ungrf_y(e->axis, 0.0), GRAPH_LINES);
-      gc_set_foreground(ax->gc, ss->sgx->black);
+      gc_set_foreground(ax->gc, ss->black);
     }
 }
 
@@ -302,28 +304,31 @@ static void mix_amp_env_resize(GtkWidget *w)
   if (!(mix_is_active(mix_dialog_id))) return;
   if (ax == NULL)
     {
-      GdkWindow *wn;
-      wn = MAIN_WINDOW(ss);
-      cur_gc = gc_new(wn);
-      gc_set_background(cur_gc, ss->sgx->graph_color);
-      gc_set_foreground(cur_gc, ss->sgx->data_color);
-      gc_set_function(cur_gc, GDK_COPY);
-      ax = (axis_context *)calloc(1, sizeof(axis_context));
+      cur_gc = gc_new();
+      gc_set_background(cur_gc, ss->graph_color);
+      gc_set_foreground(cur_gc, ss->data_color);
+      ax = (graphics_context *)calloc(1, sizeof(graphics_context));
       ax->wn = WIDGET_TO_WINDOW(w_env);
       ax->w = w_env;
       ax->gc = cur_gc;
     }
-  else clear_window(ax);
-#if USE_CAIRO
-  ax->cr = gdk_cairo_create(ax->wn);
-#endif
+  ss->cr = make_cairo(ax->wn);
+  cairo_push_group(ss->cr);
+
+  /* erase previous */
+  cairo_set_source_rgba(ss->cr, cur_gc->bg_color->red, cur_gc->bg_color->green, cur_gc->bg_color->blue, cur_gc->bg_color->alpha);
+  cairo_rectangle(ss->cr, 0, 0, widget_width(w), widget_height(w));
+  cairo_fill(ss->cr);
+
   spf->with_dots = true;
-  env_editor_display_env(spf, dialog_env, ax, _("mix env"), 0, 0, widget_width(w), widget_height(w), NOT_PRINTING);
+  env_editor_display_env(spf, dialog_env, ax, "mix env", 0, 0, widget_width(w), widget_height(w), NOT_PRINTING);
   if (with_mix_background_wave)
     show_mix_background_wave(mix_dialog_id);
-#if USE_CAIRO
-  cairo_destroy(ax->cr);
-#endif
+
+  cairo_pop_group_to_source(ss->cr);
+  cairo_paint(ss->cr);
+  free_cairo(ss->cr);
+  ss->cr = NULL;
 }
 
 
@@ -354,7 +359,7 @@ static gboolean mix_drawer_button_motion(GtkWidget *w, GdkEventMotion *ev, gpoin
       int x, y;
       GdkModifierType state;
       if (EVENT_IS_HINT(ev))
-	gdk_window_get_pointer(EVENT_WINDOW(ev), &x, &y, &state);
+	window_get_pointer(ev, &x, &y, &state);
       else
 	{
 	  x = (int)(EVENT_X(ev));
@@ -383,8 +388,10 @@ static gboolean mix_amp_env_resize_callback(GtkWidget *w, GdkEventConfigure *ev,
 }
 
 
-static GtkWidget *w_id = NULL, *w_beg = NULL, *mix_play = NULL, *w_id_label = NULL;
-static picture_t *speaker_off_pix, *speaker_on_pix, *mix_speaker_pix;
+static GtkWidget *w_id = NULL, *w_beg = NULL, *w_id_label = NULL;
+#if WITH_AUDIO
+  static GtkWidget *mix_play = NULL;
+#endif
 
 static bool id_changed = false;
 
@@ -406,7 +413,7 @@ static gint unpost_mix_error(gpointer data)
 
 static void errors_to_mix_text(const char *msg, void *data)
 {
-  info_widget_display(error_label, msg);
+  gtk_label_set_text(GTK_LABEL(error_label), msg);
   gtk_widget_show(error_frame);
   g_timeout_add_full(0, (guint32)5000, unpost_mix_error, NULL, NULL);
 }
@@ -470,7 +477,7 @@ static void beg_activated(GtkWidget *w, gpointer context)
 	{
 	  mus_long_t pos, old_pos;
 	  old_pos = mix_position_from_id(mix_dialog_id);
-	  pos = (mus_long_t)(beg * SND_SRATE(cp->sound));
+	  pos = (mus_long_t)(beg * snd_srate(cp->sound));
 	  mix_set_position_edit(mix_dialog_id, pos);
 	  syncd_mix_change_position(mix_dialog_id, pos - old_pos);
 	}
@@ -502,25 +509,19 @@ static bool mix_playing = false;
 
 void reflect_mix_play_stop(void)
 {
+  /* called in snd-dac.c */
   mix_playing = false;
-  mix_speaker_pix = speaker_off_pix;
-  if (mix_play_ax)
-    draw_picture(mix_play_ax, mix_speaker_pix, 0, 0, 2, 4, 12, 12);
 }
 
 
+#if WITH_AUDIO
 static void mix_play_callback(GtkWidget *w, gpointer context) 
 {
   if (mix_playing)
-    reflect_mix_play_stop();
+    mix_playing = false;
   else
     {
       if (!(mix_exists(mix_dialog_id))) return;
-      if (mix_play_ax)
-	{
-	  mix_speaker_pix = speaker_on_pix;
-	  draw_picture(mix_play_ax, mix_speaker_pix, 0, 0, 2, 4, 12, 12);
-	}
       syncd_mix_play(mix_dialog_id);
       mix_playing = true;
       play_mix_from_id(mix_dialog_id);
@@ -530,9 +531,10 @@ static void mix_play_callback(GtkWidget *w, gpointer context)
 
 static gboolean mix_play_pix_expose(GtkWidget *w, GdkEventExpose *ev, gpointer data)
 {
-  draw_picture(mix_play_ax, mix_speaker_pix, 0, 0, 2, 4, 12, 12);
+  draw_picture(mix_play_ax, snd_icon(SND_PNG_SPEAKER), 0, 0, 0, 0, 16, 16); /* in gtk2 this looks better if y-dest is 2 */
   return(false);
 }
+#endif
 
 
 static void mix_dB_callback(GtkWidget *w, gpointer context) 
@@ -551,7 +553,7 @@ static void mix_sync_callback(GtkWidget *w, gpointer context)
     {
       mix_set_sync_from_id(mix_dialog_id, GET_ORIGINAL_SYNC);  /* choose a new sync val or return to previous */
       /* check for resync */
-      syncd_mix_set_color(mix_dialog_id, ss->sgx->red);
+      syncd_mix_set_color(mix_dialog_id, ss->red);
     }
   else
     {
@@ -562,13 +564,13 @@ static void mix_sync_callback(GtkWidget *w, gpointer context)
 	  mix_set_sync_from_id(mix_dialog_id, 0);
 	}
     }
-  for_each_normal_chan(display_channel_mixes);
+  for_each_normal_chan(display_channel_data);
 }
 
 
 static void mix_clip_callback(GtkWidget *w, gpointer context) 
 {
-  spf->clip_p = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w));
+  spf->clipping = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w));
   mix_amp_env_resize(w_env);
 }
 
@@ -586,7 +588,7 @@ static void apply_env_callback(GtkWidget *w, gpointer context)
   if (!(mix_is_active(mix_dialog_id))) return;
 
   if ((dialog_env) && 
-      (!(default_env_p(dialog_env))))
+      (!(is_default_env(dialog_env))))
     {
       mix_set_amp_env_edit(mix_dialog_id, dialog_env);
       syncd_mix_set_amp_env(mix_dialog_id, dialog_env);  
@@ -616,7 +618,7 @@ static gint delete_mix_dialog(GtkWidget *w, GdkEvent *event, gpointer context)
 }
 
 
-static GtkWidget *nextb, *previousb, *apply_button;
+static GtkWidget *mix_next_button, *mix_previous_button, *mix_apply_button;
 
 static void mix_next_callback(GtkWidget *w, gpointer context)
 {
@@ -628,7 +630,7 @@ static void mix_next_callback(GtkWidget *w, gpointer context)
       mix_dialog_id = id;
       reflect_mix_change(id);
       if (next_mix_id(id) == INVALID_MIX_ID) 
-	set_sensitive(nextb, false);
+	set_sensitive(mix_next_button, false);
     }
 }
 
@@ -643,7 +645,7 @@ static void mix_previous_callback(GtkWidget *w, gpointer context)
       mix_dialog_id = id;
       reflect_mix_change(id);
       if (previous_mix_id(id) == INVALID_MIX_ID) 
-	set_sensitive(previousb, false);
+	set_sensitive(mix_previous_button, false);
     }
 }
 
@@ -654,100 +656,71 @@ static void mix_dialog_help_callback(GtkWidget *w, gpointer context)
 }
 
 
-static const char *speaker_xpm[] = {
-"12 12 2 1",
-"-      c None s None",
-"X	c black",
-"--------XXX-",
-"------XX--X-",
-"----XX----X-",
-"-XXX------X-",
-"-XX-------X-",
-"-XX-------X-",
-"-XX-------X-",
-"-XX-------X-",
-"-XXX------X-",
-"----XX----X-",
-"------XX--X-",
-"--------XXX-"};
-
-
-static const char *blue_speaker_xpm[] = {
-"12 12 3 1",
-"-      c None s None",
-"o      c red",
-"X	c black",
-"--------XXX-",
-"------XXooX-",
-"----XXooooX-",
-"-XXXooooooX-",
-"-XXoooooooX-",
-"-XXoooooooX-",
-"-XXoooooooX-",
-"-XXoooooooX-",
-"-XXXooooooX-",
-"----XXooooX-",
-"------XXooX-",
-"--------XXX-"};
-
-
-void make_speaker_icons_transparent(const char *bg_line)
-{
-  speaker_xpm[1] = bg_line;
-  blue_speaker_xpm[1] = bg_line;
-}
-
 static GtkWidget *w_sync;
+#define LEFT_MARGIN 6
 
 GtkWidget *make_mix_dialog(void)
 {
   if (mix_dialog == NULL)
     {
       GtkWidget *dismiss_button, *help_button, *rc, *mix_frame, *rc_top, *copy_button;
-      GtkWidget *lo_hbox, *w_dB_frame, *w_dB, *w_clip, *w_wave, *w_dB_row, *mix_play_pix;
+      GtkWidget *lo_hbox, *w_dB_frame, *w_dB, *w_clip, *w_wave, *w_dB_row;
+#if WITH_AUDIO
+      GtkWidget *mix_play_pix;
+#endif
       char amplab[LABEL_BUFFER_SIZE];
 
       gmix_speed_control_style = speed_control_style(ss);
 
       mix_dialog_id = any_mix_id();
       mix_dialog = snd_gtk_dialog_new();
+#if GTK_CHECK_VERSION(3, 14, 0)
+      gtk_window_set_transient_for(GTK_WINDOW(mix_dialog), GTK_WINDOW(MAIN_SHELL(ss)));
+#endif
       SG_SIGNAL_CONNECT(mix_dialog, "delete_event", delete_mix_dialog, NULL);
-      gtk_window_set_title(GTK_WINDOW(mix_dialog), _("Mixes"));
+      gtk_window_set_title(GTK_WINDOW(mix_dialog), "Mixes");
       sg_make_resizable(mix_dialog);
       gtk_container_set_border_width (GTK_CONTAINER(mix_dialog), 6);
       gtk_window_resize(GTK_WINDOW(mix_dialog), 560, 280);
       gtk_widget_realize(mix_dialog);
       
-      dismiss_button = gtk_button_new_from_stock(GTK_STOCK_QUIT);
-      gtk_widget_set_name(dismiss_button, "quit_button");
-      gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(mix_dialog)), dismiss_button, false, true, 10);
-      SG_SIGNAL_CONNECT(dismiss_button, "clicked", dismiss_mix_dialog, NULL);
-      gtk_widget_show(dismiss_button);
-      set_stock_button_label(dismiss_button, _("Go Away"));
+      help_button = gtk_dialog_add_button(GTK_DIALOG(mix_dialog), "Help", GTK_RESPONSE_NONE);
+      gtk_widget_set_name(help_button, "dialog_button");
+      SG_SIGNAL_CONNECT(help_button, "clicked", mix_dialog_help_callback, NULL);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(help_button);
+#endif
+      gtk_widget_show(help_button);
 
-      apply_button = sg_button_new_from_stock_with_label(_("Apply Env"), GTK_STOCK_APPLY);
-      gtk_widget_set_name(apply_button, "doit_again_button");
-      gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(mix_dialog)), apply_button, false, true, 10);
-      SG_SIGNAL_CONNECT(apply_button, "clicked", apply_env_callback, NULL);
-      gtk_widget_show(apply_button);
-
-      copy_button = sg_button_new_from_stock_with_label(_("Copy mix"), GTK_STOCK_COPY);
-      gtk_widget_set_name(copy_button, "reset_button");
-      gtk_box_pack_start(GTK_BOX(DIALOG_ACTION_AREA(mix_dialog)), copy_button, false, true, 10);
+      copy_button = gtk_dialog_add_button(GTK_DIALOG(mix_dialog), "Copy mix", GTK_RESPONSE_NONE);
+      gtk_widget_set_name(copy_button, "dialog_button");
       SG_SIGNAL_CONNECT(copy_button, "clicked", copy_mix_callback, NULL);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(copy_button);
+#endif
       gtk_widget_show(copy_button);
 
-      help_button = gtk_button_new_from_stock(GTK_STOCK_HELP);
-      gtk_widget_set_name(help_button, "help_button");
-      gtk_box_pack_end(GTK_BOX(DIALOG_ACTION_AREA(mix_dialog)), help_button, true, true, 10);
-      SG_SIGNAL_CONNECT(help_button, "clicked", mix_dialog_help_callback, NULL);
-      gtk_widget_show(help_button);
+      dismiss_button = gtk_dialog_add_button(GTK_DIALOG(mix_dialog), I_GO_AWAY, GTK_RESPONSE_NONE);
+      gtk_widget_set_name(dismiss_button, "dialog_button");
+      SG_SIGNAL_CONNECT(dismiss_button, "clicked", dismiss_mix_dialog, NULL);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(dismiss_button);
+#endif
+      gtk_widget_show(dismiss_button);
+
+      mix_apply_button = gtk_dialog_add_button(GTK_DIALOG(mix_dialog), "Apply env", GTK_RESPONSE_NONE);
+      gtk_widget_set_name(mix_apply_button, "dialog_button");
+      SG_SIGNAL_CONNECT(mix_apply_button, "clicked", apply_env_callback, NULL);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(mix_apply_button);
+#endif
+      gtk_widget_show(mix_apply_button);
 
       /* normally hidden error indication at top */
       error_frame = gtk_frame_new(NULL);
       gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(mix_dialog)), error_frame, false, false, 4);
 
-      error_label = make_info_widget();
+      error_label = gtk_label_new(NULL);
       gtk_container_add(GTK_CONTAINER(error_frame), error_label);
       gtk_widget_show(error_label);
 
@@ -766,54 +739,53 @@ GtkWidget *make_mix_dialog(void)
       gtk_container_add(GTK_CONTAINER(mix_frame), rc);
       gtk_widget_show(rc);
 
-      w_id_label = gtk_label_new(_("mix:"));
+      w_id_label = gtk_label_new("mix:");
       gtk_box_pack_start(GTK_BOX(rc), w_id_label, false, false, 4);
       gtk_widget_show(w_id_label);
 
-      w_id = snd_entry_new(rc, WITH_DEFAULT_BACKGROUND);
+      w_id = snd_entry_new(rc, NULL, WITH_DEFAULT_BACKGROUND);
       SG_SIGNAL_CONNECT(w_id, "activate", id_activated, NULL);
       SG_SIGNAL_CONNECT(w_id, "leave_notify_event", id_check_callback, NULL);
       SG_SIGNAL_CONNECT(w_id, "key_press_event", id_modify_callback, NULL);
 
-      w_beg = snd_entry_new(rc, WITH_DEFAULT_BACKGROUND);
+      w_beg = snd_entry_new(rc, NULL, WITH_DEFAULT_BACKGROUND);
       SG_SIGNAL_CONNECT(w_beg, "activate", beg_activated, NULL);
 
+#if WITH_AUDIO
       mix_play = gtk_button_new();
       gtk_box_pack_start(GTK_BOX(rc), mix_play, false, false, 2);
       SG_SIGNAL_CONNECT(mix_play, "clicked", mix_play_callback, NULL);
       gtk_widget_show(mix_play);
-      widget_modify_bg(mix_play, GTK_STATE_ACTIVE, ss->sgx->basic_color);
-      widget_modify_bg(mix_play, GTK_STATE_SELECTED, ss->sgx->basic_color);
+      widget_modify_bg(mix_play, GTK_STATE_ACTIVE, ss->basic_color);
+      widget_modify_bg(mix_play, GTK_STATE_SELECTED, ss->basic_color);
       
-      if (!speaker_off_pix)
-	{
-	  speaker_off_pix = gdk_pixmap_create_from_xpm_d(MAIN_WINDOW(ss), NULL, NULL, (gchar **)speaker_xpm);
-	  speaker_on_pix = gdk_pixmap_create_from_xpm_d(MAIN_WINDOW(ss), NULL, NULL, (gchar **)blue_speaker_xpm);
-	}
-
-      mix_speaker_pix = speaker_off_pix;
-
       mix_play_pix = gtk_drawing_area_new();
       gtk_widget_set_events(mix_play_pix, GDK_EXPOSURE_MASK);
       gtk_widget_set_size_request(mix_play_pix, 16, 16);
       gtk_container_add(GTK_CONTAINER(mix_play), mix_play_pix);
       gtk_widget_show(mix_play_pix);
-      SG_SIGNAL_CONNECT(mix_play_pix, "expose_event", mix_play_pix_expose, NULL);
+      SG_SIGNAL_CONNECT(mix_play_pix, DRAW_SIGNAL, mix_play_pix_expose, NULL);
+#endif
 
+      mix_next_button = button_new_with_icon(ICON_GO_FORWARD);
+      gtk_widget_set_name(mix_next_button, "dialog_button");
+      gtk_box_pack_end(GTK_BOX(rc), mix_next_button, false, true, 6);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(mix_next_button);
+#endif
+      SG_SIGNAL_CONNECT(mix_next_button, "clicked", mix_next_callback, NULL);
+      gtk_widget_show(mix_next_button);
+      set_stock_button_label(mix_next_button, I_NEXT);
 
-      nextb = gtk_button_new_from_stock(GTK_STOCK_GO_FORWARD);
-      gtk_widget_set_name(nextb, "doit_button");
-      gtk_box_pack_end(GTK_BOX(rc), nextb, false, true, 6);
-      SG_SIGNAL_CONNECT(nextb, "clicked", mix_next_callback, NULL);
-      gtk_widget_show(nextb);
-      set_stock_button_label(nextb, _("Next"));
-
-      previousb = gtk_button_new_from_stock(GTK_STOCK_GO_BACK);
-      gtk_widget_set_name(previousb, "reset_button");
-      gtk_box_pack_end(GTK_BOX(rc), previousb, false, true, 6);
-      SG_SIGNAL_CONNECT(previousb, "clicked", mix_previous_callback, NULL);
-      gtk_widget_show(previousb);
-      set_stock_button_label(previousb, _("Previous"));
+      mix_previous_button = button_new_with_icon(ICON_GO_BACK);
+      gtk_widget_set_name(mix_previous_button, "dialog_button");
+      gtk_box_pack_end(GTK_BOX(rc), mix_previous_button, false, true, 6);
+#if GTK_CHECK_VERSION(3, 0, 0)
+      add_highlight_button_style(mix_previous_button);
+#endif
+      SG_SIGNAL_CONNECT(mix_previous_button, "clicked", mix_previous_callback, NULL);
+      gtk_widget_show(mix_previous_button);
+      set_stock_button_label(mix_previous_button, I_PREVIOUS);
 
 
       /* SPEED */
@@ -823,9 +795,14 @@ GtkWidget *make_mix_dialog(void)
       w_speed_event = gtk_event_box_new();
       gtk_box_pack_start(GTK_BOX(w_speed_form), w_speed_event, false, false, 4);
       gtk_widget_show(w_speed_event);
-      SG_SIGNAL_CONNECT(w_speed_event, "button_press_event", speed_click_callback, NULL);
+      SG_SIGNAL_CONNECT(w_speed_event, "button_press_event", mix_speed_click_callback, NULL);
       
-      w_speed_label = gtk_label_new(_("speed:"));
+#if (!GTK_CHECK_VERSION(3, 0, 0))
+      w_speed_label = gtk_label_new("speed:");
+#else
+      w_speed_label = gtk_button_new_with_label("speed:");
+      add_highlight_button_style(w_speed_label);
+#endif
       gtk_container_add(GTK_CONTAINER(w_speed_event), w_speed_label);
       gtk_widget_show(w_speed_label);
 
@@ -843,10 +820,10 @@ GtkWidget *make_mix_dialog(void)
       gtk_container_add(GTK_CONTAINER(w_speed_label_event), w_speed_number);
       gtk_widget_show(w_speed_number);
       
-      w_speed_adj = gtk_adjustment_new(0.45, 0.0, 1.0, 0.001, 0.01, .1);
+      w_speed_adj = (GtkAdjustment *)gtk_adjustment_new(0.45, 0.0, 1.0, 0.001, 0.01, .1);
       w_speed = gtk_hscrollbar_new(GTK_ADJUSTMENT(w_speed_adj));
       gtk_box_pack_start(GTK_BOX(w_speed_form), w_speed, true, true, 4);
-      SG_SIGNAL_CONNECT(w_speed, "button_release_event", speed_release_callback, NULL);
+      SG_SIGNAL_CONNECT(w_speed, "button_release_event", mix_speed_release_callback, NULL);
       SG_SIGNAL_CONNECT(w_speed, "motion_notify_event", speed_motion_callback, NULL);
       SG_SIGNAL_CONNECT(w_speed, "button_press_event", speed_press_callback, NULL);
       gtk_widget_show(w_speed);
@@ -862,10 +839,15 @@ GtkWidget *make_mix_dialog(void)
       w_amp_event = gtk_event_box_new();
       gtk_box_pack_start(GTK_BOX(w_amp_form), w_amp_event, false, false, 4);
       gtk_widget_show(w_amp_event);
-      SG_SIGNAL_CONNECT(w_amp_event, "button_press_event", amp_click_callback, NULL);
+      SG_SIGNAL_CONNECT(w_amp_event, "button_press_event", mix_amp_click_callback, NULL);
       
-      mus_snprintf(amplab, LABEL_BUFFER_SIZE, "%s", _("amp:"));
+      snprintf(amplab, LABEL_BUFFER_SIZE, "%s", "amp:");
+#if (!GTK_CHECK_VERSION(3, 0, 0))
       w_amp_label = gtk_label_new(amplab);
+#else
+      w_amp_label = gtk_button_new_with_label("amp:");
+      add_highlight_button_style(w_amp_label);
+#endif
       gtk_container_add(GTK_CONTAINER(w_amp_event), w_amp_label);
       gtk_widget_show(w_amp_label);
       
@@ -873,12 +855,12 @@ GtkWidget *make_mix_dialog(void)
       gtk_box_pack_start(GTK_BOX(w_amp_form), w_amp_number, false, false, 0);
       gtk_widget_show(w_amp_number);
 	  
-      w_amp_adj = gtk_adjustment_new(0.5, 0.0, 1.0, 0.001, 0.01, .1);
+      w_amp_adj = (GtkAdjustment *)gtk_adjustment_new(0.5, 0.0, 1.0, 0.001, 0.01, .1);
       w_amp = gtk_hscrollbar_new(GTK_ADJUSTMENT(w_amp_adj));
       gtk_box_pack_start(GTK_BOX(w_amp_form), w_amp, true, true, 4);
 
       SG_SIGNAL_CONNECT(w_amp, "motion_notify_event", amp_motion_callback, NULL);
-      SG_SIGNAL_CONNECT(w_amp, "button_release_event", amp_release_callback, NULL);
+      SG_SIGNAL_CONNECT(w_amp, "button_release_event", mix_amp_release_callback, NULL);
       SG_SIGNAL_CONNECT(w_amp, "button_press_event", amp_press_callback, NULL);
       gtk_widget_show(w_amp);
       
@@ -901,22 +883,26 @@ GtkWidget *make_mix_dialog(void)
       gtk_container_add(GTK_CONTAINER(w_dB_frame), w_dB_row);
       gtk_widget_show(w_dB_row);	
 
-      w_clip = gtk_check_button_new_with_label(_("clip"));
+      w_clip = gtk_check_button_new_with_label("clip");
+      widget_set_margin_left(w_clip, LEFT_MARGIN);
       SG_SIGNAL_CONNECT(w_clip, "toggled", mix_clip_callback, NULL);
       gtk_box_pack_start(GTK_BOX(w_dB_row), w_clip, false, false, 0);
       gtk_widget_show(w_clip);
 
-      w_wave = gtk_check_button_new_with_label(_("wave"));
+      w_wave = gtk_check_button_new_with_label("wave");
+      widget_set_margin_left(w_wave, LEFT_MARGIN);
       SG_SIGNAL_CONNECT(w_wave, "toggled", mix_wave_callback, NULL);
       gtk_box_pack_start(GTK_BOX(w_dB_row), w_wave, false, false, 0);
       gtk_widget_show(w_wave);
 
-      w_dB = gtk_check_button_new_with_label(_("dB"));
+      w_dB = gtk_check_button_new_with_label("dB");
+      widget_set_margin_left(w_dB, LEFT_MARGIN);
       SG_SIGNAL_CONNECT(w_dB, "toggled", mix_dB_callback, NULL);
       gtk_box_pack_start(GTK_BOX(w_dB_row), w_dB, false, false, 0);
       gtk_widget_show(w_dB);
 
-      w_sync = gtk_check_button_new_with_label(_("sync"));
+      w_sync = gtk_check_button_new_with_label("sync");
+      widget_set_margin_left(w_sync, LEFT_MARGIN);
       SG_SIGNAL_CONNECT(w_sync, "toggled", mix_sync_callback, NULL);
       gtk_box_pack_start(GTK_BOX(w_dB_row), w_sync, false, false, 0);
       gtk_widget_show(w_sync);
@@ -925,9 +911,9 @@ GtkWidget *make_mix_dialog(void)
       w_env = gtk_drawing_area_new();
       gtk_widget_set_events(w_env, GDK_ALL_EVENTS_MASK);
       gtk_container_add(GTK_CONTAINER(w_env_frame), w_env);
-      widget_modify_bg(w_env, GTK_STATE_NORMAL, ss->sgx->highlight_color);
+      widget_modify_bg(w_env, GTK_STATE_NORMAL, ss->highlight_color);
       gtk_widget_show(w_env);
-      SG_SIGNAL_CONNECT(w_env, "expose_event", mix_amp_env_expose_callback, NULL);
+      SG_SIGNAL_CONNECT(w_env, DRAW_SIGNAL, mix_amp_env_expose_callback, NULL);
       SG_SIGNAL_CONNECT(w_env, "configure_event", mix_amp_env_resize_callback, NULL);
       SG_SIGNAL_CONNECT(w_env, "button_press_event", mix_drawer_button_press, NULL);
       SG_SIGNAL_CONNECT(w_env, "button_release_event", mix_drawer_button_release, NULL);
@@ -941,9 +927,11 @@ GtkWidget *make_mix_dialog(void)
       if (mix_sync_from_id(mix_dialog_id) != 0)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w_sync), true);
 
-      mix_play_ax = (axis_context *)calloc(1, sizeof(axis_context));
+#if WITH_AUDIO
+      mix_play_ax = (graphics_context *)calloc(1, sizeof(graphics_context));
       mix_play_ax->wn = WIDGET_TO_WINDOW(mix_play_pix);
-      mix_play_ax->gc = ss->sgx->basic_gc;
+      mix_play_ax->gc = ss->basic_gc;
+#endif
 
       gtk_widget_hide(error_frame);
     }
@@ -972,8 +960,8 @@ void reflect_mix_change(int mix_id)
       if ((mix_id == mix_dialog_id) || (mix_id == ANY_MIX_ID))
 	{
 	  mus_float_t val;
-	  set_sensitive(nextb, (next_mix_id(mix_dialog_id) != INVALID_MIX_ID));
-	  set_sensitive(previousb, (previous_mix_id(mix_dialog_id) != INVALID_MIX_ID));
+	  set_sensitive(mix_next_button, (next_mix_id(mix_dialog_id) != INVALID_MIX_ID));
+	  set_sensitive(mix_previous_button, (previous_mix_id(mix_dialog_id) != INVALID_MIX_ID));
 
 	  /* now reflect current mix state in mix dialog controls */
 	  if (mix_exists(mix_dialog_id))
@@ -989,10 +977,10 @@ void reflect_mix_change(int mix_id)
 		  syncd_mix_unset_color(old_mix_dialog_id);
 		}
 	      old_mix_dialog_id = mix_dialog_id;
-	      mix_set_color_from_id(mix_dialog_id, ss->sgx->red);
-	      syncd_mix_set_color(mix_dialog_id, ss->sgx->red);
+	      mix_set_color_from_id(mix_dialog_id, ss->red);
+	      syncd_mix_set_color(mix_dialog_id, ss->red);
 
-	      for_each_normal_chan(display_channel_mixes);
+	      for_each_normal_chan(display_channel_data);
 
 	      if (!dragging)
 		{
@@ -1002,21 +990,21 @@ void reflect_mix_change(int mix_id)
 
 	      beg = mix_position_from_id(mix_dialog_id);
 	      len = mix_length_from_id(mix_dialog_id);
-	      mus_snprintf(lab, LABEL_BUFFER_SIZE, "%.3f : %.3f%s",
-			   (float)((double)beg / (float)SND_SRATE(cp->sound)),
-			   (float)((double)(beg + len) / (float)SND_SRATE(cp->sound)),
+	      snprintf(lab, LABEL_BUFFER_SIZE, "%.3f : %.3f%s",
+			   (float)((double)beg / (float)snd_srate(cp->sound)),
+			   (float)((double)(beg + len) / (float)snd_srate(cp->sound)),
 			   (mix_is_active(mix_dialog_id)) ? "" : " (locked)");
 	      gtk_entry_set_text(GTK_ENTRY(w_beg), lab);
 
 	      widget_mix_to_text(w_id, mix_dialog_id);
 
-	      set_sensitive(apply_button, true);
+	      set_sensitive(mix_apply_button, true);
 	    }
 	  else
 	    {
 	      gtk_entry_set_text(GTK_ENTRY(w_id), "-1");
 	      gtk_entry_set_text(GTK_ENTRY(w_beg), "no active mixes");
-	      set_sensitive(apply_button, false);
+	      set_sensitive(mix_apply_button, false);
 	    }
 	  if (!dragging)
 	    {
