@@ -6,8 +6,8 @@
 
 struct snd_io {
   int fd, chans, bufsize;
-  mus_long_t frames, beg, end;
-  mus_sample_t **arrays;
+  mus_long_t framples, beg, end;
+  mus_float_t **arrays;
 };
 
 mus_long_t io_beg(snd_io *io)
@@ -20,11 +20,6 @@ mus_long_t io_end(snd_io *io)
   return(io->end);
 }
 
-int io_filed(snd_io *io)
-{
-  return(io->fd);
-}
-
 
 void snd_remove(const char *name, cache_remove_t forget)
 {
@@ -93,7 +88,7 @@ int snd_open(const char *filename, int flags, mode_t mode)
   ss->local_errno = 0;
   ss->local_open_errno = 0;
   errno = 0;
-#if HAVE_WINDOZE
+#if (defined(_MSC_VER) || __CYGWIN__)
   result = open(filename, flags);
 #else
   result = open(filename, flags, mode);
@@ -145,21 +140,22 @@ io_error_t copy_file(const char *oldname, const char *newname)
 {
   /* make newname a copy of oldname */
   int ifd, ofd;
-  mus_long_t bytes, wb, total;
+  mus_long_t bytes, wb;
   char *buf = NULL;
-  total = 0;
-  ifd = OPEN(oldname, O_RDONLY, 0);
+ 
+ ifd = OPEN(oldname, O_RDONLY, 0);
   if (ifd == -1) return(IO_CANT_OPEN_FILE);
+
   ofd = CREAT(newname, 0666);
   if (ofd == -1) 
     {
       snd_close(ifd, oldname);
       return(IO_CANT_CREATE_FILE);
     }
-  buf = (char *)calloc(8192, sizeof(char));
+
+  buf = (char *)malloc(8192 * sizeof(char));
   while ((bytes = read(ifd, buf, 8192)))
     {
-      total += bytes;
       wb = write(ofd, buf, bytes);
       if (wb != bytes) 
 	{
@@ -169,6 +165,7 @@ io_error_t copy_file(const char *oldname, const char *newname)
 	  return(IO_WRITE_ERROR);
 	}
     }
+
   snd_close(ifd, oldname);
   wb = disk_kspace(newname);
   snd_close(ofd, newname);
@@ -184,43 +181,44 @@ io_error_t copy_file(const char *oldname, const char *newname)
 
 static void c_io_bufclr(snd_io *io, int beg)
 {
-  int k, end;
-  end = io->bufsize;
+  int k;
+  size_t bytes;
+
+  bytes = (io->bufsize - beg) * sizeof(mus_float_t);
   for (k = 0; k < io->chans; k++)
     {
-      mus_sample_t *j;
+      mus_float_t *j;
       j = io->arrays[k];
       if (j)
-	memset((void *)(j + beg), 0, (end - beg) * sizeof(mus_sample_t));
+	memset((void *)(j + beg), 0, bytes);
     }
 }
 
 
 static void reposition_file_buffers_1(mus_long_t loc, snd_io *io)
 {
-  /* called when loc is outside the current in-core frame for the file pointed to by io */
-  mus_long_t frames;
-  /* local frames is buffer-local, not a sample number. */
-  frames = io->frames - loc;
-  if (frames > io->bufsize) frames = io->bufsize;
-  if (frames <= 0)                   /* tried to access beyond current end of file */
+  /* called when loc is outside the current in-core frample for the file pointed to by io */
+  mus_long_t framples;
+  /* local framples is buffer-local, not a sample number. */
+
+  framples = io->framples - loc;         /* io->framples is total samps in file */
+  if (framples > io->bufsize) framples = io->bufsize;
+  if (framples <= 0)                   /* tried to access beyond current end of file */
     {
       io->beg = loc; 
       c_io_bufclr(io, 0);
     }
   else
     {
-      mus_long_t seek_loc;
-      int err;
-      seek_loc = mus_file_seek_frame(io->fd, loc);
+      mus_file_seek_frample(io->fd, loc);
       io->beg = loc;
-      err = mus_file_read_chans(io->fd,
-				0, frames - 1,
-				io->chans,
-				io->arrays,
-				io->arrays);
-      if (frames < io->bufsize) 
-	c_io_bufclr(io, frames);
+      mus_file_read_chans(io->fd,
+			  loc, framples,
+			  io->chans,
+			  io->arrays,
+			  io->arrays);
+      if (framples < (io->bufsize - 1)) 
+	c_io_bufclr(io, framples);
     }
   io->end = io->beg + io->bufsize - 1;
 }
@@ -239,14 +237,14 @@ static void reposition_file_buffers(snd_data *sd, mus_long_t index)
       if (fd == -1) 
 	{
 	  /* our file has disappeared?!? */
-	  snd_error(_("%s is unreadable: %s?"), sd->filename, snd_io_strerror());
+	  snd_error("%s is unreadable: %s?", sd->filename, snd_io_strerror());
 	  return;
 	}
       hdr = sd->hdr;
       /* these need to flush active data before hidden close and fixup the io indices */
       snd_file_open_descriptors(fd,
 				sd->filename,
-				hdr->format,
+				hdr->sample_type,
 				hdr->data_location,
 				hdr->chans,
 				hdr->type);
@@ -282,15 +280,16 @@ snd_io *make_file_state(int fd, file_info *hdr, int chan, mus_long_t beg, int su
     bufsize = chansize + 1;
 
   io = (snd_io *)calloc(1, sizeof(snd_io)); /* only creation point */
-  io->arrays = (mus_sample_t **)calloc(hdr->chans, sizeof(mus_sample_t *));
+  io->arrays = (mus_float_t **)calloc(hdr->chans, sizeof(mus_float_t *));
   io->fd = fd;
   io->chans = hdr->chans;
-  io->frames = chansize;
+  io->framples = chansize;
   io->beg = 0;
   io->end = bufsize - 1;
   io->bufsize = bufsize;
-  io->arrays[chan] = (mus_sample_t *)calloc(bufsize, sizeof(mus_sample_t));
-  reposition_file_buffers_1(beg, io); /* get ready to read -- we're assuming mus_file_read_chans here */
+  io->arrays[chan] = (mus_float_t *)malloc(bufsize * sizeof(mus_float_t));
+  io->arrays[chan][bufsize - 1] = 0.0; /* there is buffer bounds confusion somewhere... */
+  reposition_file_buffers_1(beg, io);  /* get ready to read -- we're assuming mus_file_read_chans here */
   return(io);
 }
 
@@ -368,7 +367,6 @@ static int too_many_files_cleanup(void)
 {
   int *closed;
   int rtn;
-  rtn = -1;
   closed = (int *)malloc(sizeof(int));
   (*closed) = 0;
   for_each_normal_chan_with_refint(close_temp_files, closed);
@@ -400,6 +398,7 @@ int snd_open_read(const char *arg)
 int snd_reopen_write(const char *arg)
 {
   int fd;
+
   fd = OPEN(arg, O_RDWR, 0);
   if ((fd == -1) && 
       (errno == EMFILE))
@@ -439,7 +438,7 @@ io_error_t sndlib_error_to_snd(int sndlib_err)
       case MUS_CANT_OPEN_FILE:           return(IO_CANT_OPEN_FILE);
       case MUS_NO_SUCH_CHANNEL:          return(IO_BAD_CHANNEL);
       case MUS_NO_FILE_NAME_PROVIDED:    return(IO_NO_FILENAME);
-      case MUS_UNSUPPORTED_DATA_FORMAT:  return(IO_BAD_DATA_FORMAT);
+      case MUS_UNSUPPORTED_SAMPLE_TYPE:  return(IO_BAD_SAMPLE_TYPE);
       case MUS_HEADER_READ_FAILED:       return(IO_BAD_HEADER);
       case MUS_UNSUPPORTED_HEADER_TYPE:  return(IO_BAD_HEADER_TYPE);
       case MUS_FILE_DESCRIPTORS_NOT_INITIALIZED: return(IO_SNDLIB_UNINITIALIZED);
@@ -455,34 +454,42 @@ io_error_t sndlib_error_to_snd(int sndlib_err)
 }
 
 
-int snd_file_open_descriptors(int fd, const char *name, int format, mus_long_t location, int chans, int type)
+int snd_file_open_descriptors(int fd, const char *name, mus_sample_t samp_type, mus_long_t location, int chans, mus_header_t type)
 {
-  int sl_err = MUS_NO_ERROR;
-  sl_err = mus_file_open_descriptors(fd, name, format, mus_bytes_per_sample(format), location, chans, type);
+  int sl_err;
+
+  sl_err = mus_file_open_descriptors(fd, name, samp_type, mus_bytes_per_sample(samp_type), location, chans, type);
   if (sl_err != MUS_NO_ERROR)
     snd_warning("%s: open file descriptors: %s", name, mus_error_type_to_string(sl_err));
+
+  if (mus_sound_saved_data(name))
+    mus_file_save_data(fd, mus_sound_framples(name), mus_sound_saved_data(name));
+
   return(sl_err);
 }
 
 
-io_error_t snd_write_header(const char *name, int type, int srate, int chans,
-			    mus_long_t samples, int format, const char *comment,
+io_error_t snd_write_header(const char *name, mus_header_t head_type, int srate, int chans,
+			    mus_long_t samples, mus_sample_t samp_type, const char *comment,
 			    int *loops)
 {
   int err; /* sndlib-style error */
   /* trap mus_error locally here so that callers of open_temp_file can cleanup samplers and whatnot */
+
   local_mus_error = MUS_NO_ERROR;
   old_error_handler = mus_error_set_handler(local_mus_error_to_snd);
   mus_sound_forget(name);
   mus_header_set_aiff_loop_info(loops);
-  err = mus_write_header(name, type, srate, chans, samples, format, comment);
-  if (err == -1)
+
+  err = mus_write_header(name, head_type, srate, chans, samples, samp_type, comment);
+  /* err here is a mus error */
+  if (err != MUS_NO_ERROR)
     {
       if (errno == EMFILE) /* 0 => no error (err not actually returned unless it's -1) */
 	{
 	  err = too_many_files_cleanup();
 	  if (err != -1) 
-	    err = mus_write_header(name, type, srate, chans, samples, format, comment);
+	    mus_write_header(name, head_type, srate, chans, samples, samp_type, comment);
 	  else 
 	    {
 	      mus_error_set_handler(old_error_handler);
@@ -490,8 +497,7 @@ io_error_t snd_write_header(const char *name, int type, int srate, int chans,
 	    }
 	}
     }
-  if (err != -1)
-    mus_header_set_aiff_loop_info(NULL);
+  else mus_header_set_aiff_loop_info(NULL);
   mus_error_set_handler(old_error_handler);
   return(sndlib_error_to_snd(local_mus_error));
 }
@@ -508,17 +514,12 @@ typedef struct {
 
 static tempfile_ctr **tempfiles = NULL;
 static int tempfiles_size = 0;
-#if HAVE_PTHREADS
-  static mus_lock_t temp_file_lock = MUS_LOCK_INITIALIZER;
-#endif
 
 void remember_temp(const char *filename, int chans)
 {
-  int i, old_size;
+  int i;
   tempfile_ctr *tmp = NULL;
 
-  MUS_LOCK(&temp_file_lock);
-
   if (tempfiles_size == 0)
     {
       tempfiles_size = 8;
@@ -530,10 +531,7 @@ void remember_temp(const char *filename, int chans)
       for (i = 0; i < tempfiles_size; i++)
 	if ((tempfiles[i]) &&
 	    (mus_strcmp(filename, tempfiles[i]->name)))
-	  {
-	    MUS_UNLOCK(&temp_file_lock);
-	    return;
-	  }
+	  return;
 
       for (i = 0; i < tempfiles_size; i++)
 	if (tempfiles[i] == NULL)
@@ -541,6 +539,7 @@ void remember_temp(const char *filename, int chans)
 
       if (i >= tempfiles_size)
 	{
+	  int old_size;
 	  old_size = tempfiles_size;
 	  tempfiles_size += 8;
 	  tempfiles = (tempfile_ctr **)realloc(tempfiles, tempfiles_size * sizeof(tempfile_ctr *));
@@ -549,13 +548,11 @@ void remember_temp(const char *filename, int chans)
 	}
     }
 
-  tmp = (tempfile_ctr *)calloc(1, sizeof(tempfile_ctr));
+  tmp = (tempfile_ctr *)malloc(sizeof(tempfile_ctr));
   tempfiles[i] = tmp;
   tmp->name = mus_strdup(filename);
   tmp->chans = chans;
   tmp->ticks = (int *)calloc(chans, sizeof(int));
-
-  MUS_UNLOCK(&temp_file_lock);
 }
 
 
@@ -613,7 +610,7 @@ void forget_temps(void)
 snd_data *make_snd_data_file(const char *name, snd_io *io, file_info *hdr, file_delete_t temp, int ctr, int temp_chan)
 {
   snd_data *sd;
-  sd = (snd_data *)calloc(1, sizeof(snd_data));
+  sd = (snd_data *)malloc(sizeof(snd_data));
   sd->type = SND_DATA_FILE;
   sd->buffered_data = io->arrays[temp_chan];
   sd->io = io;
@@ -626,7 +623,8 @@ snd_data *make_snd_data_file(const char *name, snd_io *io, file_info *hdr, file_
   sd->inuse = false;
   sd->copy = false;
   sd->chan = temp_chan;
-  sd->data_bytes = (hdr->samples) * (mus_bytes_per_sample(hdr->format)) + hdr->data_location;
+  sd->data_bytes = (hdr->samples) * (mus_bytes_per_sample(hdr->sample_type)) + hdr->data_location;
+  sd->free_me = false;
   return(sd);
 }
 
@@ -643,13 +641,13 @@ snd_data *copy_snd_data(snd_data *sd, mus_long_t beg, int bufsize)
     return(NULL);
   snd_file_open_descriptors(fd,
 			    sd->filename,
-			    hdr->format,
+			    hdr->sample_type,
 			    hdr->data_location,
 			    hdr->chans,
 			    hdr->type);
   during_open(fd, sd->filename, SND_COPY_READER);
   io = make_file_state(fd, hdr, sd->chan, beg, bufsize);
-  sf = (snd_data *)calloc(1, sizeof(snd_data));
+  sf = (snd_data *)malloc(sizeof(snd_data));
   sf->type = sd->type;
   sf->buffered_data = io->arrays[sd->chan];
   sf->io = io;
@@ -657,29 +655,37 @@ snd_data *copy_snd_data(snd_data *sd, mus_long_t beg, int bufsize)
   sf->hdr = hdr;
   sf->temporary = DONT_DELETE_ME;
   sf->edit_ctr = sd->edit_ctr;
-  sf->open = FD_OPEN;
+
+  /* 17-Nov-14: this was sf->open = FD_OPEN; but I can't think of any reason to leave it open */
+  sf->open = FD_CLOSED; 
+  sf->io->fd = -1;
+  mus_file_close(fd); 
+
   sf->inuse = false;
   sf->copy = true;
+  sf->chan = 0;
+  sf->data_bytes = 0;
+  sf->free_me = false;
   return(sf);
 }
 
 
-snd_data *make_snd_data_buffer(mus_sample_t *data, int len, int ctr)
+snd_data *make_snd_data_buffer(mus_float_t *data, int len, int ctr)
 {
   snd_data *sf;
   sf = (snd_data *)calloc(1, sizeof(snd_data));
   sf->type = SND_DATA_BUFFER;
-  sf->buffered_data = (mus_sample_t *)malloc((len + 1) * sizeof(mus_sample_t));
+  sf->buffered_data = (mus_float_t *)malloc((len + 1) * sizeof(mus_float_t));
   /* sigh... using len + 1 rather than len to protect against access to inserted buffer at end mixups (final fragment uses end + 1) */
   /*   the real problem here is that I never decided whether insert starts at the cursor or just past it */
   /*   when the cursor is on the final sample, this causes cross-fragment ambiguity as to the length of a trailing insertion */
   /*   C > (make-region 1000 2000) (insert-region (cursor)) C-v hits this empty slot and gets confused about the previously final sample value */
-  memcpy((void *)(sf->buffered_data), (void *)data, len * sizeof(mus_sample_t));
-  sf->buffered_data[len] = MUS_SAMPLE_0;
+  memcpy((void *)(sf->buffered_data), (void *)data, len * sizeof(mus_float_t));
+  sf->buffered_data[len] = 0.0;
   sf->edit_ctr = ctr;
   sf->copy = false;
   sf->inuse = false;
-  sf->data_bytes = len * sizeof(mus_sample_t);
+  sf->data_bytes = len * sizeof(mus_float_t);
   return(sf);
 }
 
@@ -689,11 +695,11 @@ snd_data *make_snd_data_buffer_for_simple_channel(int len)
   snd_data *sf;
   sf = (snd_data *)calloc(1, sizeof(snd_data));
   sf->type = SND_DATA_BUFFER;
-  sf->buffered_data = (mus_sample_t *)calloc(len, sizeof(mus_sample_t));
+  sf->buffered_data = (mus_float_t *)calloc(len, sizeof(mus_float_t));
   sf->edit_ctr = 0;
   sf->copy = false;
   sf->inuse = false;
-  sf->data_bytes = len * sizeof(mus_sample_t);
+  sf->data_bytes = len * sizeof(mus_float_t);
   return(sf);
 }
 
@@ -759,19 +765,19 @@ int open_temp_file(const char *ofile, int chans, file_info *hdr, io_error_t *err
 {
   /* returns io fd */
   int ofd, sl_err = MUS_NO_ERROR;
-  if (!(mus_header_writable(hdr->type, hdr->format)))
+  if (!(mus_header_writable(hdr->type, hdr->sample_type)))
     {
       hdr->type = default_output_header_type(ss);
-      if (mus_header_writable(hdr->type, default_output_data_format(ss)))
-	hdr->format = default_output_data_format(ss);
+      if (mus_header_writable(hdr->type, default_output_sample_type(ss)))
+	hdr->sample_type = default_output_sample_type(ss);
       else
 	{
 	  /* was default_output_* here, but that's for the user's output, not ours */
 	  hdr->type = MUS_NEXT;
-	  hdr->format = MUS_OUT_FORMAT;
+	  hdr->sample_type = MUS_OUT_SAMPLE_TYPE;
 	}
     }
-  (*err) = snd_write_header(ofile, hdr->type, hdr->srate, chans, 0, hdr->format, hdr->comment, hdr->loops);
+  (*err) = snd_write_header(ofile, hdr->type, hdr->srate, chans, 0, hdr->sample_type, hdr->comment, hdr->loops);
   if ((*err) != IO_NO_ERROR)
     {
       /* -1 as fd */
@@ -786,7 +792,7 @@ int open_temp_file(const char *ofile, int chans, file_info *hdr, io_error_t *err
   hdr->data_location = mus_header_data_location(); /* header might have changed size (aiff extras) */
   sl_err = snd_file_open_descriptors(ofd,
 				     ofile,
-				     hdr->format,
+				     hdr->sample_type,
 				     hdr->data_location,
 				     chans,
 				     hdr->type);
@@ -797,7 +803,7 @@ int open_temp_file(const char *ofile, int chans, file_info *hdr, io_error_t *err
 }
 
 
-io_error_t close_temp_file(const char *filename, int ofd, int type, mus_long_t bytes)
+io_error_t close_temp_file(const char *filename, int ofd, mus_header_t type, mus_long_t bytes)
 {
   int err;
   err = mus_file_close(ofd);
@@ -806,6 +812,7 @@ io_error_t close_temp_file(const char *filename, int ofd, int type, mus_long_t b
       local_mus_error = MUS_NO_ERROR;
       old_error_handler = mus_error_set_handler(local_mus_error_to_snd);
       mus_header_change_data_size(filename, type, bytes);
+      mus_sound_forget(filename);
       mus_error_set_handler(old_error_handler);
       return(sndlib_error_to_snd(local_mus_error));
     }
@@ -819,12 +826,12 @@ void set_up_snd_io(chan_info *cp, int i, int fd, const char *filename, file_info
   snd_io *io;
   snd_file_open_descriptors(fd,
 			    filename,
-			    hdr->format,
+			    hdr->sample_type,
 			    hdr->data_location,
 			    hdr->chans,
 			    hdr->type);
   io = make_file_state(fd, hdr, i, 0,
-		       (post_close) ? MAX_BUFFER_SIZE : MIX_FILE_BUFFER_SIZE);
+		       (post_close) ? MAX_BUFFER_SIZE : FILE_BUFFER_SIZE);
   cp->sounds[0] = make_snd_data_file(filename, io,
 				     copy_header(hdr->name, hdr),
 				     DONT_DELETE_ME, cp->edit_ctr, i);
@@ -835,7 +842,7 @@ void set_up_snd_io(chan_info *cp, int i, int fd, const char *filename, file_info
       sd->open = FD_CLOSED; 
       io->fd = -1;
       if (mus_file_close(fd) != 0)
-	snd_error(_("can't close file %s: %s"), filename, snd_io_strerror());
+	snd_error("can't close file %s: %s", filename, snd_io_strerror());
     }
   /* this is not as crazy as it looks -- we've read in the first 64K (or whatever) samples,
    * and may need this file channel for other opens, so this file can be closed until reposition_file_state_buffers
