@@ -44,8 +44,6 @@ static void ps_write(const char *buf)
 }
 
 
-static char *previous_locale = NULL;
-
 static int start_ps_graph(const char *output, const char *title) 
 { 
   ps_fd = CREAT(output, 0666);
@@ -54,24 +52,20 @@ static int start_ps_graph(const char *output, const char *title)
   bbx = 0;
   bby = 0;
 
-#if HAVE_SETLOCALE
-  previous_locale = mus_strdup(setlocale(LC_NUMERIC, "C")); /* must use decimal point in floats since PostScript assumes that format */
-#endif
-
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, 
+  snprintf(pbuf, PRINT_BUFFER_SIZE, 
 	       "%%!PS-Adobe-2.0 EPSF-2.0\n%%%%Title: %s\n%%%%Creator: Snd: %s\n%%%%CreationDate: %s", 
 	       title, 
 	       SND_DATE,
 	       snd_local_time());
   ps_write(pbuf);
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, 
+  snprintf(pbuf, PRINT_BUFFER_SIZE, 
 	       "\n%%%%BoundingBox:(atend)\n%%%%EndComments\n%%%%EndProlog\n%%%%Page: 1 1\n");
   ps_write(pbuf);
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, 
+  snprintf(pbuf, PRINT_BUFFER_SIZE, 
 	       "/LT {lineto} bind def\n/RF {rectfill} bind def\n/RG {setrgbcolor} bind def\n/NAF {newpath arc fill} bind def\n\n");
   ps_write(pbuf);
 
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, 
+  snprintf(pbuf, PRINT_BUFFER_SIZE, 
 	       "gsave [%.3f 0.0 0.0 %.3f %.3f %.3f] concat\n\n",
 	       eps_size(ss), eps_size(ss), eps_left_margin(ss), eps_bottom_margin(ss));
   ps_write(pbuf);
@@ -91,7 +85,7 @@ static void ps_graph(chan_info *cp, int x0, int y0)
 
 static void end_ps_graph(void)
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, 
+  snprintf(pbuf, PRINT_BUFFER_SIZE, 
 	       "%s\nshowpage\n%%%%Trailer\n%%%%BoundingBox: %d %d %d %d\n",
 	       ((eps_left_margin(ss) != 0) || (eps_bottom_margin(ss) != 0)) ? "\ngrestore" : "",
 	       0, 0,
@@ -99,15 +93,7 @@ static void end_ps_graph(void)
 	       (int)(bby + 10 + eps_bottom_margin(ss)));
   ps_write(pbuf);
   ps_flush(ps_fd);
-  snd_close(ps_fd, _("eps file"));
-  if (previous_locale)
-    {
-#if HAVE_SETLOCALE
-      setlocale(LC_NUMERIC, previous_locale);
-#endif
-      free(previous_locale);
-      previous_locale = NULL;
-    }
+  snd_close(ps_fd, "eps file");
   if (nbuf)
     {
       free(nbuf);
@@ -173,14 +159,14 @@ static mus_float_t ps_grf_y(axis_info *ap, mus_float_t val)
 static void ps_draw_lines(axis_info *ap, int j, mus_float_t *xpts, mus_float_t *ypts)
 {
   int i;
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f moveto\n", ps_grf_x(ap, xpts[0]), ps_grf_y(ap, ypts[0]));
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f moveto\n", ps_grf_x(ap, xpts[0]), ps_grf_y(ap, ypts[0]));
   ps_write(pbuf);
   for (i = 1; i < j; i++)
     {
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]));
       ps_write(pbuf);
     }
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " stroke\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " stroke\n");
   ps_write(pbuf);
 }
 
@@ -192,7 +178,7 @@ static void ps_draw_dots(axis_info *ap, int j, mus_float_t *xpts, mus_float_t *y
   arc_size = .5 * dot_size; /* radius here, diameter in X */
   for (i = 0; i < j; i++)
     {
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f 0 360 NAF\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]), arc_size);
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f 0 360 NAF\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]), arc_size);
       ps_write(pbuf);
     }
 }
@@ -203,15 +189,15 @@ static void ps_fill_polygons(axis_info *ap, int j, mus_float_t *xpts, mus_float_
   int i;
   for (i = 1; i < j; i++)
     {
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f moveto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, ypts[i - 1]));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f moveto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, ypts[i - 1]));
       ps_write(pbuf);
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]));
       ps_write(pbuf);
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, y0));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, y0));
       ps_write(pbuf);
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, y0));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, y0));
       ps_write(pbuf);
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " closepath fill\n");
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " closepath fill\n");
       ps_write(pbuf);
     }
 }
@@ -245,7 +231,7 @@ void ps_draw_grf_points(axis_info *ap, int j, mus_float_t y0, graph_style_t grap
 	if (size4 < 1) size4 = 1;
 	for (i = 0; i < j; i++)
 	  {
-	    mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f %.2f RF\n",
+	    snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f %.2f RF\n",
 			 ps_grf_x(ap, xpts[i]) - size8,
 			 (float)gy0,
 			 (float)size4,
@@ -275,15 +261,15 @@ void ps_draw_both_grf_points(axis_info *ap, int j, graph_style_t graph_style, in
     case GRAPH_FILLED:
       for (i = 1; i < j; i++)
 	{
-	  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f moveto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, ypts[i - 1]));
+	  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f moveto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, ypts[i - 1]));
 	  ps_write(pbuf);
-	  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]));
+	  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts[i]));
 	  ps_write(pbuf);
-	  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts1[i]));
+	  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i]), ps_grf_y(ap, ypts1[i]));
 	  ps_write(pbuf);
-	  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, ypts1[i - 1]));
+	  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f lineto\n", ps_grf_x(ap, xpts[i - 1]), ps_grf_y(ap, ypts1[i - 1]));
 	  ps_write(pbuf);
-	  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " closepath fill\n");
+	  snprintf(pbuf, PRINT_BUFFER_SIZE, " closepath fill\n");
 	  ps_write(pbuf);
 	}
       break;
@@ -307,7 +293,7 @@ void ps_draw_both_grf_points(axis_info *ap, int j, graph_style_t graph_style, in
       if (size4 < 1) size4 = 1;
       for (i = 0; i < j; i++)
 	{
-	  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f %.2f RF\n",
+	  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f %.2f RF\n",
 		       ps_grf_x(ap, xpts[i]) - size8,
 		       ps_grf_y(ap, ypts[i]),
 		       (float)size4,
@@ -329,17 +315,17 @@ void ps_draw_sono_rectangle(axis_info *ap, int color, mus_float_t x, mus_float_t
     {
       get_current_color(color_map(ss), color, &r, &g, &b);
       last_color = color;
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n", RGB_TO_FLOAT(r), RGB_TO_FLOAT(g), RGB_TO_FLOAT(b));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n", rgb_to_float(r), rgb_to_float(g), rgb_to_float(b));
       ps_write(pbuf);
     }
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.1f %.1f %.2f %.2f RF\n", ps_grf_x(ap, x) + 2, ps_grf_y(ap, y), width, height);
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.1f %.1f %.2f %.2f RF\n", ps_grf_x(ap, x) + 2, ps_grf_y(ap, y), width, height);
   ps_write(pbuf);
 }
 
 
 void ps_reset_color(void)
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " 0 setgray\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " 0 setgray\n");
   ps_write(pbuf);
   last_color = -1;
 }
@@ -357,17 +343,17 @@ static void ps_set_color(color_t color)
   tmp_color.flags = DoRed | DoGreen | DoBlue;
   tmp_color.pixel = color;
   XQueryColor(dpy, cmap, &tmp_color);
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n",
-	       RGB_TO_FLOAT(tmp_color.red),
-	       RGB_TO_FLOAT(tmp_color.green),
-	       RGB_TO_FLOAT(tmp_color.blue));
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n",
+	       rgb_to_float(tmp_color.red),
+	       rgb_to_float(tmp_color.green),
+	       rgb_to_float(tmp_color.blue));
   ps_write(pbuf);
 #else
   #if USE_GTK
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n", 
-	       RGB_TO_FLOAT(color->red), 
-	       RGB_TO_FLOAT(color->green), 
-	       RGB_TO_FLOAT(color->blue));
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n", 
+	       rgb_to_float(color->red), 
+	       rgb_to_float(color->green), 
+	       rgb_to_float(color->blue));
   ps_write(pbuf);
   #endif
 #endif
@@ -376,7 +362,7 @@ static void ps_set_color(color_t color)
 #endif
 
 
-void ps_bg(axis_info *ap, axis_context *ax)
+void ps_bg(axis_info *ap, graphics_context *ax)
 {
   /* get background color, fill graph, then set foreground for axis */
   chan_info *cp;
@@ -390,22 +376,20 @@ void ps_bg(axis_info *ap, axis_context *ax)
 #else
 #if USE_GTK
   {
-    state_context *sx;
-    sx = ss->sgx;
-    if (cp->cgx->selected) 
-      ps_set_color(sx->selected_graph_color);
-    else ps_set_color(sx->graph_color);
+    if (cp->selected) 
+      ps_set_color(ss->selected_graph_color);
+    else ps_set_color(ss->graph_color);
   }
 #endif
 #endif
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %d %d %d %d RF\n",
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %d %d %d %d RF\n",
 	       ap->graph_x0 + bx0, ap->y_offset + by0, ap->width, ap->height);
   ps_write(pbuf);
   ps_fg(cp, ax);
 }
 
 
-void ps_fg(chan_info *cp, axis_context *ax)
+void ps_fg(chan_info *cp, graphics_context *ax)
 {
   /* set foreground color for subsequent line drawing */
 #if USE_MOTIF
@@ -413,11 +397,9 @@ void ps_fg(chan_info *cp, axis_context *ax)
 #else
 #if USE_GTK
   {
-    state_context *sx;
-    sx = ss->sgx;
-    if (cp->cgx->selected) 
-      ps_set_color(sx->selected_data_color);
-    else ps_set_color(sx->data_color);
+    if (cp->selected) 
+      ps_set_color(ss->selected_data_color);
+    else ps_set_color(ss->data_color);
   }
 #endif
 #endif
@@ -437,7 +419,7 @@ void ps_draw_line(axis_info *ap, int x0, int y0, int x1, int y1)
   if (px1 > bbx) bbx = px1;
   if (py0 > bby) bby = py0;
   if (py1 > bby) bby = py1;
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " 0 setlinewidth %d %d moveto %d %d lineto stroke\n", px0, py0, px1, py1);
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " 0 setlinewidth %d %d moveto %d %d lineto stroke\n", px0, py0, px1, py1);
   ps_write(pbuf);
 }
 
@@ -450,7 +432,7 @@ void ps_draw_spectro_line(axis_info *ap, int color, mus_float_t x0, mus_float_t
     {
       get_current_color(color_map(ss), color, &r, &g, &b);
       last_color = color;
-      mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n", RGB_TO_FLOAT(r), RGB_TO_FLOAT(g), RGB_TO_FLOAT(b));
+      snprintf(pbuf, PRINT_BUFFER_SIZE, " %.2f %.2f %.2f RG\n", rgb_to_float(r), rgb_to_float(g), rgb_to_float(b));
       ps_write(pbuf);
     }
   ps_draw_line(ap, (int)x0, (int)y0, (int)x1, (int)y1);
@@ -468,7 +450,7 @@ void ps_fill_rectangle(axis_info *ap, int x0, int y0, int width, int height)
   if (px1 > bbx) bbx = px1;
   if (py0 > bby) bby = py0;
   if (py1 > bby) bby = py1;
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %d %d %d %d RF\n", px0, py0, width, -height);
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %d %d %d %d RF\n", px0, py0, width, -height);
   ps_write(pbuf);
 }
 
@@ -483,42 +465,42 @@ void ps_draw_string(axis_info *ap, int x0, int y0, const char *str)
 #endif
   if (px0 > bbx) bbx = px0;
   if (py0 > bby) bby = py0;
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " %d %d moveto (%s) show\n", px0, py0, str);
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " %d %d moveto (%s) show\n", px0, py0, str);
   ps_write(pbuf);
 }
 
 
 void ps_set_number_font(void) 
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " /Courier findfont 15 scalefont setfont\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " /Courier findfont 15 scalefont setfont\n");
   ps_write(pbuf);
 }
 
 
 void ps_set_label_font(void) 
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Roman findfont 20 scalefont setfont\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Roman findfont 20 scalefont setfont\n");
   ps_write(pbuf);
 }
 
 
 void ps_set_bold_peak_numbers_font(void) 
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Bold findfont 14 scalefont setfont\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Bold findfont 14 scalefont setfont\n");
   ps_write(pbuf);
 }
 
 
 void ps_set_peak_numbers_font(void) 
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Roman findfont 14 scalefont setfont\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Roman findfont 14 scalefont setfont\n");
   ps_write(pbuf);
 }
 
 
 void ps_set_tiny_numbers_font(void) 
 {
-  mus_snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Roman findfont 12 scalefont setfont\n");
+  snprintf(pbuf, PRINT_BUFFER_SIZE, " /Times-Roman findfont 12 scalefont setfont\n");
   ps_write(pbuf);
 }
 
@@ -531,13 +513,12 @@ static char *snd_print_or_error(const char *output)
     {
       int j, i, err;
       int *offsets = NULL;
-      snd_info *sp;
       sync_info *si;
       chan_info *ccp;
       char *errstr = NULL;
       ccp = current_channel();
       if (ccp == NULL) 
-	return(mus_strdup(_("nothing to print?")));
+	return(mus_strdup("nothing to print?"));
       si = sync_to_chan(ccp);
       offsets = (int *)calloc(si->chans, sizeof(int));
       for (j = 0, i = (si->chans - 1); i >= 0; i--)
@@ -548,6 +529,7 @@ static char *snd_print_or_error(const char *output)
       if (si->chans > 1)
 	for (i = 0; i < si->chans; )
 	  {
+	    snd_info *sp;
 	    sp = (si->cps[i])->sound;
 	    if (sp == NULL) break;
 	    if (sp->channel_style == CHANNELS_COMBINED)
@@ -566,12 +548,12 @@ static char *snd_print_or_error(const char *output)
 	    ps_graph(si->cps[i], 0, offsets[i]);
 	  end_ps_graph();
 	}
-      else errstr = mus_format(_("print %s failed: %s"), output, snd_io_strerror());
-      if (si) si = free_sync_info(si);
+      else errstr = mus_format("print %s failed: %s", output, snd_io_strerror());
+      si = free_sync_info(si);
       if (offsets) free(offsets);
       return(errstr);
     }
-  else return(mus_strdup(_("print sound: eps file name needed")));
+  else return(mus_strdup("print sound: eps file name needed"));
 }
 
 
@@ -589,23 +571,6 @@ bool snd_print(const char *output)
 }
 
 
-void region_print(const char *output, const char *title, chan_info *cp)
-{
-  if ((output) && (*output))
-    {
-      int err;
-      err = start_ps_graph(output, title);
-      if (err == 0)
-	{
-	  ps_graph(cp, 0, 0);
-	  end_ps_graph();
-	}
-      else snd_error(_("print region %s failed: %s"), output, snd_io_strerror());
-    }
-  else snd_error_without_format(_("print region: eps file name needed"));
-}
-
-
 void print_enved(const char *output, int y0)
 {
   if ((output) && (*output))
@@ -619,42 +584,43 @@ void print_enved(const char *output, int y0)
 	  env_redisplay_with_print();
 	  end_ps_graph();
 	}
-      else snd_error(_("print env %s failed: %s"), output, snd_io_strerror());
+      else snd_error("print env %s failed: %s", output, snd_io_strerror());
     }
-  else snd_error_without_format(_("print envelope: eps file name needed"));
+  else snd_error_without_format("print envelope: eps file name needed");
 }
 
 
-static XEN g_graph_to_ps(XEN filename)
+static Xen g_graph_to_ps(Xen filename)
 {
   #define H_graph_to_ps "(" S_graph_to_ps " :optional (filename eps-file)): write the current Snd displays to an EPS file"
+
   char *error;
   const char *file;
 
-  XEN_ASSERT_TYPE(XEN_STRING_IF_BOUND_P(filename), filename, XEN_ONLY_ARG, S_graph_to_ps, "a string (filename)");
+  Xen_check_type(Xen_is_string_or_unbound(filename), filename, 1, S_graph_to_ps, "a string (filename)");
 
-  if (XEN_STRING_P(filename))
-    file = XEN_TO_C_STRING(filename);
+  if (Xen_is_string(filename))
+    file = Xen_string_to_C_string(filename);
   else file = eps_file(ss);
 
   error = snd_print_or_error(file);
   if (error)
     {
-      XEN result;
-      result = C_TO_XEN_STRING(error);
+      Xen result;
+      result = C_string_to_Xen_string(error);
       free(error);
-      XEN_ERROR(XEN_ERROR_TYPE("cannot-print"),
-		XEN_LIST_3(C_TO_XEN_STRING(S_graph_to_ps ": can't print ~S (~A)"),
-			   C_TO_XEN_STRING(file),
+      Xen_error(Xen_make_error_type("cannot-print"),
+		Xen_list_3(C_string_to_Xen_string(S_graph_to_ps ": can't print ~S (~A)"),
+			   C_string_to_Xen_string(file),
 			   result));
     }
-  return(C_TO_XEN_STRING(file));
+  return(C_string_to_Xen_string(file));
 }
 
 
 /* ---------------- gl -> ps ---------------- */
 
-#if HAVE_GL && MUS_WITH_GL2PS
+#if HAVE_GL && WITH_GL2PS
 
 #include "gl2ps.h"
 
@@ -662,7 +628,7 @@ static XEN g_graph_to_ps(XEN filename)
 static int gl2ps_types[NUM_GL2PS_TYPES] = {GL2PS_EPS, GL2PS_PS, GL2PS_PDF, GL2PS_TEX, GL2PS_SVG, GL2PS_PGF};
 
 
-static XEN g_gl_graph_to_ps(XEN filename, XEN output_type, XEN snd, XEN chn)
+static Xen g_gl_graph_to_ps(Xen filename, Xen output_type, Xen snd, Xen chn)
 {
   #define H_gl_graph_to_ps "(" S_gl_graph_to_ps " :optional filename (type 0) snd chn) produces a postscript output file from \
 OpenGL graphics. type can be 0: eps, 1: ps, 2: pdf, 3: tex, 4: svg, 5: pgf."
@@ -672,30 +638,22 @@ OpenGL graphics. type can be 0: eps, 1: ps, 2: pdf, 3: tex, 4: svg, 5: pgf."
   chan_info *cp;
   int state = GL2PS_OVERFLOW, buffsize = 1024 * 1024, type = 0;
 
-#if HAVE_SETLOCALE
-  char *old_locale = NULL;
-#endif
+  Xen_check_type(Xen_is_string_or_unbound(filename), filename, 1, S_gl_graph_to_ps, "a string (filename)");
+  Xen_check_type(Xen_is_integer_or_unbound(output_type), output_type, 2, S_gl_graph_to_ps, "an integer, 0=eps");
 
-  XEN_ASSERT_TYPE(XEN_STRING_IF_BOUND_P(filename), filename, XEN_ARG_1, S_gl_graph_to_ps, "a string (filename)");
-  XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(output_type), output_type, XEN_ARG_2, S_gl_graph_to_ps, "an integer, 0=eps");
-
-  ASSERT_CHANNEL(S_gl_graph_to_ps, snd, chn, 3);
+  Snd_assert_channel(S_gl_graph_to_ps, snd, chn, 3);
   cp = get_cp(snd, chn, S_gl_graph_to_ps);
-  if (!cp) return(XEN_FALSE);
+  if (!cp) return(Xen_false);
 
-  if (XEN_STRING_P(filename))
-    file = XEN_TO_C_STRING(filename);
+  if (Xen_is_string(filename))
+    file = Xen_string_to_C_string(filename);
   else file = eps_file(ss);
 
-  if (XEN_INTEGER_P(output_type))
-    type = XEN_TO_C_INT(output_type);
+  if (Xen_is_integer(output_type))
+    type = Xen_integer_to_C_int(output_type);
   if ((type < 0) || (type >= NUM_GL2PS_TYPES))
-    XEN_OUT_OF_RANGE_ERROR(S_gl_graph_to_ps, XEN_ARG_2, output_type, "must be between 0 and 5");
+    Xen_out_of_range_error(S_gl_graph_to_ps, 2, output_type, "must be between 0 and 5");
 
-#if HAVE_SETLOCALE
-  old_locale = mus_strdup(setlocale(LC_NUMERIC, "C"));
-#endif
-  
   fp = fopen(file, "wb");
 
   while (state == GL2PS_OVERFLOW)
@@ -722,12 +680,8 @@ OpenGL graphics. type can be 0: eps, 1: ps, 2: pdf, 3: tex, 4: svg, 5: pgf."
 	}
     }
   fclose(fp);
-#if HAVE_SETLOCALE
-  setlocale(LC_NUMERIC, old_locale);
-  if (old_locale) free(old_locale);
-#endif
   
-  return(C_TO_XEN_STRING(file));
+  return(C_string_to_Xen_string(file));
 }
   
 
@@ -749,108 +703,114 @@ void gl2ps_text(const char *msg)
 
 #else
 
-static XEN g_gl_graph_to_ps(XEN filename, XEN output_type, XEN snd_ignore, XEN chn_ignore)
+static Xen g_gl_graph_to_ps(Xen filename, Xen output_type, Xen snd_ignore, Xen chn_ignore)
 {
   #define H_gl_graph_to_ps "gl-graph->ps is a no-op in this version of Snd"
-  XEN_ASSERT_TYPE(XEN_STRING_IF_BOUND_P(filename), filename, XEN_ARG_1, S_gl_graph_to_ps, "a string (filename)");
-  XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(output_type), output_type, XEN_ARG_2, S_gl_graph_to_ps, "an integer, 0=eps");
-  return(XEN_FALSE);
+  Xen_check_type(Xen_is_string_or_unbound(filename), filename, 1, S_gl_graph_to_ps, "a string (filename)");
+  Xen_check_type(Xen_is_integer_or_unbound(output_type), output_type, 2, S_gl_graph_to_ps, "an integer, 0=eps");
+  return(Xen_false);
 }
 #endif
 
 /* -------------------------------- */
 
 
-static XEN g_eps_file(void) {return(C_TO_XEN_STRING(eps_file(ss)));}
+static Xen g_eps_file(void) {return(C_string_to_Xen_string(eps_file(ss)));}
 
-static XEN g_set_eps_file(XEN val) 
+static Xen g_set_eps_file(Xen val) 
 {
   #define H_eps_file "(" S_eps_file "): File:Print and " S_graph_to_ps " file name (snd.eps)"
-  XEN_ASSERT_TYPE(XEN_STRING_P(val), val, XEN_ONLY_ARG, S_setB S_eps_file, "a string"); 
+  Xen_check_type(Xen_is_string(val), val, 1, S_set S_eps_file, "a string"); 
   if (eps_file(ss)) free(eps_file(ss));
-  set_eps_file(mus_strdup(XEN_TO_C_STRING(val))); 
-  return(C_TO_XEN_STRING(eps_file(ss)));
+  set_eps_file(mus_strdup(Xen_string_to_C_string(val))); 
+  return(C_string_to_Xen_string(eps_file(ss)));
 }
 
 
 #define MAX_EPS_MARGIN 1000.0
 
-static XEN g_eps_left_margin(void) {return(C_TO_XEN_DOUBLE(eps_left_margin(ss)));}
+static Xen g_eps_left_margin(void) {return(C_double_to_Xen_real(eps_left_margin(ss)));}
 
-static XEN g_set_eps_left_margin(XEN val) 
+static Xen g_set_eps_left_margin(Xen val) 
 {
   #define H_eps_left_margin "(" S_eps_left_margin "): File:Print and " S_graph_to_ps " left margin"
-  XEN_ASSERT_TYPE(XEN_NUMBER_P(val), val, XEN_ONLY_ARG, S_setB S_eps_left_margin, "a number"); 
-  set_eps_left_margin(mus_fclamp(0.0, XEN_TO_C_DOUBLE(val), MAX_EPS_MARGIN));
-  return(C_TO_XEN_DOUBLE(eps_left_margin(ss)));
+  Xen_check_type(Xen_is_number(val), val, 1, S_set S_eps_left_margin, "a number"); 
+  set_eps_left_margin(mus_fclamp(0.0, Xen_real_to_C_double(val), MAX_EPS_MARGIN));
+  return(C_double_to_Xen_real(eps_left_margin(ss)));
 }
 
 
-static XEN g_eps_bottom_margin(void) {return(C_TO_XEN_DOUBLE(eps_bottom_margin(ss)));}
+static Xen g_eps_bottom_margin(void) {return(C_double_to_Xen_real(eps_bottom_margin(ss)));}
 
-static XEN g_set_eps_bottom_margin(XEN val) 
+static Xen g_set_eps_bottom_margin(Xen val) 
 {
   #define H_eps_bottom_margin "(" S_eps_bottom_margin "): File:Print and " S_graph_to_ps " bottom margin"
-  XEN_ASSERT_TYPE(XEN_NUMBER_P(val), val, XEN_ONLY_ARG, S_setB S_eps_bottom_margin, "a number"); 
-  set_eps_bottom_margin(mus_fclamp(0.0, XEN_TO_C_DOUBLE(val), MAX_EPS_MARGIN));
-  return(C_TO_XEN_DOUBLE(eps_bottom_margin(ss)));
+  Xen_check_type(Xen_is_number(val), val, 1, S_set S_eps_bottom_margin, "a number"); 
+  set_eps_bottom_margin(mus_fclamp(0.0, Xen_real_to_C_double(val), MAX_EPS_MARGIN));
+  return(C_double_to_Xen_real(eps_bottom_margin(ss)));
 }
 
 
-static XEN g_eps_size(void) {return(C_TO_XEN_DOUBLE(eps_size(ss)));}
+static Xen g_eps_size(void) {return(C_double_to_Xen_real(eps_size(ss)));}
 
-static XEN g_set_eps_size(XEN val) 
+static Xen g_set_eps_size(Xen val) 
 {
   #define MAX_EPS_SIZE 1000.0
   #define H_eps_size "(" S_eps_size "): File:Print and " S_graph_to_ps " output size scaler (1.0)"
-  XEN_ASSERT_TYPE(XEN_NUMBER_P(val), val, XEN_ONLY_ARG, S_setB S_eps_size, "a number"); 
-  set_eps_size(mus_fclamp(0.0, XEN_TO_C_DOUBLE(val), MAX_EPS_SIZE));
-  return(C_TO_XEN_DOUBLE(eps_size(ss)));
+  Xen_check_type(Xen_is_number(val), val, 1, S_set S_eps_size, "a number"); 
+  set_eps_size(mus_fclamp(0.0, Xen_real_to_C_double(val), MAX_EPS_SIZE));
+  return(C_double_to_Xen_real(eps_size(ss)));
 }
 
 
-#ifdef XEN_ARGIFY_1
-XEN_ARGIFY_1(g_graph_to_ps_w, g_graph_to_ps)
-XEN_ARGIFY_4(g_gl_graph_to_ps_w, g_gl_graph_to_ps)
-XEN_NARGIFY_0(g_eps_file_w, g_eps_file)
-XEN_NARGIFY_1(g_set_eps_file_w, g_set_eps_file)
-XEN_NARGIFY_0(g_eps_left_margin_w, g_eps_left_margin)
-XEN_NARGIFY_1(g_set_eps_left_margin_w, g_set_eps_left_margin)
-XEN_NARGIFY_0(g_eps_size_w, g_eps_size)
-XEN_NARGIFY_1(g_set_eps_size_w, g_set_eps_size)
-XEN_NARGIFY_0(g_eps_bottom_margin_w, g_eps_bottom_margin)
-XEN_NARGIFY_1(g_set_eps_bottom_margin_w, g_set_eps_bottom_margin)
-#else
-#define g_graph_to_ps_w g_graph_to_ps
-#define g_gl_graph_to_ps_w g_gl_graph_to_ps
-#define g_eps_file_w g_eps_file
-#define g_set_eps_file_w g_set_eps_file
-#define g_eps_left_margin_w g_eps_left_margin
-#define g_set_eps_left_margin_w g_set_eps_left_margin
-#define g_eps_size_w g_eps_size
-#define g_set_eps_size_w g_set_eps_size
-#define g_eps_bottom_margin_w g_eps_bottom_margin
-#define g_set_eps_bottom_margin_w g_set_eps_bottom_margin
+Xen_wrap_1_optional_arg(g_graph_to_ps_w, g_graph_to_ps)
+Xen_wrap_4_optional_args(g_gl_graph_to_ps_w, g_gl_graph_to_ps)
+Xen_wrap_no_args(g_eps_file_w, g_eps_file)
+Xen_wrap_1_arg(g_set_eps_file_w, g_set_eps_file)
+Xen_wrap_no_args(g_eps_left_margin_w, g_eps_left_margin)
+Xen_wrap_1_arg(g_set_eps_left_margin_w, g_set_eps_left_margin)
+Xen_wrap_no_args(g_eps_size_w, g_eps_size)
+Xen_wrap_1_arg(g_set_eps_size_w, g_set_eps_size)
+Xen_wrap_no_args(g_eps_bottom_margin_w, g_eps_bottom_margin)
+Xen_wrap_1_arg(g_set_eps_bottom_margin_w, g_set_eps_bottom_margin)
+
+#if HAVE_SCHEME
+static s7_pointer acc_eps_bottom_margin(s7_scheme *sc, s7_pointer args) {return(g_set_eps_bottom_margin(s7_cadr(args)));}
+static s7_pointer acc_eps_file(s7_scheme *sc, s7_pointer args) {return(g_set_eps_file(s7_cadr(args)));}
+static s7_pointer acc_eps_left_margin(s7_scheme *sc, s7_pointer args) {return(g_set_eps_left_margin(s7_cadr(args)));}
+static s7_pointer acc_eps_size(s7_scheme *sc, s7_pointer args) {return(g_set_eps_size(s7_cadr(args)));}
 #endif
 
 void g_init_print(void)
 {
-  XEN_DEFINE_PROCEDURE(S_graph_to_ps, g_graph_to_ps_w, 0, 1, 0, H_graph_to_ps);
-  XEN_DEFINE_PROCEDURE(S_gl_graph_to_ps, g_gl_graph_to_ps_w, 0, 4, 0, H_gl_graph_to_ps);
+  Xen_define_procedure(S_graph_to_ps, g_graph_to_ps_w, 0, 1, 0, H_graph_to_ps);
+  Xen_define_procedure(S_gl_graph_to_ps, g_gl_graph_to_ps_w, 0, 4, 0, H_gl_graph_to_ps);
 
-  XEN_DEFINE_PROCEDURE_WITH_SETTER(S_eps_file, g_eps_file_w, H_eps_file,
-				   S_setB S_eps_file, g_set_eps_file_w,  0, 0, 1, 0);
+  Xen_define_dilambda(S_eps_file, g_eps_file_w, H_eps_file,
+				   S_set S_eps_file, g_set_eps_file_w,  0, 0, 1, 0);
 
-  XEN_DEFINE_PROCEDURE_WITH_SETTER(S_eps_left_margin, g_eps_left_margin_w, H_eps_left_margin,
-				   S_setB S_eps_left_margin, g_set_eps_left_margin_w,  0, 0, 1, 0);
+  Xen_define_dilambda(S_eps_left_margin, g_eps_left_margin_w, H_eps_left_margin,
+				   S_set S_eps_left_margin, g_set_eps_left_margin_w,  0, 0, 1, 0);
   
-  XEN_DEFINE_PROCEDURE_WITH_SETTER(S_eps_bottom_margin, g_eps_bottom_margin_w, H_eps_bottom_margin,
-				   S_setB S_eps_bottom_margin, g_set_eps_bottom_margin_w,  0, 0, 1, 0);
+  Xen_define_dilambda(S_eps_bottom_margin, g_eps_bottom_margin_w, H_eps_bottom_margin,
+				   S_set S_eps_bottom_margin, g_set_eps_bottom_margin_w,  0, 0, 1, 0);
 
-  XEN_DEFINE_PROCEDURE_WITH_SETTER(S_eps_size, g_eps_size_w, H_eps_size,
-				   S_setB S_eps_size, g_set_eps_size_w,  0, 0, 1, 0);
+  Xen_define_dilambda(S_eps_size, g_eps_size_w, H_eps_size,
+				   S_set S_eps_size, g_set_eps_size_w,  0, 0, 1, 0);
 
-#if HAVE_GL && MUS_WITH_GL2PS
-  XEN_YES_WE_HAVE("gl2ps");
+#if HAVE_GL && WITH_GL2PS
+  Xen_provide_feature("gl2ps");
+#endif
+
+#if HAVE_SCHEME
+  s7_symbol_set_access(s7, ss->eps_bottom_margin_symbol, s7_make_function(s7, "[acc-" S_eps_bottom_margin "]", acc_eps_bottom_margin, 2, 0, false, "accessor"));
+  s7_symbol_set_access(s7, ss->eps_file_symbol, s7_make_function(s7, "[acc-" S_eps_file "]", acc_eps_file, 2, 0, false, "accessor"));
+  s7_symbol_set_access(s7, ss->eps_left_margin_symbol, s7_make_function(s7, "[acc-" S_eps_left_margin "]", acc_eps_left_margin, 2, 0, false, "accessor"));
+  s7_symbol_set_access(s7, ss->eps_size_symbol, s7_make_function(s7, "[acc-" S_eps_size "]", acc_eps_size, 2, 0, false, "accessor"));
+
+  s7_symbol_set_documentation(s7, ss->eps_bottom_margin_symbol, "*eps-bottom-margin*: File:Print and graph->ps bottom margin");
+  s7_symbol_set_documentation(s7, ss->eps_file_symbol, "*eps-file*: File:Print and graph->ps file name (snd.eps)");
+  s7_symbol_set_documentation(s7, ss->eps_left_margin_symbol, "*eps-left-margin*: File:Print and graph->ps left margin");
+  s7_symbol_set_documentation(s7, ss->eps_size_symbol, "*eps-size*: File:Print and graph->ps output size scaler (1.0)");
 #endif
 }
