@@ -14,7 +14,6 @@
 #define S_add_to_main_menu              "add-to-main-menu"
 #define S_add_to_menu                   "add-to-menu"
 #define S_add_transform                 "add-transform"
-#define S_add_watcher                   "add-watcher"
 #define S_after_apply_controls_hook     "after-apply-controls-hook"
 #define S_after_edit_hook               "after-edit-hook"
 #define S_after_graph_hook              "after-graph-hook"
@@ -28,8 +27,7 @@
 #define S_apply_controls                "apply-controls"
 #define S_as_one_edit                   "as-one-edit"
 #define S_ask_before_overwrite          "ask-before-overwrite"
-#define S_audio_input_device            "audio-input-device"
-#define S_audio_output_device           "audio-output-device"
+#define S_ask_about_unsaved_edits       "ask-about-unsaved-edits"
 #define S_auto_resize                   "auto-resize"
 #define S_auto_update                   "auto-update"
 #define S_auto_update_interval          "auto-update-interval"
@@ -50,16 +48,15 @@
 #define S_before_transform_hook         "before-transform-hook"
 #define S_bind_key                      "bind-key"  
 #define S_bold_peaks_font               "bold-peaks-font"
-#define S_bomb                          "bomb"
+#if (!HAVE_SCHEME)
 #define S_c_g                           "c-g?"
-#define S_c_g_x                         "c-g!"
+#endif
 #define S_cepstrum                      "cepstrum"
 #define S_channel_amp_envs              "channel-amp-envs"
 #define S_channel_data                  "channel-data"
 #define S_channel_properties            "channel-properties"
 #define S_channel_property              "channel-property"
 #define S_channel_style                 "channel-style"
-#define S_channel_to_vct                "channel->vct"
 #define S_channel_widgets               "channel-widgets"
 #define S_channels                      "channels"
 #define S_channels_combined             "channels-combined"
@@ -67,7 +64,6 @@
 #define S_channels_superimposed         "channels-superimposed"
 #define S_chans                         "chans"
 #define S_clear_listener                "clear-listener"
-#define S_clear_minibuffer              "clear-minibuffer"
 #define S_clip_hook                     "clip-hook"
 #define S_clipping                      "clipping"
 #define S_clm_channel                   "clm-channel"
@@ -77,20 +73,21 @@
 #define S_color_orientation_dialog      "color-orientation-dialog"
 #define S_color_hook                    "color-hook"
 #define S_color_inverted                "color-inverted"
-#define S_color_p                       "color?"
+#define S_is_color                      "color?"
 #define S_color_scale                   "color-scale"
 #define S_color_to_list                 "color->list"
 #define S_colormap                      "colormap"
 #define S_colormap_name                 "colormap-name"
-#define S_colormap_p                    "colormap?"
+#define S_is_colormap                   "colormap?"
 #define S_colormap_ref                  "colormap-ref"
 #define S_colormap_size                 "colormap-size"
 #define S_colormap_to_integer           "colormap->integer"
+#define S_combined_data_color           "combined-data-color"
 #define S_comment                       "comment"
 #define S_contrast_control              "contrast-control"
 #define S_contrast_control_amp          "contrast-control-amp"
 #define S_contrast_control_bounds       "contrast-control-bounds"
-#define S_contrast_control_p            "contrast-control?"
+#define S_contrast_control_on           "contrast-control?"
 #define S_controls_to_channel           "controls->channel"
 #define S_convolve_selection_with       "convolve-selection-with"
 #define S_convolve_with                 "convolve-with"
@@ -114,14 +111,13 @@
 #define S_cursor_style                  "cursor-style"
 #define S_cursor_update_interval        "cursor-update-interval"
 #define S_dac_combines_channels         "dac-combines-channels"
-#define S_dac_hook                      "dac-hook"
 #define S_dac_size                      "dac-size"
 #define S_data_color                    "data-color"
-#define S_data_format                   "data-format"
+#define S_sample_type                   "sample-type"
 #define S_data_location                 "data-location"
 #define S_data_size                     "data-size"
 #define S_default_output_chans          "default-output-chans"
-#define S_default_output_data_format    "default-output-data-format"
+#define S_default_output_sample_type    "default-output-sample-type"
 #define S_default_output_srate          "default-output-srate"
 #define S_default_output_header_type    "default-output-header-type"
 #define S_define_envelope               "define-envelope"
@@ -132,13 +128,12 @@
 #define S_delete_marks                  "delete-marks"
 #define S_delete_sample                 "delete-sample"
 #define S_delete_samples                "delete-samples"
+#define S_delete_samples_and_smooth     "delete-samples-and-smooth"
 #define S_delete_selection              "delete-selection"
+#define S_delete_selection_and_smooth   "delete-selection-and-smooth"
 #define S_delete_transform              "delete-transform"
-#define S_delete_watcher                "delete-watcher"
 #define S_dialog_widgets                "dialog-widgets"
 #define S_display_edits                 "display-edits"
-#define S_doit_again_button_color       "doit-again-button-color"
-#define S_doit_button_color             "doit-button-color"
 #define S_dont_normalize                "dont-normalize"
 #define S_dot_size                      "dot-size"
 #define S_draw_axes                     "draw-axes"
@@ -160,6 +155,7 @@
 #define S_edit_property                 "edit-property"
 #define S_edit_tree                     "edit-tree"
 #define S_edits                         "edits"
+#define S_effects_hook                  "effects-hook"
 #define S_env_channel                   "env-channel"
 #define S_env_channel_with_base         "env-channel-with-base"
 #define S_env_selection                 "env-selection"
@@ -167,7 +163,7 @@
 #define S_enved_add_point               "enved-add-point"
 #define S_enved_amplitude               "enved-amplitude"
 #define S_enved_base                    "enved-base"
-#define S_enved_clip_p                  "enved-clip?"
+#define S_enved_clipping                "enved-clip?"
 #define S_enved_delete_point            "enved-delete-point"
 #define S_enved_dialog                  "enved-dialog"
 #define S_enved_envelope                "enved-envelope"
@@ -181,7 +177,7 @@
 #define S_enved_srate                   "enved-srate"
 #define S_enved_style                   "enved-style"
 #define S_enved_target                  "enved-target"
-#define S_enved_wave_p                  "enved-wave?"
+#define S_enved_with_wave               "enved-wave?"
 #define S_enved_waveform_color          "enved-waveform-color"
 #define S_envelope_exponential          "envelope-exponential"
 #define S_envelope_linear               "envelope-linear"
@@ -196,7 +192,7 @@
 #define S_expand_control_hop            "expand-control-hop"
 #define S_expand_control_jitter         "expand-control-jitter"
 #define S_expand_control_length         "expand-control-length"
-#define S_expand_control_p              "expand-control?"
+#define S_expand_control_on             "expand-control?"
 #define S_expand_control_ramp           "expand-control-ramp"
 #define S_fft                           "fft"
 #define S_fft_log_frequency             "fft-log-frequency"
@@ -214,7 +210,7 @@
 #define S_filter_control_in_dB          "filter-control-in-dB"
 #define S_filter_control_in_hz          "filter-control-in-hz"
 #define S_filter_control_order          "filter-control-order"
-#define S_filter_control_p              "filter-control?"
+#define S_filter_control_on             "filter-control?"
 #define S_filter_control_waveform_color "filter-control-waveform-color"
 #define S_filter_selection              "filter-selection"
 #define S_filter_sound                  "filter-sound"
@@ -227,7 +223,8 @@
 #define S_foreground_color              "foreground-color"
 #define S_forget_region                 "forget-region"
 #define S_fourier_transform             "fourier-transform"
-#define S_frames                        "frames"
+#define S_framples                      "framples"
+#define S_free_cairo                    "free-cairo"
 #define S_free_player                   "free-player"
 #define S_free_sampler                  "free-sampler"
 #define S_gl_graph_to_ps                "gl-graph->ps"
@@ -252,7 +249,6 @@
 #define S_grid_density                  "grid-density"
 #define S_haar_transform                "haar-transform"
 #define S_header_type                   "header-type"
-#define S_help_button_color             "help-button-color"
 #define S_help_dialog                   "help-dialog"
 #define S_help_hook                     "help-hook"
 #define S_hide_widget                   "hide-widget"
@@ -265,6 +261,8 @@
   #define S_in                          "in"
 #endif
 #define S_info_dialog                   "info-dialog"
+#define S_initial_beg                   "initial-beg"
+#define S_initial_dur                   "initial-dur"
 #define S_initial_graph_hook            "initial-graph-hook"
 #define S_insert_file_dialog            "insert-file-dialog"
 #define S_insert_region                 "insert-region"
@@ -288,10 +286,11 @@
 #define S_left_sample                   "left-sample"
 #define S_lisp_graph                    "lisp-graph"
 #define S_lisp_graph_hook               "lisp-graph-hook"
-#define S_lisp_graph_p                  "lisp-graph?"
+#define S_lisp_graph_on                 "lisp-graph?"
 #define S_lisp_graph_style              "lisp-graph-style"
 #define S_listener_click_hook           "listener-click-hook"
 #define S_listener_color                "listener-color"
+#define S_listener_colorized            "listener-colorized"
 #define S_listener_font                 "listener-font"
 #define S_listener_prompt               "listener-prompt"
 #define S_listener_selection            "listener-selection"
@@ -299,6 +298,7 @@
 #define S_log_freq_start                "log-freq-start"
 #define S_main_menu                     "main-menu"
 #define S_main_widgets                  "main-widgets"
+#define S_make_cairo                    "make-cairo"
 #define S_make_color                    "make-color"
 #define S_make_graph_data               "make-graph-data"
 #define S_make_mix_sampler              "make-mix-sampler"
@@ -314,13 +314,12 @@
 #define S_mark_color                    "mark-color"
 #define S_mark_context                  "mark-context"
 #define S_mark_drag_hook                "mark-drag-hook"
-#define S_mark_drag_triangle_hook       "mark-drag-triangle-hook"
 #define S_mark_home                     "mark-home"
 #define S_mark_hook                     "mark-hook"
 #define S_mark_name                     "mark-name"
 #define S_mark_properties               "mark-properties"
 #define S_mark_property                 "mark-property"
-#define S_mark_p                        "mark?"
+#define S_is_mark                       "mark?"
 #define S_mark_sample                   "mark-sample"
 #define S_mark_sync                     "mark-sync"
 #define S_mark_sync_max                 "mark-sync-max"
@@ -330,12 +329,10 @@
 #define S_marks                         "marks"
 #define S_max_regions                   "max-regions"
 #define S_max_transform_peaks           "max-transform-peaks"
-#define S_max_virtual_ptrees            "max-virtual-ptrees"
 #define S_maxamp                        "maxamp"
 #define S_maxamp_position               "maxamp-position"
 #define S_menu_widgets                  "menu-widgets"
 #define S_min_dB                        "min-dB"
-#define S_minibuffer_history_length     "minibuffer-history-length"
 #define S_mix                           "mix"
 #define S_mix_amp                       "mix-amp"
 #define S_mix_amp_env                   "mix-amp-env"
@@ -346,14 +343,14 @@
 #define S_mix_file_dialog               "mix-file-dialog"
 #define S_mix_length                    "mix-length"
 #define S_mix_home                      "mix-home"
-#define S_mix_p                         "mix?"
+#define S_is_mix                        "mix?"
 #define S_mix_name                      "mix-name"
 #define S_mix_position                  "mix-position"
 #define S_mix_properties                "mix-properties"
 #define S_mix_property                  "mix-property"
 #define S_mix_region                    "mix-region"
 #define S_mix_release_hook              "mix-release-hook"
-#define S_mix_sampler_p                 "mix-sampler?"
+#define S_is_mix_sampler                "mix-sampler?"
 #define S_mix_selection                 "mix-selection"
 #define S_mix_speed                     "mix-speed"
 #define S_mix_sync                      "mix-sync"
@@ -362,7 +359,6 @@
 #define S_mix_tag_width                 "mix-tag-width"
 #define S_mix_tag_y                     "mix-tag-y"
 #define S_mix_to_integer                "mix->integer"
-#define S_mix_vct                       "mix-vct"
 #define S_mix_waveform_height           "mix-waveform-height"
 #define S_mixes                         "mixes"
 #define S_mouse_click_hook              "mouse-click-hook"
@@ -392,22 +388,19 @@
 #define S_open_raw_sound                "open-raw-sound"
 #define S_open_raw_sound_hook           "open-raw-sound-hook"
 #define S_open_sound                    "open-sound"
-#define S_optimization                  "optimization"
-#define S_optimization_hook             "optimization-hook"
 #define S_orientation_hook              "orientation-hook"
 #define S_output_comment_hook           "output-comment-hook"
-#define S_output_name_hook              "output-name-hook"
 #define S_pad_channel                   "pad-channel"
 #define S_pausing                       "pausing"
 #define S_peak_env_dir                  "peak-env-dir"
-#define S_peak_env_hook                 "peak-env-hook"
 #define S_peaks                         "peaks"
 #define S_peaks_font                    "peaks-font"
 #define S_play                          "play"
+#define S_play_arrow_size               "play-arrow-size"
 #define S_play_hook                     "play-hook"
 #define S_playing                       "playing"
 #define S_player_home                   "player-home"
-#define S_player_p                      "player?"
+#define S_is_player                     "player?"
 #define S_players                       "players"
 #define S_position_color                "position-color"
 #define S_position_to_x                 "position->x"
@@ -415,42 +408,34 @@
 #define S_preferences_dialog            "preferences-dialog"
 #define S_previous_sample               "previous-sample"
 #define S_print_dialog                  "print-dialog"
-#define S_print_hook                    "print-hook"
 #define S_print_length                  "print-length"
 #define S_progress_report               "progress-report"
-#define S_prompt_in_minibuffer          "prompt-in-minibuffer"
-#define S_ptree_channel                 "ptree-channel"
-#define S_pushed_button_color           "pushed-button-color"
-#define S_quit_button_color             "quit-button-color"
 #define S_ramp_channel                  "ramp-channel"
 #define S_read_hook                     "read-hook"
 #define S_read_mix_sample               "read-mix-sample"
 #define S_read_only                     "read-only"
 #define S_read_region_sample            "read-region-sample"
 #define S_read_sample                   "read-sample"
-#define S_recorder_dialog               "recorder-dialog"
 #if HAVE_RUBY
   #define S_redo                        "redo-edit"
 #else
   #define S_redo                        "redo"
 #endif
 #define S_region_chans                  "region-chans"
-#define S_region_frames                 "region-frames"
+#define S_region_framples               "region-framples"
 #define S_region_graph_style            "region-graph-style"
 #define S_region_home                   "region-home"
 #define S_region_maxamp                 "region-maxamp"
 #define S_region_maxamp_position        "region-maxamp-position"
-#define S_region_p                      "region?"
+#define S_is_region                     "region?"
 #define S_region_position               "region-position"
 #define S_region_sample                 "region-sample"
-#define S_region_sampler_p              "region-sampler?"
+#define S_is_region_sampler             "region-sampler?"
 #define S_region_srate                  "region-srate"
 #define S_region_to_integer             "region->integer"
-#define S_region_to_vct                 "region->vct"
 #define S_regions                       "regions"
+#define S_remember_sound_state          "remember-sound-state"
 #define S_remove_from_menu              "remove-from-menu"
-#define S_report_in_minibuffer          "report-in-minibuffer"
-#define S_reset_button_color            "reset-button-color"
 #define S_reset_controls                "reset-controls"
 #define S_reset_listener_cursor         "reset-listener-cursor"
 #define S_restore_controls              "restore-controls"
@@ -460,7 +445,7 @@
 #define S_reverb_control_length         "reverb-control-length"
 #define S_reverb_control_length_bounds  "reverb-control-length-bounds"
 #define S_reverb_control_lowpass        "reverb-control-lowpass"
-#define S_reverb_control_p              "reverb-control?"
+#define S_reverb_control_on             "reverb-control?"
 #define S_reverb_control_scale          "reverb-control-scale"
 #define S_reverb_control_scale_bounds   "reverb-control-scale-bounds"
 #define S_reverse_channel               "reverse-channel"
@@ -468,21 +453,21 @@
 #define S_reverse_sound                 "reverse-sound"
 #define S_revert_sound                  "revert-sound"
 #define S_right_sample                  "right-sample"
-#define S_run                           "run"
 #define S_sample                        "sample"
-#define S_sampler_at_end_p              "sampler-at-end?"
+#define S_is_sampler_at_end             "sampler-at-end?"
 #define S_sampler_home                  "sampler-home"
-#define S_sampler_p                     "sampler?"
+#define S_is_sampler                    "sampler?"
 #define S_sampler_position              "sampler-position"
 #define S_samples                       "samples"
 #define S_sash_color                    "sash-color"
+#define S_save_as_dialog_src            "save-as-dialog-src"
+#define S_save_as_dialog_auto_comment   "save-as-dialog-auto-comment"
 #define S_save_controls                 "save-controls"
 #define S_save_dir                      "save-dir"
 #define S_save_edit_history             "save-edit-history"
 #define S_save_envelopes                "save-envelopes"
 #define S_save_hook                     "save-hook"
 #define S_save_listener                 "save-listener"
-#define S_save_macros                   "save-macros"
 #define S_save_marks                    "save-marks"
 #define S_save_mix                      "save-mix"
 #define S_save_region                   "save-region"
@@ -519,12 +504,12 @@
 #define S_selection_color               "selection-color"
 #define S_selection_context             "selection-context"
 #define S_selection_creates_region      "selection-creates-region"
-#define S_selection_frames              "selection-frames"
+#define S_selection_framples            "selection-framples"
 #define S_selection_maxamp              "selection-maxamp"
 #define S_selection_maxamp_position     "selection-maxamp-position"
 #define S_selection_member              "selection-member?"
 #define S_selection_to_mix              "selection->mix"
-#define S_selection_p                   "selection?"
+#define S_is_selection                  "selection?"
 #define S_selection_position            "selection-position"
 #define S_selection_srate               "selection-srate"
 #define S_short_file_name               "short-file-name"
@@ -533,12 +518,15 @@
 #define S_show_axes                     "show-axes"
 #define S_show_bare_x_axis              "show-bare-x-axis"
 #define S_show_controls                 "show-controls"
+#define S_show_full_duration            "show-full-duration"
+#define S_show_full_range               "show-full-range"
 #define S_show_grid                     "show-grid"
 #define S_show_indices                  "show-indices"
 #define S_show_listener                 "show-listener"
 #define S_show_marks                    "show-marks"
 #define S_show_mix_waveforms            "show-mix-waveforms"
 #define S_show_no_axes                  "show-no-axes"
+#define S_show_selection                "show-selection"
 #define S_show_selection_transform      "show-selection-transform"
 #define S_show_sonogram_cursor          "show-sonogram-cursor"
 #define S_show_transform_peaks          "show-transform-peaks"
@@ -565,17 +553,17 @@
 #define S_snd_spectrum                  "snd-spectrum"
 #define S_snd_tempnam                   "snd-tempnam"
 #define S_snd_to_sample                 "snd->sample"
-#define S_snd_to_sample_p               "snd->sample?"
+#define S_is_snd_to_sample              "snd->sample?"
 #define S_snd_url                       "snd-url"
 #define S_snd_urls                      "snd-urls"
 #define S_snd_version                   "snd-version"
 #define S_snd_warning                   "snd-warning"
 #define S_snd_warning_hook              "snd-warning-hook"
 #define S_sound_file_extensions         "sound-file-extensions"
-#define S_sound_file_p                  "sound-file?"
+#define S_is_sound_file                 "sound-file?"
 #define S_sound_files_in_directory      "sound-files-in-directory"
 #define S_sound_loop_info               "sound-loop-info"
-#define S_sound_p                       "sound?"
+#define S_is_sound                      "sound?"
 #define S_sound_properties              "sound-properties"
 #define S_sound_property                "sound-property"
 #define S_sound_widgets                 "sound-widgets"
@@ -608,48 +596,49 @@
 #define S_start_playing_hook            "start-playing-hook"
 #define S_start_playing_selection_hook  "start-playing-selection-hook"
 #define S_start_progress_report         "start-progress-report"
-#define S_stop_dac_hook                 "stop-dac-hook"
+#define S_status_report                 "status-report"
 #define S_stop_player                   "stop-player"
 #define S_stop_playing                  "stop-playing"
 #define S_stop_playing_hook             "stop-playing-hook"
 #define S_stop_playing_selection_hook   "stop-playing-selection-hook"
 #define S_swap_channels                 "swap-channels"
 #define S_sync                          "sync"
+#define S_sync_all                      "sync-all"
+#define S_sync_by_sound                 "sync-by-sound"
 #define S_sync_max                      "sync-max"
+#define S_sync_none                     "sync-none"
+#define S_sync_style                    "sync-style"
 #define S_syncd_marks                   "syncd-marks"
 #define S_temp_dir                      "temp-dir"
 #define S_text_focus_color              "text-focus-color"
 #define S_time_graph                    "time-graph"
-#define S_time_graph_hook               "time-graph-hook"
-#define S_time_graph_p                  "time-graph?"
+#define S_time_graph_on                 "time-graph?"
 #define S_time_graph_style              "time-graph-style"
 #define S_time_graph_type               "time-graph-type"
 #define S_tiny_font                     "tiny-font"
 #define S_tracking_cursor_style         "tracking-cursor-style"
 #define S_transform_dialog              "transform-dialog"
-#define S_transform_frames              "transform-frames"
+#define S_transform_framples            "transform-framples"
 #define S_transform_graph               "transform-graph"
-#define S_transform_graph_p             "transform-graph?"
+#define S_transform_graph_on            "transform-graph?"
 #define S_transform_graph_style         "transform-graph-style"
 #define S_transform_graph_type          "transform-graph-type"
 #define S_transform_normalization       "transform-normalization"
-#define S_transform_p                   "transform?"
+#define S_is_transform                  "transform?"
 #define S_transform_sample              "transform-sample"
 #define S_transform_size                "transform-size"
 #define S_transform_to_integer          "transform->integer"
-#define S_transform_to_vct              "transform->vct"
 #define S_transform_type                "transform-type"
-#define S_trap_segfault                 "trap-segfault"
 #define S_unbind_key                    "unbind-key"  
 #define S_undo                          "undo"
 #define S_undo_hook                     "undo-hook"
+#define S_unselect_all                  "unselect-all"
 #define S_update_hook                   "update-hook"
 #define S_update_lisp_graph             "update-lisp-graph"
 #define S_update_sound                  "update-sound"
 #define S_update_time_graph             "update-time-graph"
 #define S_update_transform_graph        "update-transform-graph"
-#define S_variable_graph_p              "variable-graph?"
-#define S_vct_to_channel                "vct->channel"
+#define S_is_variable_graph             "variable-graph?"
 #define S_view_files_amp                "view-files-amp"
 #define S_view_files_amp_env            "view-files-amp-env"
 #define S_view_files_dialog             "view-files-dialog"
@@ -678,9 +667,14 @@
 #define S_with_file_monitor             "with-file-monitor"
 #define S_with_gl                       "with-gl"
 #define S_with_inset_graph              "with-inset-graph"
+#define S_with_interrupts               "with-interrupts"
+#define S_with_menu_icons               "with-menu-icons"
 #define S_with_mix_tags                 "with-mix-tags"
 #define S_with_pointer_focus            "with-pointer-focus"
 #define S_with_relative_panes           "with-relative-panes"
+#define S_with_smpte_label              "with-smpte-label"
+#define S_with_toolbar                  "with-toolbar"
+#define S_with_tooltips                 "with-tooltips"
 #define S_with_tracking_cursor          "with-tracking-cursor"
 #define S_with_verbose_cursor           "with-verbose-cursor"
 #define S_x_axis_as_clock               "x-axis-as-clock"
@@ -709,4 +703,18 @@
 #define S_zoom_focus_right              "zoom-focus-right"
 #define S_zoom_focus_style              "zoom-focus-style"
 
+#if HAVE_SCHEME
+#define S_channel_to_vct                "channel->float-vector"
+#define S_mix_vct                       "mix-float-vector"
+#define S_region_to_vct                 "region->float-vector"
+#define S_transform_to_vct              "transform->float-vector"
+#define S_vct_to_channel                "float-vector->channel"
+#else
+#define S_channel_to_vct                "channel->vct"
+#define S_mix_vct                       "mix-vct"
+#define S_region_to_vct                 "region->vct"
+#define S_transform_to_vct              "transform->vct"
+#define S_vct_to_channel                "vct->channel"
+#endif
+
 #endif
