@@ -1,6 +1,7 @@
 /* translate various special case sound files to something we can edit 
- * 
- * I'm ignoring proprietary or licensed schemes even where the code is publicly available (Rockwell ADPCM, shorten, etc)
+ *   (this code is going away...)
+ *
+ * I'm ignoring proprietary or licensed schemes even where the code is publicly available (Rockwell ADPCM, etc)
  *
  * currently supported:
  *   IEEE text
@@ -12,7 +13,6 @@
  *   Oki (Dialogic) ADPCM (RIFF)
  *   IBM ADPCM (as per Perry Cook)
  *   Yamaha TX-16 12-bit
- *   NeXT/Sun G721, G723 3 and 5 bit versions (also RIFF) (AIFC cases could be handled if they exist)
  *
  *   libavcodec has an amazing number of decoders -- are these useful in this context?
  *   also libmpcodecs (available with MPlayer)
@@ -20,45 +20,36 @@
 
 #include "snd.h"
 
-
-/* from io.c, but no longer in sndlib.h */
-void mus_bint_to_char(unsigned char *j, int x);
-void mus_bshort_to_char(unsigned char *j, short x);
-int mus_char_to_bint(const unsigned char *inp);
-short mus_char_to_bshort(const unsigned char *inp);
-short mus_char_to_lshort(const unsigned char *inp);
-
-
 #define TRANS_BUF_SIZE 8192
 
 static char write_error_buffer[PRINT_BUFFER_SIZE];
 
-static ssize_t snd_checked_write(int fd, unsigned char *buf, ssize_t bytes, const char *filename)
+static long long int snd_checked_write(int fd, unsigned char *buf, long long int bytes, const char *filename)
 {
   /* io.c checked_write assumes its file descriptors are around */
   /* can't call mus_error here because we need to clean up first in case of error */
-  ssize_t bytes_written;
+  long long int bytes_written;
   mus_long_t kfree;
-  kfree = disk_kspace(filename);
+  kfree = (long long int)disk_kspace(filename);
   if (kfree < 0) 
     {
-      mus_snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
-		   _("no space left on device: %s"),
+      snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
+		   "no space left on device: %s",
 		   snd_io_strerror()); 
       return(MUS_ERROR);
     }
   if (kfree < (bytes >> 10))
     { 
-      mus_snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
-		   _("only " MUS_LD " bytes left on device (we need " SSIZE_TD " bytes)"),
+      snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
+		   "only %lld bytes left on device (we need %lld bytes)",
 		   kfree << 10, bytes);
       return(MUS_ERROR);
     }
   bytes_written = write(fd, buf, bytes);
   if (bytes_written != bytes)
     {
-      mus_snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
-		   _("write error (wrote " SSIZE_TD " of requested " SSIZE_TD " bytes): %s"),
+      snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
+		   "write error (wrote %lld of requested %lld bytes): %s",
 		   bytes_written, bytes, snd_io_strerror());
       return(MUS_ERROR);
     }
@@ -70,10 +61,10 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
 {
   /* handle little-endian swap if necessary */
 #if MUS_LITTLE_ENDIAN
-  unsigned char tmp;
   int i;
   for (i = 0; i < bytes; i += 2)
     {
+      unsigned char tmp;
       tmp = buf[i];
       buf[i] = buf[i + 1];
       buf[i + 1] = tmp;
@@ -83,10 +74,9 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
 }
 
 
-#define RETURN_MUS_IO_ERROR(IO_Func, IO_Name) return(mus_error(MUS_CANT_OPEN_FILE, "translator: %s(%s) %s", IO_Func, IO_Name, snd_io_strerror()))
+#define return_mus_io_error(IO_Func, IO_Name) return(mus_error(MUS_CANT_OPEN_FILE, "translator: %s(%s) %s", IO_Func, IO_Name, snd_io_strerror()))
 
-
-#define RETURN_MUS_WRITE_ERROR(OldName, NewName) \
+#define return_mus_write_error(OldName, NewName) \
   do { \
       mus_error(MUS_WRITE_ERROR, "can't translate %s to %s:\n  %s", OldName, NewName, write_error_buffer); \
       write_error_buffer[0] = '\0'; \
@@ -94,8 +84,7 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
     } \
   while (false)
 
-
-#define RETURN_MUS_ALLOC_ERROR(OldName, Bytes, VariableName) \
+#define return_mus_alloc_error(OldName, Bytes, VariableName) \
   return(mus_error(MUS_MEMORY_ALLOCATION_FAILED, "translate %s: can't allocate %d bytes for %s", OldName, Bytes, VariableName))
 
 
@@ -113,18 +102,18 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
 #define STARTUP(OldName, NewName, BufSize, BufType) \
   do { \
     fs = CREAT(NewName, 0666); \
-    if (fs == -1) RETURN_MUS_IO_ERROR("create", NewName); \
+    if (fs == -1) return_mus_io_error("create", NewName); \
     fd = OPEN(OldName, O_RDONLY, 0); \
     if (fd == -1) \
       { \
         CLEANUP(OldName, NewName); \
-        RETURN_MUS_IO_ERROR("open", OldName); \
+        return_mus_io_error("open", OldName); \
       } \
     buf = (BufType *)calloc(BufSize, sizeof(BufType)); \
     if (buf == NULL) \
       { \
         CLEANUP(OldName, NewName); \
-        RETURN_MUS_ALLOC_ERROR(OldName, BufSize, "buf"); \
+        return_mus_alloc_error(OldName, BufSize, "buf"); \
       } \
     } \
   while (false)
@@ -162,7 +151,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   happy = true;
   inp = 21;
@@ -201,7 +190,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
 	      CLEANUP(oldname, newname);
-	      RETURN_MUS_WRITE_ERROR(oldname, newname);
+	      return_mus_write_error(oldname, newname);
 	    }
 	  osp = 0;
 	  outp = 0;
@@ -255,7 +244,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
     }
   if (outp > 0) err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
   CLEANUP(oldname, newname);
-  if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
+  if (err == MUS_ERROR) return_mus_write_error(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -297,7 +286,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
 		    {
 		      for (i = op + 15, j = 0; j < 6; i++, j++) str[j] = buf[i];
 		      str[6] = '\0';
-		      sscanf(str, "%f", &fsrate);
+		      sscanf(str, "%6f", &fsrate);
 		      srate = (int)(fsrate * 1000);
 		    }
 		  else
@@ -306,7 +295,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
 			{
 			  for (i = op + 15, j = 0; j < 6; i++, j++) str[j] = buf[i];
 			  str[6] = '\0';
-			  sscanf(str, "%d", &srate);
+			  sscanf(str, "%6d", &srate);
 			}
 		    }
 		}
@@ -338,7 +327,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
   if (snd_checked_write(fs, (unsigned char *)hdr, outp, newname) == MUS_ERROR) 
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   happy = true;
   s0 = 0;
@@ -361,7 +350,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
 	      CLEANUP(oldname, newname);
-	      RETURN_MUS_WRITE_ERROR(oldname, newname);
+	      return_mus_write_error(oldname, newname);
 	    }
 	  osp = 0;
 	  outp = 0;
@@ -371,7 +360,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
 	  if (buf[inp] == '\n')
 	    {
 	      str[s0] = '\0';
-	      sscanf(str, "%d", &j);
+	      sscanf(str, "%12d", &j);
 	      mus_bshort_to_char((unsigned char *)(hdr + osp), (short)j);
 	      osp += 2;
 	      outp += 2;
@@ -389,7 +378,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
   /* update size field? */
   CLEANUP(oldname, newname);
-  if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
+  if (err == MUS_ERROR) return_mus_write_error(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -435,8 +424,8 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   if ((mode != 4) && (mode != 0)) 
     {
       CLEANUP(oldname, newname);
-      return(mus_error(MUS_UNSUPPORTED_DATA_FORMAT,
-		       _("read_mus10: can't translate Mus10 file %s:\n  mode = %d\n"),
+      return(mus_error(MUS_UNSUPPORTED_SAMPLE_TYPE,
+		       "read_mus10: can't translate Mus10 file %s:\n  mode = %d\n",
 		       oldname, mode));
     }
   /* 4 = SAM 16-bit packing mode, 0 = 12 bit 3 to a word */
@@ -445,7 +434,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR) 
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   happy = true;
   outp = 0;
@@ -467,7 +456,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
 	      CLEANUP(oldname, newname);
-	      RETURN_MUS_WRITE_ERROR(oldname, newname);
+	      return_mus_write_error(oldname, newname);
 	    }
 	  osp = 0;
 	  outp = 0;
@@ -501,7 +490,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
     }
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
   CLEANUP(oldname, newname);
-  if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
+  if (err == MUS_ERROR) return_mus_write_error(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -524,7 +513,7 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   lseek(fd, 132, SEEK_SET);
   bytes = read(fd, buf, 18);  /* count sum type div size */
@@ -540,7 +529,7 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
     {
       if (d) free(d);
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname); /* read actually, but it's a generic message */
+      return_mus_write_error(oldname, newname); /* read actually, but it's a generic message */
     }
   osp = 0;
   for (i = 0; i < size; i++) 
@@ -577,7 +566,7 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
 	      for (i = 0; i < size; i++) free(d[i]);
 	      free(d);
 	      CLEANUP(oldname, newname);
-	      RETURN_MUS_WRITE_ERROR(oldname, newname);
+	      return_mus_write_error(oldname, newname);
 	    }
 	  osp = 0;
 	  outp = 0;
@@ -611,7 +600,7 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
   for (i = 0; i < size; i++) free(d[i]);
   free(d);
   CLEANUP(oldname, newname);
-  if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
+  if (err == MUS_ERROR) return_mus_write_error(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -638,7 +627,7 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   lseek(fd, 1024, SEEK_SET);                       /* NIST header always 1024 bytes */
   totalin = read(fd, buf, TRANS_BUF_SIZE);
@@ -743,7 +732,7 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR)
 	    {
 	      CLEANUP(oldname, newname);
-	      RETURN_MUS_WRITE_ERROR(oldname, newname);
+	      return_mus_write_error(oldname, newname);
 	    }
 	  osp = 0;
 	  outp = 0;
@@ -751,7 +740,7 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
     }
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
   CLEANUP(oldname, newname);
-  if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
+  if (err == MUS_ERROR) return_mus_write_error(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -778,7 +767,7 @@ static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
   buf1 = (short *)calloc(TRANS_BUF_SIZE, sizeof(short));
@@ -810,7 +799,7 @@ static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
 	{
 	  free(buf1);
 	  CLEANUP(oldname, newname);
-	  RETURN_MUS_WRITE_ERROR(oldname, newname);
+	  return_mus_write_error(oldname, newname);
 	}
     }
   free(buf1);
@@ -821,7 +810,7 @@ static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
 
 /* -------------------------------- Intel ADPCM --------------------------------
  *
- * described in detail Microsoft RIFF docs.  This code assumes bits = 4.
+ * described in detail in the Microsoft RIFF docs.  This code assumes bits = 4.
  * in 'wave' file, these are stored as block_align sized blocks, each with a
  * header storing the current state.  These can be multi-channel, but we're handling
  * only mono until someone complains.  See also Apple Tech note 1081 by Mark Cookson.
@@ -839,7 +828,7 @@ static int stepsizeTable[89] = {7, 8, 9, 10, 11, 12, 13, 14, 16, 17, 19, 21, 23,
 static int adpcm_decoder(unsigned char *indata, short *outdata, int totalbytes, int type)
 {
   unsigned int delta, inputbuffer = 0;
-  int step, valpred, vpdiff, index, i, j;
+  int valpred, index, i, j;
   bool happy;
   bool bufferstep = false;
   happy = true;
@@ -859,6 +848,7 @@ static int adpcm_decoder(unsigned char *indata, short *outdata, int totalbytes,
   outdata[0] = valpred;
   while (happy)
     {
+      int step, vpdiff;
       if (bufferstep) 
 	{
 	  delta = inputbuffer & 0xf;
@@ -887,7 +877,7 @@ static int adpcm_decoder(unsigned char *indata, short *outdata, int totalbytes,
 
 static int read_dvi_adpcm(const char *oldname, const char *newname, char *hdr, int type)
 {
-  int fs = -1, fd = -1, chans, srate, blksiz, samps, samps_read;
+  int fs = -1, fd = -1, chans, srate, blksiz, samps;
   unsigned char *buf = NULL;
   mus_long_t loc;
   loc = mus_sound_data_location(oldname);
@@ -895,8 +885,8 @@ static int read_dvi_adpcm(const char *oldname, const char *newname, char *hdr, i
   blksiz = mus_sound_block_align(oldname);
   samps = mus_sound_fact_samples(oldname);
   if ((chans != 1) || (mus_sound_bits_per_sample(oldname) != 4))
-    return(mus_error(MUS_UNSUPPORTED_DATA_FORMAT,
-		     _("read_dvi_adpcm: can't translate DVI ADPCM file %s: chans: %d and bits: %d\n"),
+    return(mus_error(MUS_UNSUPPORTED_SAMPLE_TYPE,
+		     "read_dvi_adpcm: can't translate DVI ADPCM file %s: chans: %d and bits: %d\n",
 		     oldname, chans, mus_sound_bits_per_sample(oldname)));
   srate = mus_sound_srate(oldname);
   mus_bint_to_char((unsigned char *)(hdr + 16), srate);
@@ -905,12 +895,12 @@ static int read_dvi_adpcm(const char *oldname, const char *newname, char *hdr, i
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
-  samps_read = 0;
   while (samps > 0)
     {
+      int samps_read;
       ssize_t totalin;
       totalin = read(fd, buf, blksiz);
       if (totalin < blksiz) break;
@@ -918,7 +908,7 @@ static int read_dvi_adpcm(const char *oldname, const char *newname, char *hdr, i
       if (be_snd_checked_write(fs, (unsigned char *)hdr, samps_read * 2, newname) == MUS_ERROR) 
 	{
 	  CLEANUP(oldname, newname);
-	  RETURN_MUS_WRITE_ERROR(oldname, newname);
+	  return_mus_write_error(oldname, newname);
 	}
       samps -= samps_read;
     }
@@ -969,16 +959,15 @@ static short oki_adpcm_decode(char code, struct oki_adpcm_status *stat)
 
 static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
 {
-  int fs = -1, fd = -1, i, j, chans, srate, blksiz, samps, samps_read;
-  ssize_t totalin;
+  int fs = -1, fd = -1, i, j, chans, srate, blksiz, samps;
   unsigned char *buf = NULL;
   mus_long_t loc;
   short *buf1;
   struct oki_adpcm_status stat;
   chans = mus_sound_chans(oldname);
   if (chans != 1)
-    return(mus_error(MUS_UNSUPPORTED_DATA_FORMAT,
-		     _("read_oki_adpcm: can't translate Oki ADPCM file %s: chans: %d\n"),
+    return(mus_error(MUS_UNSUPPORTED_SAMPLE_TYPE,
+		     "read_oki_adpcm: can't translate Oki ADPCM file %s: chans: %d\n",
 		     oldname, chans));
   loc = mus_sound_data_location(oldname);
   blksiz = mus_sound_block_align(oldname);
@@ -986,7 +975,7 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
   STARTUP(oldname, newname, blksiz, unsigned char);
   buf1 = (short *)calloc(blksiz * 2, sizeof(short));
   samps = mus_sound_fact_samples(oldname);
-  if (samps == 0) samps = (int)mus_sound_frames(oldname);
+  if (samps == 0) samps = (int)mus_sound_framples(oldname);
   srate = mus_sound_srate(oldname);
   mus_bint_to_char((unsigned char *)(hdr + 16), srate);
   mus_bint_to_char((unsigned char *)(hdr + 20), chans);
@@ -994,14 +983,15 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
     {
       free(buf1);
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
-  samps_read = 0;
   stat.last = 0;
   stat.step_index = 0;
   while (samps > 0)
     {
+      int samps_read;
+      ssize_t totalin;
       totalin = read(fd, buf, blksiz);
       if (totalin <= 0) break;
       for (i = 0, j = 0; i < totalin; i++)
@@ -1015,7 +1005,7 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
 	{
 	  free(buf1);
 	  CLEANUP(oldname, newname);
-	  RETURN_MUS_WRITE_ERROR(oldname, newname);
+	  return_mus_write_error(oldname, newname);
 	}
       samps -= samps_read;
     }
@@ -1032,7 +1022,6 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
 static int read_12bit(const char *oldname, const char *newname, char *hdr)
 {
   int chans, i, j, fs = -1, fd = -1;
-  ssize_t totalin;
   unsigned char *buf = NULL;
   short *buf1;
   mus_long_t loc, samps;
@@ -1045,12 +1034,13 @@ static int read_12bit(const char *oldname, const char *newname, char *hdr)
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
       CLEANUP(oldname, newname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
   buf1 = (short *)calloc(TRANS_BUF_SIZE, sizeof(short));
   while (samps > 0)
     {
+      ssize_t totalin;
       totalin = read(fd, buf, (int)(TRANS_BUF_SIZE * 1.5));
       if (totalin <= 0) break;
       for (i = 0, j = 0; i < totalin; i += 3, j += 2)
@@ -1062,7 +1052,7 @@ static int read_12bit(const char *oldname, const char *newname, char *hdr)
 	{
 	  free(buf1);
 	  CLEANUP(oldname, newname);
-	  RETURN_MUS_WRITE_ERROR(oldname, newname);
+	  return_mus_write_error(oldname, newname);
 	}
       samps -= j;
     }
@@ -1072,30 +1062,75 @@ static int read_12bit(const char *oldname, const char *newname, char *hdr)
 }
 
 
+#if G7XX
 /*  -------------------------------- G721 and G723 from Sun --------------------------------
  * code boiled down considerably here since I have no love of compression schemes.
  */
 
 struct g72x_state {long yl; short yu; short dms; short dml; short ap; short a[2]; short b[6]; short pk[2]; short dq[6]; short sr[2]; char td;};
 
-static short power2[15] = {1, 2, 4, 8, 0x10, 0x20, 0x40, 0x80, 0x100, 0x200, 0x400, 0x800, 0x1000, 0x2000, 0x4000};
-
-static int quan(int val, short *table, int size)
+static int quan(short val)
 {
-  int i;
-  for (i = 0; i < size; i++)
-    if (val < *table++) break;
-  return(i);
+#if 0
+  if (val >= 16384) return(15);
+  if (val >= 8192) return(14);
+  if (val >= 4096) return(13);
+  if (val >= 2048) return(12);
+  if (val >= 1024) return(11);
+  if (val >= 512) return(10);
+  if (val >= 256) return(9);
+  if (val >= 128) return(8);
+  if (val >= 64) return(7);
+  if (val >= 32) return(6);
+  if (val >= 16) return(5);
+  if (val >= 8) return(4);
+  if (val >= 4) return(3);
+  if (val >= 2) return(2);
+  if (val >= 1) return(1);
+  return(0);
+#else
+  if (val >= 256) 
+    {
+      if (val >= 1024) 
+	{
+	  if (val >= 4096) 
+	    {
+	      if (val >= 16384) return(15);
+	      if (val >= 8192) return(14);
+	      return(13);
+	    }
+	  if (val >= 2048) return(12);
+	  return(11);
+	}
+      if (val >= 512) return(10);
+      return(9);
+    }
+  if (val >= 8) 
+    {
+      if (val >= 64) 
+	{
+	  if (val >= 128) return(8);
+	  return(7);
+	}
+      if (val >= 32) return(6);
+      if (val >= 16) return(5);
+      return(4);
+    }
+  if (val >= 4) return(3);
+  if (val >= 2) return(2);
+  if (val >= 1) return(1);
+  return(0);
+#endif
 }
 
 
 static int fmult(int an, int srn)
 {
-  short	anmag, anexp, anmant;
-  short	wanexp, wanmant;
-  short	retval;
+  short anmag, anexp, anmant;
+  short wanexp, wanmant;
+  short retval;
   anmag = (an > 0) ? an : ((-an) & 0x1FFF);
-  anexp = quan(anmag, power2, 15) - 6;
+  anexp = quan(anmag) - 6;
   anmant = (anmag == 0) ? 32 : (anexp >= 0) ? anmag >> anexp : anmag << -anexp;
   wanexp = anexp + ((srn >> 6) & 0xF) - 13;
   wanmant = (anmant * (srn & 077) + 0x30) >> 4;
@@ -1172,7 +1207,7 @@ static int reconstruct(int sign, int dqln, int y)
 }
 
 
-static void update(int	code_size, int y, int wi, int fi, int dq, int sr, int dqsez, struct g72x_state *state_ptr)
+static void update(int code_size, int y, int wi, int fi, int dq, int sr, int dqsez, struct g72x_state *state_ptr)
 {
   int cnt;
   short	mag, exp, a2p = 0, a1ul, pks1, fa1, ylint, thr2, dqthr, ylfrac, thr1, pk0;
@@ -1226,7 +1261,7 @@ static void update(int	code_size, int y, int wi, int fi, int dq, int sr, int dqs
     } 
   else 
     {
-      exp = quan(mag, power2, 15);
+      exp = quan(mag);
       state_ptr->dq[0] = (dq >= 0) ?
 	(exp << 6) + ((mag << 6) >> exp) :
 	(exp << 6) + ((mag << 6) >> exp) - 0x400;
@@ -1239,14 +1274,14 @@ static void update(int	code_size, int y, int wi, int fi, int dq, int sr, int dqs
   else 
     if (sr > 0) 
       {
-	exp = quan(sr, power2, 15);
+	exp = quan(sr);
 	state_ptr->sr[0] = (exp << 6) + ((sr << 6) >> exp);
       } 
     else 
       if (sr > -32768) 
 	{
 	  mag = -sr;
-	  exp = quan(mag, power2, 15);
+	  exp = quan(mag);
 	  state_ptr->sr[0] =  (exp << 6) + ((mag << 6) >> exp) - 0x400;
 	} 
       else
@@ -1366,11 +1401,11 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
   g72x_init_state(&state);
   chans = mus_sound_chans(oldname);
   if (chans != 1)
-    return(mus_error(MUS_UNSUPPORTED_DATA_FORMAT,
-		     _("read_g72x_adpcm: can't translate G72x file %s: chans: %d\n"),
+    return(mus_error(MUS_UNSUPPORTED_SAMPLE_TYPE,
+		     "read_g72x_adpcm: can't translate G72x file %s: chans: %d\n",
 		     oldname, chans));
   fs = CREAT(newname, 0666);
-  if (fs == -1) RETURN_MUS_IO_ERROR("create", newname);
+  if (fs == -1) return_mus_io_error("create", newname);
   loc = mus_sound_data_location(oldname);
   srate = mus_sound_srate(oldname);
   mus_bint_to_char((unsigned char *)(hdr + 16), srate);
@@ -1379,20 +1414,20 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
   if (fd == NULL) 
     {
       snd_close(fs, newname); 
-      RETURN_MUS_IO_ERROR("fopen", oldname);
+      return_mus_io_error("fopen", oldname);
     }
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR) 
     {
       snd_close(fs, newname); 
       snd_fclose(fd, oldname);
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   buf = (short *)calloc(TRANS_BUF_SIZE, sizeof(short));
   if (buf == NULL) 
     {
       snd_close(fs, newname); 
       snd_fclose(fd, oldname); 
-      RETURN_MUS_ALLOC_ERROR(oldname, TRANS_BUF_SIZE, "buf");
+      return_mus_alloc_error(oldname, TRANS_BUF_SIZE, "buf");
     }
   bytes = fread(buf, 1, loc, fd);
   if (bytes == 0)
@@ -1400,7 +1435,7 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
       snd_close(fs, newname); 
       snd_fclose(fd, oldname); 
       free(buf); 
-      RETURN_MUS_WRITE_ERROR(oldname, newname);
+      return_mus_write_error(oldname, newname);
     }
   switch (which_g)
     {
@@ -1424,7 +1459,7 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
 	      snd_close(fs, newname); 
 	      snd_fclose(fd, oldname); 
 	      free(buf); 
-	      RETURN_MUS_WRITE_ERROR(oldname, newname);
+	      return_mus_write_error(oldname, newname);
 	    }
 	  j = 0;
 	}
@@ -1433,9 +1468,10 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
   snd_close(fs, newname);
   snd_fclose(fd, oldname);
   free(buf);
-  if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
+  if (err == MUS_ERROR) return_mus_write_error(oldname, newname);
   return(MUS_NO_ERROR);
 }
+#endif
 
 
 
@@ -1443,40 +1479,39 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
 
 #define RIFF_Intel_ADPCM 0x11
 #define RIFF_Oki_ADPCM 0x10
+#define RIFF_MS_ADPCM 2
+#define RIFF_IBM_ADPCM 0x103
+
+#if G7XX
 #define RIFF_G723 0x14
 #define RIFF_MS_G723 0x42
 #define RIFF_Lucent_G723 0x59
 #define RIFF_Vivo_G723 0x111
 #define RIFF_G721 0x40
-#define RIFF_MS_ADPCM 2
-#define RIFF_IBM_ADPCM 0x103
+
 #define NeXT_G721 23
 #define NeXT_G723 25
 #define NeXT_G723_5 26
+#endif
 
-static int MUS_CANT_TRANSLATE = 0;
-
-static const char *any_format_name(const char *name)
+static const char *any_samp_type_name(const char *name)
 {
-  int format;
-  format = mus_sound_data_format(name);
-  if (format != MUS_UNKNOWN)
-    return(mus_data_format_name(format));
-  else return(mus_header_original_format_name(mus_sound_original_format(name),
-					      mus_sound_header_type(name)));
+  mus_sample_t samp_type;
+  samp_type = mus_sound_sample_type(name);
+  if (samp_type != MUS_UNKNOWN_SAMPLE)
+    return(mus_sample_type_name(samp_type));
+  else return(mus_header_original_sample_type_name(mus_sound_original_sample_type(name), mus_sound_header_type(name)));
 }
 
 
-int snd_translate(const char *oldname, const char *newname, int type)
+int snd_translate(const char *oldname, const char *newname, mus_header_t type)
 {
   /* read oldname, translate to newname as 16-bit linear NeXT file */
   /* called from snd-file.c */
   int err;
   char *hdr = NULL;
 
-  if (MUS_CANT_TRANSLATE == 0) MUS_CANT_TRANSLATE = mus_make_error((char *)"can't translate");
   err = MUS_CANT_TRANSLATE;
-
   hdr = (char *)calloc(TRANS_BUF_SIZE, sizeof(char));
   /* set up default output header */
   mus_bint_to_char((unsigned char *)hdr, 0x2e736e64);   /* .snd */
@@ -1508,13 +1543,15 @@ int snd_translate(const char *oldname, const char *newname, int type)
       err = read_12bit(oldname, newname, hdr); 
       break;
 
+#if G7XX
     case MUS_NVF: 
       err = read_g72x_adpcm(oldname, newname, hdr, 0); 
       break;
+#endif
 
     case MUS_RF64:
     case MUS_RIFF:
-      switch (mus_sound_original_format(oldname))
+      switch (mus_sound_original_sample_type(oldname))
 	{
 	case RIFF_MS_ADPCM: case RIFF_Intel_ADPCM: 
 	  err = read_dvi_adpcm(oldname, newname, hdr, 0); 
@@ -1528,6 +1565,7 @@ int snd_translate(const char *oldname, const char *newname, int type)
 	  err = read_oki_adpcm(oldname, newname, hdr); 
 	  break;
 
+#if G7XX
 	case RIFF_G721: 
 	  err = read_g72x_adpcm(oldname, newname, hdr, 0); 
 	  break; /* untested */
@@ -1539,30 +1577,33 @@ int snd_translate(const char *oldname, const char *newname, int type)
 	    if (mus_sound_bits_per_sample(oldname) == 5)
 	      err = read_g72x_adpcm(oldname, newname, hdr, 2);
 	  break;
+#endif
 	}
       break;
 
     case MUS_NIST:
-      if (mus_sound_original_format(oldname) == MUS_NIST_SHORTPACK) 
+      if (mus_sound_original_sample_type(oldname) == MUS_NIST_SHORTPACK) 
 	err = read_nist_shortpack(oldname, newname, hdr); 
       break;
 
+#if G7XX
     case MUS_NEXT:
-      switch (mus_sound_original_format(oldname))
+      switch (mus_sound_original_sample_type(oldname))
 	{
 	case NeXT_G721:   err = read_g72x_adpcm(oldname, newname, hdr, 0); break;
 	case NeXT_G723:   err = read_g72x_adpcm(oldname, newname, hdr, 1); break;
 	case NeXT_G723_5: err = read_g72x_adpcm(oldname, newname, hdr, 2); break;
 	}
       break;
+#endif
 
     case MUS_AIFC:
-      if (mus_sound_original_format(oldname) == MUS_AIFF_IMA_ADPCM) 
+      if (mus_sound_original_sample_type(oldname) == MUS_AIFF_IMA_ADPCM) 
 	err = read_dvi_adpcm(oldname, newname, hdr, 1); 
       break;
  
     case MUS_OGG: case MUS_SPEEX: case MUS_FLAC: case MUS_MIDI: case MUS_MPEG:
-    case MUS_SHORTEN: case MUS_TTA: case MUS_WAVPACK:
+    case MUS_TTA: case MUS_WAVPACK:
     default:
       if (snd_decode(type, oldname, newname) == 0)
 	err = MUS_NO_ERROR;
@@ -1572,10 +1613,10 @@ int snd_translate(const char *oldname, const char *newname, int type)
   free(hdr);
   if (err == MUS_CANT_TRANSLATE)
     return(mus_error(MUS_CANT_TRANSLATE,
-		     _("can't translate %s\n  (%s header: %s (0x%x) data format)\n"),
+		     "can't translate %s\n  (%s header: %s (0x%x) sample type)\n",
 		     oldname,
 		     mus_header_type_name(type),
-		     any_format_name(oldname),
-		     mus_sound_original_format(oldname)));
+		     any_samp_type_name(oldname),
+		     mus_sound_original_sample_type(oldname)));
   return(err);
 }
