@@ -10,19 +10,29 @@
 #include <GL/glx.h>
 #endif
 
+#define XOR(a, b) ((a) ^ (b))
+/* can't get used to this operator -- in the good old days, ^ meant exponentiation */
+
 #define xm_font_t XmRenderTable
 #define XM_FONT_RESOURCE XmNrenderTable
 #define XM_FONT_FREE XmRenderTableFree
 
 #define LOTSA_PIXELS 10000
-#define XEN_WRAP_WIDGET(Value)       ((Value) ? XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("Widget"), XEN_WRAP_C_POINTER(Value)) : XEN_FALSE)
-#define XEN_WRAP_WINDOW(Value)       ((Value) ? XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("Window"), C_TO_XEN_ULONG(Value)) : XEN_FALSE)
-#define XEN_UNWRAP_WIDGET(Value)     (XEN_LIST_P(Value) ? XEN_UNWRAP_C_POINTER(XEN_CADR(Value)) : 0)
-#define XEN_WIDGET_P(Value)          (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
-                                      (strcmp("Widget", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
+
+#define Xen_wrap_widget(Value)    ((Value) ? Xen_list_2(C_string_to_Xen_symbol("Widget"), Xen_wrap_C_pointer(Value)) : Xen_false)
+#define Xen_wrap_window(Value)    ((Value) ? Xen_list_2(C_string_to_Xen_symbol("Window"), C_ulong_to_Xen_ulong(Value)) : Xen_false)
+#define Xen_unwrap_widget(Value)  (Xen_is_list(Value) ? Xen_unwrap_C_pointer(Xen_cadr(Value)) : 0)
+#define Xen_is_widget(Value)      (Xen_is_list(Value) && (Xen_list_length(Value) >= 2) && (Xen_is_symbol(Xen_car(Value))) && \
+                                     (strcmp("Widget", Xen_symbol_to_C_string(Xen_car(Value))) == 0))
+#define Xen_wrap_pixel(Value)     Xen_list_2(C_string_to_Xen_symbol("Pixel"), C_int_to_Xen_integer((int)Value))
+                                       /* not ulong here! -- messes up the equal? check */
+#define Xen_unwrap_pixel(Value)   (unsigned long)Xen_integer_to_C_int(Xen_cadr(Value))
+#define Xen_is_pixel(Value)       (Xen_is_list(Value) && (Xen_list_length(Value) >= 2) && (Xen_is_symbol(Xen_car(Value))) && \
+                                      (strcmp("Pixel", Xen_symbol_to_C_string(Xen_car(Value))) == 0))
+
 #define NULL_WIDGET NULL
 
-typedef enum {NOT_ACTIVATABLE, ACTIVATABLE, NOT_ACTIVATABLE_OR_FOCUSED, ACTIVATABLE_BUT_NOT_FOCUSED} text_cr_t;
+typedef enum {NOT_ACTIVATABLE, ACTIVATABLE, ACTIVATABLE_BUT_NOT_FOCUSED} text_cr_t;
 
 #define LINE_MARGIN 4
 #define CONTROLS_MARGIN 1
@@ -42,14 +52,7 @@ typedef enum {NOT_ACTIVATABLE, ACTIVATABLE, NOT_ACTIVATABLE_OR_FOCUSED, ACTIVATA
 #define timeout_result_t               XtIntervalId
 #define TIMEOUT_REMOVE(Id)             XtRemoveTimeOut(Id)
 
-#if MUS_DEBUGGING
-  #define ASSERT_WIDGET_TYPE(Cond, Wid) if (!(Cond)) fprintf(stderr, "%s:[%s %d] %s is wrong type", c__FUNCTION__, __FILE__, __LINE__, XtName(Wid))
-#else
-  #define ASSERT_WIDGET_TYPE(Cond, Wid)
-#endif
-
 #define widget_t Widget
-
 #define widget_is_active(Wid) XtIsManaged(Wid)
 #define activate_widget(Wid) XtManageChild(Wid)
 #define deactivate_widget(Wid) XtUnmanageChild(Wid)
@@ -65,8 +68,8 @@ typedef enum {NOT_ACTIVATABLE, ACTIVATABLE, NOT_ACTIVATABLE_OR_FOCUSED, ACTIVATA
 
 #define rgb_t unsigned short
 #define RGB_MAX 65535
-#define FLOAT_TO_RGB(Val) (rgb_t)(RGB_MAX * (Val))
-#define RGB_TO_FLOAT(Val) (float)((float)(Val) / (float)RGB_MAX)
+#define float_to_rgb(Val) (rgb_t)(RGB_MAX * (Val))
+#define rgb_to_float(Val) (float)((float)(Val) / (float)RGB_MAX)
 
 
 typedef struct {
@@ -74,93 +77,21 @@ typedef struct {
   Display *dp;
   Drawable wn;
   Font current_font;
-} axis_context;
-
-typedef struct {
-  /* we need two versions of each GC because the selected channel's colors can be different from the unselected channels' */
-  Widget *chan_widgets;
-  idle_t fft_in_progress;
-  idle_t peak_env_in_progress;
-  struct env_state *peak_env_state;
-  axis_context *ax;
-  bool selected;
-  Pixmap fft_pix;
-  unsigned int fft_pix_width, fft_pix_height;
-  int fft_pix_x0, fft_pix_y0;
-  bool fft_pix_ready;
-  mus_float_t fft_pix_cutoff;
-  Cursor current_cursor;
-} chan_context;
-
-typedef struct {
-  Widget *snd_widgets;
-  Widget *progress_widgets;
-  int num_progress_widgets;
-  Widget tab;
-  struct env_editor *flt;
-  Widget dialog;
-  Dimension minibuffer_height;
-  bool minibuffer_watcher;
-} snd_context;
+} graphics_context;
 
 typedef enum {NOT_A_SCANF_WIDGET, SRATE_WIDGET, CHANS_WIDGET, DATA_LOCATION_WIDGET, SAMPLES_WIDGET} scanf_widget_t;
 
 typedef struct {
-  Widget header_list, format_list, srate_text, chans_text, comment_text, location_text, samples_text, error_text, dialog, smenu;
-  int current_type, current_format, formats, header_pos, format_pos;
+  Widget header_type_list, sample_type_list, srate_text, chans_text, comment_text, location_text, samples_text, error_text;
+  Widget dialog, src_button, auto_comment_button;
+  mus_header_t current_header_type;
+  mus_sample_t current_sample_type;
+  int sample_types, header_type_pos, sample_type_pos;
   scanf_widget_t scanf_widget, error_widget;
-  Widget *srates;
-  int num_srates, srates_size;
+  bool src, auto_comment;
+  char *saved_comment;
 } file_data;
 
-typedef struct {
-  XtAppContext mainapp;     
-  Widget mainshell;
-  Widget mainpane;
-  Widget soundpane;
-  Widget soundpanebox;
-  Display *mdpy;
-  xm_font_t peaks_fontlist;
-  XFontStruct *peaks_fontstruct;
-  xm_font_t bold_peaks_fontlist;
-  XFontStruct *bold_peaks_fontstruct; 
-  xm_font_t listener_fontlist;
-  XFontStruct *listener_fontstruct;
-  XFontStruct *axis_label_fontstruct;
-  XFontStruct *axis_numbers_fontstruct;
-  xm_font_t tiny_fontlist;
-  XFontStruct *tiny_fontstruct;
-
-  Pixel white, black, red, yellow, green, light_blue, lighter_blue;
-  Pixel data_color, selected_data_color, mark_color, graph_color, selected_graph_color, listener_color, listener_text_color;
-  Pixel basic_color, selection_color, zoom_color, position_color, highlight_color, enved_waveform_color, cursor_color;
-  Pixel text_focus_color, filter_control_waveform_color, mix_color, pushed_button_color, sash_color;
-  Pixel help_button_color, doit_again_button_color, doit_button_color, quit_button_color, reset_button_color;
-  Pixel selected_grid_color, grid_color, axis_color;
-  Pixel orig_data_color, orig_selected_data_color, orig_mark_color, orig_mix_color;
-  Pixel orig_graph_color, orig_selected_graph_color, orig_listener_color, orig_listener_text_color, orig_cursor_color;
-  Pixel orig_basic_color, orig_selection_color, orig_zoom_color, orig_position_color, orig_highlight_color;
-
-  GC basic_gc, selected_basic_gc, combined_basic_gc;        
-  GC cursor_gc, selected_cursor_gc;      
-  GC selection_gc, selected_selection_gc;
-  GC erase_gc, selected_erase_gc;        
-  GC mark_gc, selected_mark_gc;          
-  GC mix_gc;
-  GC fltenv_basic_gc, fltenv_data_gc;
-  Widget listener_pane;
-  Widget *dialogs;
-  int num_dialogs, dialogs_size;
-  Cursor graph_cursor, wait_cursor, bounds_cursor;
-  Widget requestor_dialog;
-#if HAVE_GL
-  GLXContext cx;
-#endif
-  XtInputId fam_port;
-  Widget *mw, *pw;
-  bool axis_color_set;
-} state_context;
-
 typedef enum {WITHOUT_CHANNELS_FIELD, WITH_CHANNELS_FIELD, WITH_EXTRACT_CHANNELS_FIELD} dialog_channels_t;
 typedef enum {WITHOUT_SAMPLES_FIELD, WITH_SAMPLES_FIELD} dialog_samples_t;
 typedef enum {WITHOUT_DATA_LOCATION_FIELD, WITH_DATA_LOCATION_FIELD} dialog_data_location_t;
@@ -175,18 +106,18 @@ typedef enum {WITHOUT_COMMENT_FIELD, WITH_COMMENT_FIELD} dialog_comment_t;
   #define snd_MetaMask (Mod1Mask | Mod4Mask)
 #endif
 
-#define MAIN_SHELL(a) (a->sgx)->mainshell
-#define MAIN_PANE(a) (a->sgx)->mainpane
-#define SOUND_PANE(a) (a->sgx)->soundpane
-#define SOUND_PANE_BOX(a) (a->sgx)->soundpanebox
-#define MAIN_APP(a) (a->sgx)->mainapp
-#define MAIN_DISPLAY(a) (a->sgx)->mdpy
-#define PEAKS_FONT(a) (a->sgx)->peaks_fontstruct
-#define BOLD_PEAKS_FONT(a) (a->sgx)->bold_peaks_fontstruct
-#define AXIS_NUMBERS_FONT(a) (a->sgx)->axis_numbers_fontstruct
-#define AXIS_LABEL_FONT(a) (a->sgx)->axis_label_fontstruct
-#define TINY_FONT(a) (a->sgx)->tiny_fontstruct
-#define LISTENER_FONT(a) (a->sgx)->listener_fontstruct
+#define MAIN_SHELL(a) (a)->mainshell
+#define MAIN_PANE(a) (a)->mainpane
+#define SOUND_PANE(a) (a)->soundpane
+#define SOUND_PANE_BOX(a) (a)->soundpanebox
+#define MAIN_APP(a) (a)->mainapp
+#define MAIN_DISPLAY(a) (a)->mdpy
+#define PEAKS_FONT(a) (a)->peaks_fontstruct
+#define BOLD_PEAKS_FONT(a) (a)->bold_peaks_fontstruct
+#define AXIS_NUMBERS_FONT(a) (a)->axis_numbers_fontstruct
+#define AXIS_LABEL_FONT(a) (a)->axis_label_fontstruct
+#define TINY_FONT(a) (a)->tiny_fontstruct
+#define LISTENER_FONT(a) (a)->listener_fontstruct
 
 #define DEFAULT_GRAPH_CURSOR XC_crosshair
 
@@ -276,20 +207,25 @@ typedef enum {WITHOUT_COMMENT_FIELD, WITH_COMMENT_FIELD} dialog_comment_t;
 #define snd_K_x XK_x 
 #define snd_K_y XK_y 
 #define snd_K_z XK_z 
-#define snd_K_Home XK_Home		 
-#define snd_K_Left XK_Left		 
-#define snd_K_Up XK_Up		 
-#define snd_K_Right XK_Right	 
-#define snd_K_Down XK_Down		 
 
-#define snd_keypad_Insert XK_KP_Insert
-#define snd_keypad_Delete XK_KP_Delete
+#define snd_K_Home  XK_Home		 
+#define snd_K_Left  XK_Left		 
+#define snd_K_Up    XK_Up		 
+#define snd_K_Right XK_Right	 
+#define snd_K_Down  XK_Down		 
+
+#define snd_keypad_Insert   XK_KP_Insert
+#define snd_keypad_Delete   XK_KP_Delete
 #define snd_keypad_Multiply XK_KP_Multiply
-#define snd_keypad_Add XK_KP_Add
+#define snd_keypad_Add      XK_KP_Add
 #define snd_keypad_Subtract XK_KP_Subtract
-#define snd_keypad_Divide XK_KP_Divide
-#define snd_keypad_Decimal XK_KP_Decimal
-#define snd_keypad_Enter XK_KP_Enter
+#define snd_keypad_Divide   XK_KP_Divide
+#define snd_keypad_Decimal  XK_KP_Decimal
+#define snd_keypad_Enter    XK_KP_Enter
+#define snd_keypad_Up       XK_KP_Up
+#define snd_keypad_Down     XK_KP_Down
+#define snd_keypad_Left     XK_KP_Left
+#define snd_keypad_Right    XK_KP_Right
 
 #define snd_keypad_0 XK_KP_0
 #define snd_keypad_1 XK_KP_1
