@@ -7,38 +7,20 @@
 #include <stddef.h>
 #include <math.h>
 #include <stdio.h>
-#if HAVE_FCNTL_H
-  #include <fcntl.h>
-#endif
+#include <fcntl.h>
 #include <signal.h>
-#if HAVE_LIMITS_H
-  #include <limits.h>
-#endif
+#include <limits.h>
 #include <errno.h>
 #include <stdlib.h>
-#if HAVE_LIBC_H && (!HAVE_UNISTD_H)
-  #include <libc.h>
-#else
-  #ifndef _MSC_VER
-    #include <unistd.h>
-  #endif
-#endif
-#if HAVE_STRING_H
-  #include <string.h>
+#ifndef _MSC_VER
+  #include <unistd.h>
+  #include <locale.h>
 #endif
+#include <string.h>
 #include <stdarg.h>
 #include <time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#if HAVE_SETLOCALE
-  #include <locale.h>
-#endif
-#if HAVE_FAM_H
-  #include <fam.h>
-#endif
-#if HAVE_PTHREAD_H
-  #include <pthread.h>
-#endif
 
 #include "_sndlib.h"
 #include "xen.h"
@@ -71,11 +53,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "9-July-10"
+#define SND_DATE "30-Nov-15"
 #ifndef SND_VERSION
-#define SND_VERSION "11.7"
+#define SND_VERSION "16.1"
 #endif
-#define SND_MAJOR_VERSION "11"
-#define SND_MINOR_VERSION "7"
+#define SND_MAJOR_VERSION "16"
+#define SND_MINOR_VERSION "1"
 
 #endif
