@@ -1,6 +1,7 @@
 ;;; SNDWARP
 
 (provide 'snd-sndwarp.scm)
+(if (not (provided? 'snd-env.scm)) (load "env.scm")) ; normalize-envelope
 
 ;;;
 ;;; CLM 3 implementation of Richard Karpen's SNDWARP Csound Ugen.
@@ -151,9 +152,9 @@
     (let* ((stereo-i (= (mus-sound-chans file) 2))
 	   (stereo-o #f) ; (= (channels  *output*) 2))
 	   (f-a (make-readin file :channel 0))
-           (f-b (if stereo-i (make-readin file :channel 1) #f)) ; explicit #f needed here for optimizer
+           (f-b (and stereo-i (make-readin file :channel 1)))
 	   (fsr (mus-sound-srate file))
-	   ;; (fsize (frames file))
+	   ;; (fsize (framples file))
 	   (fdur (mus-sound-duration file))
 	   (rev-val rev)
 	   (loc-env (clmsw-envelope-or-number loc))
@@ -161,7 +162,7 @@
 	   (time-env (clmsw-envelope-or-number stretch))
            (wsize-env (clmsw-envelope-or-number wsize))
 	   (rdA (make-src :input (lambda (dir) (readin f-a)) :srate 0.0 :width srcwidth))
-	   (rdB (if stereo-i (make-src :input (lambda (dir) (readin f-b)) :srate 0.0 :width srcwidth) #f))
+	   (rdB (and stereo-i (make-src :input (lambda (dir) (readin f-b)) :srate 0.0 :width srcwidth)))
 	   (windf (make-oscil))
            (wsizef (make-env wsize-env :duration dur))
 	   (ampf (make-env amp-env :scaler amp :duration dur))
@@ -178,7 +179,7 @@
 	   (overlap-ratio-compl 0.0)
 	   (outa-val 0.0)
 	   (outb-val 0.0))
-      (run
+
        (do ((overlap 0 (+ 1 overlap)))
 	   ((or eow-flag (= overlap overlaps)))
 	 (set! overlap-ratio (/ overlap overlaps))
@@ -193,7 +194,7 @@
 	   (set! (mus-location sratef) writestart)
 	   (set! (mus-location wsizef) writestart)
 	   (set! wsize (env wsizef))
-	   (let* ((winlen (if (and (= overlap 0) (= section 0)) ; first section of first overlap isn't randomized
+	   (let* ((winlen (if (= overlap 0 section) ; first section of first overlap isn't randomized
 			      wsize
 			      (+ wsize (random randw))))
 		  (winsamps (seconds->samples winlen))
@@ -242,9 +243,8 @@
 				    (round (* winlen overlap-ratio-compl)))
 				;; Alternative style - start each overlap series at 0
 				0)))
-		       (begin
-			 (set! readstart (round (* fsr (+ inputbeg init-read-start))))
-			 (if (not (= overlap 0)) (set! winsamps (floor (* winsamps overlap-ratio))))))
+		       (set! readstart (round (* fsr (+ inputbeg init-read-start))))
+		       (if (not (= overlap 0)) (set! winsamps (floor (* winsamps overlap-ratio)))))
 		     ;; remaining sections
 		     (set! readstart (round (+ readstart (* fsr (/ winlen time-val)))))))
 	     ;; Set readin position and sampling rate
@@ -258,7 +258,7 @@
 		   (mus-reset rdB)))
 	     ;; Write window out
 	     (do ((k 0 (+ 1 k))
-		  (i writestart (+ 1 i)))
+		  (i writestart (+ i 1)))
 		 ((or eow-flag (= k winsamps)))
 	       (if (> i end)
 		   (begin
@@ -293,12 +293,12 @@
 			 (begin
 			   (outb i outb-val)	     
 			   (if *reverb* (outa i (* rev-val outa-val) *reverb*)))))))
-	     (if (not eow-flag )
-		 (begin
-		   ;; For first section, have to backup readstart
-		   (if (and (= section 0) (> overlap 0) (not time-ptr))
-		       (set! readstart (- readstart (round (* fsr winlen overlap-ratio-compl)))))))
-	     (set! writestart (+ writestart winsamps)))))))))
+	     (if (and (not eow-flag)   ;; For first section, have to backup readstart
+		      (= section 0) 
+		      (> overlap 0) 
+		      (not time-ptr))
+		 (set! readstart (- readstart (round (* fsr winlen overlap-ratio-compl)))))
+	     (set! writestart (+ writestart winsamps))))))))
 
 
 
