@@ -6,8 +6,10 @@
 
 ;; revised slightly to accommodate the run macro, Bill 13-Jun-06
 
-(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
-(if (not (provided? 'snd-env.scm)) (load "env.scm"))
+(if (provided? 'snd)
+    (require snd-ws.scm)
+    (require sndlib-ws.scm))
+(require snd-env.scm)
 
 (definstrument 
   (stochastic start dur
@@ -34,41 +36,38 @@
 	 (end (+ beg (seconds->samples dur)))
 	 (d-click (make-env (list 0 1 (- end 100) 1 end 0) :duration dur))
 	 (b (expt 2 (- bits 1))); because we use signed ints - see (- b) below
-	 ;;make vct to hold x,y breakpoints
-	 (xy-array (make-vct (* (length init-array) 2)))
+	 ;;make float-vector to hold x,y breakpoints
+	 (xy-array (make-float-vector (* (length init-array) 2)))
 	 (xy-array-l (floor (length xy-array)))
 	 )
     ;;fill xy-array with values from init-array
     (do ((iy 0 (+ iy 2));;index for reading values from init-array (a 2-dimensional list)
-	 (jy 0 (+ jy 1)));;index for writing to xy-array (a 1-dimensional vct)
+	 (jy 0 (+ jy 1)));;index for writing to xy-array (a 1-dimensional float-vector)
 	((= iy xy-array-l) xy-array)
-      (vct-set! xy-array iy 
-		(list-ref (list-ref init-array jy) 0))
-      (vct-set! xy-array (+ iy 1)
-		;;convert signed float y values into signed integers 
-		(floor (* b
-			  (list-ref (list-ref init-array jy) 1)
-			  ))))
-    (ws-interrupt?) ;;does this really belong here?
-    (run
-     (do ((i beg (+ 1 i)))
+      (set! (xy-array iy) ((init-array jy) 0))
+      (set! (xy-array (+ iy 1))
+	    ;;convert signed float y values into signed integers 
+	    (floor (* b
+		      ((init-array jy) 1)))))
+
+     (do ((i beg (+ i 1)))
 	 ((= i end))
        (if (= dx dt);;when current sample is a breakpoint
 	   (begin
-	     (set! dx (floor (vct-ref xy-array (modulo m xy-array-l))))
-	     (set! y (vct-ref xy-array (+ (modulo m xy-array-l) 1)))
-	     (set! prev-dx (floor (vct-ref xy-array (modulo (- m 2) xy-array-l))))
+	     (set! dx (floor (xy-array (modulo m xy-array-l))))
+	     (set! y (xy-array (+ (modulo m xy-array-l) 1)))
+	     (set! prev-dx (floor (xy-array (modulo (- m 2) xy-array-l))))
 	     (set! dy (- y oldy))
 	     (set! oldy y)
 	     ;;straight uniform distribution for y
-	     (set! ydev (round (* (- 1.0 (random 2.0)) (* .01 b ywig))))
+	     (set! ydev (round (mus-random (* .01 b ywig))))
 	     ;;gaussian distribution for x
 	     (set! xdev 
 		   (* xstep (round 
 			     (* xwig 
-				(* (sqrt (* -2.0 (log (- 1 (random 1.0)))))
-				   (cos (* 6.283185307179586 (random 1.0))))))))
-	     (vct-set! xy-array (modulo m xy-array-l)
+				(sqrt (* -2.0 (log (- 1 (random 1.0))))) ; ??
+				(cos (random 6.283185307179586))))))
+	     (set! (xy-array (modulo m xy-array-l))
 		       ;;mirror stuff for x
 		       (cond ((or  (< (round xmax) (+ dx xdev))
 				   (> (round xmin)(+ dx xdev)))
@@ -78,17 +77,17 @@
 				   (round xmin)))
 			     (else (round (+ (* xfb prev-dx)
 					     (* (- 1  xfb) (+ dx xdev)))))))
-	     (vct-set! xy-array (+ (modulo m xy-array-l) 1)
+	     (set! (xy-array (+ (modulo m xy-array-l) 1))
 		       ;;mirror stuff for y 
 		       (cond ((or (< b (+ y ydev)) (> (- b) (+ y ydev)))
 			      (max (min (+ y (- ydev)) b) (- b)))
 			     (else (+ y ydev))))
 	     (set! m (+ m 2))
 	     (set! dt 0)))
-       (set! dt (+ 1 dt))
+       (set! dt (+ dt 1))
        (set! j (+ j (/ dy dx)));linear interpolation
        (set! output (/ j b));normalization -1 to 1
-       (outa i (* amp output (env d-click)))))))
+       (outa i (* amp output (env d-click))))))
   
 ;(with-sound (:statistics #t)(stochastic 0 10 :xwig .25 :ywig 10.0))
   
\ No newline at end of file
