@@ -1,4 +1,4 @@
-/* gcc -o crossref crossref.c -O2 */
+/* gcc -o crossref crossref.c -O2 -Wall */
 
 #include <ctype.h>
 #include <stddef.h>
@@ -8,7 +8,25 @@
 #include <fcntl.h>
 #include <string.h>
 #include <stdbool.h>
+#include <unistd.h>
 
+#if 1
+/* this is almost four times faster */
+static bool local_strcmp(const char *s1, const char *s2)
+{
+  unsigned char c1, c2;
+  while (true)
+    {
+      c1 = (unsigned char) *s1++;
+      c2 = (unsigned char) *s2++;
+      if (c1 != c2) return(false);
+      if (c1 == '\0') break;
+    }
+  return(true);
+}
+#else
+#define local_strcmp(S1, S2) (strcmp(S1, S2) == 0)
+#endif
 
 char **names;
 char **hnames;
@@ -50,16 +68,20 @@ void add_header(char *name)
 int add_name(char *name, char *hdr)
 {
   int i;
+  
   if (name == NULL) return(-1);
   if ((isdigit(name[0])) || (strlen(name) == 1)) return(-1);
-
+  
+  /*
   if (isupper(name[0])) return(-1);
+  */
+  if (name[0] == '_') return(-1);
 
-  if ((strcmp(hdr, "snd-nogui0.h") == 0) ||
-      (strcmp(hdr, "snd-nogui1.h") == 0))
+  if ((local_strcmp(hdr, "snd-nogui0.h")) ||
+      (local_strcmp(hdr, "snd-nogui1.h")))
     nnames[nname_ctr++] = name;
   for (i = 0; i < names_ctr; i++) 
-    if (strcmp(names[i], name) == 0) return(-1);
+    if (local_strcmp(names[i], name)) return(-1);
   hnames[names_ctr] = hdr;
   names[names_ctr++] = name;
   if (names_ctr == names_size) fprintf(stderr,"oops names");
@@ -70,15 +92,15 @@ int in_nogui_h(char *name)
 {
   int i;
   for (i = 0; i < nname_ctr; i++)
-    if (strcmp(name, nnames[i]) == 0)
+    if (local_strcmp(name, nnames[i]))
       return(1);
   return(0);
 }
 
 void add_file(char *name)
 {
-  if (strcmp(name,"snd-xen.c") == 0) snd_xen_c = files_ctr;
-  if (strcmp(name,"snd-nogui.c") == 0) snd_nogui_c = files_ctr;
+  if (local_strcmp(name,"snd-xen.c")) snd_xen_c = files_ctr;
+  if (local_strcmp(name,"snd-nogui.c")) snd_nogui_c = files_ctr;
   files[files_ctr++] = mus_strdup(name);
   if (files_ctr == files_size) fprintf(stderr,"oops files");
 }
@@ -87,7 +109,7 @@ static int add_count(char *name, int curfile)
 {
   int i;
   for (i = 0; i < names_ctr; i++)
-    if (strcmp(names[i], name) == 0)
+    if (local_strcmp(names[i], name))
       {
 	if (counts[i] == NULL) counts[i] = (int *)calloc(files_size, sizeof(int));
 	counts[i][curfile] += 1;
@@ -100,7 +122,7 @@ static void add_def(char *name, int curfile)
 {
   int i;
   for (i = 0; i < names_ctr; i++)
-    if (strcmp(names[i], name) == 0)
+    if (local_strcmp(names[i], name))
       {
 	if (!(defs[i]))
 	  defs[i] = strdup(files[curfile]);
@@ -108,8 +130,9 @@ static void add_def(char *name, int curfile)
       }
 }
 
-#define MAX_CHARS 1048576
-/* xg.c is 2.7 Mb */
+/* #define MAX_CHARS 1048576 */
+#define MAX_CHARS 8388608
+/* xg.c is 3.2 Mb */
 
 static char *get_call(char *input, int input_loc, int curname_len, char *curname, int chars, char *filename)
 {
@@ -121,7 +144,11 @@ static char *get_call(char *input, int input_loc, int curname_len, char *curname
 	break;
       }
   if (start == 0)
-    fprintf(stderr, "%s at %d found no begin cr\n", curname, input_loc);
+    {
+      if (input[0] == '_')
+	return(NULL);
+      /* fprintf(stderr, "%s: %s at %d found no begin cr\n", filename, curname, input_loc); */
+    }
   for (i = input_loc; i < chars; i++)
     {
       if (input[i] == ')')
@@ -190,11 +217,11 @@ static int greater_compare(const void *a, const void *b)
 }
 
 #define NAME_SIZE 8192
-#define ID_SIZE 8192
+#define ID_SIZE 16384
 
 int main(int argc, char **argv)
 {
-  int i, j, fd, curfile, chars, k, in_comment = 0, in_white = 0, calls = 0, in_parens = 0, in_quotes = 0, in_define = 0, in_curly = 0, in_enum = 0;
+  int i, j, fd, chars, k, in_comment = 0, in_cpp_comment = 0, in_white = 0, calls = 0, in_parens = 0, in_quotes = 0, in_define = 0, in_curly = 0, in_enum = 0;
   int maxc[NAME_SIZE], maxf[NAME_SIZE], maxg[NAME_SIZE], mcalls[NAME_SIZE];
   qdata **qs;
   char input[MAX_CHARS];
@@ -222,6 +249,7 @@ int main(int argc, char **argv)
   add_header("sndlib2xen.h");
   add_header("clm2xen.h");
   add_header("snd.h");
+  add_header("glistener.h");
 #if 1
   add_header("snd-strings.h");
   add_header("sndlib-strings.h");
@@ -235,8 +263,6 @@ int main(int argc, char **argv)
   add_header("snd-g1.h");
   add_header("snd-nogui0.h");
   add_header("snd-nogui1.h");
-  add_header("xen.h");
-  add_header("mus-config.h.in");
   add_header("libclm.def");
   add_header("snd-menu.h");
   add_header("snd-file.h");
@@ -247,6 +273,11 @@ int main(int argc, char **argv)
   /* add_file("xen.h"); */
   /* add_file("snd.h"); */
 
+  /* these need to be last */
+  add_header("xen.h");
+  add_header("mus-config.h.in");
+
+  add_file("glistener.c");
   add_file("headers.c");
   add_file("audio.c");
   add_file("io.c");
@@ -257,7 +288,6 @@ int main(int argc, char **argv)
   add_file("clm2xen.c");
   add_file("snd-io.c");
   add_file("snd-utils.c");
-  add_file("snd-error.c");
   add_file("snd-completion.c");
   add_file("snd-menu.c");
   add_file("snd-draw.c");
@@ -284,28 +314,11 @@ int main(int argc, char **argv)
   add_file("snd-env.c");
   add_file("snd-xen.c");
   add_file("snd-ladspa.c");
-  add_file("run.c");
-  add_file("snd-xutils.c");
-  add_file("snd-xhelp.c");
-  add_file("snd-xfind.c");
-  add_file("snd-xmenu.c");
-  add_file("snd-xdraw.c");
-  add_file("snd-xlistener.c");
+  add_file("snd-motif.c");
   add_file("snd-listener.c");
-  add_file("snd-xchn.c");
-  add_file("snd-xsnd.c");
-  add_file("snd-xregion.c");
-  add_file("snd-xdrop.c");
-  add_file("snd-xmain.c");
-  add_file("snd-xmix.c");
-  add_file("snd-xrec.c");
-  add_file("snd-xenv.c");
+  add_file("snd-xref.c");
   add_file("snd-gxbitmaps.c");
   add_file("snd-gxcolormaps.c");
-  add_file("snd-xfft.c");
-  add_file("snd-xprint.c");
-  add_file("snd-xfile.c");
-  add_file("snd-xprefs.c");
   add_file("snd-gutils.c");
   add_file("snd-ghelp.c");
   add_file("snd-gfind.c");
@@ -315,13 +328,10 @@ int main(int argc, char **argv)
   add_file("snd-gchn.c");
   add_file("snd-gsnd.c");
   add_file("snd-gregion.c");
-  add_file("snd-gdrop.c");
   add_file("snd-gmain.c");
   add_file("snd-gmix.c");
-  add_file("snd-grec.c");
   add_file("snd-genv.c");
   add_file("snd-gfft.c");
-  add_file("snd-gprint.c");
   add_file("snd-gfile.c");
   add_file("snd-gprefs.c");
   add_file("snd-prefs.c");
@@ -338,6 +348,24 @@ int main(int argc, char **argv)
   add_file("clm1.lisp");
 
   add_file("sndins/sndins.c");
+  add_file("ffitest.c");
+  add_file("tools/gcall.c");
+
+  add_file("/home/bil/test/s7webserver/s7webserver.cpp");
+  add_file("/home/bil/test/radium-3.4.2/embedded_scheme/scheme.cpp");
+
+  add_file("/home/bil/test/cm308/cm-3.8.0/src/CmSupport.cpp");
+  add_file("/home/bil/test/cm308/cm-3.8.0/src/Scheme.cpp");
+  add_file("/home/bil/test/cm308/cm-3.8.0/src/SndLib.cpp");
+  add_file("/home/bil/test/cm308/cm-3.8.0/src/SndLibBridge.cpp");
+
+  add_file("/home/bil/test/cm390/cm/src/CmSupport.cpp");
+  add_file("/home/bil/test/cm390/cm/src/Scheme.cpp");
+  add_file("/home/bil/test/cm390/cm/src/SndLib.cpp");
+  add_file("/home/bil/test/cm390/cm/src/SndLibBridge.cpp");
+  add_file("/home/bil/test/cm390/cm/src/s7.cpp");
+  add_file("/home/bil/test/cm390/cm/src/Osc.cpp");
+  add_file("/home/bil/test/cm390/cm/src/SchemeSources.cpp");
 
   for (i = 0; i < headers_ctr; i++)
     {
@@ -346,6 +374,7 @@ int main(int argc, char **argv)
       in_white = 0;
       in_parens = 0;
       in_comment = 0;
+      in_cpp_comment = 0;
       fd = open(headers[i], O_RDONLY, 0);
       if (fd == -1)
 	fprintf(stderr, "can't find %s\n", headers[i]);
@@ -356,7 +385,7 @@ int main(int argc, char **argv)
 	      chars = read(fd, input, MAX_CHARS);
 	      for (j = 0; j < chars; j++)
 		{
-		  if ((in_comment == 0) && (in_curly == 0))
+		  if ((in_comment == 0) && (in_cpp_comment == 0) && (in_curly == 0))
 		    {
 		      if ((isalpha(input[j])) || (isdigit(input[j])) || (input[j] == '_'))
 			{
@@ -371,6 +400,9 @@ int main(int argc, char **argv)
 			  if (k < ID_SIZE)
 			    curname[k] = 0;
 			  else fprintf(stderr, "1: curname overflow: %s[%d]: %s\n", headers[i], j, curname);
+
+			  /* fprintf(stderr, "%s name: %s %d %d %d\n", headers[i], curname, k, in_parens, in_quotes); */
+
 			  if ((k > 0) && (in_parens == 0) && (in_quotes == 0))
 			    {
 			      int loc;
@@ -406,22 +438,27 @@ int main(int argc, char **argv)
 			    in_comment = 1;
 			  else 
 			    {
-			      if (input[j] == '#')
-				in_define = 1;
-			      else
+			      if ((input[j] == '/') && (input[j + 1] == '/'))
+				in_cpp_comment = 1;
+			      else 
 				{
-				  if ((input[j] == '{') && 
-				      ((j < 6) || (strncmp((input + (j - 5)), "enum", 4) != 0)))
-				    in_curly = 1;
+				  if (input[j] == '#')
+				    in_define = 1;
 				  else
 				    {
-				      if (input[j] == '(') in_parens++;
-				      if (input[j] == ')') in_parens--;
-				      if (input[j] == '"')
+				      if ((input[j] == '{') && 
+					  ((j < 6) || (strncmp((input + (j - 5)), "enum", 4) != 0)))
+					in_curly = 1;
+				      else
 					{
-					  if (in_quotes == 1)
-					    in_quotes = 0;
-					  else in_quotes = 1;
+					  if (input[j] == '(') in_parens++;
+					  if (input[j] == ')') in_parens--;
+					  if (input[j] == '"')
+					    {
+					      if (in_quotes == 1)
+						in_quotes = 0;
+					      else in_quotes = 1;
+					    }
 					}
 				    }
 				}
@@ -440,6 +477,11 @@ int main(int argc, char **argv)
 			    {
 			      if (input[j] == ';')
 				in_curly = 0;
+			      else
+				{
+				  if (input[j] == '\n')
+				    in_cpp_comment = 0;
+				}
 			    }
 			}
 		    }
@@ -459,6 +501,7 @@ int main(int argc, char **argv)
 
       k = 0;
       in_comment = 0;
+      in_cpp_comment = 0;
       in_white = 0;
       in_define = 0;
       in_enum = 0;
@@ -478,8 +521,8 @@ int main(int argc, char **argv)
 	      bool got_macro = false;
 	      in_define = 0;
 	      
-	      if ((strcmp(files[i], "sndlib2clm.lisp") == 0) ||
-		  (strcmp(files[i], "ffi.lisp") == 0))
+	      if ((local_strcmp(files[i], "sndlib2clm.lisp")) ||
+		  (local_strcmp(files[i], "ffi.lisp")))
 		curly_ctr = 1;
 	      
 	      do 
@@ -489,7 +532,7 @@ int main(int argc, char **argv)
 		  
 		  for (j = 0; j < chars; j++)
 		    {
-		      if (in_comment == 0)
+		      if ((in_comment == 0) && (in_cpp_comment == 0))
 			{
 			  if ((isalpha(input[j])) || (isdigit(input[j])) || (input[j] == '_'))
 			    {
@@ -503,39 +546,53 @@ int main(int argc, char **argv)
 				in_comment = 1;
 			      else
 				{
-				  if ((input[j] == '#') && ((input[j + 1] == 'd') || (input[j + 1] == 'u')))
-				    {
-				      in_define = 1;
-				      got_macro = false;
-				    }
+				  if ((input[j] == '/') && (input[j + 1] == '/'))
+				    in_cpp_comment = 1;
 				  else
 				    {
-				      if ((in_define == 1) && (input[j] == '\n') && (j > 0) && (input[j - 1] != '\\'))
+				      if ((input[j] == '#') && 
+					  (((input[j + 1] == 'd') && (input[j + 2] == 'e')) || 
+					   ((input[j + 1] == 'u') && (input[j + 2] == 'n'))))
 					{
-					  cancel_define = 1;
+					  in_define = 1;
+					  got_macro = false;
 					}
-				    }
-				  if ((in_define == 0) && 
-				      (j < (chars - 1)) && 
-				      ((input[j - 1] != '\'') || (input[j + 1] != '\'')))
-				    {
-				      if (input[j] == '{') 
+				      else
 					{
-					  curly_ctr++;
-					  if ((j > 4) && 
-					      (strncmp((input + (j - 5)), "enum", 4) == 0))
-					    in_enum = true;
-					}
-				      else 
-					{
-					  if (input[j] == '}') 
+					  if ((in_define == 1) && (input[j] == '\n') && (j > 0) && (input[j - 1] != '\\'))
 					    {
-					      curly_ctr--;
-					      if (in_enum) in_enum = false;
+					      cancel_define = 1;
+					    }
+					}
+				      if ((in_define == 0) && 
+					  (j < (chars - 1)) && 
+					  ((input[j - 1] != '\'') || (input[j + 1] != '\'')))
+					{
+					  if (input[j] == '{') 
+					    {
+					      curly_ctr++;
+					      if ((j > 4) && 
+						  (strncmp((input + (j - 5)), "enum", 4) == 0))
+						in_enum = true;
+					    }
+					  else 
+					    {
+					      if (input[j] == '}') 
+						{
+						  curly_ctr--;
+						  if (in_enum) in_enum = false;
+						}
 					    }
 					}
 				    }
 				}
+
+			      if ((input[j + 1] == ' ') &&
+				  (input[j + 2] == '{') &&
+				  (input[j + 3] == '}'))
+				{
+				  k = 0;
+				}
 			      
 			      if (k > 0)
 				{
@@ -556,7 +613,7 @@ int main(int argc, char **argv)
 					}
 				      
 				      for (m = 0; m < all_names_top; m++)
-					if (strcmp(curname, all_names[m]) == 0)
+					if (local_strcmp(curname, all_names[m]))
 					  {
 					    happy = true;
 					    all_names_counts[m]++;
@@ -564,8 +621,8 @@ int main(int argc, char **argv)
 				      
 				      if (((!got_macro) && 
 					   (in_define == 1) && 
-					   (strcmp(curname, "define") != 0) &&
-					   (strcmp(curname, "undef") != 0)) ||
+					   (!local_strcmp(curname, "define")) &&
+					   (!local_strcmp(curname, "undef"))) ||
 					  (in_enum))
 					{
 					  got_macro = true;
@@ -634,6 +691,11 @@ int main(int argc, char **argv)
 			{
 			  if ((input[j] == '*') && (input[j + 1] == '/'))
 			    in_comment = 0;
+			  else
+			    {
+			      if (input[j] == '\n')
+				in_cpp_comment = 0;
+			    }
 			}
 		    }
 		}
@@ -644,7 +706,10 @@ int main(int argc, char **argv)
 		int m;
 		bool name_printed = false;
 		for (m = 0; m < all_names_top; m++)
-		  if (all_names_counts[m] == 0)
+		  if ((all_names_counts[m] == 0) &&
+		      (all_names[m][0] != '_') &&
+		      (((all_names[m][0] != 'Q') && (all_names[m][0] != 'H')) || (all_names[m][1] != '_')))
+			
 		    {
 		      if (!name_printed)
 			{
@@ -705,16 +770,17 @@ int main(int argc, char **argv)
       qsort((void *)qs, names_ctr, sizeof(qdata *), greater_compare);
       for (i = 0; i < names_ctr; i++)
 	{
-	  bool menu_case = false, file_case = false, nonogui_case = false, static_case = false, x_case = true;
+	  bool menu_case, file_case, nonogui_case, static_case, x_case = true, ffitest_case;
 	  int menu_count = 0, file_count = 0, rec_count = 0, x_count = 0;
 	  int nfiles;
 	  nfiles = 0;
 	  /* try to get rid of a bunch of annoying false positives */
-	  if ((strcmp(qs[i]->hname, "xen.h") == 0) || 
-	      (strcmp(qs[i]->hname, "mus-config.h.in") == 0) ||
+	  if ((local_strcmp(qs[i]->hname, "xen.h")) || 
+	      (local_strcmp(qs[i]->hname, "mus-config.h.in")) ||
+	      (qs[i]->name[0] == '_') ||
 	      ((qs[i]->name[strlen(qs[i]->name) - 2] == '_') &&
 	       ((qs[i]->name[strlen(qs[i]->name) - 1] == 't') || 
-		(qs[i]->name[strlen(qs[i]->name) - 1] == 'H'))))
+		(qs[i]->name[strlen(qs[i]->name) - 1] == 'H')))) /* SND_0_H etc */
 	    {
 	    }
 	  else
@@ -733,10 +799,28 @@ int main(int argc, char **argv)
 		      (strncmp(qs[i]->name, "in_set_", 7) != 0))
 		    fprintf(FD, " (not void but result not used?)");
 		}
+	      if (qs[i]->calls == 0)
+		{
+		  char buf1[512], buf2[512];
+		  snprintf(buf1, 512, "fgrep -q %s xen.h", qs[i]->name);
+		  snprintf(buf2, 512, "fgrep -q %s s7.html", qs[i]->name);
+		  if (system((const char *)buf1) == 0) 
+		    {
+		      if (system((const char *)buf2) == 0) 
+			fprintf(FD, " (used in xen.h and s7.html)");
+		      else fprintf(FD, " (used in xen.h)");
+		    }
+		  else
+		    {
+		      if (system((const char *)buf2) == 0)
+			fprintf(FD, " (used in s7.html)");
+		    }
+		}
 		  
-	      menu_case = (strcmp(qs[i]->hname, "snd-menu.h") != 0);
-	      file_case = (strcmp(qs[i]->hname, "snd-file.h") != 0);
+	      menu_case = (!local_strcmp(qs[i]->hname, "snd-menu.h"));
+	      file_case = (!local_strcmp(qs[i]->hname, "snd-file.h"));
 	      static_case = ((qs[i]->def != NULL) && (qs[i]->calls > 0));
+	      ffitest_case = ((qs[i]->def != NULL) && (qs[i]->calls > 0));
 
 	      menu_count  = 0;
 	      file_count = 0;
@@ -748,9 +832,9 @@ int main(int argc, char **argv)
 		  /* fprintf(stderr, "%s...", qs[i]->name); */
 		  for (j = 0; j < files_ctr; j++)
 		    if ((counts[qs[i]->i][j] > 0) &&
-			((strcmp(files[j], "snd-xen.c") == 0) ||
-			 ((strcmp(files[j], "snd-nogui.c") != 0) &&
-			  (strncmp(files[j], "snd-x", 5) != 0) &&
+			((local_strcmp(files[j], "snd-xen.c")) ||
+			 ((!local_strcmp(files[j], "snd-nogui.c")) &&
+			  (!local_strcmp(files[j], "snd-motif.c")) &&
 			  (strncmp(files[j], "snd-g", 5) != 0))))
 		      {
 			/* fprintf(stderr,"in %s\n", files[j]); */
@@ -764,13 +848,17 @@ int main(int argc, char **argv)
 		{
 		  if ((counts[qs[i]->i]) && (counts[qs[i]->i][j] > 0))
 		    {
+		      if ((ffitest_case) &&
+			  (!local_strcmp(files[j], "ffitest.c")))
+			ffitest_case = false;
+
 		      if (menu_case)
 			{
-			  if ((strcmp(files[j], "snd-menu.c") != 0) &&
-			      (strcmp(files[j], "snd-xmenu.c") != 0) &&
-			      (strcmp(files[j], "snd-gmenu.c") != 0))
+			  if ((!local_strcmp(files[j], "snd-menu.c")) &&
+			      (!local_strcmp(files[j], "snd-motif.c")) &&
+			      (!local_strcmp(files[j], "snd-gmenu.c")))
 			    {
-			      if (strcmp(files[j], "snd-nogui.c") != 0)
+			      if (!local_strcmp(files[j], "snd-nogui.c"))
 				menu_case = false;
 			    }
 			  else menu_count++;
@@ -778,34 +866,34 @@ int main(int argc, char **argv)
 		      
 		      if (x_case)
 			{
-			  if (((strncmp(files[j], "snd-x", 5) != 0) &&
+			  if (((!local_strcmp(files[j], "snd-motif.c")) &&
 			       (strncmp(files[j], "snd-g", 5) != 0)) ||
-			      (strcmp(files[j], "snd-xen.c") == 0))
+			      (local_strcmp(files[j], "snd-xen.c")))
 			    x_case = false;
 			  else x_count++;
 			}
 
 		      if (file_case)
 			{
-			  if ((strcmp(files[j], "snd-file.c") != 0) &&
-			      (strcmp(files[j], "snd-xfile.c") != 0) &&
-			      (strcmp(files[j], "snd-gfile.c") != 0))
+			  if ((!local_strcmp(files[j], "snd-file.c")) &&
+			      (!local_strcmp(files[j], "snd-motif.c")) &&
+			      (!local_strcmp(files[j], "snd-gfile.c")))
 			    {
-			      if (strcmp(files[j], "snd-nogui.c") != 0)
+			      if (!local_strcmp(files[j], "snd-nogui.c"))
 				file_case = false;
 			    }
 			  else file_count++;
 			}
 
 		      if ((static_case) &&
-			  (strcmp(files[j], qs[i]->def) != 0) &&
-			  (strcmp(files[j], "snd-nogui.c") != 0))
+			  (!local_strcmp(files[j], qs[i]->def)) &&
+			  (!local_strcmp(files[j], "snd-nogui.c")))
 			{
-			  if (((strncmp(files[j], "snd-x", 5) == 0) || 
+			  if (((local_strcmp(files[j], "snd-motif.c")) || 
 			       (strncmp(files[j], "snd-g", 5) == 0)) &&
-			      ((strncmp(qs[i]->def, "snd-x", 5) == 0) || 
+			      ((local_strcmp(qs[i]->def, "snd-motif.c")) || 
 			       (strncmp(qs[i]->def, "snd-g", 5) == 0)) &&
-			      (strcmp((const char *)(files[j] + 5), (const char *)(qs[i]->def + 5)) == 0))
+			      (local_strcmp((const char *)(files[j] + 5), (const char *)(qs[i]->def + 5))))
 			    {
 			    }
 			  else static_case = false;
@@ -816,27 +904,38 @@ int main(int argc, char **argv)
 		    }
 		}
 
+	      if (ffitest_case)
+		{
+		  char buf1[512], buf2[512];
+		  snprintf(buf1, 512, "fgrep -q %s xen.h", qs[i]->name);
+		  snprintf(buf2, 512, "fgrep -q %s s7.html", qs[i]->name);
+		  if ((system((const char *)buf1) != 0) &&
+		      (system((const char *)buf2) != 0))
+		    fprintf(FD, "\njust ffitest!");
+		}
+
 	      if ((menu_case) && 
 		  (menu_count > 0) &&
 		  ((!(qs[i]->def)) ||
-		   (strcmp(qs[i]->def, "snd-menu.c") == 0) ||
-		   (strcmp(qs[i]->def, "snd-xmenu.c") == 0) ||
-		   (strcmp(qs[i]->def, "snd-gmenu.c") == 0)))
+		   (local_strcmp(qs[i]->def, "snd-menu.c")) ||
+		   (local_strcmp(qs[i]->def, "snd-motif.c")) ||
+		   (local_strcmp(qs[i]->def, "snd-gmenu.c"))))
 		fprintf(FD, "\n->SND-MENU.H\n");
 
 	      if ((file_case) && 
 		  (file_count > 0) &&
 		  ((!(qs[i]->def)) ||
-		   (strcmp(qs[i]->def, "snd-file.c") == 0) ||
-		   (strcmp(qs[i]->def, "snd-xfile.c") == 0) ||
-		   (strcmp(qs[i]->def, "snd-gfile.c") == 0)))
+		   (local_strcmp(qs[i]->def, "snd-file.c")) ||
+		   (local_strcmp(qs[i]->def, "snd-motif.c")) ||
+		   (local_strcmp(qs[i]->def, "snd-gfile.c"))))
 		fprintf(FD, "\n->SND-FILE.H\n");
 
 	      if ((x_case) &&
 		  (x_count > 0) &&
 		  (qs[i]->def) &&
-		  (strcmp(qs[i]->def, "snd-xen.c") != 0) &&
-		  ((strncmp(qs[i]->def, "snd-x", 5) == 0) || 
+		  (local_strcmp(qs[i]->hname, "snd-1.h")) &&
+		  (!local_strcmp(qs[i]->def, "snd-xen.c")) &&
+		  ((local_strcmp(qs[i]->def, "snd-motif.c")) || 
 		   (strncmp(qs[i]->def, "snd-g", 5) == 0)))
 		fprintf(FD, "\n    (all within gui)\n");
 
