@@ -39,11 +39,6 @@
 ;(CFNC-X "int glXQueryContext Display* dpy GLXContext ctx int attribute int* value")
 ;(CFNC-X "void glXSelectEvent Display* dpy Window draw ulong event_mask")
 ;(CFNC-X "void glXGetSelectedEvent Display* dpy Window draw ulong* event_mask")
-;(CFNC-X "GLXContextID glXGetContextIDEXT GLXContext ctx")
-;(CFNC-X "Window glXGetCurrentDrawableEXT void")
-;(CFNC-X "GLXContext glXImportContextEXT Display* dpy GLXContextID contextID")
-;(CFNC-X "void glXFreeContextEXT Display* dpy GLXContext ctx")
-;(CFNC-X "int glXQueryContextInfoEXT Display* dpy GLXContext ctx int attribute int* value")
 (CFNC "void glClearIndex GLfloat c")
 (CFNC "void glClearColor GLclampf red GLclampf green GLclampf blue GLclampf alpha")
 (CFNC "void glClear GLbitfield mask")
@@ -451,7 +446,6 @@
 (CFNC "void gluNextContour GLUtesselator* tess GLenum type")
 (CFNC "void gluNurbsCallback GLUnurbs* nurb GLenum which _GLUfuncptr CallBackFunc")
 (CFNC "void gluNurbsCallbackData GLUnurbs* nurb GLvoid* userData")
-(CFNC "void gluNurbsCallbackDataEXT GLUnurbs* nurb GLvoid* userData")
 (CFNC "void gluNurbsCurve GLUnurbs* nurb GLint knotCount GLfloat* knots GLint stride GLfloat* control GLint order GLenum type")
 (CFNC "void gluNurbsProperty GLUnurbs* nurb GLenum property GLfloat value")
 (CFNC "void gluNurbsSurface GLUnurbs* nurb GLint sKnotCount GLfloat* sKnots GLint tKnotCount GLfloat* tKnots GLint sStride GLint tStride GLfloat* control GLint sOrder GLint tOrder GLenum type")
@@ -512,63 +506,6 @@
 (CFNC-multi "void glMultiTexCoord4ivARB GLenum target GLint* v")
 (CFNC-multi "void glMultiTexCoord4sARB GLenum target GLshort s GLshort t GLshort r GLshort q")
 (CFNC-multi "void glMultiTexCoord4svARB GLenum target GLshort* v")
-;;;(CFNC "void glLockArraysEXT GLint first GLsizei count")
-;;;(CFNC "void glUnlockArraysEXT void")
-;;;(CFNC "void glBlendColorEXT GLclampf red GLclampf green GLclampf blue GLclampf alpha")
-;;;(CFNC-blend "void glPolygonOffsetEXT GLfloat factor GLfloat bias")
-;;;(CFNC-texture "void glTexImage3DEXT GLenum target GLint level GLenum internalFormat GLsizei width GLsizei height GLsizei depth GLint border GLenum format GLenum type GLvoid* pixels")
-;;;(CFNC-texture "void glTexSubImage3DEXT GLenum target GLint level GLint xoffset GLint yoffset GLint zoffset GLsizei width GLsizei height GLsizei depth GLenum format GLenum type GLvoid* pixels")
-;;;(CFNC-texture "void glCopyTexSubImage3DEXT GLenum target GLint level GLint xoffset GLint yoffset GLint zoffset GLint x GLint y GLsizei width GLsizei height")
-;;;(CFNC-object "void glGenTexturesEXT GLsizei n GLuint* textures")
-;;;(CFNC-object "void glDeleteTexturesEXT GLsizei n GLuint* textures")
-;;;(CFNC-object "void glBindTextureEXT GLenum target GLuint texture")
-;(CFNC-object "void glPrioritizeTexturesEXT GLsizei n GLuint* textures GLclampf* priorities")
-;;;(CFNC-object "GLboolean glAreTexturesResidentEXT GLsizei n GLuint* textures GLboolean* residences")
-;;;(CFNC-object "GLboolean glIsTextureEXT GLuint texture")
-;;;(CFNC-vertex "void glVertexPointerEXT GLint size GLenum type GLsizei stride GLsizei count GLvoid* ptr")
-;;;(CFNC-vertex "void glNormalPointerEXT GLenum type GLsizei stride GLsizei count GLvoid* ptr")
-;;;(CFNC-vertex "void glColorPointerEXT GLint size GLenum type GLsizei stride GLsizei count GLvoid* ptr")
-;;;(CFNC-vertex "void glIndexPointerEXT GLenum type GLsizei stride GLsizei count GLvoid* ptr")
-;;;(CFNC-vertex "void glTexCoordPointerEXT GLint size GLenum type GLsizei stride GLsizei count GLvoid* ptr")
-;;;(CFNC-vertex "void glEdgeFlagPointerEXT GLsizei stride GLsizei count GLboolean* ptr")
-;;;(CFNC-vertex "void glGetPointervEXT GLenum pname void** [params]")
-;;;(CFNC-vertex "void glArrayElementEXT GLint i")
-;;;(CFNC-vertex "void glDrawArraysEXT GLenum mode GLint first GLsizei count")
-;;;(CFNC "void glBlendEquationEXT GLenum mode")
-;;;(CFNC "void glPointParameterfEXT GLenum pname GLfloat param")
-;;;(CFNC "void glPointParameterfvEXT GLenum pname GLfloat* params")
-;(CFNC "void glPointParameterfSGIS GLenum pname GLfloat param")
-;(CFNC "void glPointParameterfvSGIS GLenum pname GLfloat* params")
-;;;(CFNC "void glColorTableEXT GLenum target GLenum internalformat GLsizei width GLenum format GLenum type GLvoid* table")
-;;;(CFNC "void glColorSubTableEXT GLenum target GLsizei start GLsizei count GLenum format GLenum type GLvoid* data")
-;(CFNC "void glGetColorTableEXT GLenum target GLenum format GLenum type GLvoid* [table]")
-;;;(CFNC "void glGetColorTableParameterfvEXT GLenum target GLenum pname GLfloat* [params]")
-;;;(CFNC "void glGetColorTableParameterivEXT GLenum target GLenum pname GLint* [params]")
-;(CFNC "void glWindowPos2iMESA GLint x GLint y")
-;(CFNC "void glWindowPos2sMESA GLshort x GLshort y")
-;(CFNC "void glWindowPos2fMESA GLfloat x GLfloat y")
-;(CFNC "void glWindowPos2dMESA GLdouble x GLdouble y")
-;(CFNC "void glWindowPos2ivMESA GLint* p")
-;(CFNC "void glWindowPos2svMESA GLshort* p")
-;(CFNC "void glWindowPos2fvMESA GLfloat* p")
-;(CFNC "void glWindowPos2dvMESA GLdouble* p")
-;(CFNC "void glWindowPos3iMESA GLint x GLint y GLint z")
-;(CFNC "void glWindowPos3sMESA GLshort x GLshort y GLshort z")
-;(CFNC "void glWindowPos3fMESA GLfloat x GLfloat y GLfloat z")
-;(CFNC "void glWindowPos3dMESA GLdouble x GLdouble y GLdouble z")
-;(CFNC "void glWindowPos3ivMESA GLint* p")
-;(CFNC "void glWindowPos3svMESA GLshort* p")
-;(CFNC "void glWindowPos3fvMESA GLfloat* p")
-;(CFNC "void glWindowPos3dvMESA GLdouble* p")
-;(CFNC "void glWindowPos4iMESA GLint x GLint y GLint z GLint w")
-;(CFNC "void glWindowPos4sMESA GLshort x GLshort y GLshort z GLshort w")
-;(CFNC "void glWindowPos4fMESA GLfloat x GLfloat y GLfloat z GLfloat w")
-;(CFNC "void glWindowPos4dMESA GLdouble x GLdouble y GLdouble z GLdouble w")
-;(CFNC "void glWindowPos4ivMESA GLint* p")
-;(CFNC "void glWindowPos4svMESA GLshort* p")
-;(CFNC "void glWindowPos4fvMESA GLfloat* p")
-;(CFNC "void glWindowPos4dvMESA GLdouble* p")
-;(CFNC "void glResizeBuffersMESA void")
 
 (CINT-X "GLX_USE_GL")
 (CINT-X "GLX_BUFFER_SIZE")
@@ -650,31 +587,9 @@
 ;(CINT-X "GLX_DEPTH_BUFFER_BIT")
 ;(CINT-X "GLX_STENCIL_BUFFER_BIT")
 ;(CINT-X "GLX_ACCUM_BUFFER_BIT")
-;(CINT-X "GLX_X_VISUAL_TYPE_EXT")
-;(CINT-X "GLX_TRANSPARENT_TYPE_EXT")
-;(CINT-X "GLX_TRANSPARENT_INDEX_VALUE_EXT")
-;(CINT-X "GLX_TRANSPARENT_RED_VALUE_EXT")
-;(CINT-X "GLX_TRANSPARENT_GREEN_VALUE_EXT")
-;(CINT-X "GLX_TRANSPARENT_BLUE_VALUE_EXT")
-;(CINT-X "GLX_TRANSPARENT_ALPHA_VALUE_EXT")
-;(CINT-X "GLX_TRUE_COLOR_EXT")
-;(CINT-X "GLX_DIRECT_COLOR_EXT")
-;(CINT-X "GLX_PSEUDO_COLOR_EXT")
-;(CINT-X "GLX_STATIC_COLOR_EXT")
-;(CINT-X "GLX_GRAY_SCALE_EXT")
-;(CINT-X "GLX_STATIC_GRAY_EXT")
-;(CINT-X "GLX_NONE_EXT")
-;(CINT-X "GLX_TRANSPARENT_RGB_EXT")
-;(CINT-X "GLX_TRANSPARENT_INDEX_EXT")
-;;(CINT-X "GLX_VISUAL_CAVEAT_EXT")
-;;(CINT-X "GLX_SLOW_VISUAL_EXT")
-;(CINT-X "GLX_NON_CONFORMANT_VISUAL_EXT")
 (CINT-X "GLX_VENDOR")
 (CINT-X "GLX_VERSION")
 (CINT-X "GLX_EXTENSIONS")
-;(CINT-X "GLX_SHARE_CONTEXT_EXT")
-;(CINT-X "GLX_VISUAL_ID_EXT")
-;(CINT-X "GLX_SCREEN_EXT")
 (CINT "GL_FALSE")
 (CINT "GL_TRUE")
 (CINT "GL_BYTE")
@@ -1354,100 +1269,6 @@
 (CINT-multi "GL_ACTIVE_TEXTURE_ARB")
 (CINT-multi "GL_CLIENT_ACTIVE_TEXTURE_ARB")
 (CINT-multi "GL_MAX_TEXTURE_UNITS_ARB")
-;(CINT "GL_CONSTANT_COLOR_EXT")
-;(CINT "GL_ONE_MINUS_CONSTANT_COLOR_EXT")
-;(CINT "GL_CONSTANT_ALPHA_EXT")
-;(CINT "GL_ONE_MINUS_CONSTANT_ALPHA_EXT")
-;(CINT "GL_BLEND_COLOR_EXT")
-;(CINT-blend "GL_POLYGON_OFFSET_EXT")
-;(CINT-blend "GL_POLYGON_OFFSET_FACTOR_EXT")
-;(CINT-blend "GL_POLYGON_OFFSET_BIAS_EXT")
-;(CINT-texture "GL_PACK_SKIP_IMAGES_EXT")
-;(CINT-texture "GL_PACK_IMAGE_HEIGHT_EXT")
-;(CINT-texture "GL_UNPACK_SKIP_IMAGES_EXT")
-;(CINT-texture "GL_UNPACK_IMAGE_HEIGHT_EXT")
-;(CINT-texture "GL_TEXTURE_3D_EXT")
-;(CINT-texture "GL_PROXY_TEXTURE_3D_EXT")
-;(CINT-texture "GL_TEXTURE_DEPTH_EXT")
-;(CINT-texture "GL_TEXTURE_WRAP_R_EXT")
-;(CINT-texture "GL_MAX_3D_TEXTURE_SIZE_EXT")
-;(CINT-texture "GL_TEXTURE_3D_BINDING_EXT")
-;(CINT-object "GL_TEXTURE_PRIORITY_EXT")
-;(CINT-object "GL_TEXTURE_RESIDENT_EXT")
-;(CINT-object "GL_TEXTURE_1D_BINDING_EXT")
-;(CINT-object "GL_TEXTURE_2D_BINDING_EXT")
-;(CINT-rescale "GL_RESCALE_NORMAL_EXT")
-;(CINT-vertex "GL_VERTEX_ARRAY_EXT")
-;(CINT-vertex "GL_NORMAL_ARRAY_EXT")
-;(CINT-vertex "GL_COLOR_ARRAY_EXT")
-;(CINT-vertex "GL_INDEX_ARRAY_EXT")
-;(CINT-vertex "GL_TEXTURE_COORD_ARRAY_EXT")
-;(CINT-vertex "GL_EDGE_FLAG_ARRAY_EXT")
-;(CINT-vertex "GL_VERTEX_ARRAY_SIZE_EXT")
-;(CINT-vertex "GL_VERTEX_ARRAY_TYPE_EXT")
-;(CINT-vertex "GL_VERTEX_ARRAY_STRIDE_EXT")
-;(CINT-vertex "GL_VERTEX_ARRAY_COUNT_EXT")
-;(CINT-vertex "GL_NORMAL_ARRAY_TYPE_EXT")
-;(CINT-vertex "GL_NORMAL_ARRAY_STRIDE_EXT")
-;(CINT-vertex "GL_NORMAL_ARRAY_COUNT_EXT")
-;(CINT-vertex "GL_COLOR_ARRAY_SIZE_EXT")
-;(CINT-vertex "GL_COLOR_ARRAY_TYPE_EXT")
-;(CINT-vertex "GL_COLOR_ARRAY_STRIDE_EXT")
-;(CINT-vertex "GL_COLOR_ARRAY_COUNT_EXT")
-;(CINT-vertex "GL_INDEX_ARRAY_TYPE_EXT")
-;(CINT-vertex "GL_INDEX_ARRAY_STRIDE_EXT")
-;(CINT-vertex "GL_INDEX_ARRAY_COUNT_EXT")
-;(CINT-vertex "GL_TEXTURE_COORD_ARRAY_SIZE_EXT")
-;(CINT-vertex "GL_TEXTURE_COORD_ARRAY_TYPE_EXT")
-;(CINT-vertex "GL_TEXTURE_COORD_ARRAY_STRIDE_EXT")
-;(CINT-vertex "GL_TEXTURE_COORD_ARRAY_COUNT_EXT")
-;(CINT-vertex "GL_EDGE_FLAG_ARRAY_STRIDE_EXT")
-;(CINT-vertex "GL_EDGE_FLAG_ARRAY_COUNT_EXT")
-;(CINT-vertex "GL_VERTEX_ARRAY_POINTER_EXT")
-;(CINT-vertex "GL_NORMAL_ARRAY_POINTER_EXT")
-;(CINT-vertex "GL_COLOR_ARRAY_POINTER_EXT")
-;(CINT-vertex "GL_INDEX_ARRAY_POINTER_EXT")
-;(CINT-vertex "GL_TEXTURE_COORD_ARRAY_POINTER_EXT")
-;(CINT-vertex "GL_EDGE_FLAG_ARRAY_POINTER_EXT")
-;(CINT "GL_CLAMP_TO_EDGE_SGIS")
-;(CINT "GL_FUNC_ADD_EXT")
-;(CINT "GL_MIN_EXT")
-;(CINT "GL_MAX_EXT")
-;(CINT "GL_BLEND_EQUATION_EXT")
-;(CINT "GL_FUNC_SUBTRACT_EXT")
-;(CINT "GL_FUNC_REVERSE_SUBTRACT_EXT")
-;(CINT "GL_POINT_SIZE_MIN_EXT")
-;(CINT "GL_POINT_SIZE_MAX_EXT")
-;(CINT "GL_POINT_FADE_THRESHOLD_SIZE_EXT")
-;(CINT "GL_DISTANCE_ATTENUATION_EXT")
-;(CINT "GL_TABLE_TOO_LARGE_EXT")
-;(CINT "GL_COLOR_TABLE_FORMAT_EXT")
-;(CINT "GL_COLOR_TABLE_WIDTH_EXT")
-;(CINT "GL_COLOR_TABLE_RED_SIZE_EXT")
-;(CINT "GL_COLOR_TABLE_GREEN_SIZE_EXT")
-;(CINT "GL_COLOR_TABLE_BLUE_SIZE_EXT")
-;(CINT "GL_COLOR_TABLE_ALPHA_SIZE_EXT")
-;(CINT "GL_COLOR_TABLE_LUMINANCE_SIZE_EXT")
-;(CINT "GL_COLOR_TABLE_INTENSITY_SIZE_EXT")
-;(CINT "GL_TEXTURE_INDEX_SIZE_EXT")
-;(CINT "GL_COLOR_INDEX1_EXT")
-;(CINT "GL_COLOR_INDEX2_EXT")
-;(CINT "GL_COLOR_INDEX4_EXT")
-;(CINT "GL_COLOR_INDEX8_EXT")
-;(CINT "GL_COLOR_INDEX12_EXT")
-;(CINT "GL_COLOR_INDEX16_EXT")
-;(CINT "GL_CLIP_VOLUME_CLIPPING_HINT_EXT")
-;;(CINT "GL_ARRAY_ELEMENT_LOCK_FIRST_EXT")
-;;(CINT "GL_ARRAY_ELEMENT_LOCK_COUNT_EXT")
-;;(CINT "GL_OCCLUSION_TEST_HP")
-;;(CINT "GL_OCCLUSION_TEST_RESULT_HP")
-;(CINT "GL_SHARED_TEXTURE_PALETTE_EXT")
-;(CINT "GL_INCR_WRAP_EXT")
-;(CINT "GL_DECR_WRAP_EXT")
-;(CINT "GL_NORMAL_MAP_NV")
-;;(CINT "GL_DOT3_RGB_EXT")
-;;(CINT "GL_DOT3_RGBA_EXT")
-;(CINT "GL_REFLECTION_MAP_NV")
 (CINT "GLU_FALSE")
 (CINT "GLU_TRUE")
 ;(CINT "GLU_VERSION_1_1")
@@ -1464,29 +1285,17 @@
 (CINT "GLU_NURBS_ERROR")
 (CINT "GLU_ERROR")
 (CINT "GLU_NURBS_BEGIN")
-(CINT "GLU_NURBS_BEGIN_EXT")
 (CINT "GLU_NURBS_VERTEX")
-(CINT "GLU_NURBS_VERTEX_EXT")
 (CINT "GLU_NURBS_NORMAL")
-(CINT "GLU_NURBS_NORMAL_EXT")
 (CINT "GLU_NURBS_COLOR")
-(CINT "GLU_NURBS_COLOR_EXT")
 (CINT "GLU_NURBS_TEXTURE_COORD")
-(CINT "GLU_NURBS_TEX_COORD_EXT")
 (CINT "GLU_NURBS_END")
-(CINT "GLU_NURBS_END_EXT")
 (CINT "GLU_NURBS_BEGIN_DATA")
-(CINT "GLU_NURBS_BEGIN_DATA_EXT")
 (CINT "GLU_NURBS_VERTEX_DATA")
-(CINT "GLU_NURBS_VERTEX_DATA_EXT")
 (CINT "GLU_NURBS_NORMAL_DATA")
-(CINT "GLU_NURBS_NORMAL_DATA_EXT")
 (CINT "GLU_NURBS_COLOR_DATA")
-(CINT "GLU_NURBS_COLOR_DATA_EXT")
 (CINT "GLU_NURBS_TEXTURE_COORD_DATA")
-(CINT "GLU_NURBS_TEX_COORD_DATA_EXT")
 (CINT "GLU_NURBS_END_DATA")
-(CINT "GLU_NURBS_END_DATA_EXT")
 (CINT "GLU_NURBS_ERROR1")
 (CINT "GLU_NURBS_ERROR2")
 (CINT "GLU_NURBS_ERROR3")
@@ -1533,15 +1342,10 @@
 (CINT "GLU_U_STEP")
 (CINT "GLU_V_STEP")
 (CINT "GLU_NURBS_MODE")
-(CINT "GLU_NURBS_MODE_EXT")
 (CINT "GLU_NURBS_TESSELLATOR")
-(CINT "GLU_NURBS_TESSELLATOR_EXT")
 (CINT "GLU_NURBS_RENDERER")
-(CINT "GLU_NURBS_RENDERER_EXT")
 (CINT "GLU_OBJECT_PARAMETRIC_ERROR")
-(CINT "GLU_OBJECT_PARAMETRIC_ERROR_EXT")
 (CINT "GLU_OBJECT_PATH_LENGTH")
-(CINT "GLU_OBJECT_PATH_LENGTH_EXT")
 (CINT "GLU_PATH_LENGTH")
 (CINT "GLU_PARAMETRIC_ERROR")
 (CINT "GLU_DOMAIN_DISTANCE")
