@@ -2,25 +2,25 @@
 
 (define gl-file (open-output-file "gl.c"))
 
-(define (hey . args)
-  (display (apply format #f args) gl-file))
+(define-expansion (hey . args)
+  `(format gl-file ,@args))
 
 (define (heyc arg)
   (display arg gl-file))
 
-(define names '())
-(define types '())
-(define ints '())
-(define funcs '())
+(define names ())
+(define types ())
+(define ints ())
+(define funcs ())
 
-(define x-types '())
-(define x-funcs '())
-(define x-ints '())
-;(define g-types '())
-;(define g-funcs '())
-;(define g-ints '())
-;(define g5-funcs '())
-;(define g5-ints '())
+(define x-types ())
+(define x-funcs ())
+(define x-ints ())
+;(define g-types ())
+;(define g-funcs ())
+;(define g-ints ())
+;(define g5-funcs ())
+;(define g5-ints ())
 
 (define in-glu #f)
 
@@ -42,57 +42,31 @@
 	(set! in-glu #f))))
 
 (define (cadr-str data)
-  (let ((sp1 -1)
-	(len (string-length data)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i 0 (+ 1 i)))
-	   ((= i len) (substring data sp1))
-	 (if (char=? (string-ref data i) #\space)
-	     (if (= sp1 -1)
-		 (set! sp1 i)
-		 (return (substring data (+ 1 sp1) i)))))))))
+  (let ((sp1 (char-position #\space data)))
+    (let ((sp2 (char-position #\space data (+ sp1 1))))
+      (if sp2
+	  (substring data (+ sp1 1) sp2)
+	  (substring data sp1)))))
 
 (define (caddr-str data)
-  (let ((sp1 -1)
-	(sp2 -1)
-	(len (string-length data)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i 0 (+ 1 i)))
-	   ((= i len) (substring data sp2))
-	 (if (char=? (string-ref data i) #\space)
-	     (if (= sp1 -1)
-		 (set! sp1 i)
-		 (if (= sp2 -1)
-		     (set! sp2 i)
-		     (return (substring data (+ 1 sp2)))))))))))
+  (let ((sp1 (char-position #\space data)))
+    (let ((sp2 (char-position #\space data (+ sp1 1))))
+      (let ((sp3 (char-position #\space data (+ sp2 1))))
+	(if sp3
+	    (substring data (+ sp2 1))
+	    (substring data sp2))))))
 
 (define (car-str data)
-  (let ((len (string-length data)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i 0 (+ 1 i)))
-	   ((= i len) data)
-	 (if (char=? (string-ref data i) #\space)
-	     (return (substring data 0 i))))))))
+  (let ((sp (char-position #\space data)))
+    (if sp
+	(substring data 0 sp)
+	data)))
 
 (define (cdr-str data)
-  (let ((len (string-length data)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i 0 (+ 1 i)))
-	   ((= i len) data)
-	 (if (char=? (string-ref data i) #\space)
-	     (return (substring data (+ 1 i)))))))))
-
-(define (string-upcase name)
-  (let* ((len (string-length name))
-	 (str (make-string len)))
-    (do ((i 0 (+ 1 i)))
-	((= i len))
-      (string-set! str i (char-upcase (string-ref name i))))
-    str))
+  (let ((sp (char-position #\space data)))
+    (if sp
+	(substring data (+ sp 1))
+	data)))
 
 (define (ref-arg? arg)
   (and (= (length arg) 3)
@@ -126,30 +100,29 @@
 
 (define (deref-type arg)
   (let ((type (car arg)))
-    (substring type 0 (- (string-length type) 1))))
+    (substring type 0 (- (length type) 1))))
 
 (define (deref-name arg)
-  (let* ((name (cadr arg)))
+  (let ((name (cadr arg)))
     (string-append "ref_" name)))
 
 (define (derefable type)
-  (let ((len (string-length type)))
+  (let ((len (length type)))
     (call-with-exit
      (lambda (return)
        (do ((i (- len 1) (- i 1))
 	    (ctr 0 (+ 1 ctr)))
 	   ((= i 0) #f)
-	 (if (not (char=? (string-ref type i) #\*))
+	 (if (not (char=? (type i) #\*))
 	     (return (> ctr 1))))))))
 
 (define (has-stars type)
-  (let ((len (string-length type)))
+  (let ((len (length type)))
     (call-with-exit
      (lambda (return)
-       (do ((i (- len 1) (- i 1))
-	    (ctr 0 (+ 1 ctr)))
+       (do ((i (- len 1) (- i 1)))
 	   ((= i 0) #f)
-	 (if (char=? (string-ref type i) #\*)
+	 (if (char=? (type i) #\*)
 	     (return #t)))
        #f))))
 
@@ -158,54 +131,54 @@
       "Display"
       (if (string=? type "XVisualInfo*")
 	  "XVisualInfo"
-	  (let ((len (string-length type))
+	  (let ((len (length type))
 		(val (string-copy type)))
-	    (do ((i 0 (+ 1 i)))
+	    (do ((i 0 (+ i 1)))
 		((= i len) val)
-	      (if (char=? (string-ref val i) #\*)
-		  (string-set! val i #\_)))))))
+	      (if (char=? (val i) #\*)
+		  (set! (val i) #\_)))))))
 
 (define (no-arg-or-stars name)
-  (let ((len (string-length name)))
+  (let ((len (length name)))
     (call-with-exit
      (lambda (return)
-       (do ((i 0 (+ 1 i)))
+       (do ((i 0 (+ i 1)))
 	   ((= i len) name)
-	 (if (or (char=? (string-ref name i) #\()
-		 (char=? (string-ref name i) #\*))
+	 (if (or (char=? (name i) #\()
+		 (char=? (name i) #\*))
 	     (return (substring name 0 i))))))))
 
 (define* (parse-args args x)
-  (let ((data '())
+  (let ((data ())
 	(sp -1)
 	(type #f)
-	(len (string-length args)))
+	(len (length args)))
     (if (string=? args "void")
-	'()
-	(do ((i 0 (+ 1 i)))
+	()
+	(do ((i 0 (+ i 1)))
 	    ((= i len) (reverse data))
-	  (let ((ch (string-ref args i)))
+	  (let ((ch (args i)))
 	    (if (or (char=? ch #\space)
 		    (= i (- len 1)))
 		(begin
 		  (if type
-		      (let* ((given-name (substring args (+ 1 sp) (if (= i (- len 1)) (+ 1 i) i)))
-			     (reftype #f))
-			(if (char=? (string-ref given-name 0) #\@)
+		      (let ((given-name (substring args (+ 1 sp) (if (= i (- len 1)) (+ i 1) i)))
+			    (reftype #f))
+			(if (char=? (given-name 0) #\@)
 			    (set! data (cons (list type 
-						   (substring given-name 1 (string-length given-name))
+						   (substring given-name 1 (length given-name))
 						   'null)
 					       data))
-			    (if (char=? (string-ref given-name 0) #\#)
+			    (if (char=? (given-name 0) #\#)
 				(set! data (cons (list type 
-						       (substring given-name 1 (string-length given-name))
+						       (substring given-name 1 (length given-name))
 						       'opt)
 						 data))
-				(if (char=? (string-ref given-name 0) #\[) 
+				(if (char=? (given-name 0) #\[) 
 				    (begin
 				      (set! reftype (deref-type (list type)))
 				      (set! data (cons (list type 
-							     (substring given-name 1 (- (string-length given-name) 1))
+							     (substring given-name 1 (- (length given-name) 1))
 							     given-name) 
 						       data)))
 				    (set! data (cons (list type given-name) data)))))
@@ -213,11 +186,9 @@
 			(if (eq? x 'x)
 			    (if (not (member type x-types))
 				(set! x-types (cons type x-types)))
-			    (if (eq? x 'g)
-				(if (not (member type g-types))
-				    (set! g-types (cons type g-types)))
-				(if (not (member type types))
-				    (set! types (cons type types)))))
+			    (if (and (not (eq? x 'g))
+				     (not (member type types)))
+				(set! types (cons type types))))
 			(set! type #f))
 		      (if (> i (+ 1 sp))
 			  (set! type (substring args (+ 1 sp) i))))
@@ -225,14 +196,14 @@
 
 (define (helpify name type args)
   (let* ((initial (format #f "  #define H_~A \"~A ~A(" name type name))
-	 (line-len (string-length initial))
-	 (len (string-length args))
+	 (line-len (length initial))
+	 (len (length args))
 	 (typed #f)
 	 (help-max 100))
     (hey initial)
-    (do ((i 0 (+ 1 i)))
+    (do ((i 0 (+ i 1)))
 	((= i len))
-      (let ((ch (string-ref args i)))
+      (let ((ch (args i)))
 	(if (char=? ch #\space)
 	    (if typed
 		(begin
@@ -290,9 +261,28 @@
 		  "gluGetTessProperty" "gluTessBeginContour" "gluTessBeginPolygon" "gluTessEndContour" "gluTessEndPolygon"
 		  "gluTessNormal" "gluTessProperty" "gluNewTess"))
 
+(define (c-to-xen-macro-name typ str)
+  (if (string=? str "INT") "C_int_to_Xen_integer"
+      (if (string=? str "DOUBLE") "C_double_to_Xen_real"
+	  (if (string=? str "BOOLEAN") "C_bool_to_Xen_boolean"
+	      (if (string=? str "ULONG") "C_ulong_to_Xen_ulong"
+		  (if (string-ci=? str "String")
+		      (if (string=? (car typ) "guchar*") 
+			  "C_to_Xen_String"
+			  "C_string_to_Xen_string")
+		      (format #f "~A unknown" str)))))))
+
+(define (xen-to-c-macro-name str)
+  (if (string=? str "INT") "Xen_integer_to_C_int"
+      (if (string=? str "DOUBLE") "Xen_real_to_C_double"
+	  (if (string=? str "BOOLEAN") "Xen_boolean_to_C_bool"
+	      (if (string=? str "ULONG") "Xen_ulong_to_C_ulong"
+		  (if (string-ci=? str "String")
+		      "Xen_string_to_C_string"
+		      (format #f "~A unknown" str)))))))
+
 (define (type-it type)
-  (let ((typ (assoc type direct-types))
-	(g2 '()))
+  (let ((typ (assoc type direct-types)))
     (if typ
 	(if (cdr typ)
 	    (begin
@@ -302,38 +292,42 @@
 				     (list "Display*" "XVisualInfo*" "int*" "Pixmap" "Font" "GLubyte*"
 					   "GLdouble*" "GLfloat*" "GLvoid*" "GLuint*"
 					   "GLboolean*" "void*" "GLint*" "GLshort*"
-					   "GLsizei" "GLclampd" "GLclampf" "GLbitfield" "GLshort" "GLubyte" "GLbyte"
+					   "GLsizei" "GLclampd" "GLclampf" "GLbitfield" "GLshort" "GLbyte"
 					   "unsigned_long"
 					   "void**")))
 			(if (string=? (car typ) "constchar*")
-			    (hey "#define C_TO_XEN_~A(Arg) C_TO_XEN_~A((char *)(Arg))~%" (no-stars (car typ)) (cdr typ))
-			    (hey "#define C_TO_XEN_~A(Arg) C_TO_XEN_~A(Arg)~%" (no-stars (car typ)) (cdr typ))))
-		    (if (not (member (car typ)
-				     (list "constchar*")))
-			(hey "#define XEN_TO_C_~A(Arg) (~A)(XEN_TO_C_~A(Arg))~%" 
-			     (no-stars (car typ)) (car typ) (cdr typ)))
-		    (if (not (member (car typ)
-				     (list "constchar*")))
-			(hey "#define XEN_~A_P(Arg) XEN_~A_P(Arg)~%" 
+			    (hey "#define C_to_Xen_~A(Arg) C_string_to_Xen_string((char *)(Arg))~%" (no-stars (car typ)))
+			    (hey "#define C_to_Xen_~A(Arg) ~A(Arg)~%" (no-stars (car typ)) (c-to-xen-macro-name typ (cdr typ)))))
+
+		    (if (not (string=? (car typ) "constchar*"))
+			(hey "#define Xen_to_C_~A(Arg) (~A)(~A(Arg))~%" (no-stars (car typ)) (car typ) (xen-to-c-macro-name (cdr typ))))
+
+		    (if (not (string=? (car typ) "constchar*"))
+			(hey "#define Xen_is_~A(Arg) Xen_is_~A(Arg)~%" 
 			     (no-stars (car typ))
 			     (if (string=? (cdr typ) "INT") 
-				 "INTEGER" 
-				 (if (string=? (cdr typ) "DOUBLE")
-				     "NUMBER"
-				     (cdr typ))))))
+				 "integer" 
+				 (if (string=? (cdr typ) "ULONG")
+				     "ulong"
+				     (if (string=? (cdr typ) "DOUBLE")
+					 "number"
+					 (apply string (map char-downcase (cdr typ)))))))))
 		  (begin
-		    (hey "#define XEN_~A_P(Arg) 1~%" (no-stars (car typ)))
-		    (hey "#define XEN_TO_C_~A(Arg) ((gpointer)Arg)~%" (no-stars (car typ)))))))
+		    (hey "#define Xen_is_~A(Arg) 1~%" (no-stars (car typ)))
+		    (hey "#define Xen_to_C_~A(Arg) ((gpointer)Arg)~%" (no-stars (car typ)))))))
 
 	(if (not (or (string=? type "Display*")     ; why are these 2 handled specially?
 		     (string=? type "XVisualInfo*")
-		     (string=? type "GLXContext"))) ; Snd g_snd_glx_context (snd-xmain.c) calls this a pointer
+		     (string=? type "GLXContext"))) ; Snd g_snd_gl_context (snd-motif.c) calls this a pointer
 	    (begin
-	      (if (member type glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
+	      (if (member type glu-1-2) 
+		  (hey "#ifdef GLU_VERSION_1_2~%")
+		  (if (member type (list "GLUnurbs*" "GLUtesselator*" "GLUquadric*" "_GLUfuncptr"))
+		      (hey "#if HAVE_GLU~%")))
 	      (hey "XL_TYPE~A~A(~A, ~A)~%" 
 		   (if (has-stars type) "_PTR" "")
 		   (if (member type (list "int*" "Pixmap" "Font" "GLubyte*" 
-					  "GLubyte*" "GLdouble*" "GLfloat*" "GLvoid*" 
+					  "GLdouble*" "GLfloat*" "GLvoid*" 
 					  "GLuint*" "GLboolean*" "GLint*" "GLshort*"
 					  "PangoFontDescription*" "GtkWidget*" "GdkGLConfigMode"
 					  ))
@@ -343,7 +337,9 @@
 			   ""))
 		   (no-stars type)
 		   type)
-	      (if (member type glu-1-2) (hey "#endif~%")))
+	      (if (or (member type glu-1-2) 
+		      (member type (list "GLUnurbs*" "GLUtesselator*" "GLUquadric*" "_GLUfuncptr")))
+		  (hey "#endif~%")))
 	    (if (string=? type "Display*")
 		(hey "XL_TYPE_PTR(Display, Display*)~%")
 		(if (string=? type "XVisualInfo*")
@@ -355,7 +351,7 @@
   (let ((name (cadr-str data))
 	(args (caddr-str data)))
     (if (assoc name names)
-	(display (format #f "~A CFNC~%" name))
+	(format #t "~A CFNC~%" name)
 	(let ((type (car-str data)))
 	  (if (not (member type types))
 	      (set! types (cons type types)))
@@ -367,7 +363,7 @@
 
 (define* (CINT name type)
   (if (assoc name names)
-      (display (format #f "~A CINT~%" name))
+      (format #t "~A CINT~%" name)
       (begin
 	(set! ints (cons name ints))
 	(set! names (cons (cons name 'int) names)))))
@@ -376,7 +372,7 @@
   (let ((name (cadr-str data))
 	(args (caddr-str data)))
     (if (assoc name names)
-	(display (format #f "~A CFNC-X~%" name))
+	(format #t "~A CFNC-X~%" name)
 	(let ((type (car-str data)))
 	  (if (not (member type x-types))
 	      (set! x-types (cons type x-types)))
@@ -388,18 +384,18 @@
 
 (define* (CINT-X name type)
   (if (assoc name names)
-      (display (format #f "~A CINT-X~%" name))
+      (format #t "~A CINT-X~%" name)
       (begin
 	(set! x-ints (cons name x-ints))
 	(set! names (cons (cons name 'int) names)))))
 
 (define (no-arg name)
-  (let ((len (string-length name)))
+  (let ((len (length name)))
     (call-with-exit
      (lambda (return)
-       (do ((i 0 (+ 1 i)))
+       (do ((i 0 (+ i 1)))
 	   ((= i len) name)
-	 (if (char=? (string-ref name i) #\()
+	 (if (char=? (name i) #\()
 	     (return (substring name 0 i))))))))
 
 ;;; ---------------------------------------- read data ---------------------------------------- 
@@ -416,6 +412,8 @@
 (hey " * 'gl is added to *features*~%")
 (hey " *~%")
 (hey " * HISTORY:~%")
+(hey " *~%")
+(hey " *     16-Apr-14: changed max-args to 8.~%")
 (hey " *     --------~%")
 (hey " *     16-Dec-09: removed Guile support.~%")
 (hey " *     --------~%")
@@ -436,7 +434,7 @@
 (hey " *     20-May-02: initial version.~%")
 (hey " */~%~%")
 
-(hey "#include <mus-config.h>~%~%")
+(hey "#include \"mus-config.h\"~%~%")
 
 (hey "#if HAVE_EXTENSION_LANGUAGE~%")
 
@@ -477,33 +475,33 @@
 (hey "#endif~%")
 (hey "~%")
 
-(hey "#define WRAP_FOR_XEN(Name, Value) XEN_LIST_2(C_STRING_TO_XEN_SYMBOL(Name), XEN_WRAP_C_POINTER(Value))~%")
-(hey "#define WRAP_P(Name, Value) (XEN_LIST_P(Value) && \\~%")
-(hey "                            (XEN_LIST_LENGTH(Value) >= 2) && \\~%")
-(hey "                            (XEN_SYMBOL_P(XEN_CAR(Value))) && \\~%")
-(hey "                            (strcmp(Name, XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))~%")
+(hey "#define wrap_for_Xen(Name, Value) Xen_list_2(C_string_to_Xen_symbol(Name), Xen_wrap_C_pointer(Value))~%")
+(hey "#define is_wrapped(Name, Value) (Xen_is_list(Value) && \\~%")
+(hey "                            (Xen_list_length(Value) >= 2) && \\~%")
+(hey "                            (Xen_is_symbol(Xen_car(Value))) && \\~%")
+(hey "                            (strcmp(Name, Xen_symbol_to_C_string(Xen_car(Value))) == 0))~%")
 (hey "~%")
 
 ;;; these have to match the choices in xm.c 
 (hey "#define XL_TYPE(Name, XType) \\~%")
-(hey "  static XEN C_TO_XEN_ ## Name (XType val) {return(XEN_LIST_2(C_STRING_TO_XEN_SYMBOL(#Name), C_TO_XEN_ULONG(val)));} \\~%")
-(hey "  static XType XEN_TO_C_ ## Name (XEN val) {return((XType)XEN_TO_C_ULONG(XEN_CADR(val)));} \\~%")
-(hey "  static int XEN_ ## Name ## _P(XEN val) {return(WRAP_P(#Name, val));}~%")
+(hey "  static Xen C_to_Xen_ ## Name (XType val) {return(Xen_list_2(C_string_to_Xen_symbol(#Name), C_ulong_to_Xen_ulong(val)));} \\~%")
+(hey "  static XType Xen_to_C_ ## Name (Xen val) {return((XType)Xen_ulong_to_C_ulong(Xen_cadr(val)));} \\~%")
+(hey "  static bool Xen_is_ ## Name (Xen val) {return(is_wrapped(#Name, val));}~%")
 (hey "#define XL_TYPE_1(Name, XType) \\~%")
-(hey "  static XType XEN_TO_C_ ## Name (XEN val) {return((XType)XEN_TO_C_ULONG(XEN_CADR(val)));} \\~%")
-(hey "  static int XEN_ ## Name ## _P(XEN val) {return(WRAP_P(#Name, val));}~%")
+(hey "  static XType Xen_to_C_ ## Name (Xen val) {return((XType)Xen_ulong_to_C_ulong(Xen_cadr(val)));} \\~%")
+(hey "  static bool Xen_is_ ## Name (Xen val) {return(is_wrapped(#Name, val));}~%")
 (hey "~%")
 (hey "#define XL_TYPE_PTR(Name, XType) \\~%")
-(hey "  static XEN C_TO_XEN_ ## Name (XType val) {if (val) return(WRAP_FOR_XEN(#Name, val)); return(XEN_FALSE);} \\~%")
-(hey "  static XType XEN_TO_C_ ## Name (XEN val) {if (XEN_FALSE_P(val)) return(NULL); return((XType)XEN_UNWRAP_C_POINTER(XEN_CADR(val)));} \\~%")
-(hey "  static int XEN_ ## Name ## _P(XEN val) {return(WRAP_P(#Name, val));} /* if NULL ok, should be explicit */~%")
+(hey "  static Xen C_to_Xen_ ## Name (XType val) {if (val) return(wrap_for_Xen(#Name, val)); return(Xen_false);} \\~%")
+(hey "  static XType Xen_to_C_ ## Name (Xen val) {if (Xen_is_false(val)) return(NULL); return((XType)Xen_unwrap_C_pointer(Xen_cadr(val)));} \\~%")
+(hey "  static bool Xen_is_ ## Name (Xen val) {return(is_wrapped(#Name, val));} /* if NULL ok, should be explicit */~%")
 (hey "#define XL_TYPE_PTR_1(Name, XType) \\~%")
-(hey "  static XType XEN_TO_C_ ## Name (XEN val) {if (XEN_FALSE_P(val)) return(NULL); return((XType)XEN_UNWRAP_C_POINTER(XEN_CADR(val)));} \\~%")
-(hey "  static int XEN_ ## Name ## _P(XEN val) {return(WRAP_P(#Name, val));} /* if NULL ok, should be explicit */~%")
+(hey "  static XType Xen_to_C_ ## Name (Xen val) {if (Xen_is_false(val)) return(NULL); return((XType)Xen_unwrap_C_pointer(Xen_cadr(val)));} \\~%")
+(hey "  static bool Xen_is_ ## Name (Xen val) {return(is_wrapped(#Name, val));} /* if NULL ok, should be explicit */~%")
 
 ;XL_TYPE_PTR_2 was for "GdkVisual*" "PangoFont*" "GdkColormap*"
 ;(hey "#define XL_TYPE_PTR_2(Name, XType) \\~%")
-;(hey "  static XEN C_TO_XEN_ ## Name (XType val) {if (val) return(WRAP_FOR_XEN(#Name, val)); return(XEN_FALSE);}~%")
+;(hey "  static Xen C_to_Xen_ ## Name (XType val) {if (val) return(wrap_for_Xen(#Name, val)); return(Xen_false);}~%")
 
 
 (hey "~%~%/* ---------------------------------------- types ---------------------------------------- */~%~%")
@@ -561,6 +559,7 @@
 
 (define need-vals-check (list "glGetIntegerv" "glGetFloatv" "glGetMaterialfv" "glGetLightfv" "glGetBooleanv"))
 
+(define max-args 8)
 
 (hey "~%~%/* ---------------------------------------- functions ---------------------------------------- */~%~%")
 
@@ -573,11 +572,10 @@
 	  (refargs (ref-args args))
 	  (xgargs (- cargs refargs))
 	  (argstr (cadddr data))
-	  (lambda-type (cdr (assoc name names)))
+	  ;(lambda-type (cdr (assoc name names)))
 	  (arg-start 0)
 	  (line-len 0)
-	  (line-max 120)
-	  (max-args 10)) 
+	  (line-max 120))
 
      (define (hey-start)
        ;; start of checked line
@@ -590,17 +588,17 @@
      (define (hey-on . args)
        ;; no cr -- just append
        (let ((line (apply format #f args)))
-	 (set! line-len (+ line-len (string-length line)))
+	 (set! line-len (+ line-len (length line)))
 	 (heyc line)))
 
      (define (hey-ok arg)
        ;; cr ok after arg
-       (set! line-len (+ line-len (string-length arg)))
+       (set! line-len (+ line-len (length arg)))
        (heyc arg)
        (if (> line-len line-max)
 	   (begin
 	     (hey "~%")
-	     (do ((i 0 (+ 1 i)))
+	     (do ((i 0 (+ i 1)))
 		 ((= i arg-start))
 	       (heyc " "))
 	     (set! line-len arg-start))))
@@ -609,22 +607,22 @@
      (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
 
      (if (and (> (length data) 4)
-	      (eq? (list-ref data 4) 'if))
-	 (hey "#if HAVE_~A~%" (string-upcase (symbol->string (list-ref data 5)))))
-     (hey "static XEN gxg_~A(" name)
+	      (eq? (data 4) 'if))
+	 (hey "#if HAVE_~A~%" (string-upcase (symbol->string (data 5)))))
+     (hey "static Xen gxg_~A(" name)
      (if (= (length args) 0)
 	 (heyc "void")
 	 (if (>= (length args) max-args)
-	     (begin
-	       (heyc "XEN arglist"))
+	     (heyc "Xen arglist")
 	     (let ((previous-arg #f))
 	       (for-each 
 		(lambda (arg)
 		  (let ((argname (cadr arg))
-			(argtype (car arg)))
+			;(argtype (car arg))
+			)
 		    (if previous-arg (heyc ", "))
 		    (set! previous-arg #t)
-		    (hey "XEN ~A" argname)))
+		    (hey "Xen ~A" argname)))
 		args))))
      (hey ")~%{~%")
      (helpify name return-type argstr)
@@ -639,7 +637,7 @@
      (if (and (>= (length args) max-args)
 	      (> xgargs 0))
 	 (let ((previous-arg #f))
-	   (heyc "  XEN ")
+	   (heyc "  Xen ")
 	   (for-each
 	    (lambda (arg)
 	      (if (not (ref-arg? arg)) ;(< (length arg) 3)
@@ -653,7 +651,7 @@
 	     (for-each
 	      (lambda (arg)
 		(if (not (ref-arg? arg))
-		    (hey "  ~A = XEN_LIST_REF(arglist, ~D);~%" (cadr arg) ctr))
+		    (hey "  ~A = Xen_list_ref(arglist, ~D);~%" (cadr arg) ctr))
 		(set! ctr (+ 1 ctr)))
 	      args))))
      (if (> (length args) 0)
@@ -664,30 +662,29 @@
 		    (argtype (car arg)))
 		(if (not (ref-arg? arg))
 		    (if (null-arg? arg)
-			(hey "  XEN_ASSERT_TYPE(XEN_~A_P(~A) || XEN_FALSE_P(~A), ~A, ~D, ~S, ~S);~%" 
+			(hey "  Xen_check_type(Xen_is_~A(~A) || Xen_is_false(~A), ~A, ~D, ~S, ~S);~%" 
 			     (no-stars argtype) argname argname argname ctr name argtype)
 			(if (opt-arg? arg)
 			    (begin
-			      (hey "  if (XEN_NOT_BOUND_P(~A)) ~A = XEN_FALSE; ~%" argname argname)
-			      (hey "  else XEN_ASSERT_TYPE(XEN_~A_P(~A), ~A, ~D, ~S, ~S);~%" 
+			      (hey "  if (!Xen_is_bound(~A)) ~A = Xen_false; ~%" argname argname)
+			      (hey "  else Xen_check_type(Xen_is_~A(~A), ~A, ~D, ~S, ~S);~%" 
 				   (no-stars argtype) argname argname ctr name argtype))
-			    (hey "  XEN_ASSERT_TYPE(XEN_~A_P(~A), ~A, ~D, ~S, ~S);~%"
+			    (hey "  Xen_check_type(Xen_is_~A(~A), ~A, ~D, ~S, ~S);~%"
 				 (no-stars argtype) argname argname ctr name argtype))))
 		(set! ctr (+ 1 ctr))))
 	    args)))
-     (let ((using-result #f)
-	   (using-loc #f))
+     (let ((using-result #f))
        (set! using-result (and (> refargs 0)
 			       (not (string=? return-type "void"))))
        (if using-result
 	   (begin
 	     (hey "  {~%")
-	     (hey "    XEN result = XEN_FALSE;~%")))
+	     (hey "    Xen result;~%")))
        (hey-start)
        (if (not (string=? return-type "void"))
 	   (if (= refargs 0)
-	       (hey-on "  return(C_TO_XEN_~A(" (no-stars return-type))
-	       (hey-on "    result = C_TO_XEN_~A(" (no-stars return-type)))
+	       (hey-on "  return(C_to_Xen_~A(" (no-stars return-type))
+	       (hey-on "    result = C_to_Xen_~A(" (no-stars return-type)))
 	   (hey-on "  "))
 
        (hey-on "~A(" name)
@@ -701,16 +698,16 @@
 		  (if previous-arg (hey-ok ", "))
 		  (if (and (not previous-arg)
 			   (> (length data) 4)
-			   (eq? (list-ref data 4) 'const))
+			   (eq? (data 4) 'const))
 		      (hey "(const ~A)" argtype))
 		  (set! previous-arg #t)
 		  (if (ref-arg? arg)
 		      (hey-on "~A" (deref-name arg))
-		      (hey-on "XEN_TO_C_~A(~A)" (no-stars argtype) argname))))
+		      (hey-on "Xen_to_C_~A(~A)" (no-stars argtype) argname))))
 	      args)))
 
        (if (> refargs 0)
-	   (let* ((previous-arg using-result))
+	   (let ((previous-arg using-result))
 	     (if (not (string=? return-type "void")) 
 		 (heyc ")"))
 	     (hey ");~%")
@@ -719,25 +716,25 @@
 		 (begin
 		   (hey "  {~%")
 		   (if (not using-result)
-		       (hey "    XEN result;~%"))
+		       (hey "    Xen result;~%"))
 		   (hey "    int i, vals;~%")
-		   (hey "    vals = how_many_vals(XEN_TO_C_GLenum(pname));~%")
-		   (hey "    result = XEN_EMPTY_LIST;~%")
+		   (hey "    vals = how_many_vals(Xen_to_C_GLenum(pname));~%")
+		   (hey "    result = Xen_empty_list;~%")
 		   (hey "    for (i = 0; i < vals; i++)~%")
-		   (hey "      result = XEN_CONS(C_TO_XEN_~A(~A[i]), result);~%" 
-			(no-stars (deref-type (list-ref args (- (length args) 1))))
-			(deref-name (list-ref args (- (length args) 1))))
+		   (hey "      result = Xen_cons(C_to_Xen_~A(~A[i]), result);~%" 
+			(no-stars (deref-type (args (- (length args) 1))))
+			(deref-name (args (- (length args) 1))))
 		   (hey "    return(result);~%")
 		   (hey "  }~%"))
 		 (begin
-		   (hey "  return(XEN_LIST_~D(" (+ refargs (if using-result 1 0)))
+		   (hey "  return(Xen_list_~D(" (+ refargs (if using-result 1 0)))
 		   (if using-result (heyc "result"))
 		   (for-each 
 		    (lambda (arg)
 		      (if (ref-arg? arg)
 			  (begin
 			    (if previous-arg (heyc ", "))
-			    (hey "C_TO_XEN_~A(~A[0])" (no-stars (deref-type arg)) (deref-name arg))
+			    (hey "C_to_Xen_~A(~A[0])" (no-stars (deref-type arg)) (deref-name arg))
 			    (set! previous-arg #t))))
 		    args)
 		   (hey "));~%")))
@@ -745,7 +742,7 @@
 	   (if (string=? return-type "void")
 	       (begin
 		 (hey ");~%")
-		 (hey "  return(XEN_FALSE);~%"))
+		 (hey "  return(Xen_false);~%"))
 	       (hey ")));~%")))
        )
 
@@ -764,23 +761,23 @@
 
 ;;; ---------------- argify linkages
 
-(hey "#ifdef XEN_ARGIFY_1~%")
 (define (argify-func func)
-  (let* ((cargs (length (caddr func)))
-	 (name (car func))
-	 (refargs (+ (ref-args (caddr func)) (opt-args (caddr func))))
-	 (args (- cargs refargs))
-	 (if-fnc (and (> (length func) 4)
-		      (eq? (list-ref func 4) 'if))))
+  (let ((cargs (length (caddr func)))
+	(name (car func))
+	(refargs (+ (ref-args (caddr func)) (opt-args (caddr func))))
+	;(args (- cargs refargs))
+	(if-fnc (and (> (length func) 4)
+		     (eq? (func 4) 'if))))
     (check-glu name)
     (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
     (if if-fnc
-	(hey "#if HAVE_~A~%" (string-upcase (symbol->string (list-ref func 5)))))
-    (hey "XEN_~A(gxg_~A_w, gxg_~A)~%" 
-	 (if (>= cargs 10) "VARGIFY"
+	(hey "#if HAVE_~A~%" (string-upcase (symbol->string (func 5)))))
+    (hey "Xen_wrap_~A(gxg_~A_w, gxg_~A)~%" 
+	 (if (>= cargs max-args) 
+	     "any_args"
 	     (if (> refargs 0)
-		 (format #f "ARGIFY_~D" cargs)
-		 (format #f "NARGIFY_~D" cargs)))
+		 (format #f "~D_optional_arg~A" cargs (if (= cargs 1) "" "s"))
+		 (format #f "~A_arg~A" (if (zero? cargs) "no" (number->string cargs)) (if (= cargs 1) "" "s"))))
 	 (car func) (car func))
     (if if-fnc
 	(hey "#endif~%"))
@@ -793,41 +790,121 @@
 (for-each argify-func (reverse funcs))
 (uncheck-glu)
 
-(hey "~%#else~%~%")
-
-(define (unargify-func func)
-  (let* ((cargs (length (caddr func)))
-	 (name (car func))
-	 (refargs (+ (ref-args (caddr func)) (opt-args (caddr func))))
-	 (args (- cargs refargs))
-	 (if-fnc (and (> (length func) 4)
-		      (eq? (list-ref func 4) 'if))))
-
-    (check-glu name)
-    (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
-
-    (if if-fnc
-	(hey "#if HAVE_~A~%" (string-upcase (symbol->string (list-ref func 5)))))
-    (hey "#define gxg_~A_w gxg_~A~%" 
-	 (car func) (car func))
-    (if if-fnc
-	(hey "#endif~%"))
-    (if (member (car func) glu-1-2) (hey "#endif~%"))))
-	 
-(hey "#if USE_MOTIF~%")
-(for-each unargify-func (reverse x-funcs))
-(hey "#endif~%")
-
-(for-each unargify-func (reverse funcs))
-(uncheck-glu)
-
-(hey "#endif~%")
 
 
 ;;; ---------------- procedure linkages
+
+(define (gtk-type->s7-type gtk)
+  (let ((dt (assoc gtk direct-types)))
+    (if (and (pair? dt)
+	     (string? (cdr dt)))
+	(let ((direct (cdr dt)))
+	  (cond ((member direct '("INT" "ULONG") string=?) 'integer?)
+		((string=? direct "BOOLEAN")               'boolean?)
+		((string=? direct "DOUBLE")                'real?)
+		((string=? direct "CHAR")                  'char?)
+		((string=? direct "String")                'string?)
+		(#t #t)))
+	#t)))
+	       
+(define (make-signature fnc)
+  (define (compress sig)
+    (if (and (pair? sig)
+	     (pair? (cdr sig))
+	     (or (not (eq? (car sig) 'pair?))
+		 (not (null? (cddr sig))))
+	     (eq? (car sig) (cadr sig)))
+	(compress (cdr sig))
+	sig))
+  (let ((sig (list (gtk-type->s7-type (cadr fnc)))))
+    (for-each
+     (lambda (arg)
+       (set! sig (cons (gtk-type->s7-type (car arg)) sig)))
+     (caddr fnc))
+    (reverse (compress sig))))
+
+(define signatures (make-hash-table))
+(define (make-signatures lst)
+  (for-each
+   (lambda (f)
+     (let ((sig (make-signature f)))
+       (if (pair? sig)
+	   (let ((count (signatures sig)))
+	     (if (not count)
+		 (set! (signatures sig) 0)
+		 (set! (signatures sig) (+ count 1)))))))
+   lst))
+
+(make-signatures funcs)
+(make-signatures x-funcs)
+;(format *stderr* "~D entries, ~D funcs~%" (hash-table-entries signatures) (length funcs))
+
 (hey "static void define_functions(void)~%")
 (hey "{~%")
-(hey "  #define GL_DEFINE_PROCEDURE(Name, Value, A1, A2, A3, Help) XEN_DEFINE_PROCEDURE(XL_PRE #Name XL_POST, Value, A1, A2, A3, Help)~%")
+
+(hey "#if HAVE_SCHEME~%")
+(hey "static s7_pointer s_boolean, s_integer, s_real, s_any;~%")
+(hey "static s7_pointer ")
+
+(define (sig-name sig)
+  (call-with-output-string
+   (lambda (p)
+     (display "pl_" p)
+     (for-each
+      (lambda (typ)
+	(display (case typ
+		   ((integer?) "i")
+		   ((boolean?) "b")
+		   ((real?) "r")
+		   (else "t"))
+		 p))
+      sig))))
+     
+(for-each
+ (lambda (sigc)
+   (let ((sig (car sigc)))
+     (hey (sig-name sig))
+     (hey ", ")))
+ signatures)
+(hey "pl_unused;~%")
+
+(hey "  s_boolean = s7_make_symbol(s7, \"boolean?\");~%")
+(hey "  s_integer = s7_make_symbol(s7, \"integer?\");~%")
+(hey "  s_real = s7_make_symbol(s7, \"real?\");~%")
+(hey "  s_any = s7_t(s7);~%~%")
+
+(for-each
+ (lambda (sigc)
+   (let ((sig (car sigc)))
+     (hey "  ")
+     (hey (sig-name sig))
+     (hey " = s7_make_circular_signature(s7, ")
+     (let ((len (length sig)))
+       (hey (number->string (- len 1)))
+       (hey ", ")
+       (hey (number->string len))
+       (hey ", ")
+       (do ((i 0 (+ i 1))
+	    (s sig (cdr s)))
+	   ((= i len))
+	 (let ((typ (car s)))
+	   (hey (case typ
+		  ((integer?) "s_integer")
+		  ((boolean?) "s_boolean")
+		  ((real?) "s_real")
+		  (else "s_any"))))
+	 (if (< i (- len 1)) (hey ", "))))
+     (hey ");~%")))
+ signatures)
+(hey "pl_unused = NULL;~%")
+(hey "#endif~%~%")
+
+(hey "#if HAVE_SCHEME~%")
+(hey "  #define gl_define_procedure(Name, Value, A1, A2, A3, Help, Sig) s7_define_typed_function(s7, XL_PRE #Name XL_POST, Value, A1, A2, A3, Help, Sig)~%")
+(hey "#else~%")
+(hey "  #define gl_define_procedure(Name, Value, A1, A2, A3, Help, Sig) Xen_define_safe_procedure(XL_PRE #Name XL_POST, Value, A1, A2, A3, Help)~%")
+(hey "#endif~%")
+(hey "~%")
 
 (define (defun func)
   (let* ((cargs (length (caddr func)))
@@ -837,12 +914,14 @@
     (check-glu name)
     (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
 
-    (hey "  GL_DEFINE_PROCEDURE(~A, gxg_~A_w, ~D, ~D, ~D, H_~A);~%"
+    (hey "  gl_define_procedure(~A, gxg_~A_w, ~D, ~D, ~D, H_~A, ~A);~%"
 		     (car func) (car func) 
-		     (if (>= cargs 10) 0 args)
-		     (if (>= cargs 10) 0 refargs) ; optional ignored
-		     (if (>= cargs 10) 1 0)
-		     (car func))
+		     (if (>= cargs max-args) 0 args)
+		     (if (>= cargs max-args) 0 refargs) ; optional ignored
+		     (if (>= cargs max-args) 1 0)
+		     (car func)
+		     (sig-name (make-signature func)))
+
     (if (member (car func) glu-1-2) (hey "#endif~%"))
     ))
 
@@ -859,11 +938,7 @@
 (hey "/* ---------------------------------------- constants ---------------------------------------- */~%~%")
 (hey "static void define_integers(void)~%")
 (hey "{~%~%")
-(hey "#if HAVE_SCHEME~%")
-(hey "#define DEFINE_INTEGER(Name) s7_define_constant(s7, XL_PRE #Name XL_POST, C_TO_XEN_INT(Name))~%")
-(hey "#else~%")
-(hey "#define DEFINE_INTEGER(Name) XEN_DEFINE(XL_PRE #Name XL_POST, C_TO_XEN_INT(Name))~%")
-(hey "#endif~%")
+(hey "#define DEFINE_INTEGER(Name) Xen_define(XL_PRE #Name XL_POST, C_int_to_Xen_integer(Name))~%")
 (hey "~%")
 
 (hey "#if USE_MOTIF~%")
@@ -878,7 +953,7 @@
 
      (if in-glu
 	 (if (not (string=? "GLU" (substring val 0 3)))
-	     (BEGIN
+	     (begin
 	       (set! in-glu #f)
 	       (hey "#endif~%")))
 	 (if (string=? "GLU" (substring val 0 3))
@@ -906,8 +981,8 @@
 (hey "    {~%")
 (hey "      define_integers();~%")
 (hey "      define_functions();~%")
-(hey "      XEN_YES_WE_HAVE(\"gl\");~%")
-(hey "      XEN_DEFINE(\"gl-version\", C_TO_XEN_STRING(\"~A\"));~%" (strftime "%d-%b-%y" (localtime (current-time))))
+(hey "      Xen_provide_feature(\"gl\");~%")
+(hey "      Xen_define(\"gl-version\", C_string_to_Xen_string(\"~A\"));~%" (strftime "%d-%b-%y" (localtime (current-time))))
 (hey "      gl_already_inited = true;~%")
 (hey "    }~%")
 (hey "}~%")
