@@ -1,10 +1,9 @@
 (define (no-dashes-or-cr str)
-  (let* ((len (string-length str))
-	 (newstr (make-string 0))
-	 (colons 0)
-	 (last-ch #\-))
-    (do ((i 0 (1+ i)))
-	((= i (1- len)))
+  (let ((len (length str))
+	(newstr (make-string 0))
+	(last-ch #\-))
+    (do ((i 0 (+ i 1)))
+	((= i (- len 1)))
       (let ((ch (string-ref str i)))
 	(if (and (or (not (char=? ch #\-))
 		     (char-alphabetic? last-ch))
@@ -17,14 +16,14 @@
   (call-with-input-file 
       "snd-test.scm"
     (lambda (file)
-      (let loop ((line (read-line file 'concat)))
-	(set! ctr (1+ ctr))
+      (let loop ((line (read-line file #t)))
+	(set! ctr (+ ctr 1))
 	(or (eof-object? line)
-	    (let ((len (string-length line)))
+	    (let ((len (length line)))
 	      (if (and (> len 30)
 		       (string=? ";;; ---------------- test "
 				 (substring line 0 26)))
-		  (display (format #f "~A ~48,1T[~D]~%" (no-dashes-or-cr line) ctr)))
-	      (loop (read-line file 'concat))))))))
+		  (format #t "~A ~48,1T[~D]~%" (no-dashes-or-cr line) ctr))
+	      (loop (read-line file #t))))))))
 
 (exit)
